/*-----------------------------------------------------------------------------*
* Title: CLEANING - LONG TERM FOLLOW_UP (COHORT 2014 & 2015) - APPLICANT  DATA                          
*                                                                                           
* Description: 	Cleans data for Applicant Long term Follow-up
* Cohort:		2014 and 2015 								         						 
* Start Date:	09/17/2023 	
* Status:		In progress
* End Data:																		
* Author:		Raaga Akkineni 										 						  
* Purpose: 		Cleans  applicant data  
*
* Input: 		MCF_followup_2022_alum.dta
* Output: 		
*
*Note: Run master .do file to set up global macros
*-----------------------------------------------------------------------------*/

version 17
set more off

clear all
clear mata

use "$applicant_enc/data/MCF_followup_2022_alum.dta"

rename *, lower

**Cleaning date variable 
replace date = today if date == .   	// One missing date variable 
/*------------------------------------------------------------------------------
						** Cleaning Section A **
------------------------------------------------------------------------------*/

local xlist_a "a1 a2 app_name_check not_same app_new_name aa6_yes_checktrue aa6_yes_nametrue aa6_yes_othernametrue aa6_yes_knownumbertrue aa6_yes_numbertrue1 aa6_yes_numbertrue2 aa6_yes_knowloctrue aa6_yes_regtrue aa6_yes_distrue aa6_yes_viltrue aa6_yes_knowdirectionstrue aa6_yes_directionstrue"

* Creating a new variables for each variable in local xlist_c
foreach var of local xlist_a {
  set more off
  gen `var'_c=`var'
  _crcslbl `var'_c `var' 				// Keeping variable label //
}

*2 observations with different app names
egen app_name = concat(app_sur app_oth),punct(" ")
replace  app_name = app_new_name if app_name_check == 0 & not_same == 1 //same applicant, name changed


* Dropping variables that have been cleaned
foreach var of local xlist_a {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
						** Cleaning Section B & BB **
------------------------------------------------------------------------------*/
/*
	Missing: b1a b2a b3a b4b b5b b5c b5e b5f b7_oth b7a b7b bb_1_2015 bb_2_2015 bb_2_2015_oth bb_3_2015 bb_3_2015_other bb_4_2015 bb_4_2015_region bb_5_2015 b8_2015 b8_2015_oth b9_2015 b9a_2015 b9_oth_2015 bb_1_2016 bb_2_2016 bb_2_2016_oth bb_3_2016 bb_3_2016_other bb_4_2016 bb_4_2016_other bb_4_2016_region bb_5_2016 b8_2016 b8_2016_oth b9_2016 b9a_2016 b9_oth_2016 bb_1_2017 bb_2_2017 bb_2_2017_oth bb_3_2017 bb_3_2017_other bb_4_2017 bb_4_2017_other bb_4_2017_region bb_5_2017 b8_2017 b8_2017_oth spent_time spent_time_other b11 b12 b12a_oth b13 b13a b13a_oth
	Addiitons: b3_ccheckfail primary_phone_number secondary_phone_number other_phone_number intl_phone_number other_phone_number_owner b10_check b11_b12_diff_b10 b13 pov0 c3a pov3 pov4 pov5 c5a c5b pov11 pov6 c6a pov7 pov8 pov9 pov10 pov1
	Updates: b3 -> b3_check
*/

* Saving variables in section B as a local
local xlist_b "b1 b2 b3_check b3 b3_ccheckfail b4 primary_phone_number secondary_phone_number other_phone_number intl_phone_number other_phone_number_owner b5 b6 b7 b8 b9 b10 b11 b12 b11_b12 b10_check b11_b12_diff_b10 b13 pov0 pov1 c3a pov3 pov4 pov5 c5a c5b pov11 pov6 c6a pov7 pov8 pov9 pov10 pov12" 
 
* Creating a new variables for each variable in local xlist_b
foreach var of local xlist_b {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}

*recoding missing variables 
recode other_phone_number_owner_c (97 = .d)

* Cleaning money values and passing to missing all "others" values
foreach var in b13_c {
  replace `var'= .m if `var'<1000 & `var'!=0 & `var'!=.
}

*Replacing "refused to answer", "don't know" and "does not apply" to missing
foreach var in pov3_c pov12_c {
  recode `var' (99=.r) (98=.d) (97=.n)
}

*Cleaning up string variables
replace b8_c = strlower(b8)				// email ids
replace b9_c = strlower(b9)				// email ids


*Dropping variables that have been cleaned
foreach var of local xlist_b {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}

/*------------------------------------------------------------------------------
						** Cleaning Section C **
------------------------------------------------------------------------------*/

* Saving variables in section C as a local
local xlist_c "c0 c1_1 c1_2 c1_3 c2_1 c2_2 c2_2_1 c2_2_2 c2_2_3 c2_2_4 c2_2_5 c2_2_6 c3_1 c3_2 c3_3 c3_4 c3_5 c3_6 c3_7 c3_8 c3_8_1 c3_8_2 c3_8_3 c3_8_4 c3_8_5 c3_8_6 c3_8_7 c3_8_8 c3_9 c3_10 c3_11 c3_12a c3_12b c3_13 c3_14 c3_15 c3_16 c3_19 c3_20 c3_21 c3_22a c3_22b c3_23 c3_23chk c3_23b c3_24 c3_25 c3_26 c3_29 c3_30a c3_30b c3_31 c4_1 c4_2 c4_3 c4_4 c4_5 c4_6 c4_7 c4_8 c4_8_1 c4_8_2 c4_8_3 c4_8_4 c4_8_5 c4_8_6 c4_8_7 c4_8_8 c4_9 c4_10 c4_11 c4_12a c4_12b c4_13 c4_14 c4_15 c4_16 c4_19 c4_20 c4_21 c4_22a c4_22b c4_23 c4_23chk c4_24 c4_25 c4_26 c4_29 c4_30 c4_31 c4_32 c4_32_1 c4_32_2 c4_32_3 c4_32_4 c4_32_5 c4_32_6 c4_32_7 c4_32_8 c4_32_9 c4_32_10 c4_32_11 c4_32_12 c4_32_13 c4_32_14 c4_32_15 c4_32_16 c4_32_88 c5_0a c5_0b c5_0c c5_0c_1 c5_0c_2 c5_0c_3 c5_0c_4 c5_0c_5 c5_0c_6 c5_1 c5_2 c5_3 c5_3_1 c5_3_2 c5_3_3 c5_3_4 c5_3_5 c5_3_6 c5_3_7 c5_3_8 c5_3_9 c5_3_10 c5_3_other v238 c5_4 c5_5 c6_1 c6_2 c7 c8 c8_1 c8_2 c8_3 c8_4 c8_5 c8_6 c8_7 c8_8 c8_9 c8_10 c8_11 c8_12 c8_88 c8_b_1 c8_b_2 c8_b_3 c8_b_4 c8_c_1 c8_c_2 c8_c_3 c8_c_4 c8_d1_1 c8_d1_2 c8_d1_3 c8_d1_4 c8_d2_1 c8_d2_2 c8_d2_3 c8_d2_4 c8_e_1 c8_e_2 c8_e_3 c8_e_4 c8_f_1 c8_f_2 c8_f_3 c8_f_4 c8_g1_1 c8_g1_2 c8_g1_3 c8_g1_4 c8_g2_1 c8_g2_2 c8_g2_3 c8_g2_4 c8_h1_1 c8_h1_2 c8_h1_3 c8_h1_4 c8_h2_1 c8_h2_2 c8_h2_3 c8_h2_4 c8_h3_1 c8_h3_2 c8_h3_3 c8_h3_4 c8_i_1 c8_i_2 c8_i_3 c8_i_4 c8_j_1 c8_j_2 c8_j_3 c8_j_4 c8_k_1 c8_k_1_1 c8_k_2_1 c8_k_3_1 c8_k_4_1 c8_k_5_1 c8_k_6_1 c8_k_7_1 c8_k_8_1 c8_k_1_2 c8_k_2_2 c8_k_3_2 c8_k_4_2 c8_k_5_2 c8_k_6_2 c8_k_7_2 c8_k_8_2 c8_k_1_3 c8_k_2_3 c8_k_3_3 c8_k_4_3 c8_k_5_3 c8_k_6_3 c8_k_7_3 c8_k_8_3 c8_k_1_4 c8_k_2_4 c8_k_3_4 c8_k_4_4 c8_k_5_4 c8_k_6_4 c8_k_7_4 c8_k_8_4 c8_k1_1 c8_k1_2 c8_k1_3 c8_k1_4 c8_k2_1 c8_k2_2 c8_k2_3 c8_k2_4 c8_k3_1 c8_k3_2 c8_k3_3 c8_k3_4 c8_k4_1 c8_k4_1_1 c8_k4_2_1 c8_k4_3_1 c8_k4_4_1 c8_k4_5_1 c8_k4_6_1 c8_k4_7_1 c8_k4_8_1 c8_k4_9_1 c8_k4_10_1 c8_k4_other_1 v298 c8_k4_2 c8_k4_1_2 c8_k4_2_2 c8_k4_3_2 c8_k4_4_2 c8_k4_5_2 c8_k4_6_2 c8_k4_7_2 c8_k4_8_2 c8_k4_9_2 c8_k4_10_2 c8_k4_other_2 v370 c8_k4_3 c8_k4_1_3 c8_k4_2_3 c8_k4_3_3 c8_k4_4_3 c8_k4_5_3 c8_k4_6_3 c8_k4_7_3 c8_k4_8_3 c8_k4_9_3 c8_k4_10_3 c8_k4_other_3 v442 c8_k4_4 c8_k4_1_4 c8_k4_2_4 c8_k4_3_4 c8_k4_4_4 c8_k4_5_4 c8_k4_6_4 c8_k4_7_4 c8_k4_8_4 c8_k4_9_4 c8_k4_10_4 c8_k4_other_4 v514 c8_k5_1 c8_k5_2 c8_k5_3 c8_k5_4 c8_k5lab_1 c8_k5lab_2 c8_k5lab_3 c8_k5lab_4 c8_k6_1 c8_k6_2 c8_k6_3 c8_k6_4 c8_k7_1 c8_k7_2 c8_k7_3 c8_k7_4 c8_k7_other_1 c8_k7_other_2 c8_k7_other_3 c8_k7_other_4 c8_k8_1 c8_k8_2 c8_k8_3 c8_k8_4 c8_l_1 c8_l_other_1 c8_l_2 c8_l_other_2 c8_l_3 c8_l_other_3 c8_l_4 c8_l_other_4 c8_m1_1 c8_m1_1_1 c8_m1_2_1 c8_m1_3_1 c8_m1_4_1 c8_m1_5_1 c8_m1_6_1 c8_m1_7_1 c8_m1_8_1 c8_m1_9_1 c8_m1_10_1 c8_m1_11_1 c8_m1_12_1 c8_m1_13_1 c8_m1_14_1 c8_m1_15_1 c8_m1_16_1 c8_m1_17_1 c8_m1_18_1 c8_m1_19_1 c8_m1_20_1 c8_m1_21_1 c8_m1_88_1 c8_m1_2 c8_m1_1_2 c8_m1_2_2 c8_m1_3_2 c8_m1_4_2 c8_m1_5_2 c8_m1_6_2 c8_m1_7_2 c8_m1_8_2 c8_m1_9_2 c8_m1_10_2 c8_m1_11_2 c8_m1_12_2 c8_m1_13_2 c8_m1_14_2 c8_m1_15_2 c8_m1_16_2 c8_m1_17_2 c8_m1_18_2 c8_m1_20_2 c8_m1_21_2 c8_m1_88_2 c8_m1_3 c8_m1_1_3 c8_m1_2_3 c8_m1_3_3 c8_m1_4_3 c8_m1_5_3 c8_m1_6_3 c8_m1_7_3 c8_m1_8_3 c8_m1_9_3 c8_m1_10_3 c8_m1_11_3 c8_m1_12_3 c8_m1_13_3 c8_m1_14_3 c8_m1_15_3 c8_m1_16_3 c8_m1_17_3 c8_m1_18_3 c8_m1_19_3 c8_m1_20_3 c8_m1_21_3 c8_m1_88_3 c8_m1_4 c8_m1_1_4 c8_m1_2_4 c8_m1_3_4 c8_m1_4_4 c8_m1_5_4 c8_m1_6_4 c8_m1_7_4 c8_m1_8_4 c8_m1_9_4 c8_m1_10_4 c8_m1_11_4 c8_m1_12_4 c8_m1_13_4 c8_m1_14_4 c8_m1_15_4 c8_m1_16_4 c8_m1_17_4 c8_m1_18_4 c8_m1_19_4 c8_m1_20_4 c8_m1_21_4 c8_m1_88_4 c8_m2_1 c8_m2_2 c8_m2_3 c8_m2_4"

* Creating a new variables for each variable in local xlist_c
foreach var of local xlist_c {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
} 	

*renaming unnamed variables 
rename v298_c c8_k4_othersp_1_c // "others - specify"
rename v370_c c8_k4_othersp_2_c
rename v442_c c8_k4_othersp_3_c
rename v514_c c8_k4_othersp_4_c
	
*Replacing "refused to answer", "don't know" and "does not apply" to missing - string
foreach var in c3_5_c c3_6_c c3_7_c c3_21_c c4_2_c c4_5_c c4_6_c c4_7_c c4_11_c c8_b_1_c c8_b_2_c c8_b_3_c c8_c_2_c c8_c_3_c c8_e_1_c c8_e_2_c c8_e_3_c {
  replace `var' = "" if `var'=="0" | `var'=="97" | `var'=="98" | `var'=="99" | `var'=="97" | `var'=="_999" | `var'=="999" | `var'=="9999" | `var' == "Don't know" | `var' == "Don't remember" | `var' == "No" | `var' == "None" | `var' == "Not applicable" 
}

replace c3_21_c = "" if c3_21_c == "320031" | c3_21_c == "41" 
replace c4_11_c = "" if c4_11_c == "11" | c4_11_c == "6" 
replace c4_21_c = "" if c4_21_c == "11" | c4_21_c == "12" | c4_21_c == "5" 	
replace c8_c_2_c= "" if c8_c_2_c=="2"

recode c6_2 (97=.m)


replace c3_16_c = .m if c3_16 == 801209 
replace c3_26_c = .m if c3_26 >1000 & c3_26 <.
replace c4_13_c = .m if c4_13 == 25 | c4_13 == 27 // UACE score ranges from 0-20  
replace c4_26_c = .m if c4_26 == 604  | c4_26 == 14451 | c4_26 == 39217  | c4_26 == 962695 

*Replacing "refused to answer", "don't know" and "does not apply" to missing - numerical
foreach var in c3_13_c c3_16_c c3_23_c c3_23chk_c c3_23b_c c3_26_c c4_13_c c6_2_c c8_i_1_c c8_i_2_c c8_i_3_c c8_i_4_c c8_k6_1_c c8_k6_2_c c8_k6_3_c c8_k6_4_c{
  recode `var' (97=.m) (98=.m) (99=.m) (888=.m) (999=.m)
}

gen c5_3_11_c = (v238_c == "Mattress")			// itemn received as a part of the scholarship: Mattress
 
*recoding 0 and 'dk' units of time to missing   
recode c8_g1_1_c (0 = .m)
recode c8_g1_2_c (0 = .m)
recode c8_g1_3_c (999 = .m)
recode c8_k2_1_c (99=.m)
recode c8_k2_2_c (99=.m)
  
* replace scores reported by applicant if not equal to one enumerator entered from score card
replace c3_13_c = c3_16_c if (c3_13_c != c3_16_c) & c3_16_c != . & c3_16_c != .m  
replace c3_23_c = c3_26_c if (c3_23_c != c3_26_c) & c3_26_c != . & c3_26_c != .m
replace c4_13_c = c4_16_c if (c4_13_c != c4_16_c) & c4_16_c != . & c4_16_c != .m
replace c4_23_c = c4_26_c if (c4_23_c != c4_26_c) & c4_26_c != . & c4_26_c != .m 

* Cleaning money values
foreach var in c8_i_1_c c8_i_2_c c8_k6_1_c c8_k6_2_c{
   replace `var'=. if `var'<1000 & `var'!=0
}

* defining labels 
label define c6_1_c 1 "Self Motivation" 2 "Inability to Pay School Fees" 3 "Permission from Family Members" 4 "My Health" 5 "Family Member Health" 6 "Institution Did not Admit Me" 7 "Help with Household Chores" 8 "Tend Animals or Work on Family Business" 9 "Physical or Mental Health" 10 "Classrooms are Crowded" 11 "Teachers do not Perform Well" 12 "School is Too Far" 13 "Unsafe to Travel to School" 14 "Scholarship/Sponsorship Ended" 15 "Menstruation" 16 "Got Married" 17 "Got Pregnant or Had Child" 18 "Schooling is not Important" 19 "School Graduates Cannot Find Jobs" 20 "School is Too Expensive" 21 "Covid19 Restrictions" 88 "Other"
label values c6_1_c c6_1_c

label define c8_d1_1_c 1 "CENTRAL " 2 "EASTERN" 3 "NORTHERN" 4 "WESTERN" 
label values c8_d1_1_c c8_d1_1_c
label values c8_d1_2_c c8_d1_1_c
label values c8_d1_3_c c8_d1_1_c
label values c8_d1_4_c c8_d1_1_c

*Cleaning "others - specify" variables 
local i=1
while `i'<4 { 
	gen  	c8_k4_11_`i'_c = 1 if c8_k4_other_`i'== "1" & (c8_k4_othersp_`i'_c == "Mattress" | c8_k4_othersp_`i'_c == "Matress")
	replace c8_k4_11_`i'_c = 0 if c8_k4_11_`i'_c != 1
	label var c8_k4_11_`i'_c "What did you receive as part of the scholarship?" 
	replace	c8_k4_other_`i'= "" if c8_k4_other_`i'== "1" & (c8_k4_othersp_`i'_c == "Mattress" | c8_k4_othersp_`i'_c == "Matress")
	replace	c8_k4_othersp_`i'_c= "" if (c8_k4_othersp_`i'_c == "Mattress" | c8_k4_othersp_`i'_c == "Matress")

	local i=`i'+1
}

replace c8_k4_5_3_c = "1" if c8_k4_other_3== "1" & (c8_k4_othersp_3_c == "Internship and  Residence allowences" | c8_k4_othersp_3_c == "Living out allowance")
replace	c8_k4_other_3= "" if c8_k4_other_3== "1" & (c8_k4_othersp_3_c == "Internship and  Residence allowences" | c8_k4_othersp_3_c == "Living out allowance")
replace	c8_k4_othersp_3_c= "" if c8_k4_other_3== "1" & (c8_k4_othersp_3_c == "Internship and  Residence allowences" | c8_k4_othersp_3_c == "Living out allowance")	

local i=1
while `i'<5 { 
	replace c8_k7_`i'_c = "88" if c8_k7_`i'_c == "other"
	replace c8_l_`i'_c = "" if c8_l_`i'_c == "other" & (c8_l_other_`i'_c == "None" | c8_l_other_`i'_c == "98" | c8_l_other_`i'_c == "Nothing")
	replace c8_l_other_`i'_c = "" if c8_l_`i'_c == "other" & (c8_l_other_`i'_c == "None" | c8_l_other_`i'_c == "98" | c8_l_other_`i'_c == "Nothing")
	replace c8_l_`i'_c = "88" if c8_l_`i'_c == "other"

local i=`i'+1
}

* Destring numerical variables
foreach var in c8_k4_1_1_c c8_k4_2_1_c c8_k4_3_1_c c8_k4_4_1_c c8_k4_5_1_c c8_k4_6_1_c c8_k4_7_1_c c8_k4_8_1_c c8_k4_9_1_c c8_k4_10_1_c c8_k4_11_1_c c8_k4_1_2_c c8_k4_2_2_c c8_k4_3_2_c c8_k4_4_2_c c8_k4_5_2_c c8_k4_6_2_c c8_k4_7_2_c c8_k4_8_2_c c8_k4_9_2_c c8_k4_10_2_c c8_k4_11_2_c c8_k4_1_3_c c8_k4_2_3_c c8_k4_3_3_c c8_k4_4_3_c c8_k4_5_3_c c8_k4_6_3_c c8_k4_7_3_c c8_k4_8_3_c c8_k4_9_3_c c8_k4_10_3_c c8_k4_11_3_c c8_k4_1_4_c c8_k4_2_4_c c8_k4_3_4_c c8_k4_4_4_c c8_k4_5_4_c c8_k4_6_4_c c8_k4_7_4_c c8_k4_8_4_c c8_k4_9_4_c c8_k4_10_4_c c8_k7_1 c8_k7_2 c8_k7_3 c8_k7_4 c8_l_1_c c8_l_2_c c8_l_3_c c8_l_4_c c5_3_other_c{	
  set more off
  destring `var', replace		
}

*Cleaning index numbers
foreach var in c3_31_c c4_30_c c4_31_c{	
  set more off
  tostring `var', replace		
}

replace c3_30a_c = "1141" if c3_30a_c == "1141-014"
replace c3_30b_c = "041" if c3_30b_c == "1141-014"

foreach var in c3_30a_c c3_30b_c c4_30_c c4_31_c{
  replace `var' = "" if `var' == "0" | `var' == "99" | `var' == "999" 
}

*UCE index number
egen c3_30ab_c = concat(c3_30a_c c3_30b_c) if c3_30a != c3_30b & c3_30a != "" & c3_30b != "" 
gen c4_31a_c = c3_30ab_c if c3_30ab_c == c3_31_c

replace c4_31a_c = c3_31_c if c3_31_c == "1411010" | c3_31_c == "1411009" | c3_31_c == "737057" | c3_31_c == "1664012" | c3_31_c == "437117" | c3_31_c == "334128" | c3_31_c == "2236052" | c3_31_c == "2236035"
 
*UACE index number
gen c4_30_31_c = c4_30_c 		if c4_30_c == c4_31_c

replace c4_30_31_c =  c4_30_c	if (c4_30_c != c4_31_c) & c4_30_c == "443531"
replace c4_30_31_c =  c4_30_c	if (c4_30_c != c4_31_c) & c4_30_c == "737529"
replace c4_30_31_c =  c4_30_c	if (c4_30_c != c4_31_c) & c4_31_c == "775"
replace c4_30_31_c =  c4_30_c	if (c4_30_c != c4_31_c) & c4_30_c == "19513"


*Dropping unnecessary variables 
drop c8_k5lab_1_c c8_k5lab_2_c c8_k5lab_3_c c8_k5lab_4_c

*Cleaning date variables
local date "c1_1_c c1_2_c c3_10_c c3_20_c c4_10_c c4_20_c c5_1_c c5_2_c c8_f_1_c c8_f_2_c c8_f_3_c c8_f_4_c c8_h3_1_c c8_h3_2_c c8_h3_3_c c8_h3_4_c c8_k1_1_c c8_k1_2_c c8_k1_3_c c8_k1_4_c"

format `date' %td

* Dropping variables that have been cleaned
foreach var of local xlist_c {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}



/*------------------------------------------------------------------------------
						** Cleaning Section D **
------------------------------------------------------------------------------*/

* Saving variables in section D as a local
local xlist_d "d1 d2 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25"

* Creating a new variables for each variable in local xlist_d
foreach var of local xlist_d {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
} 

*Replacing "refused to answer", "don't know" and "does not apply" to missing - numerical
foreach var in d1_c d4_c d5_c d6_c d7_c d8_c d9_c d10_c d11_c d12_c d13_c d14_c d15_c d16_c d17_c d18_c d19_c d20_c d21_c d22_c d23_c d24_c d25_c{
  recode `var' (98=.m) (99=.m) 
}

*Cleaning "other - specify" variables
replace  d2_c = "88" if d2_c == "other"

*Destring numberical variables 
destring d2_c, replace



* Dropping variables that have been cleaned
foreach var of local xlist_d {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}



/*------------------------------------------------------------------------------
						** Cleaning Section E **
------------------------------------------------------------------------------*/

* Saving variables in section E as a local
local xlist_e "e1_1 e1_2 e1_3 e2_a_1 e2_a_2 e2_a_3 e2_a_4 e2_b_1 e2_b_2 e2_b_3 e2_b_4 e2_c_1 e2_c_2 e2_c_3 e2_c_4 e3_d_1 e3_d_2 e3_d_3 e3_d_4 e2_e_1 e2_e_2 e2_e_3 e2_e_4 e2_f_1 e2_f_2 e2_f_3 e2_f_4 e2_g_1 e2_g_1_1 e2_g_2_1 e2_g_3_1 e2_g_4_1 e2_g_88_1 e2_g_other_1 v593 e2_g_2 e2_g_1_2 e2_g_2_2 e2_g_3_2 e2_g_4_2 e2_g_88_2 e2_g_other_2 v630 e2_g_3 e2_g_1_3 e2_g_2_3 e2_g_3_3 e2_g_4_3 e2_g_88_3 e2_g_other_3 v667 e2_g_4 e2_g_1_4 e2_g_2_4 e2_g_3_4 e2_g_4_4 e2_g_88_4 e2_g_other_4 v704 e2_h_1 e2_h_2 e2_h_3 e2_h_4 e2_i_1 e2_i_2 e2_i_3 e2_i_4 e2_j_a_1 e2_j_a_2 e2_j_a_3 e2_j_a_4 e2_j_b_1 e2_j_b_2 e2_j_b_3 e2_j_b_4 e2_j_c_1 e2_j_c_2 e2_j_c_3 e2_j_c_4 e2_k_1 e2_k_2 e2_k_3 e2_k_4 e2_l1_1 e2_l1_2 e2_l1_3 e2_l1_4 e2_l2_1 e2_l2_2 e2_l2_3 e2_l2_4 e2_m_0_1 e2_m_0_2 e2_m_0_3 e2_m_0_4 e2_m_1 e2_m_1_1 e2_m_1_2 e2_m_1_3 e2_m_1_4 e2_m_2 e2_m_2_1 e2_m_2_2 e2_m_2_3 e2_m_2_4 e2_m_3 e2_m_3_1 e2_m_3_2 e2_m_3_3 e2_m_3_4 e2_m_4 e2_m_4_1 e2_m_4_2 e2_m_4_3 e2_m_4_4 e2_m_5_1 e2_m_5_2 e2_m_5_3 e2_m_5_4 e2_m_6_1 e2_m_6_2 e2_m_6_3 e2_m_6_4 e2_n_1 e2_n_2 e2_n_3 e2_n_4 e2_o_1 e2_o_2 e2_o_3 e2_o_4 e2_p_1 e2_p_2 e2_p_3 e2_p_4 e2_q_1 e2_q_2 e2_q_3 e2_q_4 e2_r_1 e2_r_2 e2_r_3 e2_r_4 e2_s_1 e2_s_2 e2_s_3 e2_s_4 e2_t_1 e2_t_2 e2_t_3 e2_t_4 e3_1 e3_2 e3_3_1 e3_3_2 e3_3_3 e3_4_0_1 e3_4_0_2 e3_4_0_3 e3_4_1 e3_4_1_1 e3_4_1_2 e3_4_1_3 e3_4_2 e3_4_2_1 e3_4_2_2 e3_4_2_3 e3_4_3 e3_4_3_1 e3_4_3_2 e3_4_3_3 e3_4_4_1 e3_4_4_2 e3_4_4_3 e3_4_5_1 e3_4_5_2 e3_4_5_3 e3_4_88_1 e3_4_88_2 e3_4_88_3 e4_0 e4a e4b e4c e4d e4e e4f e4g e4h e4i e4j sumhrs_check sumhrs_too_high e5 e5_0 e5_1 e5_2 e5_3 e5_4 e5_88 e6 e6_1 e6_2 e6_3 e6_other v783 e7 e8 e9 e10 e11a e11b e12 e13a e13b e14 e15 e16 e17 e17_10 e17_12 e17_13 e17_14 e17_15 e17_21 e17_22 e17_23 e17_24 e17_25 e17_26 e17_27 e17_28 e17_29 e17_3 e17_31 e17_32 e17_34 e17_8 e18_1 e18_2 e19_1 e19_2 e20_1 e20_2 e21_1 e21_2 e22_1 e22_2 e23_1 e23_2 e24_1 e24_2 e25_1 e25_2 e26_1 e26_2 e27_1 e27_2 e28 e29 e29_10 e29_12 e29_13 e29_14 e29_15 e29_21 e29_22 e29_23 e29_24 e29_25 e29_26 e29_27 e29_28 e29_29 e29_3 e29_31 e29_32 e29_8 e30 e31 e32 e33 e34 e35 e36 e37 e38 e39"

* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_e {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}

*Dropping variables with no observations
drop e2_j_a_4_c e2_j_b_3_c e2_j_b_4_c e2_k_4_c e2_l1_3_c e2_l1_4_c e2_l2_3_c e2_l2_4_c e2_q_4_c e2_t_3_c  sumhrs_too_high_c

*renaming unnamed variables 
rename v593_c e2_g_othersp_1_c // "others - specify"
rename v630_c e2_g_othersp_2_c 
rename v667_c e2_g_othersp_3_c 
rename v704_c e2_g_othersp_4_c 

rename e6_other_c e6_88_c
rename v783_c e6_othersp_c
	

*Cleaning "refused to answer", "don't know" and "does not apply" to missing - numerical
foreach var in e3_d_3_c e2_e_3_c e2_f_3_c e2_h_1_c e2_h_2_c e2_h_3_c e2_h_4_c e2_j_a_1_c e2_j_a_2_c e2_j_a_3_c e2_k_1_c e2_k_3_c e2_n_1_c e2_n_2_c e7_c e24_1_c e25_1_c e26_1_c e27_1_c e34_c e35_c e36_c e37_c e38_c e39_c{
  recode `var' (-98=.m) (98=.m) (99=.m) (999=.m)
}

* Cleaning money values
foreach var in e2_h_1_c e2_h_2_c e2_h_3_c e2_h_4_c e2_j_a_1_c e2_j_a_2_c e2_j_a_3_c e2_j_c_1_c e34_c e35_c e36_c e37_c e38_c e39_c{
   replace `var'=. if `var'<1000 & `var'!=0
}

*Replacing unnecesary "other" variable 
local i=1
while `i'<5 { 
	replace e2_g_88_`i'_c = "1" if e2_g_other_`i'_c == "1"
	drop e2_g_other_`i'_c
local i=`i'+1
}

*Savings - if applicant responds they have savings in bank, mobile or  other way, then they cant have no savings, ie, e5_c = 0
replace e5_0_c = 0 if  e5_0 == 1 & (e5_1 == 1 | e5_2 == 1 | e5_3 == 1 | e5_4 == 1 | e5_88 == 1)

*Cleaning variables that dont make sense

*no.of months, days and hours worked in biz == 0 
local i = 1
while `i' <5{
	replace e2_a_`i'_c = .m if (e3_d_`i' == 0 & e2_e_`i' == 0 & e2_f_`i' ==0)  // no.of months, days and hours worked  = 0, then app did not work in bizoccupation
	replace e2_b_`i'_c = .m if (e3_d_`i' == 0 & e2_e_`i' == 0 & e2_f_`i' ==0) 
	replace e3_d_`i'_c = .m if (e3_d_`i' == 0 & e2_e_`i' == 0 & e2_f_`i' ==0)
	replace e2_e_`i'_c = .m if (e3_d_`i' == 0 & e2_e_`i' == 0 & e2_f_`i' ==0) 
	replace e2_f_`i'_c = .m if (e3_d_`i' == 0 & e2_e_`i' == 0 & e2_f_`i' ==0) 

local i = `i' + 1
}

replace e30_c = 0 if (e31_c==0 & e32_c == 0 & e33_c == 0)  // no.of months, days and hours worked  = 0, then app did not work in bizoccupation
replace e31_c = .m if (e31_c==0 & e32_c == 0 & e33_c == 0)  
replace e32_c = .m if (e31_c==0 & e32_c == 0 & e33_c == 0)  
replace e33_c = .m if (e31_c==0 & e32_c == 0 & e33_c == 0)  

replace e4h_c = .m if e4h == 0  // no.of hours spend sleeping cannot be 0 

* Destring numerical variables
foreach var in e2_g_1_1_c e2_g_2_1_c e2_g_3_1_c e2_g_4_1_c e2_g_88_1_c e2_g_1_2_c e2_g_2_2_c e2_g_3_2_c e2_g_4_2_c e2_g_88_2_c e2_g_1_3_c e2_g_2_3_c e2_g_3_3_c e2_g_4_3_c e2_g_88_3_c e2_g_1_4_c e2_g_2_4_c e2_g_3_4_c e2_g_4_4_c e2_g_88_4_c e2_m_0_1_c e2_m_0_2_c e2_m_0_3_c e2_m_0_4_c e2_m_1_1_c e2_m_1_2_c e2_m_1_3_c e2_m_1_4_c e2_m_2_1_c e2_m_2_2_c e2_m_2_3_c e2_m_2_4_c e2_m_3_1_c e2_m_3_2_c e2_m_3_3_c e2_m_3_4_c e2_m_4_1_c e2_m_4_2_c e2_m_4_3_c e2_m_4_4_c e2_m_5_1_c e2_m_5_2_c e2_m_5_3_c e2_m_5_4_c e2_m_6_1_c e2_m_6_2_c e2_m_6_3_c e2_m_6_4_c e3_4_1_1_c e3_4_1_2_c e3_4_1_3_c e3_4_2_1_c e3_4_2_2_c e3_4_2_3_c e3_4_3_1_c e3_4_3_2_c e3_4_3_3_c e3_4_4_1_c e3_4_4_2_c e3_4_4_3_c e3_4_5_1_c e3_4_5_2_c e3_4_5_3_c e3_4_88_1_c e3_4_88_2_c e3_4_88_3_c e6_88_c{
  set more off
  destring `var', replace
}


*Cleaning date variables
local date "e1_2_c e2_c_1_c e2_c_2_c e2_c_3_c e2_c_4_c e2_p_1_c e2_p_2_c e2_p_3_c e2_p_4_c"

format `date' %td


* Dropping variables that have been cleaned
foreach var of local xlist_e {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}



/*------------------------------------------------------------------------------
						** Cleaning Section G **
------------------------------------------------------------------------------*/

* Saving variables in section G as a local
local xlist_g "g1a g1b g1c g1d g1e g1f g1g g1h g1i g1j g2a g2b g2c g2d g2e g2f g2g g2h g2i g2j g3a g3b g3c g3d g3e g3f g3g g3h g3i g3j g3k g3l g3m g3n g3o g3p g3q g3r g3s g3t g3u g3v g3w g3x g3y g3a1 g3b1 g3c1 g3d1 g3e1 g3f1 g3g1 g3h1 g3i1 g3j1"


* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_g {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}

**Recoding missing "98"
foreach var of local xlist_g {
  replace `var'_c= . if  `var'_c ==  98
} 
* Dropping variables that have been cleaned
foreach var of local xlist_g {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}



/*------------------------------------------------------------------------------
						** Cleaning Section H **
------------------------------------------------------------------------------*/

* Saving variables in section H as a local
local xlist_h "h1 h2 h3 h4 h5 h6 h7 h8 h9 h10 h11 h12 h13 h14 h15 h16 h17 h18 h19 h20 h21 h22"

* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_h {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}


* Dropping variables that have been cleaned
foreach var of local xlist_i {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
						** Cleaning Section I **
------------------------------------------------------------------------------*/

* Saving variables in section I as a local
local xlist_i "i1 i1a i1b i1c i2 i2_yes i3 i4 i5 i6 i7 i8 i9 i9_0 i9_1 i9_2 i9_3 i9_4 i9_5 i9_88 i9_98 i10 i11_a i11_b i12a i12b i12c i13 i13a i13b i13c i13d i14a i14b i14c i15a i15b i16a i16b i16c i23 i24 i25 i26"

* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_i {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}

*Cleaning "not applicable", "refuse to answer" "dont know" to missing - numerical
foreach var in i1a_c i2_c i2_yes_c i3_c i4_c i5_c i6_c i7_c i8_c i11_a_c i13_c i14b_c i14c_c i15a_c i15b_c i16b_c i16c_c i23_c i24_c i25_c{
  recode `var' (97=.n) (98=.r) (99=.d) 
}

*Cleaning "not applicable", "refuse to answer" "dont know" to missing - string
replace i9_c="" if i9_c == "98"po


*Cleaning variables that do not make sense 
replace i14b_c = .m if i14b <15   // age you would like to get pregnant
replace i13d = .m if i13b < i13d	//number of biological children cannot be less than number of time pregnant



* Dropping variables that have been cleaned
foreach var of local xlist_i {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
						** Cleaning Section J **
------------------------------------------------------------------------------*/

* Saving variables in section J as a local
local xlist_j "j1a j1b j2a j2b j3a j3b j4a j4b j5a j5b j6a j6b j7a j7b j8a j8b j9a j9b j10a j10b j11a j11b j12a j12b j13a j13b j14a j14b j15 j16 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26"

* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_j {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}


*Cleaning "dont know" to missing - numerical
foreach var in j15 j16 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26{
  recode `var' (99=.m) 
}



* Dropping variables that have been cleaned
foreach var of local xlist_j {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}


/*------------------------------------------------------------------------------
						** Cleaning Section K **
---------------------	---------------------------------------------------------*/			

* Saving variables in section K as a local
local xlist_k "k1a k1b k1c k1d k1e k1f k2a k2b k2c k2d k2e k2f k2g"

* Creating a new variables for each variable in local xlist_e
foreach var of local xlist_k {
  gen `var'_c=`var'
  _crcslbl `var'_c `var'  // Keeping variable and value labels //
}

*Cleaning "refused to answer" to missing - numerical
foreach var in k1a_c k1b_c k1d_c k1f_c{
  recode `var' (98=.m) 
}


* Dropping variables that have been cleaned
foreach var of local xlist_k {
	capture confirm variable `var'_c
	if !_rc {
		drop `var' 
		}
	/*If the original var is a multiple choice, it was split up in many dummies.
	Check if first dummy exists and drop original var.*/
	capture confirm variable `var'_c1 
	if !_rc {
		drop `var'
		}
}

rename id id_new 

merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta", nogen 	// keep all observation for bounds

replace  baseline = 1 if notfoundatFU !=. & NSC_intdcode != .

**
gen survey_year_a = year(date)
lab var survey_year_a "Applicant survey year"

**Cleaning disparities in sex of the applicant

gen gender_app = (b2_c == 1)  // 1 if male 0 if female 
label define gender 0 Female 1 Male
label value gender_app gender

replace gender_app = 1 if  id_new == 15140 |  id_new == 15395 |  id_new == 153363 |  id_new == 154865 |  id_new == 1412551 |  id_new == 1513656  |  id_new == 1517550			// female in applicant dataset but male in caregiver dataset - took a call that they are male based on name

replace gender_app = 0 if  id_new == 1418048		// male in applicant dataset but female in caregiver dataset - took a call that they are female based on name

save "$applicant_enc/data/LTFU_Cohort_2014_2015_ApplicantDataset_cleaned.dta", replace

***** Deidentify 

	drop deviceid subscriberid simid devicephonenum username duration caseid  audit_* statement_of_consent_* start_* end_* formdef_version submissiondate o6 starttime endtime start today
	
	drop a1_c a2_c app_name app_sur app_oth resp_surname resp_othername enu_name enu_code enu_name_check enu_name_checkfail village interview_gpslatitude interview_gpslongitude interview_gpsaltitude interview_gpsaccuracy interview_location_other interview_location_detail app_new_name_c aa6_yes_nametrue_c aa6_yes_othernametrue_c b8_c b9_c c3_2_c c3_11_c c3_21_c c4_2_c c4_11_c c4_21_c c8_b_1_c c8_b_2_c c8_b_3_c c8_b_4_c c3_7_c c4_7_c c8_e_1_c c8_e_2_c c8_e_3_c c8_e_4_c c3_6_c c4_6_c c3_5_c c4_5_c primary_phone_number_c secondary_phone_number_c other_phone_number_c intl_phone_number_c aa6_yes_numbertrue1_c aa6_yes_numbertrue2_c aa6_yes_checktrue_c aa6_yes_knownumbertrue_c aa6_yes_regtrue_c aa6_yes_distrue_c aa6_yes_knowdirectionstrue_c aa6_yes_knowloctrue_c aa6_yes_viltrue_c aa6_yes_directionstrue_c aa6_no_other
	
*Save applicant database

save "$applicant_mast/Data/LTFU_Cohort_2014_2015_ApplicantDataset_cleaned_deid.dta", replace
