* Open data: Cohort 2014 and 2015, Baseline and Follow-up1

keep if baseline == 0

#d ;
local districts ABIM ADJUMANI AGAGO ALEBTONG AMOLATAR AMUDAT AMURIA AMURU APAC ARUA
BUDAKA BUDUDA BUGIRI BUHWEJU BUIKWE BUKEDEA BUKOMANSIMBI BUKWO BULAMBULI BULIISA
BUNDIBUGYO BUSHENYI BUSIA BUTALEJA BUTAMBALA BUVUMA BUYENDE DOKOLO ENTEBBE FORTPORTAL GOMBA 
GULU HOIMA IGANGA ISINGIRO JINJA KAABONG KABALE KABAROLE KABERAMAIDO KALANGALA 
KALIRO KALUNGU KAMPALA KAMULI KAMWENGE IBANDA KANUNGU KAPCHORWA KASESE
KATAKWI KAYUNGA KIBAALE KIBOGA KIBUKU KIRUHURA KIRYANDONGO KISORO KITGUM KOBOKO
KOLE KOTIDO KUMI KWEEN KYANKWANZI KYEGEGWA KYENJOJO LAMWO LIRA LUUKA LUWEERO 
LUWERO LWENGO LYANTONDE MANAFWA MARACHA MASAKA MASINDI MAYUGE MBALE MBARARA MITOOMA
MITYANA MOROTO MOYO MPIGI MUBENDE MUKONO NAKAPIRIPIRIT NAKASEKE NAKASONGOLA 
NAMAYINGO NAMUTUMBA NAMATUMBA NAPAK NEBBI NGORA NTOROKO NTUGAMO NTUNGAMO NWOYA OTUKE OYAM PADER 
PALLISA RAKAI RUBIRIZI RUKUNGIRI SEMBABULE SSEMBABULE SERERE SHEEMA SIRONKO SOROTI
TORORO WAKISO YUMBE ZOMBO;
#d cr

/* Obtain database of schools only*/
keep bb_4_* bb_5_*
tostring bb_4_2015_c bb_4_2016_c bb_4_2017_c, replace

/* Fill in name and district for every school*/
forvalues year = 2015(1)2017{
local prevyear = `year' - 1
	replace bb_5_`year'_c = bb_5_`prevyear'_c if bb_4_`year'_c == "1" ///
		& bb_5_`year'_c == .
	replace bb_4_`year'_c = bb_4_`prevyear'_c if bb_4_`year'_c == "1"
	replace bb_4_`year'_c = bb_4_`year'_other_c if bb_4_`year'_c != "1" ///
		& bb_4_`year'_other_c != ""
	replace bb_4_`year'_c  = "" if bb_4_`year'_c == "."
}

/* Save each school and district per year in separate file*/
forvalues year = 2014(1)2017{
	preserve
	keep bb_*_`year'_c bb_*_`year'_c
	rename bb_*_`year'_c bb_*
	dropmiss, force
	tempfile schoolattended_`year'
	save `schoolattended_`year''
	restore
}

/* Append them to have a unique school database*/

use `schoolattended_2014', clear
append using `schoolattended_2015'
append using `schoolattended_2016'
append using `schoolattended_2017'
dropmiss, obs force
tempfile Schools_in_RCT_Raw
save `Schools_in_RCT_Raw'

gen bb_4_clean = bb_4
lab var bb_4_clean "School Name cleaned for matching"

gen bb_5_clean = bb_5
lab var bb_5_clean "School District cleaned for matching"

/* Capitalize all */
replace bb_4_clean = upper(bb_4_clean)

/*Remove commas and full stops*/ 
replace bb_4_clean = subinstr(bb_4_clean, ",", " ",.)
replace bb_4_clean = stritrim(subinstr(bb_4_clean, ".", " ",.))

/*Remove hyphens*/
replace bb_4_clean = stritrim(subinstr(bb_4_clean, "-", " ",.))

/* Standardize abbreviations */
replace bb_4_clean = subinstr(subinstr(subinstr(subinstr(bb_4_clean, " ST.", " ST ",.), "ST.", "ST ", 1), "MT.", "MT ", 1), "DR.", "DR ", 1)

/*Remove leading, trailing, double blanks*/ 
replace bb_4_clean = stritrim(strtrim(bb_4_clean))

/*Expand word "school"*/
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -3, .), "SCHOOL", 1) if substr(bb_4_clean, -3, .) == "SCH"

/* Correct word "school" */
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -7, .), "SCHOOL", 1) if substr(bb_4_clean, -7, .) == "SCHOOLS"

/* Expand word "bishop" */
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, 1, 3), "BISHOP", 1) if substr(bb_4_clean, 1, 2) == "BP"

/*Expand word "vocational"*/
replace bb_4_clean = subinstr(subinstr(bb_4_clean, " VOC ", " VOCATIONAL ", 1), " VOC ", " VOCATIONAL ", 1)

/*Expand word "secondary school"*/
replace bb_4_clean = subinstr(subinstr(subinstr(bb_4_clean, " SSS ", " SECONDARY SCHOOL ", 1), " SENIOR SEC SCHOOL", " SECONDARY SCHOOL", 1), " S S S ", " SECONDARY SCHOOL ", 1)
replace bb_4_clean = subinstr(bb_4_clean, " SEN SEC SCHOOL", " SECONDARY SCHOOL", 1)
replace bb_4_clean = subinstr(bb_4_clean, " SENIOR SECONDARY SCHOOL", " SECONDARY SCHOOL", 1)
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -6, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -6, .) == " S S S"
replace bb_4_clean = subinstr(subinstr(subinstr(bb_4_clean, " SS ", " SECONDARY SCHOOL ", 1), " SEC SCHOOL", " SECONDARY SCHOOL", 1), " S S ", " SECONDARY SCHOOL ", 1)
replace bb_4_clean = subinstr(bb_4_clean, " SEC SCH ", " SECONDARY SCHOOL", 1)
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -3, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -3, .) == " SS"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -4, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -4, .) == " S S" |substr(bb_4_clean, -4, .) == " SSS"|substr(bb_4_clean, -4, .) == " SS "
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -6, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -6, .) == " S S S"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -8, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -8, .) == " SEC SCH"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -11, .), " SECONDARY SCHOOL", 1) if substr(bb_4_clean, -11, .) == " SEC SCHOOL"
replace bb_4_clean = subinstr(bb_4_clean, " SECOMDARY", " SECONDARY", 1)

/*Expand word "high school"*/
replace bb_4_clean = subinstr(subinstr(subinstr(subinstr(bb_4_clean, " HS ", " HIGH SCHOOL ", 1), " H/S", " HIGH SCHOOL", 1), " H S ", " HIGH SCHOOL ", 1), " HIGH SCH ", " HIGH SCHOOL", 1)
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -3, .), " HIGH SCHOOL", 1) if substr(bb_4_clean, -3, .) == " HS"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -4, .), " HIGH SCHOOL", 1) if substr(bb_4_clean, -4, .) == " H S"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -5, .), " HIGH SCHOOL", 1) if substr(bb_4_clean, -5, .) == " HIGH"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -7, .), " HIGH SCHOOL", 1) if substr(bb_4_clean, -7, .) == " HIGH S"
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -9, .), " HIGH SCHOOL", 1) if substr(bb_4_clean, -9, .) == " HIGH SCH"

/*Expand word "college"*/
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -5, .), " COLLEGE", 1) if substr(bb_4_clean, -5, .) == " COLL"
replace bb_4_clean = subinstr(subinstr(subinstr(bb_4_clean, " COL ", " COLLEGE,", 1), " COLL ", " COLLEGE ", 1), " COLEEGE ", " COLLEGE ", 1)
replace bb_4_clean = subinstr(bb_4_clean, " COLLAGE", " COLLEGE", 1)
replace bb_4_clean = subinstr(bb_4_clean, " COLEGE", " COLLEGE", 1)

/* Expand word "community */
replace bb_4_clean = subinstr(bb_4_clean, " COMM ", " COMMUNITY ", 1) 

/* Expand word "comprehensive" */
replace bb_4_clean = subinstr(bb_4_clean, " COMP ", " COMPREHENSIVE ", 1) 

/* Expand word "memorial"*/
replace bb_4_clean = subinstr(bb_4_clean, " MEM ", " MEMORIAL ", 1)
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -4, .), " MEMORIAL", 1) if substr(bb_4_clean, -4, .) == " MEM"

/* Expand word "technical institute"*/
replace bb_4_clean = subinstr(bb_4_clean, "TECH INST", " TECHNICAL INSTITUTE", 1) if substr(bb_4_clean, -10, .) == " TECH INST"
replace bb_4_clean = subinstr(bb_4_clean, " TECH INST ", " TECHNICAL INSTITUTE ", 1)

/* Expand word "vocational training institute"*/
replace bb_4_clean = subinstr(bb_4_clean, " VTI", " VOCATIONAL TRAINING INSTITUTE", 1) if substr(bb_4_clean, -4, .) == " VTI"

/* Fix possessive adjective */
replace bb_4_clean = subinstr(subinstr(bb_4_clean, " GIRLS ", " GIRLS' ", 1), " GIRL'S", " GIRLS'", 1)
replace bb_4_clean = subinstr(subinstr(bb_4_clean, " BOYS ", " BOYS' ", 1), " BOY'S", " BOYS'", 1)

foreach saintname in PAUL JOSEPH JOHN ANTHONY MARK MARY PHILLIP ADRIAN BERNARD GERALD PETER AUGUSTINE EDWARD{

	replace bb_4_clean = subinstr(subinstr(bb_4_clean, "ST `saintname' ", "ST `saintname''S ", 1), "ST `saintname'S", "ST `saintname''S ", 1)

}
replace bb_4_clean = subinstr(bb_4_clean, "ST THEREZA ", "ST THERESA ", 1)

/*Eliminate redundant district info*/
gen lastword = word(bb_4_clean, -1)
foreach district in `districts'{
	replace bb_4_clean = subinstr(bb_4_clean,word(bb_4_clean, -1),"", 1) if lastword == "`district'"
}

/* Eliminate word "seed"*/
replace bb_4_clean = subinstr(subinstr(bb_4_clean, " SEED ", " ", 1), " SEEDS ", " ", 1)
replace bb_4_clean = subinstr(bb_4_clean, substr(bb_4_clean, -6, .), "", 1) if substr(bb_4_clean, -6, .) == "SEEDSS"

/* Store additional parish/village info into other string...*/
split bb_4_clean, parse("SCHOOL") g(geo)
/*...and remove it from the school name, unless there are schools with 
	the same name in the same district */
replace bb_4_clean = subinstr(bb_4_clean,geo2,"", 1)

replace bb_4_clean = stritrim(strtrim(bb_4_clean))
replace geo2 = stritrim(strtrim(geo2))

/* Add word "secondary school" if school name ends by "girls" */
replace lastword = word(bb_4_clean, -1)
replace bb_4_clean = subinstr(bb_4_clean, "GIRLS", "GIRLS'", 1) if lastword == "GIRLS"
replace lastword = word(bb_4_clean, -1)
replace bb_4_clean = bb_4_clean + " " + "SECONDARY SCHOOL" if lastword == "GIRLS'"

/* Correct mistakes in name spelling */
replace bb_4_clean = subinstr(bb_4_clean, "LOTUKEI", "LOTUKE", 1)
replace bb_4_clean = subinstr(bb_4_clean, "LIRA PAULO ", "LIRA PALWO ", 1)

/* Drop if no info on school name*/
drop if bb_4_clean == "" | bb_4_clean == "99" | bb_4_clean == "DONT KNOW" | bb_4_clean == "DON'T KNOW"
format bb_4_clean %40s

/* Clean 700+ school names such that they match the school list*/

replace bb_4_clean = "MORULEM GIRLS' SECONDARY SCHOOL" ///
	if bb_5_clean == 1 & bb_4_clean == "MORULEM SECONDARY SCHOOL" 
recode bb_5_clean (3 = 1)  if bb_4_clean == "MORULEM GIRLS' SECONDARY SCHOOL"
recode bb_5_clean (3 = 1) if bb_4_clean == "MORULEM"
replace bb_4_clean = "MORULEM GIRLS' SECONDARY SCHOOL" ///
	if bb_5_clean == 1 & bb_4_clean == "MORULEM" 
recode bb_5_clean (3 = 70) if bb_4_clean == "LUWERO SECONDARY SCHOOL"
replace bb_4_clean = "ADUKU SECONDARY SCHOOL" 		///
	if bb_4_clean == "ADUKUKU SECONDARY SCHOOL" & bb_5_clean == 9
replace bb_4_clean = "ST JOSEPH'S COLLEGE OMBACI" 	///
	if bb_4_clean == "ST JOSEPH'S COLLEGE OMBACHI" & bb_5_clean == 10
		
replace bb_4_clean = "RAINBOW HIGH SCHOOL" 	///
	if bb_4_clean == "RAIN BOW HIGH SCHOOL" & bb_5_clean == 11

replace bb_4_clean = "UNIVERSAL HIGH SCHOOL" 	///
	if bb_4_clean == "UNIVERSAL SECONDARY SCHOOL" & bb_5_clean == 13
	
replace geo2 = "NALUWERERE" 			///
	if bb_4_clean == "UNIVERSAL HIGH SCHOOL" & bb_5_clean == 13
	
replace bb_4_clean = "LUGAZI MIXED SCHOOL" 	///
	if bb_4_clean == "LUGAZI MIXED NAALYA" & bb_5_clean == 15
	
replace geo2 = "NAALYA" 	///
	if bb_4_clean == "LUGAZI MIXED SCHOOL" & bb_5_clean == 15
	
replace bb_4_clean = "MPOMA BOYS' SECONDARY SCHOOL" 	///
	if bb_4_clean == "MPOMA BOYS" & bb_5_clean == 15
	
replace bb_4_clean = "MOUNT ST MARY'S COLLEGE NAMANGUNGA" 	///
	if (bb_4_clean == "MT ST MARYS COLLEGE NAMAGUNGA"			///
	|bb_4_clean == "ST MARY'S NAMAGUNGA SECONDARY SCHOOL" 	///
	|bb_4_clean == "ST MARY'S COLLEGE NAMAGUNGA")				///
	& bb_5_clean == 15
	
recode bb_5_clean (86 = 15) if bb_4_clean == "ST MARY'S COLLEGE LOGAZI" | bb_4_clean == "ST MARY'S COLLEGE LUGAZI" | bb_4_clean == "ST MARY'S S COLLEGE LUGAZI"

replace bb_4_clean = "ST MARY'S COLLEGE LUGAZI" 	///
	if (bb_4_clean == "ST MARYS COLLEGE LUGAZI" 	///
	| bb_4_clean == "ST MARY'S LUGAZI"				///
	| bb_4_clean == "ST MARY'S COLLEGE LOGAZI"		///
	| bb_4_clean == "ST MARY'S S COLLEGE LUGAZI") ///
	& bb_5_clean == 15
	
recode bb_5_clean (86 = 15) if bb_4_clean == "REHABOTH SECONDARY SCHOOL"

recode bb_5_clean (15 = 110)   	///
	if bb_4_clean == "TORORO GIRLS' SECONDARY SCHOOL"
	
replace bb_4_clean = "BUKEDEA LIFELINE SECONDARY SCHOOL" 	///
	if bb_4_clean == "LIFELINE BUKEDEA SCHOOL" & bb_5_clean == 16
	
recode bb_5_clean (16 = 109) 	///
	if bb_4_clean == "TESO COLLEGE ALOET"
replace bb_4_clean = "ST GEORGE SECONDARY SCHOOL" 	///
	if bb_4_clean == "ST GEORGY MAKUUKULU SECONDARY SCHOOL" & bb_5_clean == 17
	
replace geo2 = "MAKUKUULU" ///
	if bb_4_clean == "ST GEORGE SECONDARY SCHOOL" & bb_5_clean == 17
	
replace bb_4_clean = "BUBUKWANGA SECONDARY SCHOOL" 	///
	if bb_4_clean == "BUKWANGA SECONDARY SCHOOL" & bb_5_clean == 21
	
replace bb_4_clean = "BUMADU SECONDARY SCHOOL" 	///
	if bb_4_clean == "BUMADU SCHOOL" & bb_5_clean == 21
	
replace bb_4_clean = "CHRIST SCHOOL" 	///
	if bb_4_clean == "CHRIST SECONDARY SCHOOL" & bb_5_clean == 21
replace geo2 = "BUNDIBUGYO" 	///
	if bb_4_clean == "CHRIST SCHOOL" & bb_5_clean == 21
	
replace geo2 = "IZAURA" 	///
	if bb_4_clean == "SEMULIKI HIGH SCHOOL" & bb_5_clean == 21
	
replace bb_4_clean = "ST MARY'S SIMBYA SECONDARY SCHOOL" 	///
	if bb_4_clean == "ST MARY'S SIMBYA" & bb_5_clean == 21
replace bb_4_clean = "BISHOP OGEZ HIGH SCHOOL" 	///
	if bb_4_clean == "BISHOP OGEZ" & bb_5_clean == 22
	
replace geo2 = "ISHAKA" 					///
	if bb_4_clean == "BISHOP OGEZ HIGH SCHOOL" & bb_5_clean == 22
replace bb_4_clean = "BWERANYANGI GIRLS' SCHOOL" 	///
	if (bb_4_clean == "BWERANYANGE GIRLS' SECONDARY SCHOOL"	/// 
	| bb_4_clean == "BWERANYANGI GIRLS' SECONDARY SCHOOL" 	///
	| bb_4_clean == "BWERANYANGI GIRLS'S SECONDARY SCHOOL"	///
	| bb_4_clean == "BWERANYANGYE SECONDARY SCHOOL")			///
	& bb_5_clean == 22
	
replace bb_4_clean = "DABANI GIRLS' SCHOOL" 	///
	if bb_4_clean == "DABANI GIRLS' SECONDARY SCHOOL" & bb_5_clean == 23
	
replace bb_4_clean = "BULO PARENTS SECONDARY SCHOOL" 	///
	if (bb_4_clean == "BBULO PARENTS SECONDARY SCHOOL" ///
	| bb_4_clean == "BULO PARENTS SECONDARY") & bb_5_clean == 25
recode bb_5_clean (28 = 94) if bb_4_clean == "NGORA HIGH SCHOOL"
replace bb_4_clean = "OCER CAMPION JESUIT COLLEGE" 	///
	if (bb_4_clean == "OCER CAMPION JUSUIT COLLEGE" 	///
	| bb_4_clean == "OCER CAMPION SECONDARY SCHOOL") ///
	& bb_5_clean == 30
replace bb_4_clean = "POPE JOHN PAUL II COLLEGE" 	///
	if (bb_4_clean == "POP JOHN PAUL 11COLLEGE" 	///
	| bb_4_clean == "POPE JOHN PAUL COLLEGE"		///
	| bb_4_clean == "POPE JOHN PAUL II"			///
	| bb_4_clean == "POPE JOHN PAUL II SECONDARY SCHOOL" ///
	| bb_4_clean == "POPE JOHNPAUL II SECONDARY SCHOOL" ///
	| bb_4_clean == "POPE PAUL LALIYA") ///
	& bb_5_clean == 30
replace bb_4_clean = "POPE PAUL VI SECONDARY SCHOOL" 	///
	if (bb_4_clean == "POPE PAUL ANAKA SECONDARY SCHOOL" 	///
	| bb_4_clean == "POPE PAUL SECONDARY SCHOOL") ///
	& bb_5_clean == 30
replace geo2 = "ANAKA" if bb_4_clean == "POPE PAUL VI SECONDARY SCHOOL" & bb_5_clean == 30
replace bb_4_clean = "SACRED HEART SECONDARY SCHOOL" 	///
	if (bb_4_clean == "SECRET HEART SECONDRY" 	///
	| bb_4_clean == "SECRED HEART GIRLS' SECONDARY SCHOOL" ///
	| bb_4_clean == "SECRET HEART SECONDRY SCHOOL") ///
	& bb_5_clean == 30
replace bb_4_clean = "ST JOSEPH'S COLLEGE LAYIBI" 	///
	if bb_4_clean == "ST JOSEPH'S LAYIBI COLLEGE" 	///
	& bb_5_clean == 30
replace bb_4_clean = "ST THOMAS MOORE SECONDARY SCHOOL" 	///
	if bb_4_clean == "ST THOMAS SECONDARY SCHOOL" 	///
	& bb_5_clean == 30

replace bb_4_clean = "RENA SECONDARY SCHOOL" 	///
	if bb_4_clean == "ELENA SECONDARY SCHOOL" 	///
	& bb_5_clean == 31

replace bb_4_clean = "ST CYPRIAN'S SECONDARY SCHOOL" 	///
	if bb_4_clean == "ST CIPRIAN SECONDARY SCHOOL" 	///
	& bb_5_clean == 31
	
replace geo2 = "BUTEMA" if bb_4_clean == "ST CYPRIAN'S SECONDARY SCHOOL" & bb_5_clean == 31
replace bb_4_clean = "ST ANDREA KAAHWA'S COLLEGE" 	///
	if (bb_4_clean == "ST ANDREA COLLEGE" 	///
	| bb_4_clean == "ST ANDREA KAAHWA COLLEGE" ///
	| bb_4_clean == "ST ANDREA KAHWA'S COLLEGE" ///
	| bb_4_clean == "ST ANDREA KAHWA'SCOLLEGE" ///
	| bb_4_clean == "ST ANDREA KAWA'S COLLEGE SCHOOL" ///
	| bb_4_clean == "ST ANDREW KAAHWA COLLEGE" ///
	| bb_4_clean == "ST ANDREA KHAAW'S COLLEGE" ///
	| bb_4_clean == "ST ANDREA BUJUMBURA" ///
	| bb_4_clean == "ST ANDREA KAAW'S COLLEGE") ///
	& bb_5_clean == 31
	
replace bb_4_clean = "BIGYERA SECONDARY SCHOOL" 	///
	if bb_4_clean == "BIGERA SECONDARY SCHOOL" 	///
	& bb_5_clean == 32
	
replace bb_4_clean = "EQUATORIAL COLLEGE" 	///
	if bb_4_clean == "EQUATORIAL COLLEGE SCHOOL" 	///
	& bb_5_clean == 32
	
replace bb_4_clean = "IBANDA PROGRESSIVE SECONDARY SCHOOL" 	///
	if (bb_4_clean == "IBANDA PROGRESSIVE" 	///
	| bb_4_clean == "IBANDA PROGRESSIVI SECONDARY SCHOOL")		///
	& bb_5_clean == 32

*** IGANGA
	recode bb_5_clean (53 = 33) if bb_4_clean == "AGAPE SECONDARY SCHOOL"
	replace geo2 = "INTERN. BUSEMBATIA" if bb_4_clean == "AGAPE SECONDARY SCHOOL" & bb_5_clean == 33
	
replace bb_4_clean = "CITIZEN'S HIGH SCHOOL" 	///
	if bb_4_clean == "CITIZENS HIGH SCHOOL" & bb_5_clean == 34
	
recode bb_5_clean 34 = 57 if bb_4_clean == "MUHABURA SHINE SECONDARY SCHOOL"
*check pope john paul secondary school refers to college in gulu or kotido

recode bb_5_clean 34 = 37 if bb_4_clean == "ST MARY'S COLLEGE GISHOROZA"
replace bb_4_clean = "ST MARY'S COLLEGE RUSHOROZA" 	///
	if bb_4_clean == "ST MARY'S COLLEGE GISHOROZA" & bb_5_clean == 37
	
replace bb_4_clean = "GOODHEART SECONDARY SCHOOL" 	///
	if bb_4_clean == "GOOD HEART SECONDARY SCHOOL" & bb_5_clean == 35
	
replace bb_4_clean = "HOLY CROSS LAKE VIEW SECONDARY SCHOOL" 	///
	if bb_4_clean == "HOLLY CROSS LAKE VIEW" & bb_5_clean == 35
	
replace bb_4_clean = "JINJA COLLEGE" 	///
	if bb_4_clean == "JINJA COLLEGE SECONDARY SCHOOL" & bb_5_clean == 35
	
replace bb_4_clean = "KIIRA COLLEGE BUTIKI" 	///
	if (bb_4_clean == "KIRA COLLEGE BUTIIKI" 	///
	| bb_4_clean == "KIRA COLLEGE BUTIKI")		///
	& bb_5_clean == 35
replace bb_4_clean = "BUSOGA COLLEGE MWIRI" 	///
	if bb_4_clean == "MWIRI COLLEGE" & bb_5_clean == 35
	
replace bb_4_clean = "WANYANGE GIRLS' SCHOOL" 	///
	if (bb_4_clean == "WANYANGE GIRLS' SCHONDARY SCHOOL" 	///
	| bb_4_clean == "WANYANGE GIRLS' SECONDARY SCHOOL")		///
	& bb_5_clean == 35
	
replace bb_4_clean = "ST MARY'S COLLEGE RUSHOROZA" 	///
	if (bb_4_clean == "ST MARY'S COLLEGE GISHIRORA" 	///
	| bb_4_clean == "ST MARY'S RUSHOROOZA"			///
	| bb_4_clean == "ST MARY'S SCHOOL")				///
	& bb_5_clean == 37
	
replace geo2 = "" if geo2 == "RUSHOROZA" & bb_4_clean == "ST MARY'S COLLEGE RUSHOROZA"
replace bb_4_clean = "ST PAUL'S SECONDARY SCHOOL" 	///
	if bb_4_clean == "ST PAUL'S BUKINDA" & bb_5_clean == 37
	
replace geo2 = "BUKINDA" if bb_4_clean == "ST PAUL'S SECONDARY SCHOOL" & bb_5_clean == 37
replace bb_4_clean = "FORT PORTAL SECONDARY SCHOOL" 	///
	if (bb_4_clean == "FORTPORTAL SECONDARY SCHOOL" 	///
	& bb_5_clean == 38)
	
replace bb_4_clean = "KIBIITO SECONDARY SCHOOL" 	///
	if bb_4_clean == "KIBITO SECONDARY SCHOOL" 	///
	& bb_5_clean == 38
	
replace bb_4_clean = "KYEBAMBE GIRLS' SECONDARY SCHOOL" 	///
	if (bb_4_clean == "KYEBAMBE GIRLS' SCHOOL" 		///
	| bb_4_clean == "KYEBAMBE SECONDARY SCHOOL") 	///
	& bb_5_clean == 38
	
replace bb_4_clean = "MPANGA SECONDARY SCHOOL" 	///
	if bb_4_clean == "MPANGA SCONDARY SCHOOL" 	///
	& bb_5_clean == 38
	
replace bb_4_clean = "NYAKASURA SCHOOL" 	///
	if bb_4_clean == "NYAKASURA" 	///
	& bb_5_clean == 38
	
replace bb_4_clean = "SAMLING KAZINGO PEAS HIGH SCHOOL" 	///
	if bb_4_clean == "SAMLING PEAS HIGH SCHOOL" 	///
	& bb_5_clean == 38 & geo2 == "KAZINGO"
replace geo2 = "" 	///
	if bb_4_clean == "SAMLING KAZINGO PEAS HIGH SCHOOL" 	///
	& bb_5_clean == 38 & geo2 == "KAZINGO"
	
replace bb_4_clean = "ST MARIA GORETTI GIRLS' SCHOOL" 	///
	if bb_4_clean == "ST MARIA GORRET GIRLS' SECONDARY SCHOOL" 	///
	& bb_5_clean == 38 
	
replace bb_4_clean = "BRIGHT FUTURE SECONDARY SCHOOL" 	///
	if bb_4_clean == "BRIGHT FUTURE" 	///
	& bb_5_clean == 42 

*** KALUNGU

recode bb_5_clean 75 = 43 if bb_4_clean == "WAGGWA HIGH SCHOOL"
replace  bb_4_clean = "WAGWA HIGH SCHOOL" if ///
	bb_4_clean == "WAGGWA HIGH SCHOOL" 	///
	& bb_5_clean == 43

replace geo2 = "LUKAYA" 	///
	if bb_4_clean == "CRESTED HIGH SCHOOL" 	///
	& bb_5_clean == 43
	
replace bb_4_clean = "GREEN HILL SECONDARY SCHOOL" 	///
	if bb_4_clean == "GREENHILL SECONDARY SCHOOL" 	///
	& bb_5_clean == 43
	
replace geo2 = "KYAMULIBWA" 	///
	if bb_4_clean == "GREEN HILL SECONDARY SCHOOL" 	///
	& bb_5_clean == 43
replace bb_4_clean = "HOLY FAMILY KYAMULIBWA SECONDARY SCHOOL" 	///
	if bb_4_clean == "HOLYFAMILY SECONDARY SCHOOL" 	///
	& bb_5_clean == 43
replace bb_4_clean = "KABUKUNGE MUSLIM SECONDARY SCHOOL" 	///
	if bb_4_clean == "KABUKUNGE SECONDARY SCHOOL" 	///
	& bb_5_clean == 43
	
replace bb_4_clean = "ST THEREZA'S GIRLS' SECONDARY SCHOOL" 	///
	if (bb_4_clean == "ST THERESA SECONDARY SCHOOL" 	///
	| bb_4_clean == "ST THERESA GIRLS' SECONDARY SCHOOL" ///	
	| bb_4_clean == "ST THERESA BWANDA" 	///
	| bb_4_clean == "ST THERESA SECONDARY SCHOOL") 	///
	& bb_5_clean == 43
replace geo2 = "BWANDA" 	///
	if bb_4_clean == "ST THEREZA'S GIRLS' SECONDARY SCHOOL" 	///
	& bb_5_clean == 43

	****** KAMPALA
	
	* Abu Aisha Islamic Secondary School, Bethany high school and Najjanankumbi Young Christian School are either in Kampala or Wakiso, depending on dataset. Here, Kampala.
	
	recode bb_5_clean (111 = 44) if bb_4_clean == "ABU AISHA SECONDARY SCHOOL" & geo2 == "BULENGA"
	replace bb_4_clean = "ABU AISHA ISLAMIC SECONDARY SCHOOL" if bb_4_clean == "ABU AISHA SECONDARY SCHOOL" & geo2 == "BULENGA"
	
replace geo2 = "NAALYA" 	///
	if bb_4_clean == "BETHANY HIGH SCHOOL" 	///
	& bb_5_clean == 44
replace bb_4_clean = "BETHANY HIGH SCHOOL" ///
	if bb_4_clean == "BETHANY HIGH SCHOOLSCHOOL" ///
	& bb_5_clean == 44	///
	& geo2 == "NAALYA"

	recode bb_5_clean (111 = 44) if bb_4_clean == "NAJJANAMKUMBI YOUNG CHRISTIAN SCHOOL"
	replace bb_4_clean = "NAJJANANKUMBI YOUNG CHRISTIAN SCHOOL" 	///
	if bb_4_clean == "NAJJANAMKUMBI YOUNG CHRISTIAN SCHOOL"			///
	& bb_5_clean == 44
	
replace bb_4_clean = "BISHOP CIPRIANO KIHANGIRE" 	///
	if (bb_4_clean == "BISHOP CIPRIANO KIHANGIRE SECONDARY SCHOOL" 	///
	| bb_4_clean == "BISHOP CIPRIANO KIYANGIRE SECONDARY SCHOOL" ///
	| bb_4_clean == "BISHOP KIHANGIRE LUZIRA" 	///
	| bb_4_clean == "BISHOPS SIPRIANO KIHANGIRA" 	///
	| bb_4_clean == "BISHOPS CIPIRANO KIANGIRE SECONDARY SCHOOL" 	///
	| bb_4_clean == "BISHOP CIPRIANO KAHINGIRE SECONDARY SCHOOL") 	///
	& bb_5_clean == 44
	
replace bb_4_clean = "CITYSIDE COLLEGE MAKERERE" 	///
	if (bb_4_clean == "CITY SIDE COLLEGE MAKERERE" 	///
	|bb_4_clean == "CITYSIDE COLLEGE SCHOOL") ///
	& bb_5_clean == 44
	
replace bb_4_clean = "EAST HIGH SCHOOL" 	///
	if (bb_4_clean == "EASTHIGH SECONDARY SCHOOL") 	///
	& bb_5_clean == 44
replace geo2 = "NTINDA" 	///
	if bb_4_clean == "EAST HIGH SCHOOL" 	///
	& bb_5_clean == 44
	
replace bb_4_clean = "WANYANGE GIRLS' SCHOOL" ///
	if bb_4_clean == "WANYANGE GIRLS' SECONDARY SCHOOL" & bb_5_clean == 44

recode bb_5_clean (111 = 44) if bb_4_clean == "KABOWA HIGH SECONDARY SCHOOL"
replace bb_4_clean = "KABOWA HIGH SCHOOL" if bb_4_clean == "KABOWA HIGH SECONDARY SCHOOL" & bb_5_clean == 44

recode bb_5_clean (111 = 44) if bb_4_clean == "KAWEMPE MOSLEM SCHOOL"|bb_4_clean == "KAWEMPE MUSLIM SCHOOL"
replace bb_4_clean = "KAWEMPE MUSLIM SECONDARY SCHOOL" if bb_4_clean == "KAWEMPE MOSLEM SCHOOL"|bb_4_clean == "KAWEMPE MUSLIM SCHOOL" & bb_5_clean == 44

recode bb_5_clean (44 = 111) if bb_4_clean == "HANA MIXED SCHOOL" ///
	| (bb_4_clean == "MAKERERE HIGH SCHOOL" & geo2 == "MIGADDE") ///
	| (bb_4_clean == "MAKERERE HIGH SCHOOL" & geo2 == "MIGADE") ///
	| bb_4_clean == "KENEDI SECONDARY SCHOOL" ///
	| bb_4_clean == "KINGS WAY SECONDARY SCHOOL" ///
	| bb_4_clean == "NAALYA SECONDARY SCHOOL"		///
	| bb_4_clean == "NALIA AS NAMUGONGO"			///
	| bb_4_clean == "NAMIREMBE HILL SIDE SCHOOL"	///
	| bb_4_clean == "ST JULIAN HIGH SCHOOL"		///
	| bb_4_clean == "ST MARK'S COLLEGE NAMAGOMA" ///
	| bb_4_clean == "STANDARD HIGH SCHOOL"				///
	| bb_4_clean == "TRINITY COLLEGE NABBINGO" 	///
	| bb_4_clean == "TRUST HIGH SCHOOL"			///
	| bb_4_clean == "ZANA MIXED SCHOOL"

		* One of St Lawrence Schools is called "The Academy", it's in Buddo
		
recode bb_5_clean (111 = 44) if bb_4_clean == "ACADEMY OF ST LAWRENCE BUDDO" ///
						| bb_4_clean == "ACADEMY ST LAWRENCE SECONDARY SCHOOL" ///
						| bb_4_clean == "ST LAWRENCE ACADEMY"
recode bb_5_clean (75 = 44) if bb_4_clean == "ACADEMY ST LAWRENCE"

replace bb_4_clean = "ACADEMY OF ST LAWRENCE" if ///
						(bb_4_clean == "ACADEMY OF ST LAWRENCE BUDDO" ///
						| bb_4_clean == "ACADEMY ST LAWRENCE SECONDARY SCHOOL" ///
						| bb_4_clean == "ST LAWRENCE ACADEMY"				///
						| bb_4_clean == "ST LWARENCE ACADEMY SCHOOL"		///
						| bb_4_clean == "ACADEMY ST LAWRENCE")		///
						& bb_5_clean == 44

recode bb_5_clean (44 = 84) if  bb_4_clean == "ST LAWERENCE PARIS PALAIS" ///
	| bb_4_clean == "ST LAWRENCE PARIS PALAIS"						
recode bb_5_clean (44 = 84) if  bb_4_clean == "ST LWARENCE ACADEMY SCHOOL" ///
	& geo2 == "S AND COLLEGES PARIS PALAIS CAMPUS"						

recode bb_5_clean (15 = 86) if  bb_4_clean == "NAKIFUMA MODERN SECONDARY SCHOOL"
replace bb_4_clean = "NAKIFUMA MODERN SECONDARY SCHOOL MUKONO" 	///
	if (bb_4_clean == "NAKIFUMA MODERN SECONDARY SCHOOL") 	///
	& bb_5_clean == 86
	
recode bb_5_clean (44 = 35) if bb_4_clean == "WANYANGE GIRLS' SCHOOL" 

recode bb_5_clean (44 = 86) if  bb_4_clean == "OUR LADY OF AFRICA" ///
	| bb_4_clean == "OUR LADY OF AFRICA SECONDARY SCHOOL"		///
	| bb_4_clean == "NAMILYANGO COLLEGE"						///
	| bb_4_clean == "NAMILYAGO COLLEGE"						///
	| bb_4_clean == "SPRING FIELD HIGH SCHOOL"				

recode bb_5_clean (101 = 86) if  bb_4_clean == "OUR LADY OF AFRICA SECONDARY SCHOOL" & geo2 == "NAMILYANGO"
recode bb_5_clean (111 = 86) if  bb_4_clean == "OUR LADY SECONDARY SCHOOL" & geo2 == "NAMILYANGO"
recode bb_5_clean (111 = 86) if  bb_4_clean == "OUR LADY OF AFRICA"

recode bb_5_clean (50 = 86) if  bb_4_clean == "ST MICHAEL HIGH SCHOOL" & geo2 == "SONDE"
replace geo2 = " SONDE" if geo2 == "SONDE"


recode bb_5_clean (50 = 111) if  bb_4_clean == "NAALYA SECONDARY SCHOOL" 

recode bb_5_clean (84 = 111) if (	bb_4_clean == "HANA MIXED SECONDARY SCHOOL" & geo2 == "NSANGI") ///
							|bb_4_clean == "HANNAH MIXED BOARDING NSANJI"					///
							|bb_4_clean == "TRINITY COLLEGE NABINGO"
							
recode bb_5_clean 89 = 44 if bb_4_clean == "PRINCESS DIANA SECONDARY SCHOOL"

recode bb_5_clean (111 = 44) if bb_4_clean == "NABISUNSA GIRLS' SECONDARY SCHOOL"

replace bb_4_clean = "LAKESIDE COLLEGE LUZIRA" 	///
	if (bb_4_clean == "LAKESIDE SECONDARY SCHOOL") 	///
	& bb_5_clean == 44
replace geo2 = "" 	///
	if bb_4_clean == "LAKESIDE COLLEGE LUZIRA" 	///
	& bb_5_clean == 44
replace bb_4_clean = "MBOGO HIGH SCHOOL" 	///
	if (bb_4_clean == "MBOGO MIXED HIGH SCHOOL"	///
	| bb_4_clean == "MBUGO HIGH SCHOOL") 	///
	& bb_5_clean == 44
replace geo2 = "KAWEMPE" 	///
	if bb_4_clean == "MIDLAND HIGH SCHOOL" 	///
	& bb_5_clean == 44
replace bb_4_clean = "NABISUNSA GIRLS' SCHOOL" 	///
	if (bb_4_clean == "NABISUNSA GIRLS' SECONDARY SCHOOL"	///
	| bb_4_clean == "NABISUNSA SECONDARY SCHOOL") 	///
	& bb_5_clean == 44
replace bb_4_clean = "NSAMBYA SECONDARY SCHOOL" 	///
	if (bb_4_clean == "MBOGO MIXED HIGH SCHOOL"	///
	| bb_4_clean == "NSAABYA SECONDARY SCHOOL") 	///
	& bb_5_clean == 44
replace bb_4_clean = "NTINDA VIEW COLLEGE" 		///
	if bb_4_clean == "NTINDA VIEW COLLEGE SCHOOL" ///
	& bb_5_clean == 44
	
replace bb_4_clean = "PRINCESS DIANA HIGH SCHOOL" 		///
	if bb_4_clean == "PRINCESS DIANA SECONDARY SCHOOL" ///
	& bb_5_clean == 44
	
replace bb_4_clean = "ST JOSEPH'S GIRLS' NSAMBYA" 		///
	if (bb_4_clean == "ST JOSEPH'S GIRLS' SCHOOL" ///
	| bb_4_clean == "ST JOSEPH'S GIRLS' SCHOOL" ///
	| bb_4_clean == "ST JOSEPH'S GIRLS' SECONDARY SCHOOL" ///
	| bb_4_clean == "ST JOSEPH'S NSAMBYA")				///
	& bb_5_clean == 44
replace geo2 = "" if bb_4_clean == "ST JOSEPH'S GIRLS' NSAMBYA" & bb_5_clean == 44

replace bb_4_clean = "STENA HILL SECONDARY SCHOOL" ///
	if bb_4_clean == "STENA HILL SCHOOL" & bb_5_clean == 44
replace bb_4_clean = "GREEN HILL COLLEGE BULOPA" 		///
	if (bb_4_clean == "GREEN HILL COLLEGE" ///
	| bb_4_clean == "GREEN HILL") ///
	& bb_5_clean == 45
	
replace bb_4_clean = "JINJA COLLEGE" if bb_4_clean == "JINJA COLLEGE SECONDARY SCHOOL"

recode bb_5_clean (45 = 33) if bb_4_clean == "IGANGA HIGH SCHOOL" | ///
	bb_4_clean == "IGANGA SECONDARY SCHOOL" 					///
	| bb_4_clean == "JINJA COLLEGE"

recode bb_5_clean (91 = 33) if bb_4_clean == "IGANGA SECONDARY SCHOOL" 			

recode bb_5_clean (45 = 35) if bb_4_clean == "LUBANI SECONDARY SCHOOL"

replace bb_4_clean = "KYABENDA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KAYABENDA SECONDARY SCHOOL" ///
	| bb_4_clean == "KYABENDE SECONDARY SCHOOL") ///
	& bb_5_clean == 46

replace bb_4_clean = "ST THOMAS AQUINAS COLLEGE" 		///
	if (bb_4_clean == "ST THOMAS AQULNAS COLLEGE") ///
	& bb_5_clean == 46

	*** KANUNGU
replace bb_4_clean = "BISHOP COMBONI COLLEGE KAMBUGA" 		///
	if (bb_4_clean == "BISHOP KOMBONI COLLEGE"				///
	| bb_4_clean == "KOMBONI") ///
	& bb_5_clean == 47

replace bb_4_clean = "KIHIHI MUSLIM SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KIHIIHI MOSLEM SECONDARY SCHOOL") ///
	& bb_5_clean == 47

replace bb_4_clean = "KINKIIZI HIGH SCHOOL" 		///
	if (bb_4_clean == "KINKINZI HIGH SCHOOL") ///
	& bb_5_clean == 47

	*** KAYUNGA
	
replace bb_4_clean = "BUSAANA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "BUSANA SECONDARY SCHOOL") ///
	& bb_5_clean == 51

replace bb_4_clean = "ST MATHIAS KALEMBA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST KALEMBA SECONDARY SCHOOL"				///
	| bb_4_clean == "ST M KALEMBA'S SECONDARY SCHOOL"			///
	| bb_4_clean == "ST MATHEUS KALEMBA NAZZIGO"				///
	| bb_4_clean == "ST MATHIUS KALEMBA"						///
	| bb_4_clean == "ST MATHIUS KALEMBA SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MATHIUS KALEMBE SECONDARY SCHOOL") ///
	& bb_5_clean == 51

replace bb_4_clean = "ST FRANCIS XAVIER MODERN SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST FRANCIS EXAVIER MORDEN SECONDARY SCHOOL") ///
	& bb_5_clean == 52

replace bb_4_clean = "NOTRE DAME ACADEMY BUSEESA" 		///
	if (bb_4_clean == "NOTRIDEME ACADEMY") ///
	& bb_5_clean == 52

	*** KIBOGA (part of it is now Kyankwanzi)
recode bb_5_clean (53 = 64) if bb_4_clean == "BEATRICE INTERNATIONAL" 

replace bb_4_clean = "BEATRICE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "BEATRICE INTERNATIONAL") ///
	& bb_5_clean == 64

replace bb_4_clean = "HIGHLIGHT SECONDARY SCHOOL" 		///
	if (bb_4_clean == "HIGH LIGHT SECONDARY SCHOOL") ///
	& bb_5_clean == 54
replace  geo2 = "KADAMA" if geo2 == "" & bb_4_clean == "HIGHLIGHT SECONDARY SCHOOL" & bb_5_clean == 54
	
replace bb_4_clean = "KIGUMBA INTENSIVE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "INTENSIVE SECONDARY SCHOOL") ///
	& bb_5_clean == 56

replace bb_4_clean = "KISORO VISION SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KOSOVO VISION SECONDARY SCHOOL"		///
	| bb_4_clean == "KISORI VISION SECONDARY SCHOOL" 		///
	| bb_4_clean == "KISORO VISION" 						///
	| bb_4_clean == "VISION SECONDARY SCHOOL") 				///
	& bb_5_clean == 57

replace bb_4_clean = "SESEME GIRLS' SCHOOL" 		///
	if (bb_4_clean == "SESEME GIRLS' SECONDARY SCHOOL")		///
	& bb_5_clean == 57

replace bb_4_clean = "MURAMBA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "MURAMBA SECONDARY")		///
	& bb_5_clean == 57

replace bb_4_clean = "KITGUM COMPREHENSIVE COLLEGE" 		///
	if (bb_4_clean == "KITGUM COMPREHENSIVE HIGH SCHOOL"		///
	| bb_4_clean == "KITGUM COMPREHENSIVE SCHOOL") 		///
	& bb_5_clean == 58

replace bb_4_clean = "KITGUM PROGRESSIVE COLLEGE" 		///
	if (bb_4_clean == "KITGUM PROGRESSIVE")		///
	& bb_5_clean == 58

replace bb_4_clean = "REV.JABULONI ISSOKE MEMORIAL COLLEGE" 		///
	if (bb_4_clean == "REV JABOLONI ISSOKE MEMORIAL COLLEGE"		///
	| bb_4_clean == "REV JABULONI ISOKE SECONDARY SCHOOL"			///
	| bb_4_clean == "REV JABULONI ISSOKE MEMORIAL COLLEGE")		///
	& bb_5_clean == 58

replace bb_4_clean = "ST BAKHITA GIRLS' SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST BAKITA GIRLS' SECONDARY SCHOOL")		///
	& bb_5_clean == 58

replace bb_4_clean = "ACULBANYA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ACULBANYA")		///
	& bb_5_clean == 60

replace bb_4_clean = "ST MARY'S COLLEGE ABOKE" 		///
	if (bb_4_clean == "ABOKE GIRLS' SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MARY'S VILLAGE ABOKE")			///
	& bb_5_clean == 60

replace bb_4_clean = "NYERO ROCK HIGH SCHOOL" 		///
	if (bb_4_clean == "NGERO HIGH SCHOOL")		///
	& bb_5_clean == 62

replace bb_4_clean = "LOKUNG SECONDARY SCHOOL" 		///
	if (bb_4_clean == "LUKUNG SECONDARY SCHOOL")		///
	& bb_5_clean == 67


replace bb_4_clean = "BULLUGE COMPREHENSIVE HIGH SCHOOL" 		///
	if (bb_4_clean == "BULLUGE HIGH SCHOOL")		///
	& bb_5_clean == 68
	
replace bb_4_clean = "DR OBOTE COLLEGE BOROBORO" 		///
	if (bb_4_clean == "DOCTOR OBOTE COLLEGE BOROBORO"	///
	| bb_4_clean =="DR OBOTE COLLEDGE"					///
	| bb_4_clean == "DR OBOTE COLLEGE")		///
	& bb_5_clean == 68

replace bb_4_clean = "KING JAMES COMP. SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KING JAMES COMPREHENSIVE SECONDARY SCHOOL")		///
	& bb_5_clean == 68

replace bb_4_clean = "LIGHT VOCATIONAL SECONDARY SCHOOL" 		///
	if (bb_4_clean == "LIGHT VOCATIONAL SCHOOL")		///
	& bb_5_clean == 68

replace bb_4_clean = "SAVIOR'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "SAVIOURS SECONDARY SCHOOL")		///
	& bb_5_clean == 68

replace bb_4_clean = "SKYLAND HIGH SCHOOL" 		///
	if (bb_4_clean == "SKY LAND HIGH SCHOOL")		///
	& bb_5_clean == 68

replace bb_4_clean = "ST KATHERINE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST CATHERINE SECONDARY SCHOOL"		///
	| bb_4_clean == "ST KATHERINE SECONDARY SCHOOL")		///
	& bb_5_clean == 68

replace bb_4_clean = "IKUMBYA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "IKUMBYA PRIMARY SCHOOL")		///
	& bb_5_clean == 69
	
replace geo2 = "KIYUNGA" if bb_4_clean == "NILE HIGH SCHOOL" & bb_5_clean == 69
	
replace geo2 = "BAMUNANIKA" if bb_4_clean == "ATLANTA HIGH SCHOOL" & bb_5_clean == 70

replace bb_4_clean = "EVEREST COLLEGE" 		///
	if (bb_4_clean == "EVEREST COLLEGE SECONDARY SCHOOL")		///
	& bb_5_clean == 70

recode bb_5_clean 81 = 70 if bb_4_clean == "KATI KAMU SDA SECONDARY SCHOOL"
recode bb_5_clean 86 = 70 if bb_4_clean == "KATIKAMU SDA SECONDARY SCHOOL"

replace bb_4_clean = "KATIKAMU SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KATIKAMU SDA SECONDARY SCHOOL"		///
	| bb_4_clean == "KATIKAMU SDA"						///
	| bb_4_clean == "KATI KAMU SDA SECONDARY SCHOOL"						///
	| bb_4_clean == "KATIKAMU SENIOR SECINDARY SCHOOL")		///
	& bb_5_clean == 70


recode bb_5_clean 89 = 70 if bb_4_clean == "MULUSA ACADEMY SECONDARY SCHOOL"
recode bb_5_clean 89 = 70 if bb_4_clean == "ST ANTHONY'S SECONDARY SCHOOL"
recode bb_5_clean 89 = 70 if bb_4_clean == "LUWERO SECONDARY SCHOOL"

replace bb_4_clean = "MULUSA ACADEMY WOBULENZI" 		///
	if (bb_4_clean == "MULUSA ACADAMY SENIIR SECONDARY SCHOOL"	///
	| bb_4_clean == "MULUSA ACADEMY SECONDARY SCHOOL") ///
	& bb_5_clean == 70

replace bb_4_clean = "SAAKU SECONDARY SCHOOL" 		///
	if (bb_4_clean == "SSAKU SECONDARY SCHOOL")		///
	& bb_5_clean == 70

replace bb_4_clean = "ST JOHN'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JOHN'S NANDERE")		///
	& bb_5_clean == 70
replace geo2 = "NANDERE" if bb_4_clean == "ST JOHN'S SECONDARY SCHOOL" & bb_5_clean == 70

replace bb_4_clean = "TARGET COMMUNITY COLLEGE" 		///
	if (bb_4_clean == "TARGET COMMUNITY HIGH SCHOOL")		///
	& bb_5_clean == 70

replace geo2 = "MBIRIZI" if geo2 == "MBIRIIZI" & bb_4_clean == "MODERN SECONDARY SCHOOL" & bb_5_clean == 71

replace bb_4_clean = "ST BERNARD'S COLLEGE KISWERA" 		///
	if (bb_4_clean == "ST BERNARD'S COLLEGE KISOWERA")		///
	& bb_5_clean == 71

replace bb_4_clean = "ST GONZAGA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST GOZAGA SECONDARY SCHOOL")		///
	& bb_5_clean == 72

replace geo2 = "KIJJUKIZO" if geo2 == "" & bb_4_clean == "ST GONZAGA SECONDARY SCHOOL" & bb_5_clean == 72

replace bb_4_clean = "ST JOHN'S KALIRO COMP. SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JOHN'S SECONDARY SCHOOL")		///
	& bb_5_clean == 72

	*** MANAFWA

	* Manafwa was carved from northern Bududa district in 2006
recode bb_5_clean (12 = 73) if bb_4_clean == "BUGOBERO SECONDARY SCHOOL"
replace bb_4_clean = "BUGOBERO HIGH SCHOOL" 		///
	if (bb_4_clean == "BUGOBERO SECONDARY SCHOOL")		///
	& bb_5_clean == 73

replace bb_4_clean = "BUBULO GIRLS' HIGH SCHOOL" 		///
	if (bb_4_clean == "BOBULO GIRLS' HIGH SCHOOL")		///
	& bb_5_clean == 73

replace bb_4_clean = "BUTIRU CHRISTIAN COMP. SECONDARY SCHOOL" 		///
	if (bb_4_clean == "BUTIRU CHRISTIAN COMPREHENSIVE SECONDARY SCHOOL")		///
	& bb_5_clean == 73

replace bb_4_clean = "TRINITY COLLEGE MAALA" 		///
	if (bb_4_clean == "TRINITY COLLEGE MARA")		///
	& bb_5_clean == 73

replace bb_4_clean = "ARCHBISHOP KIWANUKA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ARCHIVE BISHOP KIWANUKA SECONDARY SCHOOL")		///
	& bb_5_clean == 75

replace geo2 = "KITOVU" if (geo2 == "") & bb_4_clean == "ARCHBISHOP KIWANUKA SECONDARY SCHOOL" & bb_5_clean == 75

replace bb_4_clean = "KAKO SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KAKKO SECONDARY SCHOOL")		///
	& bb_5_clean == 75


replace bb_4_clean = "BLESSED SACRAMENT SECONDARY SCHOOL" 		///
	if (bb_4_clean == "BLESSED SACRAMENT KIMANYA"		///
	| bb_4_clean == "BLESSED SACRAMENT KIMANYA SECONDARY SCHOOL"						///
	| bb_4_clean == "BLESSED SACREMENT SECONDARY SCHOOL")		///
	& bb_5_clean == 75
replace geo2 = "KIMAANYA" if (geo2 == "KIMANYA"|geo2 == "") & bb_4_clean == "BLESSED SACRAMENT SECONDARY SCHOOL" & bb_5_clean == 75
	
replace bb_4_clean = "ST HENRY'S COLLEGE KITOVU" 		///
	if (bb_4_clean == "ST HENRY'S SECONDARY SCHOOL")		///
	& bb_5_clean == 75
replace geo2 = "" if (geo2 == "KITOVU") & bb_4_clean == "ST HENRY'S COLLEGE KITOVU" & bb_5_clean == 75

replace bb_4_clean = "NOTREDAME HIGH SCHOOL" 		///
	if (bb_4_clean == "NOTADAMU HIGH SCHOOL")		///
	& bb_5_clean == 75

	
replace geo2 = "NAROZARI" if (geo2 == "") & bb_4_clean == "ST MARTIN SECONDARY SCHOOL" & bb_5_clean == 75

replace bb_4_clean = "ST THERESA GIRLS' SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST THERESA BWANDA"		///
	| bb_4_clean == "ST THERESA BWANDA SECONDARY SCHOOL"						///
	| bb_4_clean == "ST THERESSAR GIRLS' SECONDARY SCHOOL"						///
	| bb_4_clean == "ST THERESSA GIRLS' SECONDARY SCHOOL"						///
	| bb_4_clean == "ST THERESA GIRLS' SCHOOL")		///
	& bb_5_clean == 75
replace geo2 = "BWANDA" if (geo2 == "") & bb_4_clean == "ST THERESA GIRLS' SECONDARY SCHOOL" & bb_5_clean == 75


replace bb_4_clean = "JORDAN PRIDE EDUCATION CENTRE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "JORDAN PRIDE SECONDARY SCHOOL") ///
	& bb_5_clean == 76

replace bb_4_clean = "BWIJANGA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "BWIJANGA") ///
	& bb_5_clean == 76

replace bb_4_clean = "MASINDI ARMY SECONDARY SCHOOL" 		///
	if (bb_4_clean == "MASINDI ARMY BARRACKS") ///
	& bb_5_clean == 76

replace bb_4_clean = "ST PAUL'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST PAUL'S PAKANYI SECONDARY SCHOOL") ///
	& bb_5_clean == 76
replace geo2 = "PAKANYI" if (geo2 == "") & bb_4_clean == "ST PAUL'S SECONDARY SCHOOL" & bb_5_clean == 76

replace bb_4_clean = "MBALE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "MBALE SECONDARY") ///
	& bb_5_clean == 78

replace bb_4_clean = "ST PAUL'S COLLEGE" 		///
	if (bb_4_clean == "ST PAUL'S") ///
	& bb_5_clean == 78

replace bb_4_clean = "MBARARA ARMY BOARDING SECONDARY SCHOOL" 		///
	if (bb_4_clean == "MBARARA ARMY SECONDARY SCHOOL") ///
	& bb_5_clean == 79

replace bb_4_clean = "MARYHILL HIGH SCHOOL" 		///
	if (bb_4_clean == "MARRY HILL GIRLS' SECONDARY SCHOOL" ///
	| bb_4_clean == "MARY HILL HIGH SCHOOL"		///
	| bb_4_clean == "MERYHILL HIGH SCHOOL")		///
	& bb_5_clean == 79

	
replace bb_4_clean = "ST JOSEPH'S VOCATIONAL SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JOSEPH'S VOCATIONAL SCHOOL") ///
	& bb_5_clean == 79

replace bb_4_clean = "ST PETER KATUKURU SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST PETER'S KATUKURU SECONDARY SCHOOL") ///
	& bb_5_clean == 79

replace bb_4_clean = "NTARE SCHOOL" 		///
	if (bb_4_clean == "NTARE HIGH SCHOOL") ///
	& bb_5_clean == 79

	
replace bb_4_clean = "MITYANA TOWN SCHOOL" 		///
	if (bb_4_clean == "MITYANA TOWN SECONDARY SCHOOL") ///
	& bb_5_clean == 81

replace bb_4_clean = "ROYAL GIANT HIGH SCHOOL" 		///
	if (bb_4_clean == "ROYAL GIANT MITYANA SECONDARY SCHOOL") ///
	& bb_5_clean == 81

replace bb_4_clean = "KING FAISAL BBUYE ISLAMIC SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KING FAISAL SECONDARY SCHOOL") ///
	& bb_5_clean == 81

replace bb_4_clean = "CENTRAL COLLEGE" 		///
	if (bb_4_clean == "CENTRAL COLLEGE SCHOOL"		///
	|bb_4_clean == "MITYANA CENTRAL COLLEGE SCHOOL") ///
	& bb_5_clean == 81

replace bb_4_clean = "LOHWA DAY SECONDARY SCHOOL" 		///
	if (bb_4_clean == "LOHWA SECONDARY SCHOOL")		///
	& bb_5_clean == 83

replace bb_4_clean = "ST ANDREWS COLLEGE MOYO" 		///
	if (bb_4_clean == "ST ANDREW MOYO SECONDARY SCHOOL"		///
	| bb_4_clean == "ST ANDREW'S COLLEGE"		///
	| bb_4_clean == "ST ANDREWS COLLEGE")		///
	& bb_5_clean == 83

replace bb_4_clean = "CROWN CITY"	 ///
	if (bb_4_clean == "ST LAWRENCE CROWN ADCEMY SCHOOL" ///
	| bb_4_clean == "ST LAWRENCE CROWN CITY CAMPUS")	///
	& bb_5_clean == 84


replace bb_4_clean = "ST LAWRENCE COLLEGE PARIS PALAIS" 		///
	if (bb_4_clean == "ST LAWERENCE PARIS PALAIS" ///
	| bb_4_clean == "ST LAWRENCE PARI PALES"		///
	| bb_4_clean == "ST LAWRENCE PARIS PALAIS"		///
	| bb_4_clean == "ST LWARENCE ACADEMY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "" if geo2 == "S AND COLLEGES PARIS PALAIS CAMPUS" & bb_4_clean == "ST LAWRENCE COLLEGE PARIS PALAIS"  & bb_5_clean == 84

replace bb_4_clean = "ST BALIKUDDEMBE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST BALIKUDEMBE MITALA MARIA SECONDARY SCHOOL" ///
	| bb_4_clean == "ST BALIKUNDEMBE SECONDARY SCHOOL")		///
	& bb_5_clean == 84
replace geo2 = "" if geo2 == "MATALA MARIA" & bb_4_clean == "ST BALIKUDDEMBE SECONDARY SCHOOL"  & bb_5_clean == 84

replace bb_4_clean = "ST MARIA GORETTI KATENDE" 		///
	if (bb_4_clean == "ST MARIA GORETTI SECONDARY SCHOOL" ///
	| bb_4_clean == "ST MARIA GORRET KATENDE"		///
	| bb_4_clean == "ST MARIA GORRETI KATENDE SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MARIA GORRETTE SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MARIA GORRETTI KATENDE SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MARIA GORRETI SECONDARY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "KATENDE" if geo2 == "" & bb_4_clean == "ST MARIA GORETTI KATENDE"  & bb_5_clean == 84

replace bb_4_clean = "ST BRUNO SSERUNKUMA'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST BRUNO GOLI SENIOR SECONDARY" ///
	| bb_4_clean == "ST BRUNO SECONDARY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "GGOLI" if geo2 == "" & bb_4_clean == "ST BRUNO SSERUNKUMA'S SECONDARY SCHOOL"  & bb_5_clean == 84

replace bb_4_clean = "ST JUDE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JUDE KATENDE SECONDARY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "KATENDE" if geo2 == "" & bb_4_clean == "ST JUDE SECONDARY SCHOOL"  & bb_5_clean == 84

replace bb_4_clean = "BULO PARENTS" 		///
	if (bb_4_clean == "BULO PARENTS SECONDARY SCHOOL")	///
	& bb_5_clean == 84

replace bb_4_clean = "GOMBE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "GOMBE SECONDRY SCHOOL")	///
	& bb_5_clean == 84

replace bb_4_clean = "LOWELL GIRLS' SCHOOL" 		///
	if (bb_4_clean == "LOWELL GIRLS' SECONDARY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "NSIMBE" if geo2 == "" & bb_4_clean == "LOWELL GIRLS' SCHOOL"  & bb_5_clean == 84
	
replace bb_4_clean = "PRIDE COLLEGE SECONDARY SCHOOL" 		///
	if (bb_4_clean == "PRIDE COLLEGE")	///
	& bb_5_clean == 84

replace bb_4_clean = "ST MARK'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST MARK'S NAMAGOMA")	///
	& bb_5_clean == 84
replace geo2 = "NAMAGOMA" if (geo2 == ""|geo2 == "NAGOMA") & bb_4_clean == "ST MARK'S SECONDARY SCHOOL"  & bb_5_clean == 84

replace bb_4_clean = "ST MARY'S NKOZI SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST MARY'S SECONDARY SCHOOL")	///
	& bb_5_clean == 84
replace geo2 = "NKOZI" if (geo2 == "NKOSI") & bb_4_clean == "ST MARY'S NKOZI SECONDARY SCHOOL"  & bb_5_clean == 84
replace geo2 = "JJALAMBA" if (geo2 == "") & bb_4_clean == "ST MUGAGGA SECONDARY SCHOOL"  & bb_5_clean == 84

replace bb_4_clean = "ST CHARLES LWANGA LWANGIRI SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST CHARLES SECONDARY SCHOOL")	///
	& bb_5_clean == 85

replace bb_4_clean = "BISHOP'S SEN. SCHOOL" 		///
	if (bb_4_clean == "BISHIOP SENIOR SCHOOL")	///
	& bb_5_clean == 86

replace bb_4_clean = "NAMILYANGO COLLEGE" 		///
	if (bb_4_clean == "NAMILYAGO COLLEGE"		///
	|bb_4_clean == "NAMIRYANGO COLLEGE")	///
	& bb_5_clean == 86

replace bb_4_clean = "MT ST MARY'S COLLEGE NAMAGUNGA" 		///
	if (bb_4_clean == "NAMAGUNGA MOUNT ST MARY'S"			///
	|bb_4_clean == "NAMAGUNGA GIRLS' SCHOOL")	///
	& bb_5_clean == 86

replace bb_4_clean = "MPOMA SCHOOL" 		///
	if (bb_4_clean == "MPOMA SECONDARY SCHOOL")	///
	& bb_5_clean == 86

	
replace bb_4_clean = "SEROMA CHRISTIAN HIGH SCHOOL" 		///
	if (bb_4_clean == "SEROMA CHRISTIAN SCHOOL"			///
	|bb_4_clean == "SEROMA HIGH SCHOOL")	///
	& bb_5_clean == 86

replace bb_4_clean = "HILTON HIGH SCHOOL" 		///
	if (bb_4_clean == "HILTONHIGH SCHOOL SCHOOL")	///
	& bb_5_clean == 86

replace bb_4_clean = "SPRINGFIELD COLLEGE KAWONGO" 		///
	if (bb_4_clean == "SPRING FIELD HIGH SCHOOL")	///
	& bb_5_clean == 86

replace bb_4_clean = "OUR LADY OF AFRICA NAMILYANGO" 		///
	if (bb_4_clean == "OUR LADY OF AFRICA NAMILYANGO"		///
	| bb_4_clean == "OUR LADY OF AFRICA NAMILYANGO SECONDARY SCHOOL"	///
	| bb_4_clean == "OURLADY OF AFRICA NAMILYANGO"			)	///
	& bb_5_clean == 86

replace bb_4_clean = "OUR LADY OF AFRICA NAMILYANGO" 		///
	if (geo2 == "NAMILYANGO"| geo2 == "NAMILYAGO") 			///
	& (bb_4_clean == "OUR LADY OF AFRICA SECONDARY SCHOOL" ///
	| bb_4_clean == "OUR OF AFRICA SECONDARY SCHOOL" 		///
	| bb_4_clean == "OURLADY OF AFRICA SECONDARY SCHOOL" 	///
	| bb_4_clean == "OUR LADY SECONDARY SCHOOL") 											///
	& bb_5_clean == 86
	replace geo2 = "" if (geo2 == "NAMILYANGO"| geo2 == "NAMILYAGO") & bb_4_clean == "OUR LADY OF AFRICA NAMILYANGO" 

replace bb_4_clean = "OUR LADY OF AFRICA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "OURLADY OF AFRICA"		///
	| bb_4_clean == "OUR LADY OF AFRICA")	///
	& bb_5_clean == 86							///
	& geo2 == ""

replace bb_4_clean = "ST JOSEPH'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JOSEPH'S NAGALAMA")	///
	& bb_5_clean == 86
replace geo2 = " NAGGALAMA" if geo2 == "" & bb_4_clean == "ST JOSEPH'S SECONDARY SCHOOL"  & bb_5_clean == 86

replace bb_4_clean = "SEETA HIGH SCHOOL GREEN CAMPUS" 		///
	if bb_4_clean == "SEETA HIGH SCHOOL" 	///
	& geo2 == "GREEN CAMPUS" ///
	& bb_5_clean == 86
replace geo2 = " GREEN CAMPUS" if geo2 == "GREEN CAMPUS" & bb_4_clean == "SEETA HIGH SCHOOL GREEN CAMPUS"  & bb_5_clean == 86

replace bb_4_clean = "ST MICHAEL HIGH SCHOOL" ///
	if (bb_4_clean == "ST MICHAEL SECONDARY SCHOOL"	///
	| bb_4_clean == "ST MICHEAL HIGH SCHOOL"		///
	| bb_4_clean == "ST MICHEAL SONDE")				///
	& bb_5_clean == 86
	
replace geo2 = " SONDE" if (geo2 == "SONDE"|geo2 == "SSONDE"|geo2 == "") & bb_4_clean == "ST MICHAEL HIGH SCHOOL" & bb_5_clean == 86

replace bb_4_clean = "ST KIZITO SECONDARY SCHOOL" ///
	if (bb_4_clean == "ST KITIZO LORENGEDWAT"	///
	| bb_4_clean == "ST KITIZO LORENGEWAT"		///
	| bb_4_clean == "ST KIZITO NARENGEDWAT SECONDARY SCHOOL")				///
	& bb_5_clean == 87
replace geo2 = "LORENGEDWAT" if geo2 == "" & bb_4_clean == "ST KIZITO SECONDARY SCHOOL" & bb_5_clean == 87

replace bb_4_clean = "ST KIZITO SECONDARY SCHOOL" ///
	if (bb_4_clean == "ST KITIZO LORENGEDWAT"	///
	| bb_4_clean == "ST KITIZO LORENGEWAT"		///
	| bb_4_clean == "ST KIZITO NARENGEDWAT SECONDARY SCHOOL")				///
	& bb_5_clean == 87

replace bb_4_clean = "NAKASEKE SDA SECONDARY SCHOOL" ///
	if (bb_4_clean == "SDA SECONDARY SCHOOL")				///
	& bb_5_clean == 88

replace bb_4_clean = "NABINYONYI PARENTS' SECONDARY SCHOOL" ///
	if (bb_4_clean == "NABINYONYI PARENTS")				///
	& bb_5_clean == 91
	
replace bb_4_clean = "ST MATHIAS MAGADA SECONDARY SCHOOL" ///
	if (bb_4_clean == "ST MATHIUS MAGADA SECONDARY SCHOOL")				///
	& bb_5_clean == 91

replace bb_4_clean = "ST ANDREWS SECONDARY SCHOOL" ///
	if bb_4_clean == "ST ANDREWS"				///
	& bb_5_clean == 92								
replace geo2 = " LOTOME" if geo2 == "" & bb_4_clean == "ST ANDREWS SECONDARY SCHOOL" & bb_5_clean == 92

replace bb_4_clean = "LIGHT COLLEGE" ///
	if bb_4_clean == "LIGHT COLLEGE NGRO"				///
	& bb_5_clean == 94								

replace bb_4_clean = "RUHAAMA SECONDARY SCHOOL" ///
	if bb_4_clean == "RUHAMA SECONDARY SCHOOL"				///
	& bb_5_clean == 96								

replace bb_4_clean = "RWASHAMAIRE HIGH SCHOOL" ///
	if (bb_4_clean == "RWASHAMEIRE"|bb_4_clean == "RWASHAMIRE HIGH SCHOOL")				///
	& bb_5_clean == 96								

replace bb_4_clean = "WEST END MODERN SECONDARY SCHOOL" ///
	if bb_4_clean == "WESTEND SECONDARY SCHOOL"				///
	& bb_5_clean == 96								

replace bb_4_clean = "HILLSIDE ACADEMY SECONDARY SCHOOL" ///
	if bb_4_clean == "HILL SIDE ACADEMY"				///
	& bb_5_clean == 96								
replace geo2 = "ITOJO" if geo2 == "" & bb_4_clean == "HILLSIDE ACADEMY SECONDARY SCHOOL" & bb_5_clean == 96

replace bb_4_clean = "POPE PAUL VI SECONDARY SCHOOL" ///
	if bb_4_clean == "POPE PAUL IV SECONDARY SCHOOL"				///
	& bb_5_clean == 97								
replace geo2 = "ANAKA" if bb_4_clean == "POPE PAUL VI SECONDARY SCHOOL" & bb_5_clean == 97

replace bb_4_clean = "ADWARI SECONDARY SCHOOL" ///
	if bb_4_clean == "ADWERO SECONDARY SCHOOL"				///
	& bb_5_clean == 98								

replace bb_4_clean = "AMWA COMPREHENSIVE SECONDARY SCHOOL" ///
	if bb_4_clean == "AMWA COMPREHENSIVE COLLEGE"				///
	& bb_5_clean == 99								

replace bb_4_clean = "ARCH BISHOP FLYNN SECONDARY SCHOOL" ///
	if (bb_4_clean == "ARCHBISHOPS FLYNN SECONDARY SCHOOL"	///
	|bb_4_clean == "BISHOP FLIN SECONDARY SCHOOL")			///
	& bb_5_clean == 100								

replace bb_4_clean = "GOGONYO SECONDARY SCHOOL" ///
	if (bb_4_clean == "GOGONYO SECODARY SCHOOL")			///
	& bb_5_clean == 101								

	*** RAKAI
replace bb_4_clean = "CHRIST THE KING SECONDARY SCHOOL" ///
	if (bb_4_clean == "CHRIST THE KING KALISIZO")			///
	& bb_5_clean == 102								

replace geo2 = "KALISIZO" if (geo2 == "KARISIZO"|geo2 == "KALIISIZO"|geo2 == "") & bb_4_clean == "CHRIST THE KING SECONDARY SCHOOL" & bb_5_clean == 102

replace bb_4_clean = "KABAALE SANJE SECONDARY SCHOOL" ///
	if (bb_4_clean == "KABALE SANJE SECONDARY SCHOOL")			///
	& bb_5_clean == 102								

replace geo2 = "KYOTERA" if geo2 == "" & bb_4_clean == "ST JAMES SECONDARY SCHOOL" & bb_5_clean == 102

replace bb_4_clean = "ST MARY'S SECONDARY SCHOOL" ///
	if (bb_4_clean == "ST MARRYS SANJE SECONDARY SCHOOL")			///
	& bb_5_clean == 102								
replace geo2 = "SSANJE" if geo2 == "" & bb_4_clean == "ST MARY'S SECONDARY SCHOOL" & bb_5_clean == 102

recode bb_5_clean (75 = 102) if bb_4_clean == "ST ANDREW'S MATALE SECONDARY SCHOOL"

replace bb_4_clean = "ARCHBISHOP BAKYENGA VOCATIONAL SECONDARY SCHOOL" ///
	if (bb_4_clean == "ARCHIBISHOP BAKYENGA VOCATIONAL SECONDARY SCHOOL")			///
	& bb_5_clean == 103								

replace bb_4_clean = "KICHWAMBA HIGH SCHOOL" ///
	if (bb_4_clean == "KICHWAMBA SECONDARY")			///
	& bb_5_clean == 103								

replace bb_4_clean = "MWONGYERA SECONDARY SCHOOL" ///
	if (bb_4_clean == "MWONGERA SECONDARY SCHOOL")			///
	& bb_5_clean == 103								

replace bb_4_clean = "IMMACULATE HEART GIRLS' SCHOOL" ///
	if (bb_4_clean == "IMMACULATE HEART GIRLS' HIGH SCHOOL"	///
	|bb_4_clean == "IMMACULATE HEART GIRLS' NYAKIBALE"		///
	|bb_4_clean == "IMMACULATE HEART GIRLS' NYAKIBALE SCHOOL" ///
	|bb_4_clean == "IMMACULATE HEART GIRLS' NYAKIBARE"			///
	|bb_4_clean == "IMMACULATE HEART GIRLS' SECONDARY SCHOOL"	///
	|bb_4_clean == "IMMACURATE HEART GIRLS' SECONDARY SCHOOL"	///
	|bb_4_clean == "ST IMMACULATE HEART SECONDARY SCHOOL")			///
	& bb_5_clean == 104								
replace geo2 = "" if geo2 == "NYAKIBALE" & bb_4_clean == "IMMACULATE HEART GIRLS' SCHOOL" & bb_5_clean == 104

replace bb_4_clean = "SUNRISE HIGH SCHOOL" ///
	if (bb_4_clean == "SUN RISE SECONDARY SCHOOL"|bb_4_clean == "SUN RISE HIGH SCHOOL")			///
	& bb_5_clean == 106								

recode bb_5_clean 103 = 107 if bb_4_clean == "SHUUKU VOCATIONAL SECONDARY SCHOOL"

	*** SHEEMA
	
	recode bb_5_clean (22 = 107) if bb_4_clean == "SACRED HEART MUSHANGA SECONDARY SCHOOL"
	
replace bb_4_clean = "SACRED HEART SECONDARY SCHOOL" ///
	if (bb_4_clean == "SACRED HEART MUSHANGA SECONDARY SCHOOL")			///
	& bb_5_clean == 107	
replace geo2 = "MUSHANGA" if geo2 == "" & bb_4_clean == "SACRED HEART MUSHANGA SECONDARY SCHOOL" & bb_5_clean == 107

replace bb_4_clean = "RYAKASINGA CENTRE FOR H.EDUC." ///
	if (bb_4_clean == "RYAKASINGA CENTER FOR HIGH EDUCATION")			///
	& bb_5_clean == 107								

replace bb_4_clean = "JERESSAR HIGH SCHOOL" ///
	if (bb_4_clean == "JERRESAH HIGH SCHOOL"	///
	|bb_4_clean == "JERESA SECONDARY SCHOOL")			///
	& bb_5_clean == 109								

replace bb_4_clean = "SOROTI MUNICIPAL SECONDARY SCHOOL" ///
	if (bb_4_clean == "SOROTI MUNICIPALITY SECONDARY SCHOOL"	///
	|bb_4_clean == "MUNICIPEL SECONDARY SCHOOL")			///
	& bb_5_clean == 109								

replace bb_4_clean = "TESO COLLEGE ALOET" ///
	if (bb_4_clean == "TESO COLLEGE"	///
	|bb_4_clean == "TESO COLLEGE ALLOET")			///
	& bb_5_clean == 109								

replace bb_4_clean = "BETHANY GIRLS' COMP. SECONDARY SCHOOL" ///
	if (bb_4_clean == "BETHANY GIRLS' COMPREHENSIVE SECONDARY SCHOOL")			///
	& bb_5_clean == 109								

replace bb_4_clean = "TORORO GIRLS' SCHOOL" ///
	if (bb_4_clean == "TORORO GIRL SECONDARY SCHOOL"|bb_4_clean == "TORORO GIRLS' SECONDARY SCHOOL")			///
	& bb_5_clean == 110								

replace bb_4_clean = "ROCK HIGH SCHOOL" ///
	if (bb_4_clean == "ROCK HIGH SECONDARY SCHOOL")			///
	& bb_5_clean == 110								

replace bb_4_clean = "GREAT AUBREY MEMORIAL COLLEGE" ///
	if (bb_4_clean == "GREAT ABRIEL"	///
	|bb_4_clean == "GRAET AUBREY MEMORIAL COLLEGE")			///
	& bb_5_clean == 110	

replace bb_4_clean = "PETTA COMMUNITY SECONDARY SCHOOL" ///
	if (bb_4_clean == "PETTA COMMUNITY SCHOOL")			///
	& bb_5_clean == 110								

	*** WAKISO
	
	recode bb_5_clean (44 = 111) if bb_4_clean == "BOSTON SECONDARY SCHOOL"
	replace bb_4_clean = "BOSTON HIGH SCHOOL" ///
	if (bb_4_clean == "BOSTON SECONDARY SCHOOL")			///
	& bb_5_clean == 111								

	recode bb_5_clean (44 = 111) if bb_4_clean == "GREEN STARS HIGH SCHOOL"
	replace bb_4_clean = "GREENSTARS HIGH SCHOOL" ///
	if (bb_4_clean == "GREEN STARS HIGH SCHOOL")			///
	& bb_5_clean == 111								
							

replace bb_4_clean = "KITEBI SECONDARY SCHOOL" ///
	if (bb_4_clean == "KITEBI SECONDARY SECONDARY")			///
	& bb_5_clean == 111								
recode bb_5_clean (111 = 44) if bb_4_clean == "KITEBI SECONDARY SCHOOL"

replace bb_4_clean = "GAYAZA HIGH SCHOOL" ///
	if (bb_4_clean == "GAYAZA SPHIRE HIGH SCHOOL")			///
	& bb_5_clean == 111								

replace bb_4_clean = "ST JULIAN HIGH SCHOOL" ///
	if (bb_4_clean == "ST JULIAN GAYAZA")			///
	& bb_5_clean == 111								

replace geo2 = "LWANGOSIA" if bb_4_clean == "ST PHILLIP'S SECONDARY SCHOOL" & bb_5_clean == 90
replace geo2 = "MIGADDE" if geo2 == "MIGADE" & bb_4_clean == "MAKERERE HIGH SCHOOL" & bb_5_clean == 111

replace bb_4_clean = "ST PETER'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST PETER'S NAALYA" ///
	| bb_4_clean == "ST PETER'S NAALYA SECONDARY SCHOOL"		///
	| bb_4_clean == "ST PETER'S NALYA")		///
	& bb_5_clean == 111
replace geo2 = "NAALYA" if geo2 == "" & bb_4_clean == "ST PETER'S SECONDARY SCHOOL" & bb_5_clean == 111

recode bb_5_clean (38 = 111) if bb_4_clean == "ST MARK'S COLLEGE NAMAGOMA"
recode bb_5_clean (75 = 111) if bb_4_clean == "ST MARK'S NAMAGOMA" | bb_4_clean == "ST MARK'S COLLEGE NAMAGOMA"
recode bb_5_clean (84 = 111) if bb_4_clean == "ST MARK'S SECONDARY SCHOOL" & geo2 =="NAMAGOMA"

replace bb_4_clean = "ST MARK'S COLLEGE NAMAGOMA" 		///
	if (bb_4_clean == "ST MARK'S COLLEGE NAMAGUNGA" ///
	| bb_4_clean == "ST MARK'S NAMAGOMA SECONDARY SCHOOL"		///
	| bb_4_clean == "ST MARK'S NAMAGOOMA"			///
	| bb_4_clean == "ST MARK'SCOLLEGE NAMAGOMA"		///
	| bb_4_clean == "ST MARK'S NAMAGOMA"			///
	| bb_4_clean == "ST MARK'S COLLEGE"				///
	| bb_4_clean == "ST MARK'S SECONDARY SCHOOL")		///
	& bb_5_clean == 111
replace geo2 = "" if bb_4_clean == "ST MARK'S COLLEGE NAMAGOMA" & bb_5_clean == 111

recode bb_5_clean (35 = 111) if  bb_4_clean == "ST THOMAS JINJA KAROLI SECONDARY SCHOOL" 
replace bb_4_clean = "ST THOMAS AQUINAS SECONDARY SCHOOL" if bb_4_clean == "ST THOMAS JINJA KAROLI SECONDARY SCHOOL"
replace geo2 = "KAWEMPE" if bb_4_clean == "ST THOMAS AQUINAS SECONDARY SCHOOL" & bb_5_clean == 111


replace bb_4_clean = "KING'S COLLEGE BUDO" ///
	if (bb_4_clean == "KINGS COLLEGE BUDDO"	///
	|bb_4_clean == "KINGS COLLEGE BUDO")			///
	& bb_5_clean == 111								

replace bb_4_clean = "TRINITY COLLEGE NABBINGO" ///
	if (bb_4_clean == "TRINITY COLLEGE NABINGO")			///
	& bb_5_clean == 111								

replace bb_4_clean = "AIRFORCE SECONDARY SCHOOL" ///
	if (bb_4_clean == "AIRFORCE HIGH SCHOOL")			///
	& bb_5_clean == 111								

replace bb_4_clean = "ST AUGUSTINE'S COLLEGE" ///
	if (bb_4_clean == "ST AGUSTINE'S COLLEGE")			///
	& bb_5_clean == 111								

replace bb_4_clean = "KENNEDY SECONDARY SCHOOL" ///
	if (bb_4_clean == "KENEDI SECONDARY SCHOOL")			///
	& bb_5_clean == 111								
replace geo2 = "KISUBI" if geo2 == "" & bb_4_clean == "KENNEDY SECONDARY SCHOOL" & bb_5_clean == 111

replace bb_4_clean = "EXCEL MILLENIUM HIGH SCHOOL" ///
	if (bb_4_clean == "EXCELL MILLENIUM HIGH SCHOOL"	///
	| bb_4_clean == "EXECEL SECONDARY SCHOOL")			///
	& bb_5_clean == 111								

replace bb_4_clean = "MERRYLAND HIGH SCHOOL" 		///
	if (bb_4_clean == "MERRY LAND HIGH SCHOOL" ///
	| bb_4_clean == "MARRYLAND HIGH SCHOOL"		///
	| bb_4_clean == "MARY LAND KIGUNGU")		///
	& bb_5_clean == 111

	// London College of St Lawrence, another one of the St Lawrence chain
replace bb_4_clean = "LONDON COLLEGE OF ST LAWRENCE" 		///
	if (bb_4_clean == "LANDAN COLLEGE OF ST LORENCE" ///
	| bb_4_clean == "LONDON COLLEGE"					///
	| bb_4_clean == "ST LAWRENCE LONDAN COLLEGE MAYA"	///
	| bb_4_clean == "ST LAWRENCE LONDON COLLEGE") ///
	& bb_5_clean == 111
	
	// St Lawrence Citizens Horizon Campus (located in Buddo), another one of the St Lawrence chain
recode bb_5_clean (75 = 111) if bb_4_clean == "ST LAWERENCE CITIZEN"
replace bb_4_clean = "ST LAWRENCE CITIZENS HORIZON CAMPUS" if bb_4_clean == "ST LAWERENCE CITIZEN"
replace geo2 = "HORIZON" if geo2 == "" & bb_4_clean == "ST LAWRENCE CITIZENS HORIZON CAMPUS"

replace bb_4_clean = "HANA MIXED SECONDARY SCHOOL" 		///
	if (bb_4_clean == "HANA MIXED SCHOOL" ///
	| bb_4_clean == "HANAH MIXED SCHOOL"		///
	| bb_4_clean == "HANNAH MIXED BOARDING NSANJI"		///
	| bb_4_clean == "HANAH MIXED SECONDARY SCHOOL"		///
	| bb_4_clean == "HANNA MIXED SECONDARY SCHOOL"		///
	| bb_4_clean == "HANNAH MIXED SCHOOL")		///
	& bb_5_clean == 111
replace geo2 = "" if geo2 == "NSANGI" & bb_4_clean == "HANA MIXED SECONDARY SCHOOL" & bb_5_clean == 111

replace bb_4_clean = "ST LUCIA HILL SCHOOL" 		///
	if (bb_4_clean == "ST LUCIA SECONDARY SCHOOL")		///
	& bb_5_clean == 111

replace bb_4_clean = "BETHEL COVENANT COLLEGE" 		///
	if (bb_4_clean == "BETHEL COVENANT SECONDARY SCHOOL")		///
	& bb_5_clean == 111

replace bb_4_clean = "KINAAWA HIGH SCHOOL" 		///
	if (bb_4_clean == "KINAAWA SECONDARY SCHOOL")		///
	& bb_5_clean == 111
replace geo2 = "MUGONGO" if geo2 == "" & bb_4_clean == "KINAAWA HIGH SCHOOL" & bb_5_clean == 111

replace geo2 = "ZZANA" if geo2 == "" & bb_4_clean == "STANDARD HIGH SCHOOL" & bb_5_clean == 111

	recode bb_5_clean (44 = 111) if bb_4_clean == "MARTIN LUTHER KING COLLEGE"
	
	** Naalya Secondary has 3 campuses: namugongo, bweyogerere and lugazi
replace bb_4_clean = "NAALYA SECONDARY SCHOOL NAMUGONGO" 		///
	if bb_4_clean == "NAALYA SECONDARY SCHOOL"		///
	& geo2 == "NAMUGONGO"							///
	& bb_5_clean == 111

replace bb_4_clean = "NAALYA SECONDARY SCHOOL NAMUGONGO" 		///
	if bb_4_clean == "NALIA AS NAMUGONGO"					///
	& bb_5_clean == 111

replace bb_4_clean = "NAALYA SECONDARY SCHOOL BWEYOGERERE" 		///
	if bb_4_clean == "NAALYA SECONDARY SCHOOL"		///
	& geo2 == "BWEYOGERERE"							///
	& bb_5_clean == 111

replace bb_4_clean = "KISUBI MAPEERA SECONDARY SCHOOL" 		///
	if (bb_4_clean == "KISUBI MAPEERA SCHOOL")		///
	& bb_5_clean == 111

replace bb_4_clean = "NANSANA ST JOSEPH'S SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ST JOSEPH'S NANSANA")		///
	& bb_5_clean == 111

replace bb_4_clean = "ZANA MIXED SECONDARY SCHOOL" 		///
	if (bb_4_clean == "ZANA MIXED SCHOOL")		///
	& bb_5_clean == 111

replace bb_4_clean = "UGANDA MARTYRS NAMUGONGO" 		///
	if (bb_4_clean == "UGANDA MARTRYS NAMUGONGO" ///
	| bb_4_clean == "UGANDA MARTYRS SECONDARY SCHOOL"		///
	| bb_4_clean == "UGANDA MARTYS' SECONDARY SCHOOL")		///
	& bb_5_clean == 111
replace geo2 = "" if geo2 == "NAMUGONGO" & bb_4_clean == "UGANDA MARTYRS NAMUGONGO" & bb_5_clean == 111

replace bb_4_clean = "JOVENS HIGH SCHOOL" 		///
	if (bb_4_clean == "ENTEBBE JOVENS HIGH SCHOOL")		///
	& bb_5_clean == 111

replace bb_4_clean = "NAMIREMBE HILLSIDE HIGH SCHOOL" 		///
	if (bb_4_clean == "NAMIREMBE HILL SIDE SCHOOL"		///
	|bb_4_clean == "NAMIREMBE HILLSIDE")		///
	& bb_5_clean == 111

	replace bb_4_clean = "ST MICHAEL INTERNATIONAL SCHOOL" 		///
	if (bb_4_clean == "ST MICHEAL"		///
	|bb_4_clean == "ST MICHEAL INTERNATIONAL"				///
	|bb_4_clean == "ST MICHEAL INTERNATIONAL SCHOOL"		///
	|bb_4_clean == "ST MICHAEL INTERNATIOAL")		///
	& bb_5_clean == 111

replace bb_4_clean = "ST MARY'S COLLEGE KISUBI" 		///
	if (bb_4_clean == "ST MARY'S S COLLEGE KISUBI")		///
	& bb_5_clean == 111
