version 13
set more off

clear all
clear mata

set seed 20200516

global cohortFE cohort2014
global districtFE i.NSC_intdcode

	* (Dataset below: product of Append, Apply NSC Criteria and Standardize. Before "Dataset Creation" which generates Analysis data.)


	* Take 2014 RCT Sample
	use "$caregiver_enc/data/Cohort2014_UCE_bytreatment.dta", clear
	keep if treatment == 0 | treatment == 1 /*Keep Applicants in RCT Only*/
	keep id surnameapp nameapp dcode hdcode intdcode treatment
	
	* Id - Make the id cohort-specific
	gen id_new = ""
	lab var id_new "Same as id but with cohort prefix"
	replace id_new = "14" + string(id)
	destring id_new, replace

	* Save in Tempfile
	tempfile Cohort2014_RCT_Sample
	save `Cohort2014_RCT_Sample'

	* Take 2015 RCT Sample
	use "$caregiver_enc/data/UCE_randomized.dta", clear 
	keep if treatment == 0 | treatment == 1 /*Keep Applicants in RCT Only*/
	keep id surname other_name dcode hdcode intdcode treatment
	rename surname surnameapp
	rename other_name nameapp
	
	* Id - Make the id cohort-specific
	gen id_new = ""
	lab var id_new "Same as id but with cohort prefix"
	replace id_new = "15" + string(id)
	destring id_new, replace
	
	* Save in Tempfile
	tempfile Cohort2015_RCT_Sample
	save `Cohort2015_RCT_Sample'
	
	* Append the two cohorts
	append using `Cohort2014_RCT_Sample'
	
	recode id_new (1415464 = 1413464) if surnameapp == "KATO"	& nameapp == "THOMAS"

	tempfile RCT_Sample
	save `RCT_Sample'
	
	use "$caregiver_enc/data/Cohort_2014_2015_StandardizedDataset.dta", clear
	merge m:1 id_new using `RCT_Sample'

	/*
	Result                           # of obs.
    -----------------------------------------
    not matched                           284
        from master                        32  (_merge==1)
        from using                        252  (_merge==2)

    matched                             4,152  (_merge==3)
    -----------------------------------------

	*/
	
	drop if _merge == 2
	
	drop _merge 
	
	*** Include selection dummies
	merge 1:1 id cohort2014 baseline using "$caregiver_enc/data/Cohort_2014_2015_finalselect.dta", nogen keepus(NSC_final_select NSC_intdcode final_select sex_app)

	*** Define Treatment Variables

	gen C_0 = (treatment_c == 0)
	gen T_0 = (treatment_c == 1)

	lab def treatment_assignment 1 "Treatment" 0 "Control"
	lab val treatment treatment_assignment

	lab var C_0 "Control in randomized assignment"
	lab var T_0 "Treatment in randomized assignment"

	*** Define "not found at followup" variable
	gen notfoundatFU = (attrited == 2)
	
	replace notfoundatFU = . if attrited == 1 | attrited == 3 /* if attrited at baseline or never found*/

	*** Add outcome variables for imputation
	keep 		id_new cohort2014 baseline dcode hdcode intdcode sex_app final_select NSC_intdcode NSC_final_select T_0 notfoundatFU gpslatitude gpslongitude gps1latitude gps1longitude

	merge 1:1 	id_new cohort2014 baseline sex_app final_select NSC_intdcode NSC_final_select T_0 using  "$caregiver_enc/data/Cohort2014_2015_AttritionAnalysis_Data.dta", keepus(out?_*  SCS* UNEB* index_*)

	/*

    Result                           # of obs.
    -----------------------------------------
    not matched                             0
    matched                             4,184  (_merge==3)
    -----------------------------------------

	*/
	
	sort id_new baseline sex_app
	replace sex_app = sex_app[_n+1] if id_new == id_new[_n+1] & sex_app == . /*(28 real changes made)*/
	
	save "$caregiver_enc/data/Cohort2014_2015_Data_ForTables.dta", replace
	
	***** Deidentify 

	capture unab audit: audit_*
	capture unab statement_of_consent: statement_of_consent_*
	capture unab start: start_* 
	capture unab end: end_*
	capture unab gps: gps*
	capture unab SCS_gps1: SCS_gps1*
	capture unab cl_e_name: cl_e*_name  
	capture unab cl_hhchd: cl_hhchd_* 
	capture unab cl_hhm: cl_hhm_* 
	capture unab cl_d3: cl_d3_* 
	capture unab cl_kid: cl_kid_* 
	capture unab cl_kid1: cl_kid1_* 
	capture unab o6_c: o6*_c 
	capture unab bb_4_201_c: bb_4_201*_c 
	capture unab bb_4_201_other: bb_4_201*_other 
	capture unab bb_4_201_other_c: bb_4_201*_other_c
	
	local metadata_vars deviceid data_phone subscriberid simid devicephonenum username duration caseid  `audit' `statement_of_consent' `start' `end' formdef_version submissiondate o6 starttime endtime start today q6_c
	
	foreach var of local metadatavars {
		
		capture drop `var'
	}

			
	local  identifymain_vars a1_c a2_c a4_c a5_c  a7_c a8_c app_name app_sur app_sur_c app_oth app_oth_c id_app_name_official id_app_name app_sur_2015_c app_new_name_c app_oth_2015_c app_bd_c app_bd_2015_c  resp_surname resp_surname_c resp_othername resp_othername_c app_mother app_father resp_surname_2015_c resp_othername_2015_c enu_name enu_code enu_name_check enu_name_checkfail aa1 aa4 tutor_oth_c tutor_sur_c village current_hh_vil_c current_hh_sub_c current_hh_boarding_c current_phone_c interview_gpslatitude interview_gpslongitude interview_gpsaltitude interview_gpsaccuracy `gps' interview_location_other interview_location_detail interview_location_detail_replac  aa9 loc_verify loc_verificationa10_1 loc_verificationa10 loc_verificationa11  loc_verificationa13 loc_verificationa14 `SCS_gps1' aa6_yes_nametrue aa6_yes_nametrue_c aa6_yes_othernametrue aa6_yes_othernametrue_c  a16_c a16a_c a16b_c a16d_c b8_c b9_c c3_2_c c3_11_c c3_21_c c4_2_c c4_11_c c4_21_c c8_b_1_c c8_b_2_c c8_b_3_c c8_b_4_c c3_7_c c4_7_c c8_e_1_c c8_e_2_c c8_e_3_c c8_e_4_c c3_6_c c4_6_c c3_5_c c4_5_c primary_phone_number_c secondary_phone_number_c other_phone_number_c intl_phone_number_c resp_phone1_c resp_phone2_c tutor_phone_c tutor_phone2_c aa6_yes_numbertrue1 aa6_yes_numbertrue1_c aa6_yes_numbertrue2 aa6_yes_numbertrue2_c aa6_yes_checktrue aa6_yes_checktrue_c aa6_yes_knownumbertrue aa6_yes_knownumbertrue_c aa6_yes_regtrue aa6_yes_regtrue_c aa6_yes_distrue aa6_yes_distrue_c aa6_yes_knowdirectionstrue aa6_yes_knowdirectionstrue_c aa6_yes_knowloctrue aa6_yes_knowloctrue_c aa6_yes_viltrue aa6_yes_viltrue_c aa6_yes_directionstrue aa6_yes_directionstrue_c aa6_no_other aa6_no_other_c a17_baseline_c a17_2_c a11_c a12_c a13_c a14_c   a14a_c uceresult_school_name SCS_schoolname2014 SCS_schoolname2015 SCS_schoolname2016 SCS_schoolname2017 UNEB_schoolname uceresult_index_number
    
	foreach var of local identifymain_vars {
		
		capture drop `var'
	}


	local identifyroster_vars `cl_e_name'  `cl_hhchd' `cl_hhm' `cl_d3' `cl_kid' `cl_kid1'  cl_chld_list cl_fchld_list cl_mem_list cl_fmem_list `o6_c' `bb_4_201_c' `bb_4_201_other' `bb_4_201_other_c'
	
	foreach var of local identifyroster_vars {
		
		capture drop `var'
	}

	save "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", replace
	
