use "$caregiver_enc/data/Cohort2014_2015_AttritionAnalysis_Data.dta", clear

preserve
keep id_new baseline cohort2014 sex_app out0_hhno final_select NSC_final_select attrited participation_c $HHroster $TREATvars $FEvars
reshape long cl_d3_ cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d8_ cl_d9_ cl_d10_ cl_d11_ cl_d12_ cl_d13_, i(id_new baseline) j(mmid)
tempfile HHroster
save `HHroster'
restore

preserve
keep id id_new baseline cohort2014 sex_app out0_hhno final_select NSC_final_select attrited participation_c cl_d3_* $EDUroster $TREATvars $FEvars
reshape long cl_d3_ cl_e2_ cl_e3_ cl_e4_ cl_e4a_ cl_e4a_2_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_ cl_e6b_ cl_e6c_ cl_e7a_ cl_e7b_ cl_e7c_ cl_e8_ cl_e9a_ cl_e9b_, i(id_new baseline) j(mmid)
tempfile EDUroster 
save `EDUroster'
restore

preserve
keep id id_new baseline cohort2014 sex_app out0_hhno final_select NSC_final_select attrited participation_c cl_d3_* $HEALTHroster $TREATvars $FEvars
reshape long cl_d3_ cl_f2_ cl_f3_a cl_f4_ cl_f5_ cl_f6_ cl_f7_ cl_f8_, i(id_new baseline) j(mmid)
tempfile HEALTHroster 
save `HEALTHroster'
restore

use `HHroster', clear
merge 1:1 id_new cohort2014 sex_app out0_hhno mmid baseline final_select NSC_final_select attrited participation_c cl_d3_ $TREATvars $FEvars using `EDUroster', nogen
merge 1:1 id_new cohort2014 sex_app out0_hhno mmid baseline final_select NSC_final_select attrited participation_c cl_d3_ $TREATvars $FEvars using `HEALTHroster', nogen

drop if cl_d4_ == . & cl_d5_ == . & cl_d6_ == . & cl_d7_ == . ///
& cl_d8_ == . & cl_d9_ == . & cl_d10_ == . & cl_d11_ == . & cl_d12_ == . 	///
& cl_d13_ == . /* All hh roster observations missing */

************************************
************ OUTCOME 0 *************
*********** DEMOGRAPHICS ***********
************************************

gen sex = cl_d4_
lab var sex "Gender"

 // Interaction btw treatment and sibling gender
gen t_x_ownsex = NSC_final_select*sex
gen tint_x_ownsex = T_0*sex
lab var t_x_ownsex "S $\times$ Gender"

gen head = cl_d5_
lab var head "Head"
gen age = cl_d6_
lab var age "Age"
gen rel = cl_d7_
lab var rel "Relationship"

gen appage = age if rel == 10
bysort id_new baseline: egen applicant_age = min(appage)
drop appage

gen older = (age > applicant_age)
lab var older "Older than Applicant"

gen x = age if age >=6 & age <=18
gsort id_new baseline -x
by id_new baseline : gen birthorder = _n if x != .
drop x
lab var birthorder "Birth order"

gen out0_lfp = (cl_d9_ < 36)
lab var out0_lfp "In labor force"

gen out0_daysworked = cl_d11_
lab var out0_daysworked "Days worked (past week)"

************************************
************ OUTCOME 1 *************
************ EDUCATION  ************
************************************

gen out1_edu = cl_d8_
recode out1_edu (18 = 0)
lab var out1_edu "Education"

gen out1_schoolage = (age >= 6 & age <= 18)
lab var out1_schoolage "Schooling age"

gen out1_childlabor = (out0_lfp == 1 & out1_schoolage == 1)
replace out1_childlabor = . if out1_schoolage == 0
lab var out1_childlabor "Youth in labor force"

gen out1_student = (cl_d9_ == 37)
recode out1_student (1 = 0) if age < 5 | age >= 40 
lab var out1_student "Occupation: Student"

gen out1_enrolled =  cl_e4_ 
lab var out1_enrolled "Enrolled"
recode out1_enrolled (.=0) if cl_e3_ == 0

gen out1_primary = (out1_edu > 0 & out1_edu <= 7) 
lab var out1_primary "Primary education"

 // Interaction btw treatment and early primary
gen t_x_primary = NSC_final_select*out1_primary
gen tint_x_primary = T_0*out1_primary
lab var t_x_primary "S $\times$ Primary"

gen out1_earlyprimary = (out1_edu > 0 & out1_edu < 5) 
lab var out1_earlyprimary "Early Primary education"

 // Interaction btw treatment and early primary
gen t_x_earlyprimary = NSC_final_select*out1_earlyprimary
gen tint_x_earlyprimary = T_0*out1_earlyprimary
lab var t_x_earlyprimary "T $\times$ Early Primary"

gen out1_lateprimary = (out1_edu >= 5 & out1_edu <= 7) 
lab var out1_primary "Late Primary education"

 // Interaction btw treatment and late primary
gen t_x_lateprimary = NSC_final_select*out1_lateprimary
gen tint_x_lateprimary = T_0*out1_lateprimary
lab var t_x_lateprimary "T $\times$ Late Primary"

gen out1_secondary = (out1_edu >= 8 & out1_edu <= 13) 
lab var out1_secondary "Secondary education"

 // Interaction btw treatment and secondary
gen t_x_secondary = NSC_final_select*out1_secondary
gen tint_x_secondary = T_0*out1_secondary
lab var t_x_secondary "S $\times$ Secondary"

gen out1_private = (cl_e5_ == 1| cl_e5_ == 2|cl_e5_ == 5|cl_e5_ == 6)
recode out1_private (0 = .) if  cl_e5_ == .
lab var out1_private "Private"

gen out1_govt = (cl_e5_ == 3| cl_e5_ == 4)
recode out1_govt (0 = .) if cl_e5_ == .
lab var out1_govt "Government"

egen out1_fees = rowtotal(cl_e6a_ cl_e6b_ cl_e6c_ cl_e7a_ cl_e7b_ cl_e7c_), missing
replace  out1_fees = . if cl_d6_ < 6 | cl_d6_ > 18 
lab var out1_fees "Total fees"

gen aggregate = cl_e8_
replace aggregate = .  if aggregate > 36 & out1_primary == 1 /* Primary aggregate ranges 4 to 36*/
replace aggregate = . if (aggregate < 8 | aggregate > 80) & out1_secondary == 1 /* Secondary aggregate ranges 8 to 80*/

sum aggregate if out1_primary == 1, d
gen out1_primaryagg = (aggregate - r(mean))/r(sd) if out1_primary == 1
sum aggregate if out1_secondary == 1, d
gen out1_secondaryagg = (aggregate - r(mean))/r(sd) if out1_secondary == 1
gen out1_aggregate = .
replace out1_aggregate = out1_primaryagg if out1_primary == 1
replace out1_aggregate = out1_secondaryagg if out1_secondary == 1
drop out1_primaryagg out1_secondaryagg
lab var out1_aggregate "Test Score"


gen out1_rank = cl_e9a_ / cl_e9b_
lab var out1_rank "Rank in class"

* Boarding school
gen out1_board = (cl_e5a_ == 1)
lab var out1_board "Boarding"

* Distance to school
gen out1_distance = cl_e5b_
lab var out1_distance "Distance"

*Top code distance at 99th percentile
_pctile out1_distance, p(99)
replace out1_distance = r(r1) if out1_distance > r(r1) & out1_distance != .


************************************
************ OUTCOME 6 *************
************ INCOME GENERATING ACTIVITIES  ************
************************************

/*
gen out6_occup_hhfarm = (cl_d9_ == 2 | cl_d9_ == 3 | cl_d9_ == 7 | cl_d9_ == 8) /*hh land and animals*/
gen out6_occup_daylabor = (cl_d9_ == 4 | cl_d9_ == 5 | cl_d9_ == 9) /*agri or other day laborer, maid*/
gen out6_occup_student = 37
gen out6_pettybusiness = (cl_d9_ ==
*/

* Deflate prices to 2014 Level, then adjust for 2014 PPP
local UGXvars out1_fees
local cpi_jan2014 = 140.784078765533
local cpi_jan2015 = 144.844204188531
local cpi_jan2016 = 155.529804184337
local cpi_jan2017 = 164.716214830046
local ppp_conversion2014 = 1020.40470669583

foreach monetaryvar in `UGXvars' {
	gen `monetaryvar'PPP = .
	
	/* Cohort 2014*/
	/* If baseline value, convert from 2015 to 2014 values*/
	replace `monetaryvar'PPP =(`monetaryvar'*(`cpi_jan2014'/`cpi_jan2014') )/`ppp_conversion2014' if baseline == 1 & cohort2014 == 1
	/* If followup value, convert from 2016 to 2014 values */
	replace `monetaryvar'PPP =(`monetaryvar'*(`cpi_jan2014'/`cpi_jan2016') )/`ppp_conversion2014' if baseline == 0 & cohort2014 == 1 

	/* Cohort 2015*/
	/* If baseline value, convert from 2015 to 2014 values*/
	replace `monetaryvar'PPP =(`monetaryvar'*(`cpi_jan2014'/`cpi_jan2015') )/`ppp_conversion2014' if baseline == 1 & cohort2014 == 0
	/* If followup value, convert from 2017 to 2014 values */
	replace `monetaryvar'PPP =(`monetaryvar'*(`cpi_jan2014'/`cpi_jan2017') )/`ppp_conversion2014' if baseline == 0 & cohort2014 == 0 
	
	local label : variable label `monetaryvar'
	label variable `monetaryvar'PPP `"`label' (USD)"'
	
	*Top code at 99th percentile
	_pctile `monetaryvar'PPP, p(99)
	replace `monetaryvar'PPP = r(r1) if `monetaryvar'PPP > r(r1) & `monetaryvar'PPP != .
}

*** GENERATE OUTCOMES FOR ANCOVA 
sort id_new mmid baseline 
unab outcomevars: out*
foreach outcome in `outcomevars' {
	gen `outcome'_b = `outcome' if baseline == 1
	local label : variable label `outcome'
	label variable `outcome'_b `"`label' (Pre)"'
	replace `outcome'_b = `outcome'_b[_n+1] if id == id[_n+1] & mmid == mmid[_n+1] & `outcome'_b == .
}

foreach var in sex age rel head applicant_age {
	gen `var'_b = `var' if baseline == 1
	local label : variable label `var'
	label variable `var'_b `"`label' (Pre)"'
	replace `var'_b = `var'_b[_n+1] if id == id[_n+1] & mmid == mmid[_n+1] & `var'_b == .
}

sort id_new mmid baseline
unab allrostervars: cl_* 						/* Packs all roster variables */
gettoken namevar allrostervars : allrostervars 	/* Eliminates cl_d3_ which is the string name variable */
local stringvars cl_e4a_oth_1 cl_e5a_oth_2 cl_e5a_oth_3 cl_e5a_oth_4 cl_e5a_oth_5 cl_e4a_oth_6 cl_e5a_oth_6 cl_e4a_oth_8 cl_e5c_oth_8 cl_e5a_oth_9
local allnumrostervars: list allrostervars - stringvars /*Eliminates stringvariables in "other" category*/

foreach var of local allnumrostervars {
	gen `var'_b =  `var' if baseline == 1
	replace `var'_b = `var'_b[_n+1] if id == id[_n+1] & mmid == mmid[_n+1] ///
		& `var'_b == .
}

save "$caregiver_enc/data/Cohort2014_2015_AttritionAnalysisRosters_Data.dta", replace

	***** Deidentify 

	drop cl_d3_

save "$caregiver_mast/data/Cohort2014_2015_AttritionAnalysisRosters_Data_deid.dta", replace
