/*-----------------------------------------------------------------------------*
* Title: CLEANING EDUCATION ROSTER - LONG TERM FOLLOW_UP (COHORT 2014 & 2015)                          
*                                                                                           
* Description: 	Cleans data for Applicant Long term Follow-up
* Cohort:		2014 and 2015 								         						 
* Start Date:	09/17/2023 	
* Status:		In progress
* End Data:																		
* Author:		Raaga Akkineni 										 						  
* Purpose: 		Cleans applicant data  
*
* Input: 		MCF_followup_2022_alum.dta
* Output: 		
*
*Note: Run master .do file to set up global macros
*-----------------------------------------------------------------------------*/

version 17
set more off

clear all
clear mata

use "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_HHRoster_long.dta" 

rename id id_new 
rename cl_d3_ name_hhmember
rename cl_d7_ relationship_hhmember


/*
preserve 

keep id_new name_hhmember relationship_hhmember

drop if name_hhmember == ""

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------+
  | Group    Obs   id_new   name_hhmem~r   relati~r |
  |-------------------------------------------------|
  |     1   1218   154160          Komol     Cousin |		// hh_mem_id: 25, 26 (everything but age same - 0,1) - ADD SEPERATELY
  |     1   1219   154160          Komol     Cousin |
  |     2   2093   158987   Kasule Hakim     Father |		// hh_mem_id: 2, 22 (everything but cl_hhm, cl_hhm_r, cl_d3_b same)
  |     2   2096   158987   Kasule Hakim     Father |		// looks like the same person recorded twice - DROP
  +-------------------------------------------------+

*/
restore
*/

** Fixing duplicate names and id problem by adding them as a seperate file
preserve 

keep if (id_new == 154160 & hh_mem_id == 26)  
drop hh_mem_id

tempfile temp1
save `temp1'

restore


** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 154160 & hh_mem_id == 26) | (id_new == 158987 & hh_mem_id == 22)


drop if name_hhmember == ""

drop hh_mem_id			// will merge to get the right memid 

tempfil temp2
save `temp2'


use "$caregiver_enc/data/Cohort2014_2015_LTFU_caregiver_pulldata.dta", clear

reshape long id_hhmember name_hhmember sex_hhmember age_hhmember relationship_hhmember exists_hhmember, i(id_new) j(hh_mem_id)

keep id_new hh_mem_id name_hhmember relationship_hhmember

drop if name_hhmember == ""


/*
drop hh_mem_id

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------------+
  | Group    Obs    id_new       name_hhmember   relati~r |
  |-------------------------------------------------------|
  |     1    698    145743       JOUSI KIKOBYE          5 |
  |     1    699    145743       JOUSI KIKOBYE          5 |		// everything but age (10, 20) same - ADD SEPERATELY
  |     2    706    145743    NAKATALE TAPENIS          5 |
  |     2    707    145743    NAKATALE TAPENIS          5 |		// everything but age (17, 15) same - ADD SEPERATELY
  |     3   3666    158969      Mukose Abraham          5 |
  |-------------------------------------------------------|
  |     3   3667    158969      Mukose Abraham          5 |		// everything but age (22, 15) same - ADD SEPERATELY
  |     4   8438   1516594   Kugonza Josephine          5 |
  |     4   8439   1516594   Kugonza Josephine          5 |		// everything same (except member id - hence two rows) - DROP! 
  +-------------------------------------------------------+
*/

*/


** Fixing duplicate names and id problem by adding them as a seperate file
preserve

keep if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5)

tempfile temp3
save `temp3'

restore



** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5) | (id_new == 1516594 & name_hhmember == "Kugonza Josephine" & hh_mem_id == 5)

merge 1:1 id_new name_hhmember relationship_hhmember using `temp2'

rename _merge merge

append using `temp1'
append using `temp3'			// Note: additional rows are from pull data file hence will not have additional information collected in LTFU

sort id_new hh_mem_id

by id_new:gen mem_id_new = _n
order mem_id_new , after (hh_mem_id)
drop hh_mem_id cl_d1 cl_new_mem cl_d3_exist_ cl_d3_all_ cl_d1_check 		///
	cl_hh_dhedk2 cl_mem_list cl_fmem_list cl_bam_total  // only in master data, ie pull data

reshape wide name_hhmember relationship_hhmember mem_id cl_d4_ cl_d5_ cl_d6_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_d6d_ cl_hhm_ cl_hhm_r_ cl_d3_b cl_c13_d3_b cl_when_dead_d3_b cl_how_dead_d3_b merge, i(id_new) j(mem_id_new) 

*
rename name_hhmember cl_d3_
rename relationship_hhmember cl_d7_

save "$caregiver_enc/data/RosterLTFU_Cohort_2014_2015_Cleaned_HHRoster_merge-wide.dta", replace