/*-----------------------------------------------------------------------------*
* Title: CLEANING EDUCATION ROSTER - LONG TERM FOLLOW_UP (COHORT 2014 & 2015)                          
*                                                                                           
* Description: 	Cleans data for Applicant Long term Follow-up
* Cohort:		2014 and 2015 								         						 
* Start Date:	09/17/2023 	
* Status:		In progress
* End Data:																		
* Author:		Raaga Akkineni 										 						  
* Purpose: 		Cleans applicant data  
*
* Input: 		MCF_followup_2022_alum.dta
* Output: 		
*
*Note: Run master .do file to set up global macros
*-----------------------------------------------------------------------------*/

version 17
set more off

clear all
clear mata

use "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_merge-long.dta" 

rename id id_new 
rename cl_d3_ name_hhmember
rename cl_d7_ relationship_hhmember

/*

/*
preserve 

keep id_new name_hhmember relationship_hhmember

drop if name_hhmember == ""

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------+
  | Group    Obs   id_new   name_hhmem~r   relati~r |
  |-------------------------------------------------|
  |     1   1218   154160          Komol     Cousin |		// hh_mem_id: 25, 26 (everything but age same - 0,1) - ADD SEPERATELY
  |     1   1219   154160          Komol     Cousin |
  |     2   2093   158987   Kasule Hakim     Father |		// hh_mem_id: 2, 22 (everything but cl_hhm, cl_hhm_r, cl_d3_b same)
  |     2   2096   158987   Kasule Hakim     Father |		// looks like the same person recorded twice - DROP
  +-------------------------------------------------+

*/
restore
*/

** Fixing duplicate names and id problem by adding them as a seperate file
preserve 

keep if (id_new == 154160 & hh_mem_id == 26)  
drop hh_mem_id

tempfile temp1
save `temp1'

restore


** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 154160 & hh_mem_id == 26) | (id_new == 158987 & hh_mem_id == 22)
*/

drop if name_hhmember == ""

drop mem_id			// will merge to get the right memid 

tempfil temp2
save `temp2'


use "$caregiver_enc/data/Cohort2014_2015_LTFU_caregiver_pulldata.dta", clear

reshape long id_hhmember name_hhmember sex_hhmember age_hhmember relationship_hhmember exists_hhmember, i(id_new) j(hh_mem_id)

keep id_new hh_mem_id name_hhmember relationship_hhmember

drop if name_hhmember == ""


/*
drop hh_mem_id

duplicates l
/*
Duplicates in terms of all variables

  +-------------------------------------------------------+
  | Group    Obs    id_new       name_hhmember   relati~r |
  |-------------------------------------------------------|
  |     1    698    145743       JOUSI KIKOBYE          5 |
  |     1    699    145743       JOUSI KIKOBYE          5 |		// everything but age (10, 20) same - ADD SEPERATELY
  |     2    706    145743    NAKATALE TAPENIS          5 |
  |     2    707    145743    NAKATALE TAPENIS          5 |		// everything but age (17, 15) same - ADD SEPERATELY
  |     3   3666    158969      Mukose Abraham          5 |
  |-------------------------------------------------------|
  |     3   3667    158969      Mukose Abraham          5 |		// everything but age (22, 15) same - ADD SEPERATELY
  |     4   8438   1516594   Kugonza Josephine          5 |
  |     4   8439   1516594   Kugonza Josephine          5 |		// everything same (except member id - hence two rows) - DROP! 
  +-------------------------------------------------------+
*/

*/



** Fixing duplicate names and id problem by adding them as a seperate file
preserve

keep if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5)

tempfile temp3
save `temp3'

restore


** Dropping to ensure id_new, name_hhmember and relationship_hhmember uniquely identify each row
drop if (id_new == 145743 & name_hhmember == "JOUSI KIKOBYE" & hh_mem_id == 7) | (id_new == 145743 & name_hhmember == "NAKATALE TAPENIS" & hh_mem_id == 6) | (id_new == 158969 & name_hhmember == "Mukose Abraham" & hh_mem_id == 5) | (id_new == 1516594 & name_hhmember == "Kugonza Josephine" & hh_mem_id == 5)


merge 1:1 id_new name_hhmember relationship_hhmember using `temp2'

rename _merge merge

**append using `temp1'
append using `temp3'			// Note: additional rows are from pull data file hence will not have additional information collected in LTFU

sort id_new hh_mem_id

by id_new:gen mem_id_new = _n
order mem_id_new , after (hh_mem_id)
drop hh_mem_id cl_d1 cl_d3_exist_ cl_d3_all_ merge? merge??	cl_hhmem_chk1 // only in master data, ie pull data

/*
reshape wide name_hhmember relationship_hhmember cl_d4_ cl_d5_ cl_d6_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_d6d_ cl_hhm_ cl_hhm_r_ cl_d3_b cl_c13_d3_b cl_when_dead_d3_b cl_how_dead_d3_b cl_hhchd_ cl_d6d_ cl_kid1_ cl_chld1_ cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e8a_y18_ cl_e8b_y18_ cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_ cl_fam_count cl_hhmem_chk cl_hhmem_chk1 cl_chld_list cl_chld_chk cl_chld1_total cl_key cl_applicant_final merge, i(id_new) j(mem_id_new) 
*/

drop cl_participation_c
reshape wide name_hhmember relationship_hhmember cl_hhm_ cl_d4_ cl_d5_ cl_d6_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_hhchd_ cl_d6d_ cl_kid1_ cl_chld1_ cl_e2_ cl_e3_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_ cl_hhm_r_ cl_d3_b cl_c13_d3_b cl_when_dead_d3_b cl_how_dead_d3_b cl_fam_count cl_hhmem_chk cl_d_13_1 cl_chld_list cl_chld_chk cl_chld1_total cl_key cl_applicant_final merge, i(id_new) j(mem_id_new)

*
rename name_hhmember* cl_d3_*
rename relationship_hhmember* cl_d7_*


gen ltfu = 1

append using "$caregiver_enc/data/Cohort_2014_2015_StandardizedDataset.dta"

**extending baseline dummy to include ltfu rows
replace baseline = 0 if baseline == . & ltfu == 1 

**extending ltfu dummy to include baseline and FU rows
replace ltfu = 0 if ltfu != 1 & ltfu == .	

save "$caregiver_enc/data/LTFU_Cohort_2014_2015_StandardizedDataset_cleaned_Roster.dta", replace
