*---------------------------------------------------------------------------*
*Description: 	Generate education outcomes for applicants					*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*				
*Input:			LTFU_Cohort_2014_2015_Cleaned_Roster_long.dta  				*
*																			*				
*Output:		LTFU2022_Cohort2014_2015_EduRoster_AnalysisData.dta			*	
*Note: 																		*
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on

*Upload dataset
use "$caregiver_enc/data/Roster/LTFU_Cohort_2014_2015_Cleaned_Roster_long.dta", clear

merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta",gen (_merge1)	


/*
    Result                      Number of obs
    -----------------------------------------
    Not matched                           300
        from master                         0  (_merge1==1)
        from using                        300  (_merge1==2)

    Matched                            42,940  (_merge1==3)
	-----------------------------------------
  */ 
  
*keep if cl_chld1_ == 1 // keep if child at ltfu (40,590 observations deleted)
 
***Siblings eligibility

gen out0_aged6to11 = (cl_d6_ >=6 & cl_d6_ < 12)
lab var out0_aged6to11 "Aged 6 to 11"

gen out0_aged12to18 = (cl_d6_ >=12 & cl_d6_ < 19)
lab var out0_aged12to18 "Aged 12 to 17"

gen out0_aged18orabv = (cl_d6_ >=19)
lab var out0_aged18orabv "Aged 18 and above"

gen out0_aged6to13 = (cl_d6_ >=6 & cl_d6_ < 14)
lab var out0_aged6to13 "Aged 6 to 13"

gen out0_aged14to19 = (cl_d6_ >=14 & cl_d6_ < 20)
lab var out0_aged14to19 "Aged 14 to 19"

gen out0_aged20orabv = (cl_d6_ >=20)
lab var out0_aged20orabv "Aged 20 and above"

gen out0_youngersib = . 
lab var out0_youngersib "Younger sibling" 

gen out0_oldersib = . 
lab var out0_oldersib "Older sibling" 

gen app_age_ =   cl_d6_ if cl_d7_ == 10
bysort id_new: egen app_age = max(app_age_) 		// age of the applicant

replace out0_youngersib = (cl_d6_ < app_age)		//FIXMEBL: does not include apps living outside the household
replace out0_oldersib = (cl_d6_ >= app_age)


keep if cl_chld1_ == 1 		// keeping only whose marked as "child" at LTFU 

**ENROLLED  
**Enrolled in School in 2022: All
gen out1_enrolled = (cl_e3_ == 1) if participation_c == 1 & cl_chld1_ == 1
lab var out1_enrolled "Enrolled"

gen out1_enrolled_22 = (cl_e4a_y22_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_22 "Enrolled 2022"

gen out1_enrolled_21 = (cl_e5a_y21_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_21 "Enrolled 2021"

gen out1_enrolled_20 = (cl_e6a_y20_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_20 "Enrolled 2020"

gen out1_enrolled_19 = (cl_e7a_y19_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_19 "Enrolled 2019"

gen out1_enrolled_18 = (cl_e8a_y18_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_18 "Enrolled 2018"

gen out1_enrolled_17 = (cl_e9a_y17_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_17 "Enrolled 2017"

gen out1_enrolled_16 = (cl_e10a_y16_ == 1) if participation_c == 1 & out1_enrolled == 1 & cl_chld1_ == 1
lab var out1_enrolled_16 "Enrolled 2016"

**Enrolled in School in 2022: Primary
gen out1_enrolled_pri = (cl_e4b_y22_ >= 1 & cl_e4b_y22_ <= 7) if participation_c == 1  & out1_enrolled == 1
lab var out1_enrolled_pri "Enrolled"

**Enrolled in School in 2022: Secondary
gen out1_enrolled_sec = (cl_e4b_y22_ >= 8 & cl_e4b_y22_ <= 15) if participation_c == 1 & out1_enrolled == 1
lab var out1_enrolled_sec "Enrolled"

**Enrolled in School in 2022: Tertiary
gen out1_enrolled_ter = (cl_e4b_y22_ >= 16 & cl_e4b_y22_ <= 19) if participation_c == 1  & out1_enrolled == 1
lab var out1_enrolled_ter "Enrolled"

**Years of education
**No education
gen out1_eduyears = 0 if cl_d8_ == 18 // no formal education obtained
lab var out1_eduyears "Years of Education"

**Primary and secondary education
forvalues i = 0(1)13 {				// Primary (7 years) and secondary (6 years)	
	    replace out1_eduyears = `i' if cl_d8_ == `i'
}

**Certificate, diploma and post secondary education
replace out1_eduyears =  10 if cl_d8_ == 14			// Post-primary/certificate - 3 years after primary education
replace out1_eduyears =  15 if cl_d8_ == 15			// Post-secondary/diploma - 2 years after secondary
replace out1_eduyears =  17 if cl_d8_ == 16			// Bachelors - an average of 4 years post senior secondary
replace out1_eduyears =  19 if cl_d8_ == 17			// Masters or higher - average 2 years post bachelors  

/*
**Replacing years of education from thh education roster (to fill in  missing observations from HH roster)
local j = 16
forvalues i = 10(-1)6 {				// var name	
	    replace out1_eduyears = cl_e`i'b_y`j'_ if participation_c == 1 & /* cl_e`i'a_y`j'_ == 1  & out1_enrolled == 1 & */ out1_eduyears == . 
		local j = `j' + 1
}
*/

**Last enrolled: Primary
gen out1_lenrolled_pri = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_pri = (cl_e`i'b_y`j'_ >= 1 & cl_e`i'b_y`j'_ <= 7) if participation_c == 1 & cl_e`i'a_y`j'_ == 1 & cl_e`i'b_y`j'_ != . & cl_e`i'b_y`j'_ != .d  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_lenrolled_pri "Enrolled Primary"

**Last enrolled: Secondary
gen out1_lenrolled_sec = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_sec = (cl_e`i'b_y`j'_ >= 8 & cl_e`i'b_y`j'_ <= 15) if participation_c == 1 & cl_e`i'a_y`j'_ == 1 & cl_e`i'b_y`j'_ != . & cl_e`i'b_y`j'_ != .d  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_lenrolled_sec "Enrolled Secondary"

**Last enrolled: Tertiary
gen out1_lenrolled_ter = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_ter = (cl_e`i'b_y`j'_ >= 16 & cl_e`i'b_y`j'_ <= 19) if participation_c == 1 & cl_e`i'a_y`j'_ == 1 & cl_e`i'b_y`j'_ != . & cl_e`i'b_y`j'_ != .d  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_lenrolled_ter "Enrolled Tertiary"

**Completed at LTFU
gen out1_primary_com_l= ((cl_d8_ >=7 & cl_d8_ <= 17) | cl_d8_ == 14 | out1_lenrolled_sec == 1) if cl_d8_ != . & cl_d8_ != 99 & out1_eduyears != . & participation_c == 1 
lab var out1_primary_com_l "Completed Primary"
gen out1_secondary_com_l = (cl_d8_ == 13 | (cl_d8_ >=15 & cl_d8_ < 18) | out1_lenrolled_ter == 1) if /* cl_d8_ != . & cl_d8_ != 99  & *//*  cl_d8_ != 14 /* & cl_d8_ != 18 */  & */ out1_eduyears != . & participation_c == 1
lab var out1_secondary_com_l "Completed Secondary"
gen out1_tertiary_com_l= (cl_d8_ == 16 | cl_d8_ == 17 ) if cl_d8_ != . & cl_d8_ != 99  & out1_eduyears != . & participation_c == 1
lab var out1_tertiary_com_l "Completed Tertiary"

**Attended by LTFU
gen out1_primary_att = (out1_primary_com_l == 1 | out1_secondary_com_l == 1 | out1_tertiary_com_l == 1) if out1_eduyears != . 
local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_primary_att = 1 if (cl_e`i'b_y`j'_ >= 1 & cl_e`i'b_y`j'_ <= 7) & participation_c == 1  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_primary_att "Attended Primary"

gen out1_secondary_att = (out1_secondary_com_l == 1 | out1_tertiary_com_l == 1) if out1_eduyears != .
local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_secondary_att = 1 if (cl_e`i'b_y`j'_ >= 8 & cl_e`i'b_y`j'_ <= 15) & participation_c == 1  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_secondary_att "Attended Secondary"
 



**Last year enrolled
gen out1_enrolled_year = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_enrolled_year = 20`j' if participation_c == 1 & cl_e`i'a_y`j'_ == 1  & out1_enrolled == 1
		local j = `j' + 1
}
lab var out1_enrolled_year "Enrolled last (Year)"

**School Fees: All
egen out1_fees = rowtotal(cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_), missing 
lab var out1_fees "School Fees"

**School Fees: Last enrolled in Primary
gen out1_fees_pri = out1_fees if participation_c == 1 & out1_lenrolled_pri == 1 
lab var out1_fees_pri "School Fees"

gen out1_fees_sec = out1_fees if participation_c == 1 & out1_lenrolled_sec == 1 
lab var out1_fees_sec "School Fees"

**Private Schoool: All 
gen out1_private = (cl_e5_ == 1 | cl_e5_ == 2 | cl_e5_ == 5 | cl_e5_ == 6) if participation_c == 1 & out1_enrolled == 1
replace out1_private = . if participation_c == 0
lab var out1_private "Private School"

**Private Schoool: Last enrolled in Primary
gen out1_private_pri = out1_private if participation_c == 1 & out1_lenrolled_pri == 1 
lab var out1_private_pri "Private School"

**Private Schoool: Last enrolled in Secondary
gen out1_private_sec = out1_private if participation_c == 1 & out1_lenrolled_sec == 1
lab var out1_private_sec "Private School"




********************************************************************************
** 				CONVERTING MONEY VALUES FROM 2022 USD PPP					  **
********************************************************************************
**Converting money values to 2022 USD PPP 
local 2014standardexchangerate	= 2599.79
local 2015standardexchangerate	= 3240.65
local 2016standardexchangerate	= 3420.10
local 2017standardexchangerate	= 3611.22
local 2018standardexchangerate	= 3727.07
local 2019standardexchangerate	= 3704.05
local 2020standardexchangerate	= 3718.25
local 2021standardexchangerate	= 3587.05
local 2022standardexchangerate	= 3689.82

local 2018PPPexchangerate 		= 1153.90			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local 2016PPPexchangerate		= 1211.94		
local 2017PPPexchangerate		= 1270.60
local 2018PPPexchangerate		= 1295.91			//FIXMEBL: To discuss		
local 2019PPPexchangerate		= 1311.27		
local 2020PPPexchangerate		= 1329.60
local 2021PPPexchangerate		= 1304.82		
local 2022PPPexchangerate		= 1278.43		

local USinflation2013to2014		= 0.0175			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local USinflation2014to2018		= 0.0149
local USinflation2014to2015		= 0.0189
local USinflation2014to2016		= 0.0148
local USinflation2014to2017		= 0.0135
local USinflation2015to2018		= 0.0136
local USinflation2016to2018		= 0.0150
local USinflation2017to2018		= 0.0190
**additions for ltfu
local USinflation2014to2022		= 0.0197		
local USinflation2015to2022		= 0.0199
local USinflation2016to2022		= 0.0215
local USinflation2017to2022		= 0.0238
local USinflation2018to2022		= 0.0215
local USinflation2019to2022		= 0.0238
local USinflation2020to2022		= 0.0215
local USinflation2021to2022		= 0.0238


local UGXvars out1_fees out1_fees_pri out1_fees_sec

 foreach monetaryvar in `UGXvars' {
 	
	di "`monetaryvar'"
 	
 	gen `monetaryvar'SYstex = .
	gen `monetaryvar'2022stex = .
	gen `monetaryvar'PPP_2022 = .

forvalues i = 16(1)22 {	
	replace `monetaryvar'SYstex 	= (`monetaryvar'/`20`i'standardexchangerate') if out1_enrolled_year == 20`i' & `monetaryvar'!=. 
	replace `monetaryvar'2022stex  	= `monetaryvar'SYstex*((1+`USinflation2016to2022')^(22-`i')) if out1_enrolled_year == 20`i'
	replace `monetaryvar'PPP_2022  	= `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate') 
}	
	
	**Saving the label
	local label : variable label `monetaryvar'
	label variable `monetaryvar'PPP_2022 `"`label'"'
	
	**Top coding at 99th percentile
	_pctile `monetaryvar'PPP_2022, p(99)
	replace `monetaryvar'PPP_2022 = r(r1) if `monetaryvar'PPP_2022 > r(r1) & `monetaryvar'PPP_2022 != .
 
 } 


/*
**Saving var labels before collapse
foreach v of var out1_enrolled out1_enrolled_22 out1_enrolled_21 out1_enrolled_20 out1_enrolled_19 out1_enrolled_18 out1_enrolled_17 out1_enrolled_16 out1_enrolled_pri out1_enrolled_sec out1_enrolled_ter out1_fees out1_private participation_c T_0 sex_app cl_e3_ {
	local l`v' : variable label `v'
       if `"`l`v''"' == "" {
		local l`v' "`v'"
 	}
 }

 
collapse out1_enrolled out1_enrolled_22 out1_enrolled_21 out1_enrolled_20 out1_enrolled_19 out1_enrolled_18 out1_enrolled_17 out1_enrolled_16 out1_enrolled_pri out1_enrolled_sec out1_enrolled_ter out1_fees out1_private participation_c T_0 sex_app cl_e3_, by(id_new)

**Updating var labels post collapse

foreach v of var out1_enrolled out1_enrolled_22 out1_enrolled_21 out1_enrolled_20 out1_enrolled_19 out1_enrolled_18 out1_enrolled_17 out1_enrolled_16 out1_enrolled_pri out1_enrolled_sec out1_enrolled_ter out1_fees out1_private participation_c T_0 sex_app cl_e3_{
	label var `v' `"`l`v''"'
 }
*/

drop if cl_d7_ == 10 		// (492 observations deleted) dropping applicant data, only need sibling data   

keep id_new T_0 sex_app cl_e3_ out0_*  out1_* participation_c 

save "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_EduRoster_AnalysisData_deid.dta", replace	