*---------------------------------------------------------------------------*
*Description: 	Generate outcomes for sibling data*							*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*				
*Input:			LTFU_Cohort_2014_2015_StandardizedDataset_cleaned_Roster.dta*
*				LTFU_Cohort_2014_2015_final_select.dta*						*
*																			*				
*Output:		LTFU2022_Cohort2014_2015_EduRoster_Analysis_SiblingData.dta	*	
*Note: 																		*
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on

*Upload dataset
use "$caregiver_enc/data/LTFU_Cohort_2014_2015_StandardizedDataset_cleaned_Roster.dta", clear

merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta",gen (_merge1)			

**Identifiers 	

// Names of hh members

gen id_resp_name = proper(strtrim(stritrim(a4_c + " " + a5_c)))
gen id_head_name = proper(strtrim(stritrim(a7_c + " " + a8_c)))
gen id_app_name = proper(strtrim(stritrim(a1_c + " " + a2_c)))


// ID of hh members

gen id_app 		= .
gen id_resp		= .
gen id_mother 	= .
gen id_father 	= .
gen id_head 	= .

forvalues x = 1(1)46 {
* Applicant
	capture replace id_app		= cl_mem_id`x' 	if cl_d7_`x' == 10 & id_app == .
* Respondent
	capture replace id_resp 	= cl_mem_id`x'	if id_resp_name == cl_d3_`x' & id_resp == .
* Mother
	capture replace id_mother	= cl_mem_id`x' 	if cl_d7_`x' == 2 & id_mother 	== .
* Father
	capture replace id_father	= cl_mem_id`x' 	if cl_d7_`x' == 1 & id_father 	== .
* Head
	capture replace id_head		= cl_mem_id`x' 	if cl_d5_`x' == 1 & id_head 	== .
}

 // Gender of hh members

gen id_head_sex = .
gen id_resp_sex = .
gen id_app_sex	= .


forvalues x = 1(1)46 {
	capture replace id_head_sex = cl_d4_`x' if id_head	 == `x'
	capture replace id_resp_sex = cl_d4_`x' if id_resp	 == `x'
	capture replace id_app_sex 	= cl_d4_`x' if id_app	 == `x'	
}

count if id_app == . /*2,366 households!!!*/	

/* Dummy = 1 if respondent is also household head */

gen resp_ishead = .

replace resp_ishead = (id_resp == id_head & id_resp != . & id_head != .)
replace resp_ishead = . 	if (id_resp == . | id_head == .)	/*Missing if any of the identifiers is*/


********************************************************************************
*							OUTCOME CREATION								   *
********************************************************************************

/*
gen out_primary == 1 if 
*/



*** GENERATE OUTCOMES FOR ANCOVA 
duplicates report id_new baseline ltfu		/*no duplicates reported*/
sort id_new ltfu baseline	
order id_new ltfu baseline

keep id_new ltfu baseline cl_*
drop cl_fam_count* cl_hhmem_chk* cl_hhmem_chk* cl_chld_list* cl_chld_chk* cl_key*

keep id_new ltfu baseline cl_d4_* cl_d5_* cl_d6_* cl_d7_* cl_d7oth_* cl_d8_* cl_d9_* cl_d9b_* cl_d10_* cl_d11_* cl_d12_* cl_d13_* cl_d13a_* cl_kid1_* cl_chld1_* cl_e2_* cl_e3_* cl_e4_* cl_e4a_y22_* cl_e4b_y22_* cl_e5a_y21_* cl_e5b_y21_* cl_e6a_y20_* cl_e6b_y20_* cl_e7a_y19_* cl_e7b_y19_* cl_e8a_y18_* cl_e8b_y18_* cl_e9a_y17_* cl_e9b_y17_* cl_e10a_y16_* cl_e10b_y16_* cl_e5_* cl_e5a_* cl_e5b_* cl_e5c_* cl_e6a_chk_* cl_e6b_chk_* cl_e6c_chk_* cl_e7a_chk_* cl_e7b_chk_* cl_e7c_chk_* cl_e8_* cl_e9a_* cl_e9b_* cl_e9c_* cl_kid1_* cl_hhchd_*

reshape long  cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_d13a_ cl_kid1_ cl_e2_ cl_e3_ cl_e4_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_ cl_hhchd_ cl_chld1_ cl_e5a_oth_ cl_e5c_oth_ cl_e5b_oth_, i(id_new ltfu baseline) j(mem_id)

gen round = 1 if baseline == 1 & ltfu == 0
replace round = 2 if baseline == 0 & ltfu == 0
replace round = 3 if baseline == 0 & ltfu == 1

drop cl_chld1_total*


reshape wide cl_d4_ cl_d5_ cl_d6_ cl_d7_ cl_d7oth_ cl_d8_ cl_d9_ cl_d9b_ cl_d10_ cl_d11_ cl_d12_ cl_d13_ cl_d13a_ cl_kid1_ cl_e2_ cl_e3_ cl_e4_ cl_e4a_y22_ cl_e4b_y22_ cl_e5a_y21_ cl_e5b_y21_ cl_e6a_y20_ cl_e6b_y20_ cl_e7a_y19_ cl_e7b_y19_ cl_e8a_y18_ cl_e8b_y18_ cl_e9a_y17_ cl_e9b_y17_ cl_e10a_y16_ cl_e10b_y16_ cl_e5_ cl_e5a_ cl_e5b_ cl_e5c_ cl_e6a_chk_ cl_e6b_chk_ cl_e6c_chk_ cl_e7a_chk_ cl_e7b_chk_ cl_e7c_chk_ cl_e8_ cl_e9a_ cl_e9b_ cl_e9c_ cl_hhchd_ cl_chld1_  cl_e5a_oth_ cl_e5c_oth_ ltfu baseline, i(id_new mem_id) j(round)

merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta",gen (_merge0)		

/*

    Result                      Number of obs
    -----------------------------------------
    Not matched                        30,452
        from master                    30,452  (_merge0==1)
        from using                          0  (_merge0==2)

    Matched                            65,780  (_merge0==3)
    -----------------------------------------
*/

drop ltfu1 ltfu2 baseline2 baseline3

/*
keep if cl_chld1_3 == 1 // keep only if "child" at LTFU (93,582 observations deleted)
 */

drop if cl_d7_3 == 10 // dropping if applicant (478 observations deleted)


/*******************************************************************************
							OUTCOME CREATION
*******************************************************************************/
**Edu at follow-up
gen out1_primary_f= (cl_d8_2 >=1 & cl_d8_2 <=7) if cl_d8_2 != .
gen out1_secondary_f = (cl_d8_2 >=8 & cl_d8_2 <=15) if cl_d8_2 != .
gen out1_tooyoung_f = (cl_d8_2 == 0) if cl_d8_2 != .

**EDU at ltfu
gen out1_enrolled_l = (cl_e3_3==1)
lab var out1_enrolled_l "Enrolled in School"

**Completed at LTFU
gen out1_primary_com_l= (cl_d8_3 >=7) if cl_d8_3 != . & cl_d8_3 != 99 
lab var out1_primary_com_l "Completed Primary"
gen out1_secondary_com_l = (cl_d8_3 >=13) if cl_d8_3 != . & cl_d8_3 != 99  & cl_d8_3 != 14 
lab var out1_secondary_com_l "Completed Secondary"
gen out1_tertiary_com_l= (cl_d8_3 == 16 | cl_d8_3 == 17 ) if cl_d8_3 != . & cl_d8_3 != 99
lab var out1_tertiary_com_l "Completed Tertiary"
 
**Last Attended at LTFU
gen out1_lenrolled_pri = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_pri = (cl_e`i'b_y`j'_3 >= 1 & cl_e`i'b_y`j'_3 <= 7) if participation_c == 1 & cl_e`i'a_y`j'_3 == 1 & cl_e`i'b_y`j'_3 != . & cl_e`i'b_y`j'_3 != .d 
		local j = `j' + 1
}
lab var out1_lenrolled_pri "Enrolled Primary"

**Last enrolled: Secondary
gen out1_lenrolled_sec = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_sec = (cl_e`i'b_y`j'_3 >= 8 & cl_e`i'b_y`j'_3 <= 15) if participation_c == 1 & cl_e`i'a_y`j'_3 == 1 & cl_e`i'b_y`j'_3 != . & cl_e`i'b_y`j'_3 != .d 
		local j = `j' + 1
}
replace out1_lenrolled_sec = 0 if out1_primary_com_l == 0			// Cannot be in secondary if not completed primary
lab var out1_lenrolled_sec "Enrolled Secondary"

**Last enrolled: Tertiary
gen out1_lenrolled_ter = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_lenrolled_ter = (cl_e`i'b_y`j'_3 >= 16 & cl_e`i'b_y`j'_3 <= 19) if participation_c == 1 & cl_e`i'a_y`j'_3 == 1 & cl_e`i'b_y`j'_3 != . & cl_e`i'b_y`j'_3 != .d 
		local j = `j' + 1
}
replace out1_lenrolled_ter = 0 if out1_lenrolled_ter == 0			// Cannot be in tertiary if not completed secondary
lab var out1_lenrolled_ter "Enrolled Tertiary"

**Last year enrolled
gen out1_enrolled_year = .

local j = 16
forvalues i = 10(-1)4 {				// var name	
	    replace out1_enrolled_year = 20`j' if participation_c == 1 & cl_e`i'a_y`j'_3 == 1 
		local j = `j' + 1
}
lab var out1_enrolled_year "Enrolled last (Year)"

**SCHOOL FEES
**School Fees: All
egen out1_fees = rowtotal(cl_e6a_chk_3 cl_e6b_chk_3 cl_e6c_chk_3 cl_e7a_chk_3 cl_e7b_chk_3 cl_e7c_chk_3), missing 
lab var out1_fees "School Fees"

**Converting money values to 2022 USD PPP 
local 2014standardexchangerate	= 2599.79
local 2015standardexchangerate	= 3240.65
local 2016standardexchangerate	= 3420.10
local 2017standardexchangerate	= 3611.22
local 2018standardexchangerate	= 3727.07
local 2019standardexchangerate	= 3704.05
local 2020standardexchangerate	= 3718.25
local 2021standardexchangerate	= 3587.05
local 2022standardexchangerate	= 3689.82

local 2018PPPexchangerate 		= 1153.90			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local 2016PPPexchangerate		= 1211.94		
local 2017PPPexchangerate		= 1270.60
local 2018PPPexchangerate		= 1295.91			//FIXMEBL: To discuss		
local 2019PPPexchangerate		= 1311.27		
local 2020PPPexchangerate		= 1329.60
local 2021PPPexchangerate		= 1304.82		
local 2022PPPexchangerate		= 1278.43		

local USinflation2013to2014		= 0.0175			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local USinflation2014to2018		= 0.0149
local USinflation2014to2015		= 0.0189
local USinflation2014to2016		= 0.0148
local USinflation2014to2017		= 0.0135
local USinflation2015to2018		= 0.0136
local USinflation2016to2018		= 0.0150
local USinflation2017to2018		= 0.0190
**additions for ltfu
local USinflation2014to2022		= 0.0197		
local USinflation2015to2022		= 0.0199
local USinflation2016to2022		= 0.0215
local USinflation2017to2022		= 0.0238
local USinflation2018to2022		= 0.0215
local USinflation2019to2022		= 0.0238
local USinflation2020to2022		= 0.0215
local USinflation2021to2022		= 0.0238


local UGXvars out1_fees

 foreach monetaryvar in `UGXvars' {
 	
	di "`monetaryvar'"
 	
 	gen `monetaryvar'SYstex = .
	gen `monetaryvar'2022stex = .
	gen `monetaryvar'PPP_2022 = .

forvalues i = 16(1)22 {	
	replace `monetaryvar'SYstex 	= (`monetaryvar'/`20`i'standardexchangerate') if out1_enrolled_year == 20`i' & `monetaryvar'!=. 
	replace `monetaryvar'2022stex  	= `monetaryvar'SYstex*((1+`USinflation2016to2022')^(22-`i')) if out1_enrolled_year == 20`i'
	replace `monetaryvar'PPP_2022  	= `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate') 
}	

	**Saving the label
	local label : variable label `monetaryvar'
	label variable `monetaryvar'PPP_2022 `"`label'"'

	**Top coding at 99th percentile
	_pctile `monetaryvar'PPP_2022, p(99)
	replace `monetaryvar'PPP_2022 = r(r1) if `monetaryvar'PPP_2022 > r(r1) & `monetaryvar'PPP_2022 != .
 
 } 
	

/*
keep if  participation_c == 1 & cl_chld1_3 == 1  // keep if child at ltfu ((93,582 observations deleted))
 */

/*
keep id_new T_0 sex_app out1_* NSC_intdcode cohort2014 participation_c 
*/

save "$caregiver_enc/data/LTFU2022_Cohort2014_2015_EduRoster_Analysis_SiblingData.dta", replace	

***** Deidentify
	
	drop cl_hhchd_* cl_kid1_* 
	

	save "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_EduRoster_Analysis_SiblingData_deid.dta", replace	
