
*---------------------------------------------------------------------------*
*Description: 	Generate outcome variables for analysis						*		
*																			* 
*Date:			10/10/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:			LTFU_Cohort_2014_2015_final_select.dta	     				*
*																			*
*Output:		LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta			*	
*Note: 													       				*
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

*Run the.do file to add educationg outcomes for ltfu from alum dataset
do "$caregiver_enc_gt/LTFU_2014_2015_EducationOutcome_merge.do"


merge m:1 id_new using "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta",gen (_merge1)	force		//adds only for ltfu == 1


**Dummy for those in control group
gen C_0 = (treatment_c == 0)

**Identifiers 	

// Names of hh members

gen id_resp_name = proper(strtrim(stritrim(a4_c + " " + a5_c)))
gen id_head_name = proper(strtrim(stritrim(a7_c + " " + a8_c)))
gen id_app_name = proper(strtrim(stritrim(a1_c + " " + a2_c)))


// ID of hh members

gen id_app 		= .
gen id_resp		= .
gen id_mother 	= .
gen id_father 	= .
gen id_head 	= .

forvalues x = 1(1)46 {
* Applicant
	capture replace id_app		= cl_mem_id`x' 	if cl_d7_`x' == 10 & id_app == .
* Respondent
	capture replace id_resp 	= cl_mem_id`x'	if id_resp_name == cl_d3_`x' & id_resp == .
* Mother
	capture replace id_mother	= cl_mem_id`x' 	if cl_d7_`x' == 2 & id_mother 	== .
* Father
	capture replace id_father	= cl_mem_id`x' 	if cl_d7_`x' == 1 & id_father 	== .
* Head
	capture replace id_head		= cl_mem_id`x' 	if cl_d5_`x' == 1 & id_head 	== .
}

 // Gender of hh members

gen id_head_sex = .
gen id_resp_sex = .
gen id_app_sex	= .


forvalues x = 1(1)46 {
	capture replace id_head_sex = cl_d4_`x' if id_head	 == `x'
	capture replace id_resp_sex = cl_d4_`x' if id_resp	 == `x'
	capture replace id_app_sex 	= cl_d4_`x' if id_app	 == `x'	
}

count if id_app == . /*2368 households!!!*/	

/* Dummy = 1 if respondent is also household head */

gen resp_ishead = .

replace resp_ishead = (id_resp == id_head & id_resp != . & id_head != .)
replace resp_ishead = . 	if (id_resp == . | id_head == .)	/*Missing if any of the identifiers is*/

********************************************************************************
****************************** PART II *****************************************
********************************************************************************


******************* OUTCOME 0: Demographics ********************

* No. of HH Members
gen out0_hhno =  cl_d1
lab var out0_hhno "No. of HH Members"

* Age/education of mother and father
gen out0_motherage = .
gen out0_fatherage = .
gen out0_caregiverage = .
gen out0_motheredu = .
gen out0_fatheredu = .
gen out0_caregiveredu = .

forvalues x = 1(1)46 {

	capture replace out0_fatherage = cl_d6_`x' if cl_d7_`x' == 1 & cl_mem_id`x' == `x' & out0_fatherage == .   	// code for father
	
	capture replace out0_motherage = cl_d6_`x' if cl_d7_`x' == 2 & cl_mem_id`x' == `x' & out0_motherage == .	// code for mother
	
	capture replace out0_caregiverage = cl_d6_`x' if cl_d7_`x' == a6_c & out0_caregiverage == .	// code for caregiver 
	
	capture replace out0_fatheredu = cl_d8_`x' if cl_d7_`x' == 1 & cl_mem_id`x' == `x' & out0_fatheredu == .	// code for father
	
	capture recode out0_fatheredu (18 = 0) /* 18 stands for "No Formal Education*/
	
	capture replace out0_motheredu = cl_d8_`x' if cl_d7_`x' == 2 & cl_mem_id`x' == `x' & out0_motheredu == .	// code for mother
	
	capture recode out0_motheredu (18 = 0)
	
	capture replace out0_caregiveredu = cl_d8_`x' if cl_d7_`x' == a6_c & out0_caregiveredu == .	// code for caregiver
	
	capture recode out0_caregiveredu (18 = 0)

}

replace out0_fatherage = .m if (out0_fatherage < 18 | out0_fatherage == 99) & out0_fatherage != .
replace out0_motherage = .m if (out0_motherage < 18 | out0_motherage == 99) & out0_motherage != . 
replace out0_caregiverage = .m if (out0_caregiverage < 18 | out0_caregiverage == 99) & out0_caregiverage != . 

* No. of dependents

forvalues x = 1(1)46 {
	capture gen dependent_`x' = 1 	 if cl_d6_`x' != . 	& (cl_d6_`x' < 15 | cl_d6_`x' > 64) 
	capture gen olddependent_`x' = 1 if cl_d6_`x' != .  & cl_d6_`x' > 64 
	capture gen yngdependent_`x' = 1 if cl_d6_`x' != .  & cl_d6_`x' < 15 
}

egen out0_dependents = rowtotal(dependent_*)
lab var out0_dependents "No. of dependents"
drop dependent_*

egen out0_olddependents = rowtotal(olddependent_*)
lab var out0_olddependents "No. of old dependents"
drop olddependent_*

egen out0_yngdependents = rowtotal(yngdependent_*)
lab var out0_yngdependents "No. of young dependents"
drop yngdependent_*

*Dependecy ratio 
gen out0_dependencyratio = out0_dependents/out0_hhno
lab var out0_dependencyratio "Dependency ratio"   // FIXMERA: tab and check accuracy


gen out0_appwork = b11_c		if ltfu == 0 & baseline != . 
lab var out0_appwork "Applicant works"
** Raaga's notes: app work in alum dataset for LTFU - possible outcome? 

gen out0_hhbrac = b13_c 		if ltfu == 0 & baseline !=.			
replace out0_hhbrac = aa12_c	if ltfu == 1 & baseline !=.	 // different question in ltfu
lab var out0_hhbrac "HH in BRAC program"

gen  out0_partner = n5_c		if ltfu == 0 & baseline !=.
lab var  out0_partner "Resp Living with partner"

* Poverty Score 

	gen out0_povscore09 = .
	gen out0_povscore09_c = .
	
	lab var out0_povscore09 "Poverty Score 09 - same calc as selection"
	lab var out0_povscore09_c "Poverty Score 09 - 2015 coding mistake corrected"

	*egen povscoreltfu = rowtotal(pov1_c pov2_c pov3_c pov4_c pov5_c pov6_c pov7_c pov8_c pov9_c pov10_c)
	
	
	*In Cohort2014 Baseline:
	
	egen povscore2014b = rowtotal(pov1_bl pov2_bl pov3_bl pov4_bl pov5_bl pov6_bl pov7_bl pov8_bl pov9_bl pov10_bl)
	
	replace out0_povscore09 	= povscore2014b if cohort2014 == 1 & baseline == 1
	replace out0_povscore09_c 	= povscore2014b if cohort2014 == 1 & baseline == 1

	

	* In Cohort2014 Followup
	egen povscore2014fu = rowtotal(pov1_fu09 pov2_fu09 pov3_fu09 pov4_fu09 pov5_fu09 pov6_fu09 pov7_fu09 pov8_fu09 pov9_fu09 pov10_fu09)

	replace out0_povscore09_c 	= povscore2014fu if cohort2014 == 1 & baseline == 0
	
	*In Cohort2015 baseline
	
	// note: pov4 and pov5 are coded wrongly (they follow the survey that was coded wrongly). The points assigned to questions on roof and wall are wrong. the povscore_09_c contains the corrected scoring. 
	
	// note: double checked with Cohort_2015/surveys/Output/hh_ple_ds_complete and povertyscore_09 is identical in every instance excluding 13 matched ids and 9 using only id. In 21 cases one is missing and the other is not. In 1 case there is a conflict which is large (80 in hh_ple_ds_complete vs 47 in my calculation). Overall: methodology is correct
	
	recode pov1_c (. = 0) if cl_fam_count>=6 & cl_fam_count != . & baseline == 1 & cohort2014 == 0
	recode pov1_c (. = 6) if (cl_fam_count==4 | cl_fam_count==5) & baseline == 1 & cohort2014 == 0
	recode pov1_c (. = 9) if cl_fam_count== 3 & baseline == 1 & cohort2014 == 0
	recode pov1_c (. = 14) if cl_fam_count== 2 & baseline == 1 & cohort2014 == 0
	recode pov1_c (. = 27) if cl_fam_count== 1 & baseline == 1 & cohort2014 == 0
	
	recode pov4_c (1 = 0) (2 = 5) if baseline == 1 & cohort2014 == 0

	egen del_pscore = rowtotal(pov2_c pov3_c pov4_c pov5_c pov6_c pov7_c pov8_c pov9_c pov10_c), missing
	replace out0_povscore09 = del_pscore if baseline == 1 & cohort2014 == 0
	drop del_pscore

	gen pov4_c_corr = pov4_c
	recode pov4_c_corr (0 = 5) (5 = 0) if baseline == 1 & cohort2014 == 0

	gen pov5_c_corr = pov5_c
	recode pov5_c_corr (0 = 2) (2 = 0) if baseline == 1 & cohort2014 == 0

	egen del_pscore_corr = rowtotal(pov1_c pov2_c pov3_c pov4_c_corr pov5_c_corr pov6_c pov7_c pov8_c pov9_c pov10_c), missing

	replace out0_povscore09_c = del_pscore_corr if baseline == 1 & cohort2014 == 0
	drop del_pscore_corr
	
	*In Cohort2015 followup	
	
	replace pov2_c = pov1_c if baseline == 0 & cohort2014 == 0
	
	replace pov1_c = . 		if baseline == 0 & cohort2014 == 0
	
	recode pov1_c (. = 0) 	if cl_fam_count>=6 & cl_fam_count != . & baseline == 0 & cohort2014 == 0
	recode pov1_c (. = 6) 	if (cl_fam_count==4 | cl_fam_count==5) & baseline == 0 & cohort2014 == 0
	recode pov1_c (. = 9) 	if cl_fam_count== 3 & baseline == 0 & cohort2014 == 0
	recode pov1_c (. = 14) 	if cl_fam_count== 2 & baseline == 0 & cohort2014 == 0
	recode pov1_c (. = 27) 	if cl_fam_count== 1 & baseline == 0 & cohort2014 == 0	

	recode pov4_c_corr (2 = 0) (1 = 5) (3 = 5) (4 = 5) if baseline == 0 & cohort2014 == 0
	recode pov5_c_corr (1 = 0) (3 = 0) (4 = 0) (5 = 0) (6 = 0) (7 = 2) (8 = 2) (9 = 0) 	if baseline == 0 & cohort2014 == 0
	recode pov6_c (2 = 11) (3 = 17) (4 = 17) 	if baseline == 0 & cohort2014 == 0
	recode pov8_c (1 = 7)  						if baseline == 0 & cohort2014 == 0
	recode pov9_c (1 = 5)  						if baseline == 0 & cohort2014 == 0
	recode pov10_c (1 = 9)  					if baseline == 0 & cohort2014 == 0

	egen del_pscore_corr = rowtotal(pov1_c pov2_c pov3_c pov4_c_corr pov5_c_corr pov6_c pov7_c pov8_c pov9_c pov10_c), missing
	
	replace out0_povscore09_c = del_pscore_corr if baseline == 0 & cohort2014 == 0
	drop del_pscore_corr
	
* Raaga's addition: Adding POV score for ltfu - for both cohorts - Caregiver 
	egen povscoreltfu = rowtotal(pov1_c pov2_c pov3_c pov4_c pov5_c pov6_c pov7_c pov8_c pov9_c pov10_c)
	
	replace out0_povscore09 	= povscoreltfu 	if ltfu == 1
	replace out0_povscore09_c 	= povscoreltfu if ltfu == 1
	
	
* Raaga's addition: Adding POV score for ltfu - for both cohorts - Alum
	egen out0_povscore09_a_c = rowtotal(pov1_a_c /* pov2_a_c */ c3a_a_c pov4_a_c pov5_a_c pov6_a_c pov7_a_c pov8_a_c pov9_a_c pov10_a_c) if alum == 1 & pov0_a_c == 0				// 277 applicants do not live in the same household as resp

* Rural/Urban Dummy
gen out0_urban = 1 if a15_c == 1 | a15_c == 2 /*1 = Urban; 2 = Semi-urban; 3 = Rural*/
recode out0_urban (. = 0) if a15_c == 3
lab var out0_urban "Urban"
lab def urban 1 "Urban or Semi-urban" 0 "Rural"
lab val out0_urban urban



************ OUTCOME 1: Education ************

**From Applicant dataset
**Sat ofr UCE and UACE



/*
out1_ucesat |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |        403       35.57       35.57
          1 |        730       64.43      100.00
------------+-----------------------------------
      Total |      1,133      100.00
*/


gen out1_ucesat = (c3_19_c == 1)			if ltfu ==1 & alum == 1 & participation_alum == 1
lab var out1_ucesat "Sat the UCE examination"

gen out1_uacesat = (c4_19_c	== 1)			if ltfu ==1 & alum == 1 & participation_alum == 1
lab var out1_uacesat "Sat the UACE examination"

**Completed O-levels and A levels
gen out1_olevel = (c0_c>=4)							if alum == 1 & participation_alum == 1

gen out1_alevel = (c0_c>=6 & c0_c!= 10) & out1_ucesat == 1  if ltfu ==1 & alum == 1 & participation_alum == 1 //Certificate = O-level	// 		

**Attended tertiary
gen out1_tertiary = ((c1_3_c>=7 & c1_3_c<=9) | c1_3_c == 13) & out1_ucesat == 1 & out1_uacesat == 1 if ltfu ==1 & alum == 1 & participation_alum == 1


**Update UCE and UACE scores
*UCE mock
gen out1_mock_uceaggregate = c3_13_c if c3_9_c == 1	& alum == 1
lab var out1_mock_uceaggregate "Mock UCE Score"

*UCE
gen out1_uceaggregate = c3_23_c if c3_19_c == 1 & out1_olevel == 1 & alum == 1			// 1 less observation that c3_23_c highest level complated is less than 4
lab var out1_uceaggregate "UCE Score"

*UACE mock
gen out1_mock_uaceaggregate = c4_13_c if c4_9_c == 1 & alum == 1
lab var out1_mock_uaceaggregate "Mock UACE Score"

*UACE
gen out1_uaceaggregate = c4_23_c if c3_19_c == 1 & c4_19_c == 1 & out1_alevel == 1	& alum == 1	// Alums need to sit for UCE and complete o-levels  to sit for a-level's, losing 9 observations since they did not meet this criteria + 17 don't know/refused to answer
lab var out1_uaceaggregate "UACE Score"

**Creating Division 1 dummies (UCE scores between 8-32)
gen out1_division1_self	= (c3_23b_c == 1 & out1_uceaggregate != .) 
replace out1_division1_self	= . if out1_uceaggregate == . | out1_uceaggregate == .m 
	
gen out1_division1_scores = (out1_uceaggregate >= 8 & out1_uceaggregate <= 32 & alum == 1)
replace out1_division1_scores = . if out1_uceaggregate == . | out1_uceaggregate == .m

*Creating a check to test descrepancies 
gen out1_division_compare = (( out1_division1_self != out1_division1_scores) & participation_alum == 1)	

**Creating top division for UACE
gen out1_uace_top_scores = (out1_uaceaggregate >= 15 & out1_uaceaggregate <= 20 & alum == 1)
replace out1_uace_top_scores = . if out1_uaceaggregate == . | out1_uaceaggregate == .m
		 

**From Caregiver dataset
// Applicant Enrollment
forvalues year = 14(1)22{							
	gen out1_appenrolled`year'	= .
	gen out1_applevel`year'		= .
	lab var out1_appenrolled`year' 	"Enrolled in 20`year'"
	lab var out1_applevel`year' 	"School level in 20`year'"
}
forvalues n0 = 14(1)15{
	local n1 = `n0'+2
	forvalues year = `n0'(1)`n1' {
			replace out1_appenrolled`year'	=	bb_1_20`year'_c		if cohort20`n0' == 1	& ltfu != 1
			replace out1_applevel`year' 	= 	bb_3_20`year'_c		if cohort20`n0' == 1	& ltfu != 1

	}
}

*For LTFU: if applicant if living in HH

forvalues x = 1(1)46{
	capture replace out1_appenrolled16	=	cl_e10a_y16_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel16 	=	cl_e10b_y16_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled17	=	cl_e9a_y17_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel17		=	cl_e9b_y17_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled18	=	cl_e8a_y18_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel18 	=	cl_e8b_y18_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled19	=	cl_e7a_y19_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel19		=	cl_e7b_y19_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled20	=	cl_e6a_y20_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel20 	=	cl_e6b_y20_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled21	=	cl_e5a_y21_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel21		=	cl_e5b_y21_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_appenrolled22	=	cl_e4a_y22_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
	capture replace out1_applevel22		=	cl_e4b_y22_`x'	if	ltfu	== 1	& cl_d7_`x'	== 10	& current_hh_c == 1
}

**Add information from alum dataset for alums not living in the household and if caregiver responded during ltfu
forvalues x = 16(1)22{
    forvalues i = 1(1)12{
	    replace out1_appenrolled`x' = 1 if 	c8_`i'_year_c == 20`x' & ltfu == 1 & current_hh_c == 0 & aa6 == 1 & participation_c == 1 & out1_appenrolled`x' == .
		replace out1_applevel`x' = `i'  if 	c8_`i'_year_c == 20`x' & ltfu == 1 & current_hh_c == 0 & aa6 == 1 & participation_c == 1 & out1_appenrolled`x' == 1 & out1_applevel`x' == .
	}		
}



**Enrolled at follow up
gen out1_appenrolled_fu = .
recode  out1_appenrolled_fu (. = 1) if out1_appenrolled16 == 1 & cohort2014 == 1 	& ltfu != 1
recode  out1_appenrolled_fu (. = 0) if out1_appenrolled16 == 0 & cohort2014 == 1	& ltfu != 1

recode  out1_appenrolled_fu (. = 1) if out1_appenrolled17 == 1 & cohort2014 == 0	& ltfu != 1
recode  out1_appenrolled_fu (. = 0) if out1_appenrolled17 == 0 & cohort2014 == 0	& ltfu != 1

lab var out1_appenrolled_fu "Enrolled"

gen out1_appyrsofedu_fu = .
lab var out1_appyrsofedu_fu "Years of Education"

	//Primary (7 years) + grade they were enrolled at year of followup  if enrolled at followup, or at previous years if enrolled before
	
replace out1_appyrsofedu_fu = 7 + out1_applevel16 if out1_appenrolled16 == 1 & cohort2014 == 1 & out1_applevel16 <= 6

replace out1_appyrsofedu_fu = 7 + out1_applevel15 if out1_appenrolled15 == 1 & out1_appenrolled16 == 0 & cohort2014 == 1 & out1_applevel15 <= 6 & out1_appyrsofedu_fu == .

replace out1_appyrsofedu_fu = 7 + out1_applevel14 if out1_appenrolled14 == 1 & out1_appenrolled15 == 0 & out1_appenrolled16 == 0 & cohort2014 == 1 & out1_applevel14 <= 6 & out1_appyrsofedu_fu == .

replace out1_appyrsofedu_fu = 7 + out1_applevel17 if out1_appenrolled17 == 1 & cohort2014 == 0 & out1_applevel17 <= 6

replace out1_appyrsofedu_fu = 7 + out1_applevel16 if out1_appenrolled16 == 1 & out1_appenrolled17 == 0 & cohort2014 == 0 & out1_applevel16 <= 6 & out1_appyrsofedu_fu == .

replace out1_appyrsofedu_fu = 7 + out1_applevel15 if out1_appenrolled15 == 1 & out1_appenrolled16 == 0 & out1_appenrolled17 == 0 & cohort2014 == 0 & out1_applevel15 <= 6 & out1_appyrsofedu_fu == .

**Enrolled at LTFU
*FIXMEBL: FYI: addition for LTFU (no differentiation between cohorts)
gen out1_appenrolled_ltfu = .
recode  out1_appenrolled_ltfu (. = 1) if out1_appenrolled22 == 1 	
recode  out1_appenrolled_ltfu (. = 0) if out1_appenrolled22 == 0	

lab var out1_appenrolled_ltfu "Enrolled at long term follow up"

gen out1_appyrsofedu_ltfu = .
lab var out1_appyrsofedu_ltfu "Years of Education"

gen out1_appenrolled = out1_appenrolled_ltfu == 1 if ltfu == 1
replace out1_appenrolled = 1 if out1_appenrolled_fu == 1 & ltfu == 0 & baseline == 0

//grade they were enrolled at year of followup  if enrolled at followup, or at previous years if enrolled before - not including +7 as primary years being captures in out1_applevel`x'
	
replace out1_appyrsofedu_ltfu = out1_applevel22 if out1_appenrolled22 == 1	& ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel21 if out1_appenrolled21 == 1 & out1_appenrolled22 == 0 & out1_appyrsofedu_ltfu == . & ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel20 if out1_appenrolled20 == 1 & out1_appenrolled21 == 0 & out1_appenrolled22 == 0 & out1_appyrsofedu_fu == . & ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel19 if out1_appenrolled19 == 1 & out1_appenrolled20 == 0 & out1_appenrolled21 == 0 & out1_appenrolled22 == 0 & out1_appyrsofedu_fu == . & ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel18 if out1_appenrolled18 == 1 & out1_appenrolled19 == 0 & out1_appenrolled20 == 0 & out1_appenrolled21 == 0 & out1_appenrolled22 == 0 & out1_appyrsofedu_fu == . & ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel17 if out1_appenrolled17 == 1 & out1_appenrolled18 == 0 & out1_appenrolled19 == 0 & out1_appenrolled20 == 0 & out1_appenrolled21 == 0 & out1_appenrolled22 == 0 & out1_appyrsofedu_fu == . & ltfu == 1

replace out1_appyrsofedu_ltfu = out1_applevel16 if out1_appenrolled16 == 1 & out1_appenrolled17 == 0 & out1_appenrolled18 == 0 & out1_appenrolled19 == 0 & out1_appenrolled20 == 0 & out1_appenrolled21 == 0 & out1_appenrolled22 == 0 & out1_appyrsofedu_fu == . & ltfu == 1


gen out1_appyrsofedu = out1_appyrsofedu_ltfu if ltfu == 1	
replace out1_appyrsofedu = out1_appyrsofedu_fu if ltfu == 0 & baseline == 0
replace out1_appyrsofedu = . if ltfu == 0 & baseline == 1

// Applicant Private/Boarding School
gen out1_app_privschool = .
lab var out1_app_privschool "Private School"
gen out1_app_board = .
lab var out1_app_board "Boarding School"

*FIXMEBL: How to for applicants not in HH?
forvalues x = 1(1)46 {
 cap recode out1_app_privschool (. = 1) if cl_d7_`x' == 10 & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)
 cap recode out1_app_privschool (. = 0) if cl_d7_`x' == 10 & (cl_e5_`x' == 3 | cl_e5_`x' == 4 | cl_e5_`x' == 88)
 cap recode out1_app_board (. = 1) if cl_d7_`x' == 10 & (cl_e5a_`x' == 1)
 cap recode out1_app_board (. = 0) if cl_d7_`x' == 10 & (cl_e5a_`x' == 2)
}


**For alums not in HH - A level school type if attended A level, if not, O level school type			// FIXMEBL: FYI 
recode out1_app_privschool (. = 1) if (c4_1_c == 1 | c4_1_c == 2 | c4_1_c == 5 | c4_1_c == 6) & (c1_3_c >= 6) & aa6 == 1 & participation_c == 1 
recode out1_app_privschool (. = 0) if (c4_1_c == 3 | c4_1_c == 4 | c4_1_c == 88) & (c1_3_c >= 6) & aa6 == 1 & participation_c == 1 

recode out1_app_privschool (. = 1) if (c3_1_c == 1 | c3_1_c == 2 | c3_1_c == 5 | c3_1_c == 6) & (c1_3_c == 4 & c1_3_c == 5) & aa6 == 1 & participation_c == 1 
recode out1_app_privschool (. = 0) if (c3_1_c == 3 | c3_1_c == 4 | c3_1_c == 88) & (c1_3_c == 4 & c1_3_c == 5) & aa6 == 1 & participation_c == 1 


forvalues x = 1(1)46 {
	capture gen schoolage_`x' = 1 		if cl_e2_`x' != .		& cl_e2_`x' != id_app & (`x' <24 | `x'>30)	
	
	capture gen inschool_`x' = 1  		if cl_e4_`x' == 1		& cl_e2_`x' != id_app & (`x' <24 | `x'>30)	& ltfu == 0
	capture replace inschool_`x' = 1		if cl_e4a_y22_`x'== 1 	& cl_e2_`x' != id_app & (`x' <24 | `x'>30) 	& ltfu == 1		// for LTFU: captures if family member went to school in 2022
}


*Total school expenditure
forvalues x = 1(1)46{
	capture egen toteduexp_`x' = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') if	ltfu == 0 & cl_e2_`x' == `x' & cl_e2_`x' != id_app
	capture replace toteduexp_`x' = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x')  if ltfu == 1 & cl_e2_`x' == `x' & cl_e2_`x' != id_app
} 



egen out1_schoolagekids = rowtotal(schoolage_*)
drop schoolage_*
lab var out1_schoolagekids "No. 6-18 children excluding applicant"

egen out1_kidsinschool = rowtotal(inschool_*)
drop inschool_*
lab var out1_kidsinschool "No. 6-18 children in school excluding applicant"

gen out1_shrinschool = out1_kidsinschool / out1_schoolagekids
lab var out1_shrinschool "Share 6-18 children in school"

egen out1_toteduexp = rowtotal(toteduexp_*)
drop toteduexp_*
lab var out1_toteduexp "Total education expenditure excluding applicant"

gen out1_eduexppc = (out1_toteduexp / out1_kidsinschool)
lab var out1_eduexppc "Per-child education expenditure"

forvalues x = 1(1)23 {
	capture egen toteduexp_app`x' = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') if cl_e2_`x' == `x' & cl_e2_`x' == id_app & ltfu == 0, missing
	capture replace  toteduexp_app`x' = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') if cl_e2_`x' == `x' & cl_e2_`x' == id_app & ltfu == 1, missing
}


*egen out1_eduexp_app = rowtotal(toteduexp_app*) if T_0 == 0
egen out1_eduexp_app = rowtotal(toteduexp_app*) if treatment_c == 0
lab var out1_eduexp_app "Education expenditure of applicant in control"

* Children of school age by gender excluding applicant
forvalues x = 1(1)46 {
	capture gen childschoolage_`x' = .
	capture gen girlschoolage_`x' = .
	capture gen boyschoolage_`x' = .
	capture recode childschoolage_`x' (. = 1) if 			   cl_d6_`x' >= 6 & cl_d6_`x' <= 18 & cl_d7_`x' != 10
	capture recode girlschoolage_`x'  (. = 1) if cl_d4_`x' == 0 & cl_d6_`x' >= 6 & cl_d6_`x' <= 18 & cl_d7_`x' != 10
	capture recode boyschoolage_`x'   (. = 1) if cl_d4_`x' == 1 & cl_d6_`x' >= 6 & cl_d6_`x' <= 18 & cl_d7_`x' != 10
	
	}

egen out1_totchild6_18 = rowtotal(childschoolage_*)
lab var out1_totchild6_18 "No. 6-18 children w/o applicant"
drop childschoolage_*
egen out1_totgirls6_18 = rowtotal(girlschoolage_*)
lab var out1_totgirls6_18 "No. 6-18 girls w/o applicant"
drop girlschoolage_*
egen out1_totboys6_18  = rowtotal(boyschoolage_*)
lab var out1_totboys6_18 "No. 6-18 boys w/o applicant"
drop boyschoolage_*

* Children of school age by gender including applicant
forvalues x = 1(1)46 {
	capture gen childschoolage_`x' = .
	capture gen girlschoolage_`x' = .
	capture gen boyschoolage_`x' = .
	capture recode childschoolage_`x' (. = 1) if 			   cl_d6_`x' >= 6 & cl_d6_`x' <= 18 
	capture recode girlschoolage_`x'  (. = 1) if cl_d4_`x' == 0 & cl_d6_`x' >= 6 & cl_d6_`x' <= 18
	capture recode boyschoolage_`x'   (. = 1) if cl_d4_`x' == 1 & cl_d6_`x' >= 6 & cl_d6_`x' <= 18
	
	}

egen out1_totallchild6_18 = rowtotal(childschoolage_*)
lab var out1_totallchild6_18 "No. 6-18 children w/ applicant"
drop childschoolage_*
egen out1_totallgirls6_18 = rowtotal(girlschoolage_*)
lab var out1_totallgirls6_18 "No. 6-18 girls w/ applicant"
drop girlschoolage_*
egen out1_totallboys6_18  = rowtotal(boyschoolage_*)
lab var out1_totallboys6_18 "No. 6-18 boys w/ applicant"
drop boyschoolage_*

* Share of children going to school by gender excluding applicant

forvalues x = 1(1)46{
	capture gen childschoolgoing_`x' = .
	capture gen girlschoolgoing_`x' = .
	capture gen boyschoolgoing_`x' = .
	capture recode childschoolgoing_`x' (. = 1) if 					cl_e2_`x' == `x' & cl_e4_`x' == 1 & cl_d7_`x' != 10
	capture recode girlschoolgoing_`x'  (. = 1) if cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_e4_`x' == 1 & cl_d7_`x' != 10
	capture recode boyschoolgoing_`x'   (. = 1) if cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_e4_`x' == 1 & cl_d7_`x' != 10
	}

egen out1_childinschool = rowtotal(childschoolgoing_*)
drop childschoolgoing_*
egen out1_girlsinschool = rowtotal(girlschoolgoing_*)
drop girlschoolgoing_*
egen out1_boysinschool = rowtotal(boyschoolgoing_*)
drop boyschoolgoing_*

gen out1_childshrinschool = out1_childinschool / out1_totchild6_18
lab var out1_childshrinschool "Share of 6-18 children in school w/o applicant"
gen out1_girlshrinschool = out1_girlsinschool / out1_totgirls6_18
lab var out1_girlshrinschool "Share of 6-18 girls in school w/o applicant"
gen out1_boyshrinschool  = out1_boysinschool / out1_totboys6_18
lab var out1_boyshrinschool "Share of 6-18 boys in school w/o applicant"

* Share of children going to school by gender including applicant

forvalues x = 1(1)46{
	capture gen childschoolgoing_`x' = .
	capture gen girlschoolgoing_`x' = .
	capture gen boyschoolgoing_`x' = .
	capture recode childschoolgoing_`x' (. = 1) if 					cl_e2_`x' == `x' & cl_e4_`x' == 1 
	capture recode girlschoolgoing_`x'  (. = 1) if cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_e4_`x' == 1 
	capture recode boyschoolgoing_`x'   (. = 1) if cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_e4_`x' == 1 
	}

egen out1_allchildinschool = rowtotal(childschoolgoing_*)
drop childschoolgoing_*
egen out1_allgirlsinschool = rowtotal(girlschoolgoing_*)
drop girlschoolgoing_*
egen out1_allboysinschool = rowtotal(boyschoolgoing_*)
drop boyschoolgoing_*

gen out1_allchildshrinschool = out1_allchildinschool / out1_totallchild6_18
lab var out1_allchildshrinschool "Share of 6-18 children in school w/ applicant"
gen out1_allgirlshrinschool = out1_allgirlsinschool / out1_totallgirls6_18
lab var out1_allgirlshrinschool "Share of 6-18 girls in school w/ applicant"
gen out1_allboyshrinschool  = out1_allboysinschool / out1_totallboys6_18
lab var out1_allboyshrinschool "Share of 6-18 boys in school w/ applicant"

* Share of children going to private school excluding applicant

forvalues x = 1(1)46{
	capture gen childpvtschool_`x' = .
	capture gen girlpvtschool_`x' = .
	capture gen boypvtschool_`x' = .
	capture recode childpvtschool_`x' (. = 1) if 				 cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)  & cl_d7_`x' != 10
	capture recode girlpvtschool_`x'  (. = 1) if cl_d4_`x' == 0 & cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)  & cl_d7_`x' != 10
	capture recode boypvtschool_`x'   (. = 1) if cl_d4_`x' == 1 & cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)  & cl_d7_`x' != 10
	}

egen out1_childpvtschool = rowtotal(childpvtschool_*)
drop childpvtschool_*
egen out1_girlpvtschool = rowtotal(girlpvtschool_*)	
drop girlpvtschool_*
egen out1_boypvtschool = rowtotal(boypvtschool_*)
drop boypvtschool_*

gen out1_childshrpvtschool = out1_childpvtschool/out1_childinschool
lab var out1_childshrpvtschool  "Share of children in private school w/o applicant"
gen out1_girlshrpvtschool  = out1_girlpvtschool/out1_childinschool
lab var out1_girlshrpvtschool  "Share of girls in private school w/o applicant"
gen out1_boyshrpvtschool   = out1_boypvtschool/out1_childinschool
lab var out1_boyshrpvtschool  "Share of boys in private school w/o applicant"

* Share of children going to private school including applicant

forvalues x = 1(1)46{
	capture gen childpvtschool_`x' = .
	capture gen girlpvtschool_`x' = .
	capture gen boypvtschool_`x' = .
	capture recode childpvtschool_`x' (. = 1) if 				 cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)  
	capture recode girlpvtschool_`x'  (. = 1) if cl_d4_`x' == 0 & cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6)  
	capture recode boypvtschool_`x'   (. = 1) if cl_d4_`x' == 1 & cl_e2_`x' == `x' & (cl_e5_`x' == 1 | cl_e5_`x' == 2 | cl_e5_`x' == 5 | cl_e5_`x' == 6) 
	}

egen out1_allchildpvtschool = rowtotal(childpvtschool_*)
drop childpvtschool_*
egen out1_allgirlpvtschool = rowtotal(girlpvtschool_*)	
drop girlpvtschool_*
egen out1_allboypvtschool = rowtotal(boypvtschool_*)
drop boypvtschool_*

gen out1_allchildshrpvtschool = out1_allchildpvtschool/out1_allchildinschool
lab var out1_allchildshrpvtschool  "Share of children in private school w/ applicant"
gen out1_allgirlshrpvtschool  = out1_girlpvtschool/out1_allchildinschool
lab var out1_allgirlshrpvtschool  "Share of girls in private school w/ applicant"
gen out1_allboyshrpvtschool   = out1_boypvtschool/out1_allchildinschool
lab var out1_allboyshrpvtschool  "Share of boys in private school w/ applicant"

	
* Share of children going to boarding school excluding applicant

forvalues x = 1(1)46{
	capture gen childbrdschool_`x' = .
	capture gen girlbrdschool_`x' = .
	capture gen boybrdschool_`x' = .
	capture recode childbrdschool_`x' (. = 1) if 				  cl_e2_`x' == `x' & cl_e5a_`x' == 1  & cl_d7_`x' != 10
	capture recode girlbrdschool_`x'  (. = 1) if cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_e5a_`x' == 1  & cl_d7_`x' != 10
	capture recode boybrdschool_`x'   (. = 1) if cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_e5a_`x' == 1  & cl_d7_`x' != 10
	}

egen out1_childbrdschool = rowtotal(childbrdschool_*)
drop childbrdschool_*
egen out1_girlbrdschool = rowtotal(girlbrdschool_*)	
drop girlbrdschool_*
egen out1_boybrdschool = rowtotal(boybrdschool_*)
drop boybrdschool_*

gen out1_childshrbrdschool = out1_childbrdschool/out1_childinschool
lab var out1_childshrbrdschool  "Share of children in boarding school"
gen out1_girlshrbrdschool  = out1_girlbrdschool/out1_childinschool
lab var out1_girlshrbrdschool  "Share of girls in boarding school"
gen out1_boyshrbrdschool   = out1_boybrdschool/out1_childinschool
lab var out1_boyshrbrdschool  "Share of boys in boarding school"

* Average km distance from school excluding applicant

forvalues x = 1(1)46{
	capture gen childdstschool_`x' = cl_e5b_`x' if 					 cl_e2_`x' == `x' & cl_d7_`x' != 10
	capture gen girldstschool_`x'  = cl_e5b_`x' if 	cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_d7_`x' != 10
	capture gen boydstschool_`x'   = cl_e5b_`x' if 	cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_d7_`x' != 10
	
	capture gen dchilddstschool_`x' = (childdstschool_`x' != .)
	capture gen dgirldstschool_`x'  = (girldstschool_`x' != .)
	capture gen dboydstschool_`x'   = (boydstschool_`x' != .)

}

egen out1_childdstschool = rowtotal(childdstschool_*)
drop childdstschool_*
egen out1_girldstschool  = rowtotal(girldstschool_*)
drop girldstschool_*
egen out1_boydstschool   = rowtotal(boydstschool_*)
drop boydstschool_*

egen out1_dchilddstschool = rowtotal(dchilddstschool_*)
drop dchilddstschool_*
egen out1_dgirldstschool  = rowtotal(dgirldstschool_*)
drop dgirldstschool_*
egen out1_dboydstschool   = rowtotal(dboydstschool_*)
drop dboydstschool_*

gen out1_childavgdstschool = out1_childdstschool/out1_dchilddstschool
lab var out1_childavgdstschool "Average distance from school"
gen out1_girlavgdstschool = out1_girldstschool/out1_dgirldstschool
lab var out1_girlavgdstschool "Average distance from school for girls"
gen out1_boyavgdstschool = out1_boydstschool/out1_dboydstschool
lab var out1_boyavgdstschool "Average distance from school for boys"

* Total expenditure in school excluding applicant

forvalues x = 1(1)46{
	capture egen childexpschool_`x' = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') if ltfu == 0 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing
	capture replace childexpschool_`x' = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') if ltfu == 1 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing
} 

egen out1_childexpschool = rowtotal(childexpschool_*), missing
drop childexpschool_*
lab var out1_childexpschool "Total education expenditure w/o applicant"

* Total expenditure in school including applicant

forvalues x = 1(1)46{
	capture egen childexpschool_`x' = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') ///
		if 				ltfu == 0 &	cl_e2_`x' == `x', missing	
	capture replace childexpschool_`x' = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') ///
		if 				ltfu == 1 &	cl_e2_`x' == `x', missing
}

egen out1_allchildexpschool = rowtotal(childexpschool_*), missing
drop childexpschool_*
lab var out1_allchildexpschool "Total education expenditure w/ applicant"

* Average expenditure per child in school excluding applicant

forvalues x = 1(1)46{
	capture egen girlexpschool_`x'  = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') ///
		if ltfu == 0 & cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing
	capture replace girlexpschool_`x'  = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') ///
		if ltfu == 1 & cl_d4_`x' == 0 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing	
		
	capture egen boyexpschool_`x'   = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') /// 
		if ltfu == 0 & cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing
	capture replace boyexpschool_`x'   = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') /// 
		if ltfu == 1 & cl_d4_`x' == 1 & cl_e2_`x' == `x' & cl_d7_`x' != 10, missing	
	
}

egen out1_girlexpschool  = rowtotal(girlexpschool_*), missing
lab var out1_girlexpschool "School expenditure for girls w/o applicant"
drop girlexpschool_*
egen out1_boyexpschool   = rowtotal(boyexpschool_*), missing
lab var out1_boyexpschool "School expenditure for boys w/o applicant"
drop boyexpschool_*

gen out1_girlshrexpschool = out1_girlexpschool/out1_childexpschool
lab var out1_girlshrexpschool "Share school expenditure for girls w/o applicant"
gen out1_boyshrexpschool = out1_boyexpschool/out1_childexpschool
lab var out1_boyshrexpschool "Share school expenditure for boys w/o applicant"

* Average expenditure per child in school including applicant

forvalues x = 1(1)46{
	capture egen girlexpschool_`x'  = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') ///
		if ltfu == 0 & cl_d4_`x' == 0 & cl_e2_`x' == `x' , missing
	capture replace girlexpschool_`x'  = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') ///
		if ltfu == 1 & cl_d4_`x' == 0 & cl_e2_`x' == `x' , missing
		
	capture egen boyexpschool_`x'   = rowtotal(cl_e6a_`x' cl_e6b_`x' cl_e6c_`x' cl_e7a_`x' cl_e7b_`x' cl_e7c_`x') /// 
		if ltfu == 0 & cl_d4_`x' == 1 & cl_e2_`x' == `x' , missing
	capture replace boyexpschool_`x'   = rowtotal(cl_e6a_chk_`x' cl_e6b_chk_`x' cl_e6c_chk_`x' cl_e7a_chk_`x' cl_e7b_chk_`x' cl_e7c_chk_`x') /// 
		if ltfu == 1 & cl_d4_`x' == 1 & cl_e2_`x' == `x' , missing
}

egen out1_allgirlexpschool  = rowtotal(girlexpschool_*), missing    
drop girlexpschool_*
egen out1_allboyexpschool   = rowtotal(boyexpschool_*), missing
drop boyexpschool_*

gen out1_allgirlshrexpschool = out1_allgirlexpschool/out1_allchildexpschool
lab var out1_allgirlshrexpschool "Share school expenditure for girls w/ applicant"
gen out1_allboyshrexpschool = out1_allboyexpschool/out1_allchildexpschool
lab var out1_allboyshrexpschool "Share school expenditure for boys w/ applicant"

*Education index
local eduvars out1_childexpschool out1_childshrinschool out1_childshrbrdschool out1_childshrpvtschool // check out1_eduexppc, variable generation not working			
swindex `eduvars', normby(C_0) gen(index_education)
lab var index_education "Education index"

*/


************ OUTCOME 2: Health **********************

*Raaga's notes: F section not included in LTFU
rename h13_c out2_familyplan 
lab var out2_familyplan "Family planning"
* Conditional on being sexually active

forvalues x = 1(1)46 {
	capture gen under5_`x' 		= 1 	if cl_f2_`x' != . & cl_f2_`x' != id_app & (`x' <24 | `x'>30 ) &   cl_d6_`x'<6
	
	capture gen dhiarrea_`x' 	= 1  	if cl_f4_`x' == 1 & under5_`x' == 1
	capture gen malaria_`x' 	= 1  	if cl_f5_`x' == 1 & under5_`x' == 1
	capture gen respissue_`x' 	= 1  	if cl_f6_`x' == 1 & under5_`x' == 1
	capture gen otherissue_`x' 	= 1  	if cl_f7_`x' == 1 & under5_`x' == 1
	capture gen anyissue_`x' 	= 1 if dhiarrea_`x' == 1|malaria_`x' == 1 |respissue_`x' == 1 |otherissue_`x' == 1
	
	* Health Expenditure
	capture gen healthexp_`x' 	= cl_f8_`x'  	if cl_f8_`x'  != . & under5_`x' == 1 	
	
	* Weight For Age
	capture gen weight_`x'		= cl_f3_a`x'  	if cl_f3_a`x' != . & under5_`x' == 1 	
	capture gen under5age_`x'	= cl_d6_`x'		if under5_`x' == 1 
	capture recode  under5age_`x' 			(0 = 0.5) 		 
	capture gen weight4age_`x' = weight_`x'/under5age_`x'
	
	capture drop under5age_`x' weight_`x'
}

 egen out2_weight4age = rowmean(weight4age_*)
 
 capture egen out2_healthexpunder5 = rowtotal(healthexp_*)
 
 foreach word in under5 dhiarrea malaria respissue otherissue anyissue {
 	
	 capture egen out2_`word'_no = rowtotal(`word'_*)
	 
	 drop `word'_*
	 
	 if "`word'" != "under5" {
	 	
		gen out2_shrund5_`word' = out2_`word'_no / out2_under5_no
		
		lab var out2_shrund5_`word' "Share of under 5 with issue `word' "
		
		drop out2_`word'_no
	 }
	
 }
  
lab var out2_under5_no "Number of children under 5"

* Children health: create index using share of children under 5 with disease
local childhealthvars out2_shrund5_dhiarrea out2_shrund5_malaria out2_shrund5_respissue out2_shrund5_otherissue out2_weight4age

swindex `childhealthvars', normby(C_0) gen(index_childhealth)		
lab var index_childhealth "Children Health Index"


************ OUTCOME 3: Dietary Diversity *******************

gen out3_nmeals = k1_c
lab var out3_nmeals "Number of Meals Score"
* Household Dietary Diversity (FANTA, USAID)

forvalues n = 2(1)17{
	gen out3_food`n' = .
	recode out3_food`n'  (. = 1) if k`n'a_c > 0 & k`n'a_c != .
	recode out3_food`n'  (. = 0) if k`n'a_c == 0 & k`n'a_c != .
}
gen out3_food18 = (out3_food3 == 1	| out3_food5 == 1| out3_food6 == 1)
gen out3_food19 = (out3_food12 == 1 	| out3_food13 == 1) 
lab var out3_food2 "Eat Cereals/Grains"
lab var out3_food4 "Eat Roots/Tubers"
lab var out3_food7 "Eat Red Meat"
lab var out3_food8 "Eat White Meat"
lab var out3_food9 "Eat Fish"
lab var out3_food10 "Eat Eggs"
lab var out3_food11 "Eat Dairy"
lab var out3_food14 "Eat Legumes"
lab var out3_food15 "Eat Sweets"
lab var out3_food16 "Eat Oils/Fats"
lab var out3_food17 "Eat Condiments"
lab var out3_food18 "Eat Vegetables"
lab var out3_food19 "Eat Fruits"

egen out3_hdd = rowtotal(out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19)
label var out3_hdd "Dietary Diversity Score"

local nutritionvars out3_hdd out3_nmeals
swindex `nutritionvars', normby(C_0) gen(index_nutrition)
lab var index_nutrition "Nutrition Index"

* Vitamin A-rich food consumption
gen out3_vitaminA = (out3_food3 == 1 | out3_food5 == 1 | out3_food12 == 1)
recode out3_vitaminA (. = 0) if out3_food3 == 1 & out3_food5 == 1 & out3_food12 == 1
label var out3_vitaminA "HH has Vitamin A-rich foods"

* Meat Consumption
gen out3_meat = (out3_food7 == 1 | out3_food8 == 1 | out3_food9 == 1)
recode out3_meat (. = 0) if out3_food7 == 1 & out3_food8 == 1 & out3_food9 == 1
label var out3_meat "HH has Fish/Meat"

************ OUTCOME 4: Assets ****************

egen out4_totincome = rowtotal(cl_d13_*)
lab var out4_totincome "Money earned by HH, past month"

gen out4_totincpercapita = out4_totincome/out0_hhno
lab var out4_totincpercapita "Per capita income"

* VALUE OF NON-LAND ASSETS (livestock, durable goods, savings)

*** Value of livestock (Cows, Small livestock (e.g., goats), Birds)

* Value of cows
gen out4_cowvalue = i5a3_c
recode out4_cowvalue (. = 0) if i5a1_c == 0 | i5a1_c == .
lab var out4_cowvalue "Cows Value"

* Value of small livestock
gen out4_goatsheepvalue = i6a3_c
recode out4_goatsheepvalue (. = 0) if i6a1_c == 0 | i6a1_c == .

gen out4_pigvalue = i7a3_c
recode out4_pigvalue (. = 0) if i7a1_c == 0 | i7a1_c == .

egen out4_smallanimalvalue = rowtotal(out4_goatsheepvalue out4_pigvalue)
lab var out4_smallanimalvalue "Sheep/Goat/Pig Value"

* Value of birds
gen out4_birdvalue = i8a3_c
recode out4_birdvalue (. = 0) if i8a1_c == 0 | i8a1_c == .
lab var out4_birdvalue "Chickens Value"

egen out4_livestockvalue = rowtotal(out4_cowvalue out4_smallanimalvalue out4_birdvalue)
lab var out4_livestockvalue "Livestock Value"

*** Value of durable goods (furniture, agricultural tools, radio/TV, bike/motorbike, appliances, cell phone).

* Value of furniture
egen out4_furniturevalue = rowtotal(i15a3_c i22a3_c)
lab var out4_furniturevalue "Furniture Value"

* Value of agricultural tools
gen out4_agritoolvalue = i4a3_c
recode out4_agritoolvalue (. = 0) if i4a1_c == 0 | i4a1_c == .
lab var out4_agritoolvalue "Agricultural Tools Value"

* Value of mobile phone
gen out4_mobilevalue = i12a3_c
recode out4_mobilevalue (. = 0) if i12a1_c == 0 | i12a1_c == .
lab var out4_mobilevalue "Mobile Phone Value"

* Value of radio/TV/Dvd Player/Computer/fridge
egen out4_appliancevalue = rowtotal(i9a3_c i10a3_c i11a3_c i13a3_c i14a3_c) 
lab var out4_appliancevalue "Appliances Value"

* Value of Bike 
gen out4_bikevalue = i16a3_c
recode out4_bikevalue (. = 0) if i16a1_c == 0 | i12a1_c == .
lab var out4_bikevalue "Bicycle Value"

* Value of Motorbike/Car
egen out4_motorvalue = rowtotal(i17a3_c i18a3_c)
lab var out4_motorvalue "Motorbike/Car Value"

*Value of machinery
gen out4_machineryvalue = i23a3_c
recode out4_machineryvalue (. = 0) if i23a1_c == 0 | i23a1_c == .
lab var out4_machineryvalue "Value of Machinery"

*Value of stock
gen out4_stockvalue = i24a3_c
recode out4_stockvalue (. = 0) if i24a1_c == 0 | i24a1_c == .
lab var out4_stockvalue "Value of Stock"

egen out4_durablevalue = ///
	rowtotal(out4_furniturevalue out4_agritoolvalue out4_appliancevalue  ///
	out4_mobilevalue out4_bikevalue out4_motorvalue out4_machineryvalue)
lab var out4_durablevalue "Durables Value"

*** Value of savings

egen out4_savingsvalue = rowtotal(m25_c m26_c m27_c m28_c m29_c m30_c m32_c)
lab var out4_savingsvalue "Savings"
egen out4_savingsvalue1 = rowtotal(m25_c m26_c m27_c m28_c m29_c m30_c m32_c), missing
lab var out4_savingsvalue1 "Savings, conditional on saving"


* VALUE OF NON-LAND ASSETS (livestock, durable goods, savings)

egen out4_nonlandvalue = rowtotal(out4_livestockvalue out4_durablevalue out4_savingsvalue), missing
lab var out4_nonlandvalue "Non-land assets"

* VALUE OF REAL ESTATE ASSETS 

*** Value of land (Includes land for business)
egen out4_landvalue = rowtotal(i1a3_c i3a3_c i20a3_c)
lab var out4_landvalue "Land Value"

gen out4_cultlandvalue = i3a3_c
recode out4_cultlandvalue (. = 0) if i3a1_c == 0
lab var out4_cultlandvalue "Cultivable Land"

egen out4_landvalue1 = rowtotal(i1a3_c i3a3_c i20a3_c), missing
lab var out4_landvalue1 "Land, Conditional on having some"

egen out4_landowned = rowtotal(i1a2_c i3a2_c)
lab var out4_landowned "Land owned (Acres)"

gen out4_cultlandowned = i3a2_c
recode out4_cultlandowned (. = 0) if i3a1_c == 0
replace out4_cultlandowned = . if i3a2_c == 99 
lab var out4_cultlandowned "Cultivable Land owned (Acres)"

gen out4_cultlandunitprice = i3a3_c / i3a2_c
replace out4_cultlandunitprice = . if i3a1_c != 1
replace out4_cultlandunitprice = . if i3a3_c == 99 | i3a2_c == 99 
lab var out4_cultlandunitprice "Land price per acre"

*Value of houses (includes houses for business)
egen out4_housevalue = rowtotal(i2a3_c i21a3_c)
lab var out4_housevalue "House Value"

gen out4_thatchroof = (pov4_c == 2 )
lab var out4_thatchroof "Thatch/Straw roof"			 

/*Unitary prices in each asset item*/				
forvalues n = 1(1)25 {
	gen out4_i`n'unitvalue =  i`n'a3_c / i`n'a2_c
	replace out4_i`n'unitvalue = . if i`n'a1_c != 1
	replace out4_i`n'unitvalue = . if i`n'a3_c == 99 |  i`n'a2_c == 99
	local name: variable label i`n'a1_c
	local name: subinstr local name "Do you/your household own a " ""
	local name: subinstr local name "Do you/your household own " ""
	local name: subinstr local name "Do you/your household have any " ""
	local name: subinstr local name "?" ""
	local name: subinstr local name " a " ""
	local name: subinstr local name "(S)" ""
	label variable out4_i`n'unitvalue "`name'"
}

drop out4_i19unitvalue out4_i25unitvalue  /*Other asset or business related item, too general*/

* Mistake in labeling
*lab var out4_i3unitvalue "Cultivable Land" // correct labeling

* Total business capital
egen out4_K = 	rowtotal(out4_landvalue out4_agritoolvalue 				///
			out4_cowvalue out4_smallanimalvalue out4_birdvalue				///
			out4_bikevalue out4_motorvalue out4_appliancevalue out4_furniturevalue 	///
			out4_mobilevalue out4_stockvalue			///
			out4_machineryvalue out4_housevalue)
lab var out4_K "Capital"

* Total asset value
egen out4_totalasset = rowtotal(out4_nonlandvalue out4_landvalue out4_housevalue)

* Asset Dummies

foreach asset in land cow smallanimal bird furniture agritool mobile bike motor appliance machinery stock house {
	gen out4_`asset'D = (out4_`asset'value >0)
	local itemname: var lab  out4_`asset'value
	local itemname : subinstr local itemname " Value" ""	
	lab var out4_`asset'D "Own `itemname'"
}

* Asset Index and Value

local assetvars out4_landvalue out4_agritoolvalue out4_cowvalue out4_smallanimalvalue out4_birdvalue out4_bikevalue out4_motorvalue out4_appliancevalue out4_furniturevalue 	out4_mobilevalue out4_stockvalue out4_machineryvalue out4_housevalue 
swindex `assetvars', normby(C_0) gen(index_assets)
lab var index_assets "Assets Index"

egen out4_assetvalue = rowtotal(`assetvars')
lab var out4_assetvalue "Assets Value"

local prodassetvars out4_cultlandvalue out4_agritoolvalue out4_cowvalue out4_smallanimalvalue out4_birdvalue out4_bikevalue out4_motorvalue out4_appliancevalue	out4_mobilevalue out4_stockvalue out4_machineryvalue
swindex `prodassetvars', normby(C_0) gen(index_prodassets)
lab var index_prodassets "Productive Assets Index"

egen out4_prodassetvalue = rowtotal(`prodassetvars')
lab var out4_prodassetvalue "Productive Assets Value"


************************************
************ OUTCOME 5 *************
****** NON-DURABLE EXPENDITURE******
************************************


gen out5_foodexp =  i28_c * 4					 
lab var out5_foodexp "Food Expenditures"

	*Student in boarding school does not consume food at home (but we only know if in boarding school at follow-up)
	gen current_hhno = .
	replace current_hhno = out0_hhno - out1_app_board if out1_app_board != .
	gen out5_foodexppercapita =  .
	replace out5_foodexppercapita = out5_foodexp/current_hhno 
	lab var out5_foodexppercapita "Per Capita Food Expenditures"
	
**Section H unavailable for LTFU
gen out5_medicalexp = h9b_c
lab var out5_medicalexp "Health Expenditures"

gen out5_eduexp = h9_c
lab var out5_eduexp "Education Expenditures"

gen out5_waterexp = h9a_c
lab var out5_waterexp "Water Expenditures"
 
egen out5_personalexp = rowtotal(h1_c h2_c h3_c h4_c h5_c h6_c h7_c h8_c), missing
lab var out5_personalexp "Personal Expenditures"

gen out5_fuelexp = i29_c
lab var out5_fuelexp "Fuel Expenditures"

*Impute 0 for missing values for ltfu 
replace out5_foodexp = 0 if (out5_foodexp == . | out5_foodexp == . ) & ltfu == 1 & notfoundatLTFU == 0
replace out5_fuelexp = 0 if (out5_fuelexp == . | out5_fuelexp == .m) & ltfu == 1 & notfoundatLTFU == 0

local expendvars out5_foodexp out5_medicalexp out5_eduexp out5_waterexp out5_personalexp out5_fuelexp
swindex `expendvars', normby(C_0) gen(index_expenditures)
lab var index_expenditures "Expenditures Index"

egen out5_expenditures = rowtotal(`expendvars'), missing
*lab var out5_expenditures "Expenditures"

*Per Capita Expenditures
gen out5_exppercapita = out5_expenditures/out0_hhno
lab var out5_exppercapita "Per Capita Expenditures"


************************************
************ OUTCOME 6 *************
***** INCOME GENERATING ACTIVITIES *****
************************************

gen resp_igatype = .
gen resp_igadesc =.

forvalues x = 1(1)28 {
	cap replace resp_igatype = cl_d10_`x' if id_resp == `x'
	cap replace resp_igadesc = cl_d9_`x' if id_resp	 == `x'

}

	gen out6_resp_employment = .
	recode out6_resp_employment (. = 0) if resp_igatype == 4 & resp_igadesc == 35
	recode out6_resp_employment (. = 9) if resp_igatype == 4 & (resp_igadesc == 36|resp_igadesc == 37)
	recode out6_resp_employment (. = 1) if resp_igatype == 1
	recode out6_resp_employment (. = 2) if resp_igatype == 2
	recode out6_resp_employment (. = 3) if resp_igatype == 3
	recode out6_resp_employment (. = 3) if resp_igatype == 4
	
	lab def employmentstatus 0 "Unemployed" 1 "Salaried" 2 "Business" 3 "HouseholdLabor" 9 "Inactive"
	lab val out6_resp_employment employmentstatus
	
	drop resp_igatype resp_igadesc

recode j2_c 34 = 3 	if j2_other_activity_c == "Agricultural produce"		///
						|j2_other_activity_c == "Re-plant trees for sale"
recode j2_c 34 = 4 	if j2_other_activity_c == "Land cultivation on rented land"
recode j2_c 34 = 8 	if 	j2_other_activity_c == "Bee keeping" 				///
						|j2_other_activity_c == "Pig rearing"				///
						|j2_other_activity_c == "She rears turkeys at the owner place"
recode j2_c 34 = 12 if j2_other_activity_c == "Owner of a bar" 				///
						|j2_other_activity_c == "Owner of a small boys hostel" ///
						|j2_other_activity_c == "Phone charging"			///
						|j2_other_activity_c == "Small scale shop"			///
						|j2_other_activity_c == "Small bar"					///
						|j2_other_activity_c == "Saloon"					///
						|j2_other_activity_c == "Owns saloon"				///
						|j2_other_activity_c == "Own Brilliant Primary school" ///
						|j2_other_activity_c == "Brilliant Primary school"
recode j2_c 34 = 13 if j2_other_activity_c == "Barber" 						///
	| j2_other_activity_c == "Hairdressing"									///
	| j2_other_activity_c == "Saloon owner"									///
	| j2_other_activity_c == "Owner of a saloon and selling soft drinks"	///
	| j2_other_activity_c == "Decoration"									///
	| j2_other_activity_c == "Mult purpose foot ware"						///
	| j2_other_activity_c == "Hiring out music system"
recode j2_c 34 = 24 if j2_other_activity_c == "Alchol manifacturer"			///
				|j2_other_activity_c == "Brewing alcohol"					///
				|j2_other_activity_c == "Brewing local brew"				///
				|j2_other_activity_c == "Local beers" 						///
				|j2_other_activity_c == "Making crude waragi"				///
				|j2_other_activity_c == "Selling local brew"				///
				|j2_other_activity_c == "Selling local brew."				///
				|j2_other_activity_c == "Selling local waragi"				///
				|j2_other_activity_c == "Selling flied cassava"				///
				|j2_other_activity_c == "Selling milk tea"
recode j2_c 34 = 26 if j2_other_activity_c == "Charcoal selling" 			///
				|j2_other_activity_c == "Selling fire wood"					///
				|j2_other_activity_c == "Selling firewood"					///
				|j2_other_activity_c == "Selling firewoods"					///
				|j2_other_activity_c == "Cocoa selling" 					///
				|j2_other_activity_c == "Hawker"							///
				|j2_other_activity_c == "Vendor"							///
				|j2_other_activity_c == "Kiosk" 							///
				|j2_other_activity_c == "She sells maize flour/posho"		///
				|j2_other_activity_c == "Sale of sugarcanes"				///
				|j2_other_activity_c == "Produce selling"					///
				|j2_other_activity_c == "Selling milk"						
recode j2_c 34 = 28 if j2_other_activity_c == "Dealer in agricultural produce" ///
				|j2_other_activity_c == "Brick laying"						///
				|j2_other_activity_c == "Bricklaying"						///
				|j2_other_activity_c == "Selling herbal drugs for children" ///	
				|j2_other_activity_c == "Selling tap water"					///
				|j2_other_activity_c == "Lozary making"						/// Rosary making!
				|j2_other_activity_c == "Stone quarrying for sale"			///
				|j2_other_activity_c == "Stone quarying"
recode j2_c 34 = . 	if j2_other_activity_c == "Watching clothes"			///
				|j2_other_activity_c == "Mobile mobile"

recode j2_c 34 = . if j2_other_activity_c == ""

recode j2_2_c 34 = 12 	if j2_2_other_activity_c == "Dry cleaner"
recode j2_2_c 34 = 13 	if j2_2_other_activity_c == "Grinding machine"
recode j2_2_c 34 = . 	if j2_2_other_activity_c == ""

forvalues bizcode = 1(1)37 {
	gen biz`bizcode' = 0
	forvalues n = 1(1)46 {
	capture recode biz`bizcode' (0 = 1) if (cl_d9_`n' == `bizcode')
	}
}
drop biz1 biz2 biz4 biz5 biz6 biz7 biz9 biz11 biz14 biz15 biz16 biz17 biz18 biz19 biz20 biz21 biz33 biz35 biz36 biz37
egen out6_businessno_roster = rowtotal(biz*)
lab var out6_businessno_roster "Activities mentioned"
drop biz*

* Obtain dummies for activity type from roster occupations
forvalues n = 1(1)46 {
	capture gen all_self_employed`n' = (cl_d10_`n' == 2)
	capture recode all_self_employed`n' (1 = 0) if cl_d9_`n' == 1 /*HOUSEWIFE*/ ///
		| cl_d9_`n' == 2 /*CULTIV OWN CONS*/ | cl_d9_`n' == 4 /*AGRI DAY LABOR*/ ///
		| cl_d9_`n' == 5 /*DAY LABOR*/ 		| cl_d9_`n' == 6 /*FACTORY*/ ///
		| cl_d9_`n' == 7/*ANIMAL OWN CONS*/ |cl_d9_`n' == 9 /*SERVANT*/ ///
		| cl_d9_`n' == 11 /*SHOP WORKER*/ 	| cl_d9_`n' == 14 /*TEACHER*/ ///
		| cl_d9_`n' == 15 /*PROFESSIONAL*/ 	| cl_d9_`n' == 16 /*MANAGER*/ ///
		| cl_d9_`n' == 17 /*CLERK*/ 		| cl_d9_`n' == 18 /*MANAGER GOVT*/ ///
		| cl_d9_`n' == 19 /*CLERK GOVT*/ 	| cl_d9_`n' == 20 /*POLITICIAN*/ ///
		| cl_d9_`n' == 21 /*PASTOR*/  		| cl_d9_`n' == 33 /*OTHER SALARIED ACTIVITY*/ ///
		| cl_d9_`n' == 35/*UNEMPLOYED*/ 	| cl_d9_`n' == 36 /*NOT LOOKING FOR WORK*/ ///
		| cl_d9_`n' == 37 /*STUDENT*/
	* Agricultural Business	
	capture gen agri_self_employed`n' = (cl_d10_`n' == 2 & 				///
		(cl_d9_`n' == 3 /*CULTIV FOR SALE*/ |cl_d9_`n' == 8 /*ANIMAL FOR SALE*/ ))
	* Driving Business
	capture gen drive_self_employed`n' = (cl_d10_`n' == 2 & 			///
		cl_d9_`n' == 10 /*DRIVING*/ )
	* Unskilled Manual Labor
	capture gen unskilled_self_employed`n' = (cl_d10_`n' == 2 & 			///
		(cl_d9_`n' == 23 /*FISHERMAN*/ | cl_d9_`n' == 24 /*FOOD*/ | cl_d9_`n' == 26 /*STREET VENDOR*/ ))
	* Skilled Manual Labor
	capture gen skilled_self_employed`n' = (cl_d10_`n' == 2 & 			///
		(cl_d9_`n' == 13 /*ARTISAN*/ | cl_d9_`n' == 22 /*MIDWIFE*/ | cl_d9_`n' == 25 /*TAILOR*/ ) )
	* Owner of shop,restaurant,hotel
	capture gen owner_self_employed`n' = (cl_d10_`n' == 2 & 			///
		(cl_d9_`n' == 12 /*OWNER OF SHOP,RESTAURANT,HOTEL*/ ))
	* Other
	capture gen trade_self_employed`n' = (cl_d10_`n' == 2 & 			///
		(cl_d9_`n' == 27 /*HOMESTEAD*/ | cl_d9_`n' == 28 /*SMALL TRADE*/ ///
		| cl_d9_`n' == 29 /*LARGE BUSINESS*/ ///
		| cl_d9_`n' == 31 /*RENT LAND*/ | cl_d9_`n' == 32 /*RENT ASSETS*/ ///
		| cl_d9_`n' == 34 /*OTHER*/))

	}

foreach activity in all agri drive unskilled skilled owner trade {
	egen out6_`activity'_biz = rowtotal(`activity'_self_employed*)
	replace out6_`activity'_biz = 1 if out6_`activity'_biz > 0 				
	drop `activity'_self_employed*
}



* Roster occupations report "main" activity per hh member. 
* Add info from reported businesses for more comprehensive outlook

foreach var in j2_c j2_2_c  {
	recode out6_all_biz 	(0 = 1) if j1_c == 1 & (`var' != 1 /*HOUSEWIFE*/ ///
		& `var' != 2 /*CULTIV OWN CONS*/ & `var' != 4 /*AGRI DAY LABOR*/ ///
		& `var' != 5 /*DAY LABOR*/ 		& `var' != 6 /*FACTORY*/ ///
		& `var' != 7/*ANIMAL OWN CONS*/ &`var' !=9 /*SERVANT*/ ///
		& `var' != 11 /*SHOP WORKER*/ 	& `var' != 14 /*TEACHER*/ ///
		& `var' != 15 /*PROFESSIONAL*/ 	& `var' != 16 /*MANAGER*/ ///
		& `var' != 17 /*CLERK*/ 		& `var' != 18 /*MANAGER GOVT*/ ///
		& `var' != 19 /*CLERK GOVT*/ 	& `var' != 20 /*POLITICIAN*/ ///
		& `var' != 21 /*PASTOR*/  		& `var' != 33 /*OTHER SALARIED ACTIVITY*/ ///
		& `var' != 35/*UNEMPLOYED*/ 	& `var' != 36 /*NOT LOOKING FOR WORK*/ ///
		& `var' != 37 /*STUDENT*/ )	
	recode out6_agri_biz 	(0 = 1) if j1_c == 1 & 							///
		(`var' == 3 /*CULTIV FOR SALE*/ |`var' == 8 /*ANIMAL FOR SALE*/ )
	recode out6_drive_biz 	(0 = 1) if j1_c == 1 & 							///
		`var' == 10 /*DRIVING*/ 
	recode out6_unskilled_biz (0 = 1) if j1_c == 1 & 						///
		(`var' == 23 /*FISHERMAN*/ | `var' == 24 /*FOOD*/ | `var' == 26 /*STREET VENDOR*/ )
	recode out6_skilled_biz (0 = 1) if j1_c == 1 & 							///
		(`var' == 13 /*ARTISAN*/ | `var' == 22 /*MIDWIFE*/ | `var' == 25 /*TAILOR*/ ) 
	recode out6_owner_biz (0 = 1) if j1_c == 1 & 							///
		(`var' == 12 /*OWNER OF SHOP,RESTAURANT,HOTEL*/ )
	recode out6_trade_biz (0 = 1) if j1_c == 1 & 							///
		(`var' == 27 /*HOMESTEAD*/ | `var' == 28 /*SMALL TRADE*/ 			///
		|`var' == 31 /*RENT LAND*/ | `var' == 32 /*RENT ASSETS*/ 			///
		|`var' == 34 /*OTHER*/)
}

foreach var in j13_c1 j13_c2 j13_c3 j13_c4 j13_c5 {
	recode out6_all_biz 	(0 = 1) if j12_c == 1 & (`var' != 1 /*HOUSEWIFE*/ ///
		& `var' != 2 /*CULTIV OWN CONS*/ & `var' != 4 /*AGRI DAY LABOR*/ ///
		& `var' != 5 /*DAY LABOR*/ 		& `var' != 6 /*FACTORY*/ ///
		& `var' != 7/*ANIMAL OWN CONS*/ &`var' !=9 /*SERVANT*/ ///
		& `var' != 11 /*SHOP WORKER*/ 	& `var' != 14 /*TEACHER*/ ///
		& `var' != 15 /*PROFESSIONAL*/ 	& `var' != 16 /*MANAGER*/ ///
		& `var' != 17 /*CLERK*/ 		& `var' != 18 /*MANAGER GOVT*/ ///
		& `var' != 19 /*CLERK GOVT*/ 	& `var' != 20 /*POLITICIAN*/ ///
		& `var' != 21 /*PASTOR*/  		& `var' != 33 /*OTHER SALARIED ACTIVITY*/ ///
		& `var' != 35/*UNEMPLOYED*/ 	& `var' != 36 /*NOT LOOKING FOR WORK*/ ///
		& `var' != 37 /*STUDENT*/ )	

	recode out6_agri_biz 	(0 = 1) if j12_c == 1 & 						///
		(`var' == 3 /*CULTIV FOR SALE*/ |`var' == 8 /*ANIMAL FOR SALE*/ )
	recode out6_drive_biz 	(0 = 1) if j12_c == 1 & 						///
		`var' == 10 /*DRIVING*/ 
	recode out6_unskilled_biz (0 = 1) if j12_c == 1 & 						///
		(`var' == 23 /*FISHERMAN*/ | `var' == 24 /*FOOD*/ | `var' == 26 /*STREET VENDOR*/ )
	recode out6_skilled_biz (0 = 1) if j12_c == 1 & 							///
		(`var' == 13 /*ARTISAN*/ | `var' == 22 /*MIDWIFE*/ | `var' == 25 /*TAILOR*/ ) 
	recode out6_owner_biz (0 = 1) if j12_c == 1 & 							///
		(`var' == 12 /*OWNER OF SHOP,RESTAURANT,HOTEL*/ )
	recode out6_trade_biz (0 = 1) if j12_c == 1 & 							///
		(`var' == 27 /*HOMESTEAD*/ | `var' == 28 /*SMALL TRADE*/ 			///
		|`var' == 31 /*RENT LAND*/ | `var' == 32 /*RENT ASSETS*/ 			///
		|`var' == 34 /*OTHER*/)
}

	lab var out6_agri_biz 		"Has Ag Business"
	lab var out6_drive_biz 		"Has Driver Business"
	lab var out6_skilled_biz 	"Has Skilled Business"
	lab var out6_unskilled_biz 	"Has Unskilled Business"
	lab var out6_owner_biz 		"Has Owner Business"
	lab var out6_trade_biz 		"Has Trade Business"
	
	* Business types the household is involved in

egen out6_businesstypes = rowtotal(out6_agri_biz out6_drive_biz out6_unskilled_biz ///
	out6_skilled_biz out6_owner_biz out6_trade_biz)

*Non-agricultural business owner
gen out6_nonagribusiness = (j1_c == 1 | j12_c == 1)
lab var out6_nonagribusiness "Household Owns Business"

	// Alternative Definition Using info from both HH & Business Roster
	gen out6_nonagribusiness2 = .
	recode out6_nonagribusiness2 (. = 1) if out6_drive_biz == 1 | out6_unskilled_biz == 1 | out6_skilled_biz == 1 | out6_owner_biz == 1 | out6_trade_biz == 1
	recode out6_nonagribusiness2 . = 0
	lab var out6_nonagribusiness2 "Has Non-Ag Business"


*No. of non-ag businesses 

gen out6_businessno = jb1_c
recode out6_businessno (. = 0) if j1_c == 0 & j12_c == 0

forvalues n = 1(1)5{
	replace out6_businessno = out6_businessno + 1 							///
	if out6_businessno !=. & j13_c`n' != .
	replace out6_businessno = 1 if out6_businessno == . & j13_c`n' != .
}
lab var out6_businessno "Number Of Businesses"

*** Business that she runs or she is involved in)

gen out6_invbiz = (j1_c == 1)
lab var out6_invbiz "Own business"
gen out6_invbusinessno = jb1_c
recode out6_invbusinessno . = 0 if j1_c == 0
lab var out6_invbusinessno "Number Of Respondent's Businesses"

forvalues n = 1(1)2 {
	gen out6_sector`n' = j`x'2_c
	recode out6_sector`n' (1 = .) (2 = .) (4 = .) (5 = .) (6 = .) (7 = .) 	///
	(9 = .) (11 = .) (14 = .) (15 = .) (16 = .) (17 = .) (18 = .) (19 = .)  /// 
	(20 = .) (21 = .) (33 = .) (35 = .) (36 = .) (37 = .)
	
	local x 2_ 
}

forvalues n = 1(1)2 {
	foreach activity in agri drive unskilled skilled owner trade {
		gen out6_invtype`n'_`activity' = 0
		
	}
}

forvalues n = 1(1)2 {

recode out6_invtype`n'_agri (0 = 1) if 										///
		j`x'2_c == 3 /*CULTIV FOR SALE*/ | j`x'2_c == 8 /*ANIMAL FOR SALE*/
recode out6_invtype`n'_drive (0 = 1) if 									///
		j`x'2_c == 10 /*DRIVING*/ 
recode out6_invtype`n'_unskilled (0 = 1) if 								///
		j`x'2_c == 23 /*FISHERMAN*/ | j`x'2_c == 24 /*FOOD*/ | j`x'2_c == 26 /*STREET VENDOR*/ 
recode out6_invtype`n'_skilled (0 = 1) if 									///
		j`x'2_c == 13 /*ARTISAN*/ | j`x'2_c == 22 /*MIDWIFE*/ | j`x'2_c == 25 /*TAILOR*/ 
recode out6_invtype`n'_owner (0 = 1) if 									///
		j`x'2_c == 12 /*OWNER OF SHOP,RESTAURANT,HOTEL*/ 
recode out6_invtype`n'_trade (0 = 1) if 									///
		j`x'2_c == 27 /*HOMESTEAD*/ | j`x'2_c == 28 /*SMALL TRADE*/ 		///
		|j`x'2_c == 31 /*RENT LAND*/ | j`x'2_c == 32 /*RENT ASSETS*/ 		///
		|j`x'2_c == 34 /*OTHER*/
		
local x 2_
}

*Business profits
gen out6_invprof1 = j10_c
recode out6_invprof1 (98 = .) (99 = .) (6 = .) (11 = .) (999 = .)
recode out6_invprof1 (. = 0) if j1_c == 0
lab var out6_invprof1 "Profits 1"

gen out6_invprof2 = j2_10_c
recode out6_invprof2 (98 = .) (99 = .) (6 = .) (11 = .) (999 = .)
/*Do not recode profits as zero if they did not have another activity because
they are counted as zero in rowtotal below and that is what I care about 
(problem is in terms of total profits earned by main woman*/

lab var out6_invprof2 "Profits 2"

egen out6_invprof = rowtotal(out6_invprof1 out6_invprof2), missing
lab var out6_invprof "Profits"

*Business expenses

gen out6_invexp1 = j11_c
recode out6_invexp1 (98 = .) (99 = .) (1 = .) (50 = .) (999 = .)
recode out6_invexp1 . = 0 if j1_c == 0
replace out6_invexp1 = out6_invexp1 * 12
lab var out6_invexp1 "Expenses 1"

gen out6_invexp2 = j2_11_c
recode out6_invexp2 (98 = .) (99 = .) (1 = .) (28 = .) (50 = .) (999 = .)
 /*Dont recode missing invexp2 as zero for same reason explained above*/
replace out6_invexp2 = out6_invexp2 * 12
lab var out6_invexp2 "Expenses 2"

egen out6_invexp = rowtotal(out6_invexp1 out6_invexp2), missing
replace out6_invexp = out6_invexp * 12
lab var out6_invexp "Expenses"

*Business revenues

egen out6_invrev1 = rowtotal(out6_invprof1 out6_invexp1), missing
egen out6_invrev2 = rowtotal(out6_invprof2 out6_invexp2), missing
egen out6_invrev = rowtotal(out6_invprof out6_invexp), missing
lab var out6_invrev "Business Revenues"

*Business hours worked 
gen out6_hours1 = j7_c 	* j8_c 	* j9_c 		if j7_c!= . 	& j8_c !=. 		& j9_c != .
recode out6_hours1 (. = 0) if j1_c == 0 /*As earlier recode to zero if no business because ultimately interested in total hours*/

gen out6_hours2 = j2_7_c * j2_8_c* j2_9_c 	if j2_7_c!= . 	& j2_8_c !=. 	& j2_9_c != .
gen out6_hours3 = j15_c 	* j16_c * j17_c		if j15_c != . 	& j16_c != . 	& j17_c != .

egen out6_hours = rowtotal(out6_hours1 out6_hours2 out6_hours3), missing
lab var out6_hours "Hours Worked In Business"

* She decides 
gen out6_invdecision1 = (j3_c == 1 		| j4_c  == 1)
recode out6_invdecision1 (0 = .) if out6_invbiz == 0
gen out6_invdecision2 = (j2_3_c == 1 	| j2_4_c  == 1)
recode out6_invdecision2 (0 = .) if out6_invbiz == 0
gen out6_invdecision = (out6_invdecision1 == 1 | out6_invdecision2 == 1)
recode out6_invdecision (0 = .) if out6_invbiz == 0
lab var out6_invdecision "She decides"

*** Own business/one where she makes most decisions

gen out6_ownhours1 = out6_hours1
replace out6_ownhours1 = . if j3_c 	 == 0 | j4_c   == 0 /*Remove hours if not her business/where she makes most decisions*/

forvalues n = 1(1)2 {
	gen out6_nonagriprof`n' = j`x'10_c
	gen out6_nonagriexp`n' = j`x'11_c
	egen out6_nonagrirev`n' = rowtotal(out6_nonagriprof`n' out6_nonagriexp`n')
	local x 2_
}

replace out6_nonagriprof1 = . 	if j3_c 	 == 0 | j4_c   == 0
replace out6_nonagriexp1 = .	if j3_c 	 == 0 | j4_c   == 0
replace out6_nonagrirev1 = . 	if j3_c 	 == 0 | j4_c   == 0

gen out6_ownhours2 = out6_hours2
replace out6_ownhours2 = . 			if j2_3_c == 0 | j2_4_c == 0 /*Remove hours if not her business/where she makes most decisions*/

replace out6_nonagriprof2 = . 	if j2_3_c == 0 | j2_4_c == 0 
replace out6_nonagriexp2 = .	if j2_3_c == 0 | j2_4_c == 0 
replace out6_nonagrirev2 = . 	if j2_3_c == 0 | j2_4_c == 0 

egen out6_ownhours = rowtotal(out6_ownhours1 out6_ownhours2), missing
egen out6_ownnonagriprof = rowtotal(out6_nonagriprof1 out6_nonagriprof2), missing
egen out6_ownnonagriexp = rowtotal(out6_nonagriexp1 out6_nonagriexp2), missing
egen out6_ownnonagrirev = rowtotal(out6_nonagrirev1 out6_nonagrirev2), missing

lab var out6_ownhours "Hours (own)"
lab var out6_ownnonagriprof "Profits (own)"
lab var out6_ownnonagriexp "Expenses (own)"
lab var out6_ownnonagrirev "Revenues (own)"

drop out6_nonagriprof? out6_nonagriexp? out6_nonagrirev?

local businessvars out6_all_biz out6_nonagribusiness2 out6_agri_biz out6_businessno_roster out6_hours out6_invrev
swindex `businessvars', normby(C_0) gen(index_business)	
lab var index_business "Business Index"

************************************
************ OUTCOME 7 *************
***** PSYCHOLOGICAL WELL-BEING *****
************************************

***CESD (Only followup)

* Negative statements
foreach var in n27_c n28_c n29_c n31_c n32_c n33_c n35_c n36_c n37_c n39_c n40_c n41_c n43_c n44_c n45_c n46_c{
	recode `var' (1=0) (2=1) (3=2) (4=3) /*rescale*/
}

* Positive statements
foreach var in n30_c n34_c n38_c n42_c{
	replace `var' = 4 - `var' /*reverse coding and rescale*/
}

egen out7_cesd = rowtotal(n27_c - n46_c), missing			
lab var out7_cesd "Depression Score"

*** Happiness
gen out7_happiness = 4 - n47_c
lab var out7_happiness "Happiness Score"

*** Life Satisfaction 
gen out7_lifesat = n48_c
replace out7_lifesat = . if cohort2014 == 1 & ltfu == 0 /*(not available for Cohort2014 because of survey coding mistake)*/
lab var out7_lifesat "Life Satisfaction Score"

*** Trust (l41 for Cohort2014 and l41_subsection if Cohort2015
gen out7_trust = l42_c				if baseline != . &	ltfu == 0	// var doesn't exist for ltfu
lab var out7_trust "Trust Score"


*** Psychological Well-being Index: Happiness, Life Satisfaction, Depression Score */

* 4 STEPS
* 1. Copy in those already positively coded
gen out7_happiness_p = out7_happiness
gen out7_lifesatisfaction_p = out7_lifesat

* 2. Positively code those who currently are negatively coded */			//FIXMERA: to check
	foreach var in out7_cesd {
		egen max`var' = max(`var')
		gen `var'_p=(max`var' - `var')
	}

local psywelvars out7_happiness_p out7_lifesatisfaction_p out7_cesd_p
swindex `psywelvars', normby(C_0) gen(index_psywel)			
lab var index_psywel "Psychological Well-being Index"


************************************
************ OUTCOME 7 *************
***** PSYCHOLOGICAL WELL-BEING *****
************************************

* Negative statements
foreach var in h1_a_c h2_a_c h3_a_c h5_a_c h6_a_c h7_a_c h9_a_c h10_a_c h11_a_c h13_a_c h14_a_c h15_a_c h17_a_c h18_a_c h19_a_c h20_a_c{
	recode `var' (1=0) (2=1) (3=2) (4=3) if ltfu == 1 & alum == 1  /*rescale*/
}

* Positive statements
foreach var in h4_a_c h8_a_c h12_a_c h16_a_c{
	replace `var' = 4 - `var' if ltfu == 1 & alum == 1 /*reverse coding and rescale*/  
}

egen out7_cesd_a = rowtotal(h1_a_c - h20_a_c), missing 	
lab var out7_cesd_a "Depression Score"

*** Happiness
gen out7_happiness_a = 4 - h21_a_c	if ltfu == 1 & alum == 1
lab var out7_happiness_a "Happiness Score"

*** Life Satisfaction 
gen out7_lifesat_a = h22_a_c	if ltfu == 1 & alum == 1 
lab var out7_lifesat_a "Life Satisfaction Score"

/*
*** Trust (l41 for Cohort2014 and l41_subsection if Cohort2015
gen out7_trust = l42_c				if baseline != . &	ltfu == 0	// var doesn't exist for ltfu
lab var out7_trust "Trust Score"
*/


*** Psychological Well-being Index: Happiness, Life Satisfaction, Depression Score */

* 4 STEPS
* 1. Copy in those already positively coded
gen out7_happiness_a_p = out7_happiness_a		if ltfu == 1 & alum == 1
gen out7_lifesatisfaction_a_p = out7_lifesat_a	if ltfu == 1 & alum == 1

* 2. Positively code those who currently are negatively coded */			//FIXMERA: to check
	foreach var in out7_cesd_a {
		egen max`var' = max(`var')
		gen `var'_p=(max`var' - `var')
	}

local psywelvars_alum out7_happiness_a_p out7_lifesatisfaction_a_p out7_cesd_a_p
swindex `psywelvars_alum', normby(C_0) gen(index_psywel_alum)			
lab var index_psywel_alum "Psychological Well-being Index (Alum)"


************************************
************ OUTCOME 8 *************
******* CONFLICT AND VIOLENCE ******
************************************

gen out8_partnertreatswell = n11_c
lab var out8_partnertreatswell "Partner treats well"


*Conflict over 10 expenditure items	(does not exist for ltfu)
forvalues n=1(1)10 {
	gen out8_conflict`n' = (g`n'_b_c == 1)
	replace out8_conflict`n' =. if g`n'_b_c == . | g`n'_b_c == 2 
	lab var out8_conflict`n' "Conflict over Item `n'"
}

*Conflict Over Money
gen out8_conflovermoney = n4_c
recode out8_conflovermoney (3 = 1) (1 = 3) 
lab var out8_conflovermoney "Frequency of conflict over money"
* Conflict Index: Conflict over 10 expenditure items, Conflict Over Money */

local conflictvars out8_conflict1 out8_conflict2 out8_conflict3 out8_conflict4 out8_conflict5 out8_conflict6 out8_conflict7 out8_conflict8 out8_conflict9 out8_conflict10 out8_conflovermoney
swindex `conflictvars', normby(C_0) gen(index_conflict)			// Raaga's notes: Not to be included in LTFU 
lab var index_conflict "Conflict Index"

*Threat of Physical Violence, dummy
gen out8_threat_d = n17_c		
replace out8_threat_d =  1 		if n17b_c  == 1	& ltfu == 1				//new question in LTFU if female has hurt or threated to hurt
recode out8_threat_d (98 = .) 
lab var out8_threat_d "Male/Female HH member threatened to hurt"  

*Threat of Physical Violence, Frequency
gen out8_threat_f = 5 - n18_c /*So that it ranges 1-4*/
recode out8_threat_f (-93 = .) (5=.) (0 = .) 							// changed answers outside the 1-4 range that created weird outputs
recode out8_threat_f (. = 0) if out8_threat_d == 0 /*So that it ranges 0-4, including the zero event*/	
lab var out8_threat_f "Male/Female HH member threatened to hurt - frequency"		

*Physical Violence
gen out8_violence_d = n21_c
recode out8_violence_d (98 = .) (2 = .)								// 2 occurence of "2"??
lab var out8_violence_d "Male/Female HH member used physical violence"			

*Physical Violence, Frequency
gen out8_violence_f = 5 - n23_c /*So that it ranges 1-4*/
*recode out8_violence_f (-93 = .) 
recode out8_violence_f (. = 0) if out8_violence_d == 0 /*So that it ranges 0-4, including the zero event*/
lab var out8_violence_f "Male/Female HH member used physical violence - frequency"	

* Violence Index: 
local violencevars out8_threat_f out8_violence_f out8_violence_d out8_threat_d
swindex `violencevars', normby(C_0) gen(index_violence)		
lab var index_violence "Violence Index"

************************************
************ OUTCOME 9 ************
******** FEMALE EMPOWERMENT ********
************************************

gen out9_decide2spend = n2_c
gen out9_decide2purchase = n3_c
gen out9_refusetogivemoney = n9_c
gen out9_allowed2market = n10_c

* Justifiability of Violence
gen out9_justviolence = n14_c
recode out9_justviolence (2 = .) (3 = .) (98 = .)
lab var out9_justviolence "Justifiability of Violence"

**Raaga's notes: Section L not included in ltfu
gen out9_right2spend = (l20_c > 5) /*Agree woman has right to buy without asking*/
recode out9_right2spend (0 = .) if l20_c == .

gen out9_right2job = (l21_c < 5) /*Disagree men have more right to jobs*/
recode out9_right2job (0 = .) if l21_c == .

gen out9_right2politics = (l22_c < 5) /*Disagree men are better political leaders*/
recode out9_right2politics (0 = .) if l22_c == .

gen out9_right2edu = (l23_c < 5) /*Disagree education more important for boys*/
recode out9_right2edu (0 = .) if l23_c == .

gen out9_right2business = (l24_c < 5) /*Disagree men better at business*/
recode out9_right2business (0 = .) if l24_c == .

gen out9_right2earn = (l25_c < 5)	/*Disagree woman earning money causes problems*/
recode out9_right2earn (0 = .) if l25_c == .

gen out9_right2market = (l26_c > 5) /*Agree woman has right to buy and sell on market without asking*/
recode out9_right2market (0 = .) if l26_c == .

gen out9_right2speak = (l27_c > 5)	/*Agree woman has right to disagree*/
recode out9_right2speak (0 = .) if l27_c == .

local expdecvars out9_decide2spend out9_decide2purchase out9_refusetogivemoney out9_allowed2market 
swindex `expdecvars', normby(C_0) gen(index_expdec)
lab var index_expdec "Women's Expenditures Decision Index"

local empowervars out9_right2spend out9_right2job out9_right2politics out9_right2edu out9_right2business out9_right2earn out9_right2market out9_right2speak
swindex `empowervars', normby(C_0) gen(index_empower)	
lab var index_empower "Women's Empowerment Index"

************************************
************ OUTCOME 10 ************
************* VALUES ***************
************************************

/* unsupervised learning to figure out how to group them?
31	Independence 
32	Hard work  
33	Responsibility 
34	Imagination 
35	Tolerance and respect for others 
36	Thrift, saving money 
37	Determination, perseverance 
38	Religious Faith 
39	Unselfishness 
40	Obedience 
41	Self-expression
*/

gen out10_independence 		= ustrregexm(note_l4_c, "31")
gen out10_hardwork			= ustrregexm(note_l4_c, "32")
gen out10_responsibility 	= ustrregexm(note_l4_c, "33")
gen out10_imagination 		= ustrregexm(note_l4_c, "34")
gen out10_tolerance 		= ustrregexm(note_l4_c, "35")
gen out10_thrift 			= ustrregexm(note_l4_c, "36")
gen out10_determination 	= ustrregexm(note_l4_c, "37")
gen out10_faith 			= ustrregexm(note_l4_c, "38")
gen out10_unselfishness		= ustrregexm(note_l4_c, "39")
gen out10_obedience 		= ustrregexm(note_l4_c, "40")
gen out10_selfexpr 			= ustrregexm(note_l4_c, "41")


************************************
********** 2014 USD PPP ************
*********** CONVERSION *************
************************************
unab unitaryprices: out4_i*unitvalue

* out1_toteduexp out1_eduexppc  out6_bsnssassetvalue out2_tothealthexp out2_healthexppc
local UGXvars  /* out1_allchildexpschool  out1_childexpschool out1_girlexpschool out1_boyexpschool  */ out4_totincome out4_totincpercapita out4_cowvalue out4_pigvalue out4_goatsheepvalue out4_smallanimalvalue out4_birdvalue out4_livestockvalue out4_furniturevalue out4_agritoolvalue out4_bikevalue out4_motorvalue out4_appliancevalue out4_mobilevalue out4_durablevalue out4_stockvalue out4_machineryvalue out4_housevalue out4_savingsvalue out4_savingsvalue1 out4_nonlandvalue out4_landvalue out4_cultlandvalue out4_totalasset out4_cultlandunitprice `unitaryprices' out4_K out4_assetvalue out4_prodassetvalue out5_foodexp out5_foodexppercapita out5_medicalexp out5_eduexp out5_waterexp out5_personalexp out5_fuelexp out5_expenditures out5_exppercapita out6_invrev out6_invrev1 out6_invrev2 out6_invprof out6_invprof1 out6_invprof2 out6_ownnonagriprof out6_invexp out6_invexp1 out6_invexp2 out6_ownnonagriexp

**FIXMERA: rates for ltfu 
local 2014standardexchangerate	= 2599.79
local 2015standardexchangerate	= 3240.65
local 2016standardexchangerate	= 3420.10
local 2017standardexchangerate	= 3611.22
local 2018standardexchangerate	= 3727.07
local 2019standardexchangerate	= 3704.05
local 2020standardexchangerate	= 3718.25
local 2021standardexchangerate	= 3587.05
local 2022standardexchangerate	= 3689.82

local 2018PPPexchangerate 		= 1153.90			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local 2016PPPexchangerate		= 1211.94		
local 2017PPPexchangerate		= 1270.60
local 2018PPPexchangerate		= 1295.91			//FIXMEBL: To discuss		
local 2019PPPexchangerate		= 1311.27		
local 2020PPPexchangerate		= 1329.60
local 2021PPPexchangerate		= 1304.82		
local 2022PPPexchangerate		= 1278.43		

local USinflation2013to2014		= 0.0175			// FIXMEBL: decision pending: to change it to updated PPP rate or not
local USinflation2014to2018		= 0.0149
local USinflation2014to2015		= 0.0189
local USinflation2014to2016		= 0.0148
local USinflation2014to2017		= 0.0135
local USinflation2015to2018		= 0.0136
local USinflation2016to2018		= 0.0150
local USinflation2017to2018		= 0.0190
**additions for ltfu
local USinflation2014to2022		= 0.0197		
local USinflation2015to2022		= 0.0199
local USinflation2016to2022		= 0.0215
local USinflation2017to2022		= 0.0238
local USinflation2018to2022		= 0.0215
local USinflation2019to2022		= 0.0238
local USinflation2020to2022		= 0.0215
local USinflation2021to2022		= 0.0238


**Converting 2023 UGX to 2022 UGX if survey conducted in 2023
local UGinflation2022			= 0.0484

foreach monetaryvar in `UGXvars' {
	replace `monetaryvar' = `monetaryvar'/((1+`UGinflation2022')^1) if ltfu == 1 & survey_year == 2023 & `monetaryvar' != .
}	


 
 
 
 foreach monetaryvar in `UGXvars' {
 	
	di "`monetaryvar'"
 	
 	gen `monetaryvar'SYstex = .
	gen `monetaryvar'2018stex = .
	gen `monetaryvar'2022stex = .
	gen `monetaryvar'PPP_2018 = .
	gen `monetaryvar'PPP_2022 = .

	
	/*Cohort 2014*/
	
	/* If baseline value, convert from 2014 UGX to 2018 USD & 2018 PPP */
	
	replace `monetaryvar'SYstex  = (`monetaryvar'/`2014standardexchangerate') if baseline == 1 & ltfu == 0 & cohort2014 == 1
		
	replace `monetaryvar'2018stex  = `monetaryvar'SYstex*((1+`USinflation2014to2018')^4) if baseline == 1 & ltfu == 0 & cohort2014 == 1
	
	replace `monetaryvar'2022stex  = `monetaryvar'SYstex*((1+`USinflation2014to2022')^8) if baseline == 1 & ltfu == 0 & cohort2014 == 1

	replace `monetaryvar'PPP_2018  = `monetaryvar'2018stex*(`2018standardexchangerate'/`2018PPPexchangerate') if baseline == 1 & ltfu == 0 & cohort2014 == 1
	
	replace `monetaryvar'PPP_2022  = `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate') if baseline == 1 & ltfu == 0 & cohort2014 == 1
	
	/* If followup value, convert from 2016 UGX to 2018 USD & 2018 PPP*/

	replace `monetaryvar'SYstex  = (`monetaryvar'/`2016standardexchangerate') if baseline == 0 & ltfu == 0 & cohort2014 == 1
	
	replace `monetaryvar'2018stex  = `monetaryvar'SYstex*((1+`USinflation2016to2018')^2) if baseline == 0 & ltfu == 0 & cohort2014 == 1
	
	replace `monetaryvar'2022stex  = `monetaryvar'SYstex*((1+`USinflation2016to2022')^6) if baseline == 0 & ltfu == 0 & cohort2014 == 1

	replace `monetaryvar'PPP_2018  = `monetaryvar'2018stex*(`2018standardexchangerate'/`2018PPPexchangerate') if baseline == 0 & ltfu == 0 & cohort2014 == 1
	
	replace `monetaryvar'PPP_2022  = `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate') if baseline == 0 & ltfu == 0 & cohort2014 == 1
	
	/*Cohort 2015*/	
	
	/* If baseline value, convert from 2015UGX to 2018 USD & 2018 PPP*/
	
	replace `monetaryvar'SYstex = (`monetaryvar'/`2015standardexchangerate') if baseline == 1 & cohort2014 == 0
	
	replace `monetaryvar'2018stex  = (`monetaryvar'SYstex*((1+`USinflation2015to2018')^3)) if baseline == 1 & ltfu == 0 & cohort2014 == 0
	
	replace `monetaryvar'2022stex  = (`monetaryvar'SYstex*((1+`USinflation2015to2022')^7)) if baseline == 1 & ltfu == 0 & cohort2014 == 0

	replace `monetaryvar'PPP_2018 = (`monetaryvar'2018stex*(`2018standardexchangerate'/`2018PPPexchangerate')) if baseline == 1 & ltfu == 0 & cohort2014 == 0

	replace `monetaryvar'PPP_2022 = (`monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate')) if baseline == 1 & ltfu == 0 & cohort2014 == 0

	
	
	/* If followup value, convert from 2017UGX to 2018 USD & 2018 PPP */
	
	replace `monetaryvar'SYstex = (`monetaryvar'/`2017standardexchangerate') if baseline == 0 & ltfu == 0 & cohort2014 == 0
	
	replace `monetaryvar'2018stex = ( `monetaryvar'SYstex*((1+`USinflation2017to2018')^1)) if baseline == 0 & ltfu == 0 & cohort2014 == 0
	
	replace `monetaryvar'2022stex = ( `monetaryvar'SYstex*((1+`USinflation2017to2022')^5)) if baseline == 0 & ltfu == 0 & cohort2014 == 0

	replace `monetaryvar'PPP_2018 = ( `monetaryvar'2018stex*(`2018standardexchangerate'/`2018PPPexchangerate')) if baseline == 0 & ltfu == 0 & cohort2014 == 0
	
	replace `monetaryvar'PPP_2022 = ( `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate')) if baseline == 0 & ltfu == 0 & cohort2014 == 0
	
	/* If long term followup value, from 2022UGX to 2022 USD, no diffferentitation between cohorts  */
	
	replace `monetaryvar'SYstex = (`monetaryvar'/`2022standardexchangerate') if baseline == 0 & ltfu == 1 
	
	replace `monetaryvar'2022stex = `monetaryvar'SYstex if baseline == 0 & ltfu == 1 
	
	replace `monetaryvar'PPP_2022 = ( `monetaryvar'2022stex*(`2022standardexchangerate'/`2022PPPexchangerate')) if baseline == 0 & ltfu == 1 
	
	
	local label : variable label `monetaryvar'
	label variable `monetaryvar'PPP_2018 `"`label'"'
	label variable `monetaryvar'PPP_2022 `"`label'"'


	*Top code at 99th percentile
	
	_pctile `monetaryvar'PPP_2018, p(99)
	replace `monetaryvar'PPP_2018 = r(r1) if `monetaryvar'PPP_2018 > r(r1) & `monetaryvar'PPP_2018 != .
	
	_pctile `monetaryvar'PPP_2022, p(99)
	replace `monetaryvar'PPP_2022 = r(r1) if `monetaryvar'PPP_2022 > r(r1) & `monetaryvar'PPP_2022 != .


 }
 
	
*** GENERATE OUTCOMES FOR ANCOVA 
duplicates report id_new baseline ltfu		/*no duplicates reported*/
sort id_new ltfu baseline
order id_new ltfu baseline

unab outcomevars: out* index_* survey_year
foreach outcome in `outcomevars' {
	gen `outcome'_l = `outcome' if ltfu == 1
	local label : variable label `outcome'
	label variable `outcome'_l `"`label' (Endline)"'		
	replace `outcome'_l = `outcome'_l[_n+1] if id_new == id_new[_n+1] & `outcome'_l == . 		// for Karlan bounds with 1,425 obs
	
	gen `outcome'_b = `outcome' if baseline == 1 & ltfu == 0
	local label : variable label `outcome'
	label variable `outcome'_b `"`label' (Pre)"'
	replace `outcome'_b = `outcome'_b[_n-1] if id_new == id_new[_n-1] & `outcome'_b == .		// for outcome tables
	replace `outcome'_b = `outcome'_b[_n-1] if id_new == id_new[_n-1] & `outcome'_b == .		// for Karlan bounds with 1,425 obs
	
	gen `outcome'_f = `outcome' if baseline == 0 & ltfu == 0
	local label : variable label `outcome'
	label variable `outcome'_f `"`label' (Follow up)"'
	replace `outcome'_f = `outcome'_f[_n-2] if id_new == id_new[_n-2] & `outcome'_f == .		// for outcome tables
	replace `outcome'_f = `outcome'_f[_n-1] if id_new == id_new[_n-1] & `outcome'_f == .		// for Karlan bounds with 1,425 obs
}

**Updating cohort for ltfu

replace cohort2014 = cohort2014[_n-1] if id_new == id_new[_n-1] & ltfu == 1 & cohort2014 == . 

**replace out1_uceaggregate_b = . /* No baseline value for this */

* Save Dataset for Analysis

drop correct_app_c app_name_check_c cl_d3__exist* cl_d3__all* cl_d1_check* cl_d_13_1? cl_d_13_1?? 

global HHroster cl_d3_? cl_d3_?? cl_d4_* cl_d5_* cl_d6_* cl_d7_* cl_d8_* cl_d9_* cl_d10_* cl_d11_* cl_d12_* cl_d13_*
global EDUroster cl_e2_* cl_e3_* cl_e4_* cl_e4a_* cl_e5_* cl_e5a_* cl_e5b_* cl_e5c_* cl_e6a_* cl_e6b_* cl_e6c_* cl_e7a_* cl_e7b_* cl_e7c_* cl_e8_* cl_e9a_* cl_e9b_*
global HEALTHroster cl_f2_1 cl_f3_a1 cl_f4_1 cl_f5_1 cl_f6_1 cl_f7_1 cl_f8_1
global TREATvars T_0 treatment_c final_select NSC_final_select /* t_x_sex tint_x_sex */			// FIXMERA: t_x_sex tint_x_sex??
global FEvars NSC_intdcode

keep ///
///
/* Identifiers: */ ///				FIXMERA: app_sur_2015_c (from app_sur_2015), app_oth_2015_c (from app_oth_2015), resp_name_check_fail1_c (from resp_name_check_fail1), resp_surname_2015_c resp_othername_2015_c a5a_c
///	
id id_new baseline ltfu alum cohort2014 cohort2015 aa? aa?? app_sur_2015_c app_oth_2015_c a1_c a2_c survey_year* /* survey_year_a */ ///
id_app_name /* id_app_name_official */ ///
resp_surname_2015_c resp_othername_2015_c a4_c a5_c a5a_c resp_name_check_c 		///
resp_name_check_fail1_c final_select NSC_final_select  sex_app gender_app notfoundatLTFU notfoundatFU				///
///
/* Outcomes: */	///	
///			
out* /// 																		
///
/* Indices */ ///
///
index_* ///
///
/* Education performance/quality indicators: */ ///	
///		
bb_* /* uce* sat_uce benefitvaluePPP SCS_* UNEB_* */ /*ple_score_nsc pscore_nsc d1_nsc applicant_id */		 ///
///
/* Sample Selection: */ ///
///
attrited participation_c participation_alum out1_mock_uceaggregate out1_uceaggregate out1_mock_uaceaggregate out1_uaceaggregate out1_division1_self out1_division1_scores out1_division_compare out1_olevel out1_alevel out1_tertiary	out1_ucesat out1_uacesat				///
///
$HHroster $EDUroster $HEALTHroster $TREATvars $FEvars		

qui compress
sort id_new baseline ltfu 
order id app_oth_201?_c app_sur_201?_c a2_c a1_c resp_othername_201?_c 		///
	resp_surname_201?_c a4_c a5_c
	
tempfile Cohort2014_2015_HHData
save `Cohort2014_2015_HHData'

save "$caregiver_enc/data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", replace

	***** Deidentify 

	capture unab audit: audit_*
	capture unab statement_of_consent: statement_of_consent_*
	capture unab start: start_* 
	capture unab end: end_*
	capture unab gps: gps*
	capture unab SCS_gps1: SCS_gps1*
	capture unab cl_e_name: cl_e*_name  
	capture unab cl_hhchd: cl_hhchd_* 
	capture unab cl_hhm: cl_hhm_* 
	capture unab cl_d3: cl_d3_* 
	capture unab cl_kid: cl_kid_* 
	capture unab cl_kid1: cl_kid1_* 
	capture unab o6_c: o6*_c 
	capture unab bb_4_201_c: bb_4_201*_c 
	capture unab bb_4_201_other: bb_4_201*_other 
	capture unab bb_4_201_other_c: bb_4_201*_other_c
	
	local metadata_vars deviceid data_phone subscriberid simid devicephonenum username duration caseid  `audit' `statement_of_consent' `start' `end' formdef_version submissiondate o6 starttime endtime start today q6_c
	
	foreach var of local metadatavars {
		
		capture drop `var'
	}

			
	local  identifymain_vars a1_c a2_c a4_c a5_c  a7_c a8_c app_name app_sur app_sur_c app_oth app_oth_c id_app_name_official id_app_name app_sur_2015_c app_new_name_c app_oth_2015_c app_bd_c app_bd_2015_c  resp_surname resp_surname_c resp_othername resp_othername_c app_mother app_father resp_surname_2015_c resp_othername_2015_c enu_name enu_code enu_name_check enu_name_checkfail aa1 aa4 tutor_oth_c tutor_sur_c village current_hh_vil_c current_hh_sub_c current_hh_boarding_c current_phone_c interview_gpslatitude interview_gpslongitude interview_gpsaltitude interview_gpsaccuracy `gps' interview_location_other interview_location_detail interview_location_detail_replac  aa9 loc_verify loc_verificationa10_1 loc_verificationa10 loc_verificationa11  loc_verificationa13 loc_verificationa14 `SCS_gps1' aa6_yes_nametrue aa6_yes_nametrue_c aa6_yes_othernametrue aa6_yes_othernametrue_c  a16_c a16a_c a16b_c a16d_c b8_c b9_c c3_2_c c3_11_c c3_21_c c4_2_c c4_11_c c4_21_c c8_b_1_c c8_b_2_c c8_b_3_c c8_b_4_c c3_7_c c4_7_c c8_e_1_c c8_e_2_c c8_e_3_c c8_e_4_c c3_6_c c4_6_c c3_5_c c4_5_c primary_phone_number_c secondary_phone_number_c other_phone_number_c intl_phone_number_c resp_phone1_c resp_phone2_c tutor_phone_c tutor_phone2_c aa6_yes_numbertrue1 aa6_yes_numbertrue1_c aa6_yes_numbertrue2 aa6_yes_numbertrue2_c aa6_yes_checktrue aa6_yes_checktrue_c aa6_yes_knownumbertrue aa6_yes_knownumbertrue_c aa6_yes_regtrue aa6_yes_regtrue_c aa6_yes_distrue aa6_yes_distrue_c aa6_yes_knowdirectionstrue aa6_yes_knowdirectionstrue_c aa6_yes_knowloctrue aa6_yes_knowloctrue_c aa6_yes_viltrue aa6_yes_viltrue_c aa6_yes_directionstrue aa6_yes_directionstrue_c aa6_no_other aa6_no_other_c a17_baseline_c a17_2_c a11_c a12_c a13_c a14_c   a14a_c uceresult_school_name SCS_schoolname2014 SCS_schoolname2015 SCS_schoolname2016 SCS_schoolname2017 UNEB_schoolname uceresult_index_number
    
	foreach var of local identifymain_vars {
		
		capture drop `var'
	}


	local identifyroster_vars `cl_e_name'  `cl_hhchd' `cl_hhm' `cl_d3' `cl_kid' `cl_kid1'  cl_chld_list cl_fchld_list cl_mem_list cl_fmem_list `o6_c' `bb_4_201_c' `bb_4_201_other' `bb_4_201_other_c'
	
	foreach var of local identifyroster_vars {
		
		capture drop `var'
	}

save "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data_deid.dta", replace
