*---------------------------------------------------------------------------*
*Description: 	Generate education outcomes for applicants					*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*Input:													     				*
*Output:	*Data - Analysis/Temp/Cohort2014_2015_AttritionAnalysis_Data.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on

*Upload dataset
use "$applicant_enc/Data/LTFU_Cohort_2014_2015_ApplicantDataset_cleaned.dta", clear

keep id_new participation gender_app aa6 c0_c c1_1_c c1_2_c c1_3_c c3_1_c c4_1_c c3_9_c c4_9_c c7_c c8_1_c c8_2_c c8_3_c c8_4_c c8_5_c c8_6_c c8_7_c c8_8_c c8_9_c c8_10_c c8_11_c c8_12_c c8_h3_1_c c8_h3_2_c c8_h3_3_c c8_h3_4_c e1_1_c c3_19_c c3_20_c c3_23_c c3_23chk_c c3_23b_c c3_24_c c3_26_c c4_19_c c4_20_c c4_23_c c4_23chk_c c4_24_c c4_26_c c3_13_c c4_13_c h1_c h2_c h3_c h4_c h5_c h6_c h7_c h8_c h9_c h10_c h11_c h12_c h13_c h14_c h15_c h16_c h17_c h18_c h19_c h20_c h21_c h22_c pov0_c c3a_c pov1_c pov3_c pov4_c pov5_c pov6_c pov7_c pov8_c pov9_c pov10_c 

 
** Cleaning completing date vairables
**Creating variables to record year of completion 
forvalues i = 1(1)12{
    gen c8_`i'_year_c = ""
	label var c8_`i'_year_c "When did you complete or estimate to complete your `i' lvl"  
	
}

** only keeping year
local year "c8_h3_1_c c8_h3_2_c c8_h3_3_c c8_h3_4_c"
foreach var in `year'{
    gen `var'_year = year(`var')
}

**Concat all years into one string variable 
egen all_years = concat(c8_h3_*_c_year), punct(",") 
replace all_years = all_years + "," 			// splitting numbers below based on "," 

sort id_new
gen num = _n
local N = _N


**FIXMERA: doest account for dates if all 4 columns are true and for missing values in the middle - fixed by hard coding below 
forvalues x = 1(1)`N'{
	forvalues i = 1(1)12 {
		replace c8_`i'_year_c = substr(all_years, 1, strpos(all_years, ",") - 1) if c8_`i'_c == 1 & num == `x' & substr(all_years, 1, 1) != "."
		replace all_years = strltrim(subinstr(subinstr(all_years,substr(all_years, 1, 4),"", 1),",","",1)) if c8_`i'_c == 1 & num == `x' & substr(all_years, 1, 1) != "."
		
		// if year attended school is missing
		**replace c8_`i'_year_c = substr(all_years, 1, strpos(all_years, ",") - 1) if c8_`i'_c == 1 & num == `x' & substr(all_years, 1, 1) != "."
		replace all_years = strltrim(subinstr(subinstr(all_years,substr(all_years, 1, 1),"", 1),",","",1)) if c8_`i'_c == 1 & num == `x' & substr(all_years, 1, 1) == "."
		
			}
			
		}

		
** FIXMERA: hard coding here, to be generalized later
replace c8_2_year_c = "" if id_new == 1421019 
replace c8_6_year_c = "2021" if id_new == 1421019 


**Dropping unnecessary variables 
drop `year' c8_h3_*_c_year all_years num c8_?_c c8_??_c

**Destring vairables
destring c8_*_year_c, replace 

rename pov*_c pov*_a_c		//Alum poverty score
rename c3a_c c3a_a_c
rename h*_c h*_a_c			// Alum psychological well-being

*Updates for merging with Standardized dataset
/*
rename id id_new 
*/

gen alum = 1 

gen ltfu = 1
gen baseline = 0

rename participation participation_alum

tempfile temp1
save `temp1'

*Upload stadardized dataset 
use "$caregiver_enc/data/LTFU_Cohort_2014_2015_StandardizedDataset.dta", clear

merge 1:1 id_new ltfu baseline using `temp1'

/*
    Result                      Number of obs
    -----------------------------------------
    Not matched                            31
        from master                         0  (_merge==1)
        from using                         31  (_merge==2)			// FIXMEBL: FYI: found applicant but did not find caregiver during survey 

    Matched                             5,314  (_merge==3)
    -----------------------------------------
*/

/* Rerunning yields different matches but I believe the above is incorrect. Why would the applicant roster merge with appended baseline and FU data? What I do not understand is the difference in sample size.

Result                      Number of obs
    -----------------------------------------
    Not matched                         4,484
        from master                     4,184  (_merge==1)
        from using                        300  (_merge==2)

    Matched                             1,130  (_merge==3)
    -----------------------------------------
*/

