   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               Mastercard Foundation Scholarship Program Uganda       *
   *               Long-term Follow-up								      *
   *               APPLICANT MASTER DO_FILE                               *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      Long term follow up of the Mastercard Foundation Scholarship Program Uganda in 2022

       ** OUTLINE:      PART 1: Set globals for dynamic file paths for Applicant data
                        PART 2: Set globals for constants and varlist
                               used across the project. Install all user-contributed
                               commands needed.
                        PART 3: Call the task-specific master do-files 
                               that call all dofiles needed for that 
                               task. Do not include Part 0-2 in a task-
                               specific master do-file


       ** IDS VAR:      list_ID_var_here         //Uniquely identifies households (update for your project)

       ** NOTES:

       ** WRITTEN BY:   Bendetta Lerva, Raaga Akkineni

       ** Last date modified: 03 D 2024
       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           - Set the global box to point to the project folder
   *            on each collaborator's computer.
   *           - Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *

* These lines are used to test that the name is not already used (do not edit manually)
*round**************************************************************************
*untObs*************************************************************************
*subFld*************************************************************************
*iefolder will not work properly if the lines above are edited


   * Project folder globals
   * ---------------------

*iefolder*1*FolderGlobals*subfolder*********************************************
*iefolder will not work properly if the line above is edited


*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited

*iefolder*1*FolderGlobals*encrypted*********************************************
*iefolder will not work properly if the line above is edited

*iefolder*1*FolderGlobals*endRounds*********************************************
*iefolder will not work properly if the line above is edited

		global mastdata_ap              "$applicant_mast/Data" 			// Applicant Data 

*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, different sets of control variables,
   * adofile paths etc.
   
	global districtFE i.NSC_intdcode
	
	**Control Variables
	global control_vars_alum  T_0 $districtFE cohort2014 gender_app survey_year_a 
   
	global control_vars_alum_gender T_0 $districtFE cohort2014 survey_year_a
	
	global control_vars_alum_gender_inter T_0##gender_app $districtFE cohort2014 survey_year_a


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited


*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DOFILE
   *
   *           - When survey rounds are added, this section will
   *            link to the master dofile for that round.
   *           - The default is that these dofiles are set to not
   *            run. It is rare that all round-specfic master dofiles
   *            are called at the same time; the round specific master
   *            dofiles are almost always called individually. The
   *            exception is when reviewing or replicating a full project.
   *
   * ******************************************************************** *
   
   global mastdata_do_ap              "$applicant_mast_gt/Dofiles" 			// .do files for caregiver master data 
 
 *ACTION NEEDED: Set this value to "1" to run corresponding .do files 

 
********************************************************************************
*							 VARIABLE CONSTRUCTION							   *
******************************************************************************** 
  
 ** Variable Construction 
   global applicant_construction	1			// Runs .do file which constructs variables for Caregiver dataset
   
      if $applicant_construction == 1 {
       
		do "$mastdata_do_ap/Construction/LTFU2022_Cohort_2014_2015_OutcomesCreation_Applicant.do" 	
   }
   
********************************************************************************
*							 OUTPUT CREATION								   *
********************************************************************************


********************************************************************************
*							 Tables (Latex files)							   *
********************************************************************************
	
	
	*		Table VI: APPLICANTS' EMPLOYMENT, PAST 12 MONTHS (ITT Effects/ITT Effects_Horizontal/RI_Bounds/Tab15_applicant_RI_bounds_MHT_H)		   *
	*	 	Table B.VI: INDICES FOR COGNITIVE AND SOCIO-EMOTIONAL SKILLS (ITT Effects/ITT Effects_Horizontal/RI_Bounds/Tab16_applicant_RI_bounds_MHT_H)	   *
	
   global applicant_ITTeffect  		1			// Runs .do file builds tables for Applicant dataset
   
      if $applicant_ITTeffect == 1 {

	  do "$mastdata_do_ap/Tables/LTFU2022_Cohort_2014_2015_ITT_Effects_Applicant_RI_bounds_MHT.do" 
   }
   
   ***Tables by Gender: 
   ** Table B.V: ACTUAL AND DESIRED FERTILITY, OVERALL AND BY GENDER (ITT Effects/Gendered ITT Effects_Horizontal/Tab12_applicant_gender_H)**
   ** Table B.VII: APPLICANTS' ACTIVITY OVERALL AND BY GENDER, PAST 12 MONTHS (ITT Effects/Gendered ITT Effects_Horizontal/Tab15_applicant_gender_H)**
   ** Table B.VIII: APPLICANTS' EMPLOYMENT OVERALL AND BY GENDER, PAST 12 MONTHS (ITT Effects/Gendered ITT Effects_Horizontal/Tab2_applicant_gender_H) **
   
      global applicant_gender  		1			// Runs .do file builds tables for Applicant dataset
   
      if $applicant_gender == 1 {

	  do "$mastdata_do_ap/Tables/LTFU2022_Cohort_2014_2015_ITT_Effects_Applicant_Gender_RI.do" 
   }
   
   
   ***Tables with IV estimates: 
   ** Table F.XII: COGNITIVE SKILLS (ITT Effects/ITT Effects_Vertical/Tab6_applicant)**
   ** Table F.XIII: SELF-EFFICACY (ITT Effects/ITT Effects_Vertical/Tab7_applicant)**
   ** Table F.XIV: SELF-ESTEEM (ITT Effects/ITT Effects_Vertical/Tab8_applicant)**
   ** Table F.XV: RESILIENCE (ITT Effects/ITT Effects_Vertical/Tab9_applicant)**
   ** Table F.XVI: ATTITUDE AND SELF CONFIDENCE (ITT Effects/ITT Effects_Vertical/Tab10_applicant)**
   
   
      global applicant_iv  		1			// Runs .do file builds tables for Applicant dataset
   
      if $applicant_iv == 1 {

	  do "$mastdata_do_ap/Tables/LTFU2022_Cohort_2014_2015_ITT_Effects_Applicant.do" 
   }
  
   
   
********************************************************************************
*							 Figures (.pdf files)							   *
********************************************************************************      
  
	**Figure III: DISTRIBUTION OF THE HIGHEST LEVEL OF COMPLETED EDUCATION (education_ind_levels_CI)**
	
	 global applicant_edu_levels  		1 
	 
	    
   if $applicant_edu_levels == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Education_ind_Levels_CI.do" 
   }
   
   	**Figure IV: FERTILITY AND CONTRACEPTIVE USE BY GENDER (Family_planning_gender)**
	
	 global applicant_family_planning  		1 
	 
	    
   if $applicant_family_planning == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Family_planning_gender.do" 
   }
  
  	
	**Figure  V: APPLICANTS' MAIN ACTIVITY IN THE PAST 12 MONTHS (education_work_split_both_12mths)**
	
	 global applicant_work_study  		1 
	 
	    
   if $applicant_work_study == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Education_Work_gender_split_12.do" 
   }
   
   **Figure A.VII: DISTRIBUTION OF UACE YEAR BY COHORT AND TREATMENT STATUS (UACE)**
   global applicant_uace_hist 			1
   
   if $applicant_uace_hist == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU_Cohort_2014_2015_Applicant_Figures.do" 
   }
   
  
   **Figure  A.VIII: WHAT APPLICANTS THINK IS NEEDED TO FULFILL ASPIRATIONS (Aspirations_education)**
	
	 global applicant_aspiration_edu  	1
	 
	    
   if $applicant_aspiration_edu == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Aspirations_education.do" 
   }
  
	
	
/*  // The following figures are not included in the paper 

	*Figure 1: Bar graph: Highest education attended by T_0 groups - 3 levels  *
	* Output: 																   *
	*	1) Coefplot_summary_T_0.pdf											   *
   
   global applicant_edu_3_levels  		0			// Switch to run .do file

   
   if $applicant_edu_3_levels == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Education_3_Levels.do" 
   }
   
	*Figure 2: Line Graph: Wage over highest attended education by T_0		   *
	* Output: 																   *
	*	1) Coefplot_summary_T_0.pdf											   *

   
   global applicant_pay_edu  			0			// Switch to run .do file

   
   if $applicant_pay_edu == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Education_Pay_3_Levels.do" 
   }   
   
   
   *Figure 3: Bar graph: Highest education attended by T_0 groups - All levels*
	* Output: 																   *
	*	1) Coefplot_summary_T_0.pdf											   *

   
   global applicant_edu_ind_levels  		0			// Switch to run .do file

   
   if $applicant_edu_ind_levels == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU2022_Cohort_2014_2015_Figure_Education_ind_Levels.do" 
   }   
   
      global applicant_time_use  		0			// Switch to run .do file

	*Figure 4: Stacked Bar graph: Applicant Time use        				   *
	* Output: 																   *
	*	1) Time_use.png														   *  
   
   if $applicant_time_use == 1 {
       
	  do "$mastdata_do_ap/Figures/LTFU_Cohort_2014_2015_Applicant_Figures.do" 
   }   
   
   
*/

*iefolder*3*End_RunDofiles******************************************************
*iefolder will not work properly if the line above is edited

