
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Output/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

keep if participation_alum == 1
	
	**Creating a new scores vairables by imputing mock scores if actual scores are missing
	gen out1_olevel_m = out1_olevel if out1_olevel != .
	replace out1_olevel_m = out1_mock_uceaggregate if out1_olevel == .  &  out1_mock_uceaggregate != .
	label var out1_olevel_m "UCE scores with mock imputed"

	gen out1_alevel_m = out1_alevel if out1_alevel != .
	replace out1_olevel_m = out1_mock_uaceaggregate if out1_alevel == .  &  out1_mock_uaceaggregate != .
	label var out1_olevel_m "UACE scores with mock imputed"	
	
	
/*
	foreach var in out1_olevel out1_olevel_m  out1_alevel out1_alevel_m {
		
		sum `var' if ltfu == 1 & T_0 == 0, d 
		
		replace `var' = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var' "`zscorelabel'"

	}
*/
	
	* Set local
	local educ_cat out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 $districtFE gender_app cohort2014, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control vars_treat vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control if _n == 1
				replace vars`var' = vars_treat if _n == 2
				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var')
				
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `out1_olevel', clear

		* Create graphable dataset	
		foreach var in out1_ucesat out1_alevel out1_uacesat out1_tertiary {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout1_olevel counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar varsout1_olevel counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
					(scatter varsout1_olevell counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_olevel) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout1_ucesat counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout1_ucesat counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout1_ucesatl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_ucesat) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///out6_incomePPP_22_L
				(bar varsout1_alevel counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout1_alevel counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
					(scatter varsout1_alevell counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_alevel) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout1_uacesat counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout1_uacesat counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
					(scatter varsout1_uacesatl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_uacesat) mlabs(vsmall) mlabposition(12) mlabgap(0.5) mlabcolor(black)) 		///
				(bar varsout1_tertiary counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar varsout1_tertiary counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
					(scatter varsout1_tertiaryl counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundout1_tertiary) mlabs(vsmall) mlabposition(12) mlabgap(0.5) mlabcolor(black)) 		///	
					///
				(rcap lbout1_olevel ubout1_olevel counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout1_ucesat ubout1_ucesat counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout1_alevel ubout1_alevel counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout1_uacesat ubout1_uacesat counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbout1_tertiary ubout1_tertiary counter if T_0 == 1,  lcolor(black)), ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(1.5 "Completed" 2.75 "O-Level" 4 "Sat for UCE" 5.25 " " 6.5 "Completed" 7.75 "A-Level" 9 "Sat for UACE" 11.5 "Tertiary",  noticks alternate labsize(vsmall)) 																///
			   $TwowayBar
			   
		 graph export "$caregiver_mast/Outputs/Figures/Edu_outcomes_levels.png", replace