
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Output/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

do "$mastdata_do_ap/Figures/GraphFormatting.do" 

**Setting scheme
set scheme tab1 

**Use of time
local time_vars out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep

label define T_0 0 "Control" 1 "Treatment"
label value T_0 T_0

/*
graph bar `time_vars', over(T_0) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use.png", replace



graph bar `time_vars', over(T_0) over(gender_app) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use_gender.png", replace
*/

**graph bar heatdd , over(region) blabel(total)
/*
gen time_use_school = (out0_enrolledschool == 1 & out0_working == 0) if participation_alum == 1
lab var time_use_school "Studying"
gen time_use_work = (out0_enrolledschool == 0 & out0_working == 1) if participation_alum == 1
lab var time_use_work "Working"
gen time_use_both = (out0_enrolledschool == 1 & out0_working == 1) if participation_alum == 1
lab var time_use_both "Both"
gen time_use_neither = (out0_enrolledschool == 0 & out0_working == 0) if participation_alum == 1
lab var time_use_neither "Neither"
*/

**Currently Working
local educ_cat time_use_school time_use_work time_use_both time_use_neither

	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & !missing(`var')
				local controlMean = r(mean)
				
				* Run regression
				qui reg `var' T_0 i.NSC_intdcode cohort2014 gender_app, robust
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1
				
				* Coefficients
				gen vars_control = `controlMean' if T_0 == 0
				gen vars_treat = `controlMean' + _b[T_0] if T_0 == 1
				
				gen var_T`var' = _b[T_0] if T_0 == 1
				
				* Lower and upper bound
				gen lb`var' = vars_treat - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				gen ub`var' = vars_treat + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1
				
				* Collapse t o have one observation for T/C
				gen `var'_o = .
				collapse (firstnm) `var' vars_control vars_treat `var'_o lb`var' ub`var' pval`var' var_T`var', by(T_0)
				sort T_0
				
				* All var variables into one - vars
				replace `var'_o = vars_control if _n == 1
				replace `var'_o = vars_treat if _n == 2
				
				* Var for scatter plot
				gen `var'_ol = `var'_o + (ub`var'-`var'_o)
					
				tempfile `var'
				save "``var''"  
				
			restore
			
			}
		
		use `time_use_school', clear

		* Create graphable dataset	
		foreach var in time_use_work time_use_both time_use_neither{
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") if var_T`var' >= 0.015 | var_T`var' <= -0.015
			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05 
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar time_use_school_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9))						///
				(bar time_use_school_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 			 			///	
/*
					(scatter time_use_school_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundtime_use_school) mlabposition(12) mlabcolor(black)) */ 	///
					(scatter time_use_school_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundtime_use_school) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar time_use_work_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar time_use_work_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter time_use_work_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundtime_use_work) mlabposition(12) mlabcolor(black))  */	///
					(scatter time_use_work_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundtime_use_work) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar time_use_both_o counter if T_0==0, 			///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar time_use_both_o counter if T_0==1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9)) ///
/*
					(scatter time_use_both_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundtime_use_both) mlabposition(12) mlabcolor(black)) */ 	///
					(scatter time_use_both_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundtime_use_both) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar time_use_neither_o counter if T_0==0, 				///
					bcolor("gs10") lcolor("black") barwidth(.9)) 							///
				(bar time_use_neither_o counter if T_0==1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///	
/*
					(scatter time_use_neither_o counter if T_0==0,		///
					msymbol(none) mlabel(vars_roundtime_use_neither) mlabposition(12) mlabcolor(black)) 	 */	///
					(scatter time_use_neither_ol counter if T_0==1,		///
					msymbol(none) mlabel(vars_roundtime_use_neither) mlabposition(12) mlabcolor(black))		///
					///
///
				(rcap lbtime_use_school ubtime_use_school counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbtime_use_work ubtime_use_work counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbtime_use_both ubtime_use_both counter if T_0 == 1,  lcolor(black)) ///
				(rcap lbtime_use_neither ubtime_use_neither counter if T_0 == 1,  lcolor(black)), ///
 ///
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 0.6)																///
			   xlabel(1.5 "School" 4 "Work" 6.5 "Both" 9 "Neither", labsize(vsmall)) 																///
			   $TwowayBar
			   
			    graph export "$applicant_mast/Outputs/Figures/education_work_split.png", replace
				