*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni												*
*Input:													     				*
*Output:	
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1
	
	* Set local
	local educ_cat out18_child out17_contraceptives 
	
	foreach var in `educ_cat'  {	// Loop over each variable in global
			
			preserve
								
				* Generate control mean
				qui sum `var' if T_0 == 0 & gender_app == 0 & !missing(`var')
				local controlMean1 = r(mean)
				
				qui sum `var' if T_0 == 0 & gender_app == 1 & !missing(`var')
				local controlMean2 = r(mean)
				
				* Run regression  - female only 
				qui reg `var' $control_vars_alum if gender_app == 0 
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				gen pval`var' = `pval1' if T_0 == 1 & gender_app == 0
				
				* Coefficients
				gen vars_control`var' = `controlMean1' if T_0 == 0 & gender_app == 0
				gen vars_treat`var' = `controlMean1' + _b[T_0] if T_0 == 1 & gender_app == 0
				
				** Treatment effect
				gen var_T`var' = _b[T_0] if T_0 == 1 & gender_app == 0 
				* Lower and upper bound
				gen lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1 & gender_app == 0
				gen ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1 & gender_app == 0
				
				* Run regression  - male only 
				qui reg `var' $control_vars_alum  if gender_app == 1 
				
				* T-tests
				test _b[T_0] = 0
				local pval1 = r(p)
								
				replace pval`var' = `pval1' if T_0 == 1 & gender_app == 1
				
				* Coefficients				
				replace vars_control`var' = `controlMean2' if T_0 == 0 & gender_app == 1
				
				replace vars_treat`var' = `controlMean2' + _b[T_0] if T_0 == 1 & gender_app == 1
				
				** Treatment effect
				replace var_T`var' = _b[T_0] if T_0 == 1 & gender_app == 1 		
				
				* Lower and upper bound
				replace lb`var' = vars_treat`var' - invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1 & gender_app == 1
				replace ub`var' = vars_treat`var' + invttail(e(df_r),0.025)*_se[T_0] if T_0 == 1 & gender_app == 1
				
				* Collapse t o have one observation for T/C
				gen vars`var' = .
				collapse (firstnm) `var' vars_control`var' vars_treat`var' vars`var' lb`var' ub`var' pval`var' var_T`var', by(T_0 gender_app)
				sort gender_app T_0
				
				* All var variables into one - vars
				replace vars`var' = vars_control`var' if /* T_0 == 0 & gender_app == 1 */ _n == 1

				replace vars`var' = vars_treat`var' if  /* T_0 == 0 & gender_app == 1 */ _n == 2
				
				replace vars`var' = vars_control`var' if /* T_0 == 0 & gender_app == 1 */ _n == 3

				replace vars`var' = vars_treat`var' if  /* T_0 == 0 & gender_app == 1 */ _n == 4

				
				* Var for scatter plot
				gen vars`var'l = vars`var' + (ub`var'-vars`var') if gender_app == 0
					
				tempfile `var'
				save "``var''"  
				
				
				
			restore
			
			}
		

		* Create graphable dataset
		use `out18_child', clear
			
		foreach var in  out17_contraceptives  {
			append using "``var''" 
		}
		
		* Globals for graph formatting do
		global b1title	""
		global b2title	""
		global x1title  ""
		global ytitle1	"% of Applicants"
		global ytitle2	""
		global title1	""
		global title2	""
		global note		""
		
		* Graph Formatting
		do "$mastdata_do_ap/Figures/GraphFormatting.do"
		
		* Set order		
		scalar var_count = `:word count `educ_cat''
		local N = 4*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		replace counter = 3 if _n == 3
		replace counter = 4 if _n == 4
		
		forvalues i = 5(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.7 	if T_0 ==0 & gender_app == 0 & _n == `i'
			replace counter = `x' + 2.7		if T_0 ==1 & gender_app == 0 &  _n == `i'+1
			
			replace counter = `x' + 1		if T_0 ==0 & gender_app == 1 & _n == `i'
			replace counter = `x' + 2 		if T_0 ==1 & gender_app == 1 &  _n == `i'+1
			
		}
		
		
		foreach var in `educ_cat'  {
			* Round variables
			gen vars_round`var' = string(var_T`var', "%3.2f") 


			
			* Add p-value
			replace vars_round`var'=vars_round`var'+"*" if pval`var'<=0.1 & pval`var' > 0.05
			replace vars_round`var'=vars_round`var'+"**" if pval`var'<=0.05 & pval`var' > 0.01
			replace vars_round`var'=vars_round`var'+"***" if pval`var'<=0.01	
		}	
		
		* Plot bar graph
		twoway 	(bar varsout18_child counter if T_0==0 & gender_app == 0, 				///
					bcolor("purple*1.2%25") lcolor("black") barwidth(.9)) 							///
					///
				(bar varsout18_child counter if T_0==1 & gender_app == 0, 				///
					bcolor("purple*.5") lcolor("black") barwidth(.9)) 				///
					(scatter varsout18_childl counter if T_0==1 & gender_app == 0,		///
					msymbol(none) mlabel(vars_roundout18_child) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout18_child counter if T_0==0 & gender_app == 1, 			///
					bcolor("maroon*1.2%25") lcolor("black") barwidth(.9)) 							///
					///
				(bar varsout18_child counter if T_0==1 & gender_app == 1, 				///
					bcolor("maroon") lcolor("black") barwidth(.9)) 				///
					(scatter varsout18_childl counter if T_0==1 & gender_app == 1,		///
					msymbol(none) mlabel(vars_roundout18_child) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(bar varsout17_contraceptives counter if T_0==0 & gender_app == 0 , 			///
					bcolor("purple*1.2%25") lcolor("black") barwidth(.9)) 							///
					///
				(bar varsout17_contraceptives counter if T_0==1 & gender_app == 0 , 			///
					bcolor("purple*.5") lcolor("black") barwidth(.9))							///
					(scatter varsout17_contraceptivesl counter if T_0==1 & gender_app == 0,		///
					msymbol(none) mlabel(vars_roundout17_contraceptives) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
					(bar varsout17_contraceptives counter if T_0==0 & gender_app == 1 , 			///
					bcolor("maroon*1.2%25") lcolor("black") barwidth(.9)) 							///
					///
				(bar varsout17_contraceptives counter if T_0==1 & gender_app == 1, 			///
					bcolor("maroon") lcolor("black") barwidth(.9))							///
					(scatter varsout17_contraceptivesl counter if T_0==1 & gender_app == 1,		///
					msymbol(none) mlabel(vars_roundout17_contraceptives) mlabs(vsmall) mlabposition(12) mlabcolor(black)) 		///
					///
				(rcap lbout18_child ubout18_child counter if T_0 == 1 & gender_app == 0,  lcolor(black)) ///
				(rcap lbout18_child ubout18_child counter if T_0 == 1 & gender_app == 1,  lcolor(black)) ///
				(rcap lbout17_contraceptives ubout17_contraceptives counter if T_0 == 1 & gender_app == 0,  lcolor(black)) ///
				(rcap lbout17_contraceptives ubout17_contraceptives counter if T_0 == 1 & gender_app == 1,  lcolor(black)), ///	 ///
/*
			   xalternate yalternate */ ///
			   legend(order(1 "Control - Female" 2 "Treatment - Female" 4 "Control - Male" 5 "Treatment - Male")) 						///					 
			   ylabel(0 (.2) 1)																///
			   xlabel(2.5 "Has Children" 7.2 "Uses Contraceptives") 		///
			   $TwowayBar
			   
			 graph export "$applicant_mast/Outputs/Figures/Family_planning_gender.png", replace
	
