
*---------------------------------------------------------------------------*
*Description: 	Generate outcome graphs*		
*																			* 
*Date:			12/05/2023													*
*Author:		Raaga Akkineni 												*
*---------------------------------------------------------------------------*
version 17
set more off

clear all
clear mata


**Upload applicant dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if participation_alum == 1

do "$mastdata_do_ap/Figures/GraphFormatting.do" 

**Setting scheme
set scheme tab3 

label define cohort2014 0 "Cohort 2015" 1 "Cohort 2014"
label value cohort2014 cohort2014

label define T_0 0 "Control" 1 "Treatment"
label value T_0 T_0

label define sex_app 0 "Women" 1 "Men"
label value sex_app sex_app


**Histogram - Passed UACE
hist out6_uace_sat, percent  by(cohort2014 T_0) xlabel(2015 (1) 2023) ylabel(0 (50) 100) bcolor("maroon")
graph export "$applicant_mast/Outputs/Figures/UACE.png", replace

// The following figures are not in the paper 

/*
**Use of time
local time_vars out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep

**Time use: by treatment groups
graph bar `time_vars', over(T_0) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						bar(1, color(161	23	39)) bar(2, color(235	148	134)) bar(3, color(	85	91	110)) ///
						bar(4, color(152	193	217)) bar(5, color(	124	174	122)) bar(6, color(195	191	109)) ///
						bar(7, color(gs13)) ///
						legend(size(small)) ///
						legend(rows(2))						
graph export "$applicant_mast/Outputs/Figures/Time_use.png", replace


**Time use: by gender and treat groups
graph bar `time_vars', over(T_0) over(gender_app) stack 	 ///
		legend(order(1 "School" 2 "Study" 3 "Work for household" ///
						4 "Work outside household" 5 "Domestic work" ///
						6 "Unpaid work outside household" 7 "Sleep")) ///
						bar(1, color(161	23	39)) bar(2, color(235	148	134)) bar(3, color(	85	91	110)) ///
						bar(4, color(152	193	217)) bar(5, color(	124	174	122)) bar(6, color(195	191	109)) ///
						bar(7, color(gs13)) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/Time_use_gender.png", replace

**Currently in Education/working: by treatment groups
graph bar time_use_school time_use_work time_use_both time_use_neither, over(T_0) ///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))

graph export "$applicant_mast/Outputs/Figures/school_work.png", replace

**Currently in Education/working: by treatment groups and gender
graph bar time_use_school time_use_work time_use_both time_use_neither, over(T_0) over(gender_app) ///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/school_work_gender.png", replace	

**In Education/working in the past 12 months: by treatment groups
graph bar out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME, over(T_0) ///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))

graph export "$applicant_mast/Outputs/Figures/school_work_12.png", replace

**In Education/working in the past 12 months: by treatment groups and gender
graph bar out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME, over(T_0) over(gender_app) ///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))
graph export "$applicant_mast/Outputs/Figures/school_work_gender_12.png", replace	



local work_edu_vars time_use_school time_use_work time_use_both time_use_neither

		* Set order		
		scalar var_count = `:word count `work_edu_vars''
		local N = 2*var_count
		
		gen counter = 1 if _n == 1
		replace counter = 2 if _n == 2
		
		forvalues i = 3(2)`N' {
			
			local x = counter[`i'-1]
			
			replace counter = `x' + 1.5 	if _n == `i'
			replace counter = `x' + 2.5 		if _n == `i'+1
			
		}


twoway (bar time_use_school counter if T_0 == 0, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) ///
		(bar time_use_school counter if T_0 == 1, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///
		(bar time_use_work counter if T_0 == 0, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) ///
		(bar time_use_work counter if T_0 == 1, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///
		(bar time_use_both counter if T_0 == 0, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) ///
		(bar time_use_both counter if T_0 == 1, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) ///
		(bar time_use_neither counter if T_0 == 0, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) ///
		(bar time_use_neither counter if T_0 == 1, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)), ///
		xlabel(1.5 "School" 4 "Work" 6.5 "Both" 9 "Neither", labsize(vsmall)) ///
		legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))

///
		(bar time_use_work, over(T_0) over(sex_app)) ///
		(bar time_use_both, over(T_0) over(sex_app)) ///
		( bar time_use_neither, over(T_0) over(sex_app)) ///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))

						
						
						
						
						
						
/*

gen 	time_use = 1 if (out0_enrolledschool == 1 & out0_working == 0 & participation_alum == 1)
replace	time_use = 2 if (out0_enrolledschool == 0 & out0_working == 1 & participation_alum == 1)
replace time_use = 3 if (out0_enrolledschool == 1 & out0_working == 1 & participation_alum == 1)
replace time_use = 4 if (out0_enrolledschool == 0 & out0_working == 0 & participation_alum == 1)
label define time_use 1 "Studying" 2 "Working" 3 "Both" 4 "Neither"

gen Control = (T_0 == 0)
gen Treatment = (T_0 == 1)
graph bar Control Treatment, over(time_use) over(sex_app)

///
			legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))


/*
graph bar time_use, over(T_0) ///
		legend(order(1 "School" 2 "Work" ///
						3 "Both" 4 "Neither")) ///
						legend(size(small)) ///
						legend(rows(2))

graph bar, over (time_use) over(T_0)
**graph bar , over (T_0) over(time_use)

graph export "$output/Figures/school_work.png", replace
*/


/*
lab define time_use 1 "Studying" 2 "Working" 3 "Both" 4 "Neither"
*/



/*

**Plot graph
twoway 	(bar time_use if T_0 ==0 & time_use == 1, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar time_use if T_0 ==1 & time_use == 1, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) 						///				
				(bar time_use if T_0 ==0 & time_use == 2, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar time_use if T_0 ==1 & time_use == 2, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) 						///	
				(bar time_use if T_0 ==0 & time_use == 3, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar time_use if T_0 ==1 & time_use == 3, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)) 						///	
				(bar time_use if T_0 ==0 & time_use == 4, 				///
					bcolor("$blue2") lcolor("black") barwidth(.9)) 							///
				(bar time_use if T_0 ==1 & time_use == 4, 				///
					bcolor("$wfp_blue1") lcolor("black") barwidth(.9)), 						///		
			   legend(order(1 "Control" 2 "Treatment")) 						///					 
			   ylabel(0 (.1) 1)																///
			   xlabel(none) 																///
			   $TwowayBar
			   
			   graph export "$output/Figures/Work_study.png", replace
*/
