
*---------------------------------------------------------------------------*
*Description: 	Generate outcomes for analysis 								*		
*																			* 
*Date:			10/10/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Temp/Cohort2014_2015_AttritionAnalysis_Data.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*

*************************************
* INDEX								*
* 									*
*PART I								*
* 	0.Preliminaries					*
*	1.Aggregate, Standardize Data	*
*	2.Select Sample					*
*	3.Define Treatment Variables	*
*	4.Define Identifiers			*
*									*
*PART II							*
*	Outcome 0: Demographics			*
*	Outcome 1: Education			*
*	Outcome 2: Health				*
*	Outcome 3: Dietary Diversity	*	
*	Outcome 4: Assets				*
* 									*
*************************************


version 17
set more off

clear all
clear mata

pause on

set seed 20200501

**Upload dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if baseline == 1  // keep only baseline sample

**Rename variables to avoid running out of varname characters allowed
rename *raw_score* *raw*
rename out12_ravens_attempted_raw out12_ravens_att_raw
rename out6_monthlyprofitPPP_22 out6_monthprofitPPP_22
rename out4_assets_*PPP_22 out4_*PPP_22


*All indices
local indices index_scholarship index_wage_activity index_business index_cognitive index_timeuse index_psych_skills index_self_esteem index_resilience index_attitude



foreach var in out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw `indices' {
		
		di `var'
		
		sum `var' if T_0 == 0 & participation_alum == 1, d 
		
		gen `var'_Z= 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"

	}


	local outcomes out1_receivescholarship out1_acceptscholarship out6_wage_activity out6_fulltime out6_contract out6_ownbusiness out17_drinking out17_contraceptives out17_transactionalsex out18_child out0_caregiver out0_partner out1_scholarshipmonths out1_scholarshipitems out4_landPPP_22 out4_housePPP_22 out4_furniturePPP_22 out4_machinePPP_22 out4_stockPPP_22 out4_otherPPP_22 out6_education out6_pay out6_monthlyprofit out6_avg_profit out6_monthlyhrs out6_totalhrs out6_payPPP_22 out6_monthprofitPPP_22 out6_avg_profitPPP_22 out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw out12_dight_fwd_raw_Z out12_dight_bkwd_raw_Z out12_dight_tot_raw_Z out12_rds_fwd_Z out12_rds_bkwd_Z out12_rds_Z out12_ravens_Z out12_ravens_att_raw_Z out18_numchild out18_numchild_d out0_alone out0_hhsize out0_minor g1a_c g1b_c g1c_c g1d_c g1e_c g1f_c g1g_c g1h_c g1i_c g1j_c g2a_c g2b_c g2c_c g2d_c g2e_c g2f_c g2g_c g2h_c g2i_c g2j_c g3a_c g3b_c g3c_c g3d_c g3e_c g3f_c g3g_c g3h_c g3i_c g3j_c g3k_c g3l_c g3m_c g3n_c g3o_c g3p_c g3q_c g3r_c g3s_c g3t_c g3u_c g3v_c g3w_c g3x_c g3y_c g3a1_c g3b1_c g3c1_c g3d1_c g3e1_c g3f1_c g3g1_c g3h1_c g3i1_c g3j1_c index_scholarship_Z index_wage_activity_Z index_business_Z index_cognitive_Z index_timeuse_Z index_psych_skills_Z index_self_esteem_Z index_resilience_Z index_attitude_Z out6_numactivites out6_pay_cPPP_22 out6_fulltime_c out6_intern out6_pay_mthPPP_22 out6_pay_mth_cPPP_22 out6_worktime out0_urban out0_moved_urban out0_moved_rural out6_inc_skilled out6_inc_nonmanual out6_inc_selfemployed out6_inc_activity out6_inc_month out6_avg_inc_cPPP_22 out6_inc_activity_12 out6_wage_act_12 out6_intern_12     
	
foreach yvar of local outcomes {
		
	// Imputation bounds: Calculate mean & s.d. within treatment-season bins

		bys T_0: egen `yvar'_mean = mean(`yvar')
		bys T_0: egen `yvar'_sd   = sd(`yvar')
	
		// Correct Outcome Variable
		
		gen `yvar'_L5 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U5 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_L10 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U10 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_L20 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U20 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0

		replace `yvar'_U5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 1 
		replace `yvar'_U5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 0 
		
		replace `yvar'_L5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 1 
		replace `yvar'_L5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 0 

		replace `yvar'_U10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 1 
		replace `yvar'_U10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 0 
	
		replace `yvar'_L10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 1 
		replace `yvar'_L10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 0 

		replace `yvar'_U20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 1 
		replace `yvar'_U20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 0 
	
		replace `yvar'_L20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 1 
		replace `yvar'_L20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 0 

		}
		
		** Lee Bounds
	local outcomes_binary out6_inc_activity out6_wage_activity out6_inc_selfemployed out6_intern out6_inc_nonmanual out17_contraceptives out6_inc_activity_12 out6_wage_act_12 out6_intern_12


	local outcomes_conts out6_pay_mth_cPPP_22 out6_inc_month out18_child out18_numchild out18_numchild_d out6_avg_inc_cPPP_22   
	
	* From table printed in AttritionTable.do,  need to trim 155 observations from treatment to equalize attrition with C (54%) (for continuous vars, 33%).

	* Binary variables
	
	cap drop random1
	
	sort id_new
	
	gen random1=uniform()


	foreach var of local outcomes_binary {

		gen `var'_lt=`var'
	
		gen `var'_ut=`var'

		sort T_0 `var' random1

		egen grp_`var'=group(T_0 `var'), missing /* 4 groups: T = 0 & var = 0, T = 0 & var = 1, T = 1 & var = 0, T = 1 & var = 1*/

		egen rank_`var'=rank(random1), by(grp_`var') 

		replace `var'_lt=. if rank_`var'<= 155 & T_0 == 1 & `var' ==0

		replace `var'_ut=. if rank_`var'<= 155 & T_0 == 1 & `var' ==1

	}
	
	
	* Continuous variables
	
	foreach var of local outcomes_conts {
	
	gen `var'_lt=`var'
	
	gen `var'_ut=`var'

	sort T_0 `var' random1

	egen grp_`var'=group(T_0 `var'), missing
	
	egen rank_`var'=rank(random1), by(grp_`var') 

	replace `var'_lt=. if rank_`var'<= 155 & T_0 == 1 & `var'==0
	
	egen lwr_`var'=pctile(`var') 	if 	T_0 == 1 , p(33)
	
	replace `var'_lt=. 			if  T_0 == 1 & `var'<lwr_`var'

	drop lwr_`var'

	egen upr_`var'=pctile(`var') 	if 	T_0 == 1 , p(33)
	
	replace `var'_ut=. 			if  T_0 == 1 & `var'>upr_`var'

	drop upr_`var'

}	



/*
local tab0outcomes index_cognitive_Z index_psych_skills_Z index_self_esteem_Z index_resilience_Z index_attitude_Z

local tab1outcomes out1_receivescholarship out1_acceptscholarship out1_scholarshipmonths out1_scholarshipitems
*/

local tab2outcomes out6_inc_activity out6_wage_activity out6_intern /* out6_inc_selfemployed */ /* out6_payPPP_22 out6_pay_mthPPP_22 */ /* out6_pay_cPPP_22 */ /* out6_pay_mth_cPPP_22 */ out6_avg_inc_cPPP_22  /* out6_contract */ /* out6_worktime */ out6_inc_month /* out6_inc_skilled */ out6_inc_nonmanual

/*
local tab3outcomes out6_ownbusiness out6_numactivites out6_monthprofitPPP_22 out6_avg_profitPPP_22 out6_monthlyhrs out6_totalhrs

local tab4outcomes out4_landPPP_22 out4_housePPP_22 out4_furniturePPP_22 out4_machinePPP_22 out4_stockPPP_22 out4_otherPPP_22

local tab5outcomes out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out

local tab6outcomes out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw

local tab7outcomes g1a_c g1b_c g1c_c g1d_c g1e_c g1f_c g1g_c g1h_c g1i_c g1j_c

local tab8outcomes g2a_c g2b_c g2c_c g2d_c g2e_c g2f_c g2g_c g2h_c g2i_c g2j_c

local tab9outcomes g3a_c g3b_c g3c_c g3d_c g3e_c g3f_c g3g_c g3h_c g3i_c g3j_c g3k_c g3l_c g3m_c g3n_c g3o_c g3p_c g3q_c g3r_c g3s_c g3t_c g3u_c g3v_c g3w_c g3x_c g3y_c

local tab10outcomes g3a1_c g3b1_c g3c1_c g3d1_c g3e1_c g3f1_c g3g1_c g3h1_c g3i1_c g3j1_c

local tab11outcomes out17_drinking out17_contraceptives out17_transactionalsex
*/

local tab12outcomes out18_child out18_numchild out18_numchild_d out17_contraceptives

/*
local tab13outcomes out0_alone out0_caregiver out0_partner out0_hhsize out0_minor

local tab14outcomes out0_urban out0_moved_urban out0_moved_rural
*/

local tab15outcomes out6_inc_activity_12 out6_wage_act_12 out6_intern_12 /* out6_inc_selfemployed */ /* out6_avg_incPPP_22 */ out6_avg_inc_cPPP_22 out6_inc_month  out6_inc_nonmanual 

local alltablesno 	= 2
	

**Tables in BL's format: With Lee bounds
forvalues tableno = 2(1)`alltablesno' {
	
	scalar var_count = `:word count `tab`tableno'outcomes''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Horizontal/RI_Bounds/Tab`tableno'_applicant_MHT_RI_bounds_H.tex", write replace
	
	**Variable name
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		local variable: var label `outcome'
		local variable "`variable'"
		
		file write output_file " & `variable'"
		
		 qui reg `outcome' $control_vars_alum  /* T_0 $districtFE cohort2014 gender_app survey_year_a */  if participation_alum == 1
		scalar n_`outcome' = e(N)
		scalar beta_`outcome' = e(b)[1,1]
		
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
	
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)
		
		// Multiple Hypothesis Testing 
			mhtreg (`outcome' $control_vars_alum), robust seed(20200501)
			scalar mht_p_`outcome' = r(results)[1,4]
			
		// Randomization Inference
			ritest T_0 _b[T_0], reps(1000) seed(20200501): reg `outcome' $control_vars_alum, robust
			matrix pvalues=r(p) // save the p-values from ritest
			scalar ri_p_`outcome' = r(p)[1,1]		
			
		
		//Lee Bounds
			
			// Upper Lee Bounds
			qui reg `outcome'_ut $control_vars_alum, robust 
			
			scalar betaU_`outcome' = e(b)[1,1]
			scalar sd_betaU_`outcome' = sqrt(e(V)[1,1])
			scalar Upvalue_`outcome' = r(table)[4,1]
			
			// Lower Lee Bound Column
			qui reg `outcome'_lt $control_vars_alum, robust
			
			scalar betaL_`outcome' = e(b)[1,1]
			scalar sd_betaL_`outcome' = sqrt(e(V)[1,1])
			scalar Lpvalue_`outcome' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`outcome'  < 0.10 local stars`coltype'_`outcome'   "*"
			
			if `coltype'pvalue_`outcome'  < 0.05 local stars`coltype'_`outcome'   "**"
			
			if `coltype'pvalue_`outcome'  < 0.01 local stars`coltype'_`outcome'   "***"
			
			}
		
		// Fairlie Bound
		foreach boundtype in U5 L5 U10 L10 U20 L20 {			
				
		qui reg `outcome'_`boundtype' $control_vars_alum  /* T_0 $districtFE cohort2014 gender_app survey_year_a  */, robust
		scalar obs = e(N)

		scalar beta_`outcome'`boundtype' = e(b)[1,1]
		scalar sd_`outcome'`boundtype' = sqrt(e(V)[1,1])
		scalar pv_`outcome'`boundtype' = r(table)[4,1]

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if pv_`outcome'`boundtype' < 0.10 local str_`outcome'`boundtype'  "*"
			
			if pv_`outcome'`boundtype' < 0.05 local str_`outcome'`boundtype'  "**"
			
			if pv_`outcome'`boundtype' < 0.01 local str_`outcome'`boundtype'  "***"
		}
		
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}


	file write output_file " \\ " _n
	file write output_file " \hline \\ " 

	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome''}$} " 
		
		}
	
	file write output_file " \\ " 	_n	

	
	** Multiple Hypothesis Testing
	
/*
	file write output_file "MHT"
*/
	
	foreach outcome of local tab`tableno'outcomes {
		
		file write output_file " & {\scriptsize{" %5.3f (mht_p_`outcome') "} } "
	}
	file write output_file " \medskip \\  " 	_n
	
	
	
	** Radomization Inference 
	
/*
	file write output_file "RI"
*/
	
	foreach outcome of local tab`tableno'outcomes {
		
		file write output_file " & {\scriptsize[" %5.3f (ri_p_`outcome') "] } "
	}
	file write output_file " \medskip \\  " 	_n
	
	
	*Lee Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Lee Bounds - Point Estimates}} \\" 
	
		foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (betaU_`outcome' ) "," %8.2fc (betaL_`outcome' )  "] } "
		
		}
		file write output_file " \medskip \\  " 	_n	
	
	*Fairlie Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Fairlie Bounds - Point Estimates}} \\" 
	
	*5% Imputations
	file write output_file "5\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U5) "," %8.2fc (beta_`outcome'L5) "] } "
		
		}
	file write output_file " \\ " _n
	
	*10% Imputations
	file write output_file "10\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U10) "," %8.2fc (beta_`outcome'L10) "] } "
		
		}
	file write output_file " \\ " _n
	
	*20% Imputations
	file write output_file "20\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U20) "," %8.2fc (beta_`outcome'L20) "] } "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \bigskip \\ " _n
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}	
