
*---------------------------------------------------------------------------*
*Description: 	Generate outcomes for analysis 								*		
*																			* 
*Date:			10/10/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Temp/Cohort2014_2015_AttritionAnalysis_Data.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*

*************************************
* INDEX								*
* 									*
*PART I								*
* 	0.Preliminaries					*
*	1.Aggregate, Standardize Data	*
*	2.Select Sample					*
*	3.Define Treatment Variables	*
*	4.Define Identifiers			*
*									*
*PART II							*
*	Outcome 0: Demographics			*
*	Outcome 1: Education			*
*	Outcome 2: Health				*
*	Outcome 3: Dietary Diversity	*	
*	Outcome 4: Assets				*
* 									*
*************************************


version 17
set more off

clear all
clear mata

pause on

set seed 20200501

**Upload dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if baseline == 1  // keep only baseline sample

**Rename variables to avoid running out of varname characters allowed
rename *raw_score* *raw*
rename out12_ravens_attempted_raw out12_ravens_att_raw
rename out6_monthlyprofitPPP_22 out6_monthprofitPPP_22
rename out4_assets_*PPP_22 out4_*PPP_22


*All indices
local indices index_scholarship index_wage_activity index_business index_cognitive index_timeuse index_psych_skills index_self_esteem index_resilience index_attitude



foreach var in out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw `indices' {
		
		di `var'
		
		sum `var' if T_0 == 0 & participation_alum == 1, d 
		
		gen `var'_Z= 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"

	}


	local outcomes out1_receivescholarship out1_acceptscholarship out6_wage_activity out6_fulltime out6_contract out6_ownbusiness out17_drinking out17_contraceptives out17_transactionalsex out18_child out0_caregiver out0_partner out1_scholarshipmonths out1_scholarshipitems out4_landPPP_22 out4_housePPP_22 out4_furniturePPP_22 out4_machinePPP_22 out4_stockPPP_22 out4_otherPPP_22 out6_education out6_pay out6_monthlyprofit out6_avg_profit out6_monthlyhrs out6_totalhrs out6_payPPP_22 out6_monthprofitPPP_22 out6_avg_profitPPP_22 out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out out11_time_sleep out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw out12_dight_fwd_raw_Z out12_dight_bkwd_raw_Z out12_dight_tot_raw_Z out12_rds_fwd_Z out12_rds_bkwd_Z out12_rds_Z out12_ravens_Z out12_ravens_att_raw_Z out18_numchild out18_numchild_d out0_alone out0_hhsize out0_minor g1a_c g1b_c g1c_c g1d_c g1e_c g1f_c g1g_c g1h_c g1i_c g1j_c g2a_c g2b_c g2c_c g2d_c g2e_c g2f_c g2g_c g2h_c g2i_c g2j_c g3a_c g3b_c g3c_c g3d_c g3e_c g3f_c g3g_c g3h_c g3i_c g3j_c g3k_c g3l_c g3m_c g3n_c g3o_c g3p_c g3q_c g3r_c g3s_c g3t_c g3u_c g3v_c g3w_c g3x_c g3y_c g3a1_c g3b1_c g3c1_c g3d1_c g3e1_c g3f1_c g3g1_c g3h1_c g3i1_c g3j1_c index_scholarship_Z index_wage_activity_Z index_business_Z index_cognitive_Z index_timeuse_Z index_psych_skills_Z index_self_esteem_Z index_resilience_Z index_attitude_Z out6_numactivites out6_pay_cPPP_22 out6_fulltime_c out6_intern out6_pay_mthPPP_22 out6_pay_mth_cPPP_22 out6_worktime out0_urban out0_moved_urban out0_moved_rural out6_inc_skilled out6_inc_nonmanual out6_inc_selfemployed out6_inc_activity out6_inc_monthPPP_22 out6_avg_inc_cPPP_22 out6_inc_month
	
	lab var index_cognitive "Cognitive Skills Index"
	lab var index_cognitive_Z "Cognitive Skills Index"

	lab var index_psych_skills "Self-Efficacy Index"
	lab var index_psych_skills_Z "Self-Efficacy Index"

	lab var index_attitude "Self-Confidence Index"
	lab var index_attitude_Z "Self-Confidence Index"

// Locals commented out are not in the paper	
/*
local tab0outcomes index_cognitive_Z index_psych_skills_Z index_self_esteem_Z index_resilience_Z index_attitude_Z

local tab1outcomes out1_receivescholarship out1_acceptscholarship out1_scholarshipmonths out1_scholarshipitems

local tab2outcomes /* out6_education  out6_inc_activity */ out6_wage_activity out6_intern /* out6_inc_selfemployed */ /* out6_payPPP_22 out6_pay_mthPPP_22 */ /* out6_pay_cPPP_22 */ /* out6_pay_mth_cPPP_22 */ out6_avg_inc_cPPP_22  /* out6_contract */ /* out6_worktime */ out6_inc_month /* out6_inc_skilled */ out6_inc_nonmanual

local tab3outcomes out6_ownbusiness out6_numactivites out6_monthprofitPPP_22 out6_avg_profitPPP_22 out6_monthlyhrs out6_totalhrs

local tab4outcomes out4_landPPP_22 out4_housePPP_22 out4_furniturePPP_22 out4_machinePPP_22 out4_stockPPP_22 out4_otherPPP_22

local tab5outcomes out11_time_school out11_time_study out11_time_familywork out11_time_work_out out11_time_domesticwork out11_unpaidwork_out
*/

local tab6outcomes out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw index_cognitive  // in the paper 

local tab7outcomes g1a_c g1b_c g1c_c g1d_c g1e_c g1f_c g1g_c g1h_c g1i_c g1j_c index_psych_skills  // in the paper 

local tab8outcomes g2a_c g2b_c g2c_c g2d_c g2e_c g2f_c g2g_c g2h_c g2i_c g2j_c index_self_esteem  // in the paper 

local tab9outcomes g3a_c g3b_c g3c_c g3d_c g3e_c g3f_c g3g_c g3h_c g3i_c g3j_c g3k_c g3l_c g3m_c g3n_c g3o_c g3p_c g3q_c g3r_c g3s_c g3t_c g3u_c g3v_c g3w_c g3x_c g3y_c index_resilience   // in the paper 

local tab10outcomes g3a1_c g3b1_c g3c1_c g3d1_c g3e1_c g3f1_c g3g1_c g3h1_c g3i1_c g3j1_c index_attitude  // in the paper 

/*
local tab11outcomes out17_drinking out17_contraceptives out17_transactionalsex


local tab12outcomes out18_child out18_numchild out18_numchild_d out17_contraceptives 


local tab13outcomes out0_alone out0_caregiver out0_partner out0_hhsize out0_minor

local tab14outcomes out0_urban out0_moved_urban out0_moved_rural
*/


local alltablesno 	= 14
	



forvalues tableno = 6(1)10 {
	
	capture file close output_file	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Vertical/Tab`tableno'_applicant.tex", write replace
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// ITT Estimates
		local variable: var label `outcome'
		*local variable "`variable'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE cohort2014 gender_app survey_year_a */ if participation_alum == 1, robust
		scalar obs = e(N)

		scalar betaT = e(b)[1,1]
		scalar sd_betaT = sqrt(e(V)[1,1])
		scalar betaTpvalue = r(table)[4,1]
		
		qui sum `outcome' if T_0 == 0
		scalar mean_C = r(mean)
		scalar sd_C = r(sd)
		
		// Add Significance Stars
		
		local starsT ""
						
			if betaTpvalue < 0.10 local starsT  "*"
			
			if betaTpvalue < 0.05 local starsT  "**"
			
			if betaTpvalue < 0.01 local starsT  "***"
		
		****** IV Estimates
		
		qui ivregress 2sls `outcome' (NSC_final_select = T_0) $districtFE cohort2014 gender_app if participation_alum == 1

		scalar betaIV = e(b)[1,1]
		scalar sd_betaIV = sqrt(e(V)[1,1])
		scalar betaIVpvalue = r(table)[4,1]

		// Add Significance Stars
		
		local starsIV ""
						
			if betaIVpvalue < 0.10 local starsIV  "*"
			
			if betaIVpvalue < 0.05 local starsIV  "**"
			
			if betaIVpvalue < 0.01 local starsIV  "***"
		file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (betaIV) " & " %8.2fc (mean_C) " & " %5.0fc (obs) " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$("%8.2fc (sd_betaIV) ")^{`starsIV'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} & \medskip \\ " 	_n

			
		}
		
	
	file close output_file


	}

