
*---------------------------------------------------------------------------*
*Description: 	Applicant Dataset - Education/Working by treatment groups	*		
*																			* 
*Date:			03/07/2024													*
*Author:		Raaga Akkineni 												*
*Input:													     				*
*Output:	*Applicant_workEdu.tex											*	
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on 
set seed 20200501

**Upload dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if baseline == 1  // keep only baseline sample

/*
gen time_use_school = (out0_enrolledschool == 1 & out0_working == 0) if participation_alum == 1
lab var time_use_school "Studying"
gen time_use_work = (out0_enrolledschool == 0 & out0_working == 1) if participation_alum == 1
lab var time_use_work "Working"
gen time_use_both = (out0_enrolledschool == 1 & out0_working == 1) if participation_alum == 1
lab var time_use_both "Both"
gen time_use_neither = (out0_enrolledschool == 0 & out0_working == 0) if participation_alum == 1
lab var time_use_neither "Neither"
*/

/*
**Rename variables to avoid running out of varname characters allowed
rename *raw_score* *raw*
rename out12_ravens_attempted_raw out12_ravens_att_raw
rename out6_monthlyprofitPPP_22 out6_monthprofitPPP_22
rename out4_assets_*PPP_22 out4_*PPP_22


*All indices
local indices index_scholarship index_wage_activity index_business index_cognitive index_timeuse index_psych_skills index_self_esteem index_resilience index_attitude



foreach var in out12_dight_fwd_raw out12_dight_bkwd_raw out12_dight_tot_raw out12_rds_fwd out12_rds_bkwd out12_rds out12_ravens out12_ravens_att_raw `indices' {
		
		di `var'
		
		sum `var' if T_0 == 0 & participation_alum == 1, d 
		
		gen `var'_Z= 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"

	}
*/


	local outcomes time_use_school time_use_work time_use_both time_use_neither out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME out6_inc_study_12_ME out6_inc_act_12_ME out6_inc_both_12_ME out6_inc_nth_12_ME
		
foreach yvar of local outcomes {
		
	// Imputation bounds: Calculate mean & s.d. within treatment-season bins

		bys T_0: egen `yvar'_mean = mean(`yvar')
		bys T_0: egen `yvar'_sd   = sd(`yvar')
	
		// Correct Outcome Variable
		
		gen `yvar'_L5 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U5 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_L10 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U10 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_L20 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0
		gen `yvar'_U20 = `yvar' if notfoundatLTFU == 0 | notfoundatFU == 0

		replace `yvar'_U5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 1 
		replace `yvar'_U5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 0 
		
		replace `yvar'_L5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 1 
		replace `yvar'_L5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 0 

		replace `yvar'_U10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 1 
		replace `yvar'_U10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 0 
	
		replace `yvar'_L10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 1 
		replace `yvar'_L10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 0 

		replace `yvar'_U20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 1 
		replace `yvar'_U20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 0 
	
		replace `yvar'_L20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 1 
		replace `yvar'_L20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 0 

		}
		
				** Lee Bounds
	local outcomes_binary time_use_school time_use_work time_use_both time_use_neither out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME out6_inc_study_12_ME out6_inc_act_12_ME out6_inc_both_12_ME out6_inc_nth_12_ME

	local outcomes_conts  
	
	* From table printed in AttritionTable.do,  need to trim 155 observations from treatment to equalize attrition with C (54%) (for continuous vars, 33%).

	* Binary variables
	
	cap drop random1
	
	sort id_new
	
	gen random1=uniform()


	foreach var of local outcomes_binary {

		gen `var'_lt=`var'
	
		gen `var'_ut=`var'

		sort T_0 `var' random1

		egen grp_`var'=group(T_0 `var'), missing /* 4 groups: T = 0 & var = 0, T = 0 & var = 1, T = 1 & var = 0, T = 1 & var = 1*/

		egen rank_`var'=rank(random1), by(grp_`var') 

		replace `var'_lt=. if rank_`var'<= 155 & T_0 == 1 & `var' ==0

		replace `var'_ut=. if rank_`var'<= 155 & T_0 == 1 & `var' ==1

	}
	
	
	* Continuous variables
	
	foreach var of local outcomes_conts {
	
	gen `var'_lt=`var'
	
	gen `var'_ut=`var'

	sort T_0 `var' random1

	egen grp_`var'=group(T_0 `var'), missing
	
	egen rank_`var'=rank(random1), by(grp_`var') 

	replace `var'_lt=. if rank_`var'<= 155 & T_0 == 1 & `var'==0
	
	egen lwr_`var'=pctile(`var') 	if 	T_0 == 1 , p(33)
	
	replace `var'_lt=. 			if  T_0 == 1 & `var'<lwr_`var'

	drop lwr_`var'

	egen upr_`var'=pctile(`var') 	if 	T_0 == 1 , p(33)
	
	replace `var'_ut=. 			if  T_0 == 1 & `var'>upr_`var'

	drop upr_`var'

}	



/* local outcomes_1 time_use_school time_use_work time_use_both time_use_neither */  // not used in paper 
local outcomes_2 out6_time_study_ME out6_time_work_ME out6_time_both_ME out6_time_neither_ME
/* local outcomes_3 out6_inc_study_12_ME out6_inc_act_12_ME out6_inc_both_12_ME out6_inc_nth_12_ME  */ //not used in paper 
	
local alltablesno 	= 3
	

/*
**Tables: Vertical
	
forvalues tableno = 1(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Vertical/Applicant_work_edu_`tableno'", write replace
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' $control_vars_alum /* T_0 i.NSC_intdcode cohort2014 gender_app survey_year_a  */ if participation_alum == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"

		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		//Lee Bounds
			
			// Upper Lee Bounds
			qui reg `outcome'_ut $control_vars_alum, robust 
			
			scalar betaU_`outcome' = e(b)[1,1]
			scalar sd_betaU_`outcome' = sqrt(e(V)[1,1])
			scalar Upvalue_`outcome' = r(table)[4,1]
			
			// Lower Lee Bound Column
			qui reg `outcome'_lt $control_vars_alum, robust
			
			scalar betaL_`outcome' = e(b)[1,1]
			scalar sd_betaL_`outcome' = sqrt(e(V)[1,1])
			scalar Lpvalue_`outcome' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`outcome'  < 0.10 local stars`coltype'_`outcome'   "*"
			
			if `coltype'pvalue_`outcome'  < 0.05 local stars`coltype'_`outcome'   "**"
			
			if `coltype'pvalue_`outcome'  < 0.01 local stars`coltype'_`outcome'   "***"
			
			}
		
		// Fairlie Bound
		foreach boundtype in U5 L5 U10 L10 U20 L20 {			
				
		qui reg `outcome'_`boundtype' $control_vars_alum /* T_0 i.NSC_intdcode cohort2014 gender_app survey_year_a  */, robust
		scalar obs = e(N)

		scalar beta`boundtype' = e(b)[1,1]
		scalar sd_beta`boundtype' = sqrt(e(V)[1,1])
		scalar beta`boundtype'pvalue = r(table)[4,1]

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if beta`boundtype'pvalue < 0.10 local stars`boundtype'  "*"
			
			if beta`boundtype'pvalue < 0.05 local stars`boundtype'  "**"
			
			if beta`boundtype'pvalue < 0.01 local stars`boundtype'  "***"
		}
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & {\footnotesize [" %8.2fc (betaU_`outcome' ) "\$^{`starsU_`outcome''}\$" "," %8.2fc (betaL_`outcome' ) "\$^{`starsL_`outcome''}\$" "] } & {\footnotesize [" %8.2fc (betaU5) "\$^{`starsU5'}\$" "," %8.2fc (betaL5) "\$^{`starsL5'}\$" "] }  & {\footnotesize [" %8.2fc (betaU10) "\$^{`starsU10'}\$" "," %8.2fc (betaL10) "\$^{`starsL10'}\$" "] } & {\footnotesize [" %8.2fc (betaU20) "\$^{`starsU20'}\$" "," %8.2fc (betaL20) "\$^{`starsL20'}\$" "] } & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & & & & \medskip \\ " 	_n
		
		}
		
	file write output_file " \hline \\ " 	
	
	file close output_file

		}
*/


**Tables in BL's format (Horizontal)
forvalues tableno = 1(1)`alltablesno' {
	
	scalar var_count = `:word count `outcomes_`tableno'''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Horizontal/Applicant_work_edu_`tableno'_H.tex", write replace
	
	**Variable name
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		local variable: var label `outcome'
		local variable "`variable'"
		
		file write output_file " & `variable'"
		
		qui reg `outcome' $control_vars_alum /* T_0 i.NSC_intdcode cohort2014 gender_app survey_year_a  */ if participation_alum == 1
		scalar n_`outcome' = e(N)
		scalar beta_`outcome' = e(b)[1,1]
		
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
	
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)
		
		//Randomized Inference 
		ritest T_0 _b[T_0], reps(1000) seed(20200501): reg `outcome' $control_vars_alum, robust
		
		matrix pvalues=r(p) // save the p-values from ritest
		scalar ri_p_`outcome' = r(p)[1,1]	
		
		//Lee Bounds
			
			// Upper Lee Bounds
			qui reg `outcome'_ut $control_vars_alum, robust 
			
			scalar betaU_`outcome' = e(b)[1,1]
			scalar sd_betaU_`outcome' = sqrt(e(V)[1,1])
			scalar Upvalue_`outcome' = r(table)[4,1]
			
			// Lower Lee Bound Column
			qui reg `outcome'_lt $control_vars_alum, robust
			
			scalar betaL_`outcome' = e(b)[1,1]
			scalar sd_betaL_`outcome' = sqrt(e(V)[1,1])
			scalar Lpvalue_`outcome' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`outcome'  < 0.10 local stars`coltype'_`outcome'   "*"
			
			if `coltype'pvalue_`outcome'  < 0.05 local stars`coltype'_`outcome'   "**"
			
			if `coltype'pvalue_`outcome'  < 0.01 local stars`coltype'_`outcome'   "***"
			
			}
		
		// Fairlie Bound
		foreach boundtype in U5 L5 U10 L10 U20 L20 {			
				
		qui reg `outcome'_`boundtype' $control_vars_alum /* T_0 i.NSC_intdcode cohort2014 gender_app survey_year_a  */, robust
		scalar obs = e(N)

		scalar beta_`outcome'`boundtype' = e(b)[1,1]
		scalar sd_`outcome'`boundtype' = sqrt(e(V)[1,1])
		scalar pv_`outcome'`boundtype' = r(table)[4,1]

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if pv_`outcome'`boundtype' < 0.10 local str_`outcome'`boundtype'  "*"
			
			if pv_`outcome'`boundtype' < 0.05 local str_`outcome'`boundtype'  "**"
			
			if pv_`outcome'`boundtype' < 0.01 local str_`outcome'`boundtype'  "***"
		}
		
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}


	file write output_file " \\ " _n
	file write output_file " \hline \\ " 

	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local outcomes_`tableno' {

		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local outcomes_`tableno' {

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")$} " 
		
		}
	file write output_file "\\ " 	_n	
		
	**Random Inference 
	foreach outcome of local outcomes_`tableno' {

		file write output_file " & \scriptsize{$["%5.3f (ri_p_`outcome') "]$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Lee Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Lee Bounds - Point Estimates}} \\" 
	
		foreach outcome of local outcomes_`tableno' {
			
		file write output_file " & {\footnotesize [" %8.2fc (betaU_`outcome' )  "," %8.2fc (betaL_`outcome' ) " ] } "
		
		}
		file write output_file " \medskip \\  " 	_n	
		
	*Fairlie Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Fairlie Bounds - Point Estimates}} \\" 
	file write output_file " \\ " _n 
	*5% Imputations
	file write output_file "5\% Imputation"
	
	foreach outcome of local outcomes_`tableno' {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U5) /* "\$^{`str_`outcome'U5'}\$" */ "," %8.2fc (beta_`outcome'L5) /* "\$^{`str_`outcome'L5'}\$" */ " ] } "
		
		}
	file write output_file " \\ " _n
	
	*10% Imputations
	file write output_file "10\% Imputation"
	
	foreach outcome of local outcomes_`tableno' {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U10) /* "\$^{`str_`outcome'U10'}\$" */ "," %8.2fc (beta_`outcome'L10) /* "\$^{`str_`outcome'L10'}\$" */ " ] } "
		
		}
	file write output_file " \\ " _n
	
	*20% Imputations
	file write output_file "20\% Imputation"
	
	foreach outcome of local outcomes_`tableno' {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U20) /* "\$^{`str_`outcome'U20'}\$" */ "," %8.2fc (beta_`outcome'L20) /* "\$^{`str_`outcome'L20'}\$" */ " ] } "
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local outcomes_`tableno' {

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local outcomes_`tableno' {
			
		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \bigskip \\ " _n
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}	
*/
		
/*		
**With interaction variable T_0##gender_app: Vertical
	
/*
forvalues tableno = 1(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Vertical/Applicant_work_edu_`tableno'_interaction.tex", write replace
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' $control_vars_alum_gender_inter /* T_0##gender_app i.NSC_intdcode cohort2014 survey_year_a */ if participation_alum == 1
		
		**Treatment effect
		scalar beta_`outcome'_T = e(b)[1,2]
		scalar sd_`outcome'_T = sqrt(e(V)[2,2])
		scalar beta_`outcome'pval_T = r(table)[4,2]
		
		**Sex of the applicant
		scalar beta_`outcome'_S = e(b)[1,4]
		scalar sd_`outcome'_S = sqrt(e(V)[4,4])
		scalar beta_`outcome'pval_S = r(table)[4,4]
		
		**Interaction
		scalar beta_`outcome'_I = e(b)[1,8]
		scalar sd_`outcome'_I = sqrt(e(V)[8,8])
		scalar beta_`outcome'pval_I = r(table)[4,8]
		
		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
/*
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"

		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
*/
		
				// Add Significance Stars
		foreach coeff in T S I {			
		
		local stars`outcome'`coeff' ""
						
			if beta_`outcome'pval_`coeff' < 0.10 local stars`outcome'`coeff'  "*"
			
			if beta_`outcome'pval_`coeff' < 0.05 local stars`outcome'`coeff'  "**"
			
			if beta_`outcome'pval_`coeff' < 0.01 local stars`outcome'`coeff'  "***"
		}
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome'_T) " & " %8.2fc (beta_`outcome'_S) " & " %8.2fc (beta_`outcome'_I) " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome'_T) ")^{`stars`outcome'T'}$} & \scriptsize{$("%8.2fc (sd_`outcome'_S) ")^{`stars`outcome'S'}$} & \scriptsize{$("%8.2fc (sd_`outcome'_I) ")^{`stars`outcome'I'}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
		
	file write output_file " \hline \\ " 	
	
	file close output_file

		}
		
*/


		
**Gender diff in BL format
forvalues tableno = 1(1)`alltablesno' {
	
	scalar var_count = `:word count `tab`tableno'outcomes''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/Gendered ITT Effects_Horizontal/Applicant_work_edu_`tableno'_gender_H.tex", write replace
	
	**Variable name
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		local variable: var label `outcome'
		local variable "`variable'"
		
		file write output_file " & `variable'"
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}
	
	file write output_file " \\ " _n
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel A: All}}} \\"
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app survey_year_a  */ if participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app survey_year_a  */ if participation_alum == 1	
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome''}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app survey_year_a  */ if participation_alum == 1
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
	**For women only 
	
	file write output_file " \hline \\ " 

	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel B: Female}}} \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 0 & participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 0 & participation_alum == 1
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_F  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_F  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_F  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_F'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & gender_app == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 0 & participation_alum == 1
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
	**For men only 
	
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel C: Male}}} \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 1 & participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 1 & participation_alum == 1
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_M  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_M  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_M  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_M'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & gender_app == 1 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local outcomes_`tableno' {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum_gender /* T_0 $districtFE survey_year_a  */ if gender_app == 1 & participation_alum == 1	
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	

	
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}				