
*---------------------------------------------------------------------------*
*Description: 	Applicant Dataset - Education/Working by treatment groups	*		
*																			* 
*Date:			03/07/2024													*
*Author:		Raaga Akkineni 												*
*Input:													     				*
*Output:	*Applicant_workEdu.tex											*	
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on 
set seed 20200501

**Upload dataset
use "$applicant_mast/Data/LTFU2022_Cohort2014_2015_Analysis_Data_Applicant.dta", clear

keep if baseline == 1  // keep only baseline sample

local tab1outcomes out6_inc_activity out6_wage_activity out6_intern /* out6_inc_selfemployed */ /* out6_payPPP_22 out6_pay_mthPPP_22 */ /* out6_pay_cPPP_22 */ /* out6_pay_mth_cPPP_22 */ out6_avg_inc_cPPP_22  /* out6_contract */ /* out6_worktime */ out6_inc_month /* out6_inc_skilled */ out6_inc_nonmanual

local tab2outcomes out6_inc_activity_12 out6_wage_act_12 out6_intern_12 /* out6_inc_selfemployed */ /* out6_avg_incPPP_22 */ out6_avg_inc_cPPP_22 out6_inc_month  out6_inc_nonmanual

local alltablesno 	= 2
	

**Panels for All, only work, and both in BL format
forvalues tableno = 1(1)`alltablesno' {
	
	scalar var_count = `:word count `tab`tableno'outcomes''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	file open output_file using "$applicant_mast/Outputs/Tables/ITT Effects/ITT Effects_Horizontal/Applicant_work_edu_`tableno'_panel_12mths_H.tex", write replace
	
	**Variable name
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		local variable: var label `outcome'
		local variable "`variable'"
		
		file write output_file " & `variable'"
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}
	
	file write output_file " \\ " _n
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel A: All}}} \\" 
	
		file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if participation_alum == 1	
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome''}$} " 
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if participation_alum == 1
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
	**For those only working in the past 12 months

	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel B: Only worked in the past 12 months}}} \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_act_12_ME == 1 & participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_act_12_ME == 1 & participation_alum == 1
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_F  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_F  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_F  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_F'}$} " 
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & out6_inc_act_12_ME == 1 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_act_12_ME == 1 & participation_alum == 1
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
/*
	**For those only studying in the past 12 months 
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel B: Only studied in the past 12 months}}} \\" 
	
		file write output_file "& \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_study_12_ME == 1 & participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_study_12_ME == 1 & participation_alum == 1
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_M  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_M  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_M  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_M'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & out6_inc_study_12_ME == 1 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_study_12_ME == 1 & participation_alum == 1	
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
*/
	
	**For those studying and working in the past 12 months 
	
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel C: Studied and worked in the last 12 months}}} \\" 
	
		file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_both_12_ME == 1 & participation_alum == 1
		scalar beta_`outcome' = e(b)[1,1]
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
	
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_both_12_ME == 1 & participation_alum == 1
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_M  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_M  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_M  "***"

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_M'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & out6_inc_both_12_ME == 1 & participation_alum == 1
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' $control_vars_alum /* T_0 $districtFE gender_app cohort2014 survey_year_a  */ if out6_inc_both_12_ME == 1 & participation_alum == 1	
		scalar n_`outcome' = e(N)

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	

	
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}				