/*---------------------------------------------------------------------------*
*Description: 	Attrition Ananlysis of Caregiver and Applicant Survey		*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*
*Input:			LTFU_Cohort_2014_2015_cleaned.dta			     			*
*				Cohort2014_2015_LTFU_caregiver_pulldata.dta	     			*
*				LTFU_Cohort_2014_2015_ApplicantDataset_cleaned.dta			*
*																			*
*Output:		LTFU_table_participationBy_treatment.tex					*
*				LTFU_table_attrition_applicant.tex							*	
*Note: 													      				*			
*---------------------------------------------------------------------------*/

version 17
set more off

clear all
clear mata

set seed 20200516
pause on

global cohortFE cohort2014
global districtFE NSC_intdcode

*** Sample

**Attrited dummy in LTFU	
	use "$caregiver_mast/Data/LTFU_Cohort_2014_2015_cleaned_deid.dta", clear
	
	gen ltfu = 1
	
	gen attrited_ltfu = 1 if ((aa6 == 0) | 						/// Former caregiver, but not found
						(aa6 == 1 	& participation_c == 0) | 	///	Former caregiver, found, but did not participate
						(replace == 1 	& aa6_replace == 0) |					///	Replacement caregiver, not found
						(replace == 1 	& aa6_replace == 1 & participation_c == 0))				///	Replacement caregiver, found, but did not participate	 

	*keep id_new aa6 participation_c attrited region
	
	tempfile temp
	save `temp'

** Houshold not found 
	use "$caregiver_mast/data/Cohort2014_2015_LTFU_caregiver_pulldata_deid.dta", clear
	
	merge 1:1 id_new using `temp', force			// "force": in case of type mismatch
	
/*
	  Result                      Number of obs
    -----------------------------------------
    Not matched                           195
        from master                       195  (_merge==1)		// in FU but not in LTFU
        from using                          0  (_merge==2)

    Matched                             1,130  (_merge==3)
    -----------------------------------------

	
*/
	replace attrited_ltfu = 1 if _merge == 1 	// in pull data but data not found in LTFU				
	
	replace ltfu = 1 if _merge == 1		// in ltfu sub sample
	
	keep id_new aa6 participation_c attrited_ltfu region ltfu survey_year	// only keep necessary variables
	
	tempfile temp1
	save `temp1'
	
	use "$attrition_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", clear			// to pull variables "T_0", "final_select" & "notfoundatFU"
	
	keep baseline id_new NSC_intdcode cohort2014 NSC_final_select final_select sex_app T_0 notfoundatFU  
	
	keep if baseline == 0 & final_select == 1 /*(2,754  observations deleted)*/
	
	merge 1:1 id_new using `temp1' 
	
	/*
	
	 Result                      Number of obs
    -----------------------------------------
    Not matched                           105
        from master                       105  (_merge==1)			// in baseline but not in LTFU
        from using                          0  (_merge==2)

    Matched                             1,325  (_merge==3)			// in FU and LTFU
    -----------------------------------------
	
	*/
	
	replace attrited_ltfu = 1 if _merge == 1 	// in baseline but data not found in LTFU (FIXMEBL)
	/*105 real changes made*/
	
	replace ltfu = 1 if _merge == 1	/*105 real changes made*/
	
	gen notfoundatLTFU = (attrited_ltfu == 1) 		// FIXMERA: change made from "attrited == 1" to "attrited_ltfu == 1"
	order notfoundatLTFU, after(notfoundatFU) 

	save "$attrition_mast/Data/LTFU_Cohort_2014_2015_final_select.dta", replace
	
/*
	* Attrition between Baseline and Followup of RCT Sample
	
		qui reg notfoundatFU T_0 $districtFE sex_app $cohortFE
		
		scalar beta_all = e(b)[1,1]
		scalar sd_all = sqrt(e(V)[1,1])
		scalar beta_allpvalue = r(table)[4,1]

		scalar n_all  = e(N)
		sum notfoundatFU if T_0 == 0
		scalar mean_all = r(mean)
*/		
	* Attrition between baseline and FU of RCT Sample in which NSC_select == 1
	
		qui reg notfoundatFU T_0 $districtFE sex_app $cohortFE if final_select == 1 // baseline to FU
		scalar beta_eligibles_FU = e(b)[1,1]
		scalar sd_eligibles_FU = sqrt(e(V)[1,1])
		scalar beta_eligibles_FUpvalue = r(table)[4,1]

		scalar n_eligibles_FU = e(N)
		local 	n_eligibles_FU = e(N)

		sum notfoundatFU if T_0 == 0 & final_select == 1
		scalar mean_eligibles_FU = r(mean)
	
	* Attrition between baseline and LTFU of RCT Sample in which NSC_select == 1
	
		qui reg notfoundatLTFU T_0 $districtFE sex_app $cohortFE if final_select == 1 & notfoundatFU != . // baseline to LTFU
		scalar beta_eligibles_LTFU = e(b)[1,1]
		scalar sd_eligibles_LTFU = sqrt(e(V)[1,1])
		scalar beta_eligibles_LTFUpvalue = r(table)[4,1]

		scalar n_eligibles_LTFU = e(N)

		sum notfoundatLTFU if T_0 == 0 & final_select == 1 & notfoundatFU != .
		scalar mean_eligibles_LTFU = r(mean)

	* Attrition between FU and LTFU of RCT Sample in which NSC_select == 1 

		qui reg notfoundatLTFU T_0 $districtFE sex_app $cohortFE if final_select == 1 & notfoundatFU == 0
		scalar beta_eligibles_FU1 = e(b)[1,1]
		scalar sd_eligibles_FU1  = sqrt(e(V)[1,1])
		scalar beta_eligibles_FU1pvalue  = r(table)[4,1]

		scalar n_eligibles_FU1   = e(N)

		sum notfoundatLTFU if T_0 == 0 & final_select == 1 & notfoundatFU == 0
		scalar mean_eligibles_FU1  = r(mean)


	/* Removing Significance Stars to Harmonize style with paper
		
		local stars_eligibles_FU ""
		local stars_eligibles_LTFU ""
		local stars_eligibles_FU1 ""

		foreach coltype in /*all*/ eligibles_FU eligibles_LTFU eligibles_FU1 {
						
			if beta_`coltype'pvalue < 0.10 local stars_`coltype'  "*"
			
			if beta_`coltype'pvalue < 0.05 local stars_`coltype'  "**"
			
			if beta_`coltype'pvalue < 0.01 local stars_`coltype'  "***"
			
		}
		*/
	capture file close output_file	
	
	file open output_file using "$attrition_mast/Tables/LTFU_table_attrition_update1.tex", write replace
	
	
	file write output_file "T & " %5.3f (beta_eligibles_FU) " & " %5.3f (beta_eligibles_LTFU) " & " %5.3f (beta_eligibles_FU1) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (sd_eligibles_FU) ")^{`stars_eligibles_FU'}$} & \scriptsize{$(" %5.3f (sd_eligibles_LTFU) ")^{`stars_eligibles_LTFU'}$} & \scriptsize{$(" %5.3f (sd_eligibles_FU1) ")^{`stars_eligibles_FU1'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_eligibles_FU) " & " %5.2f (mean_eligibles_LTFU) " & " %5.2f (mean_eligibles_FU1) " \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_eligibles_FU) " & " %5.0fc (n_eligibles_LTFU) " & " %5.0fc (n_eligibles_FU1) " \\ " _n

	file close output_file



/*******************************************************************************
Pariticiaption rate
*/
	keep id_new participation_c notfoundatLTFU notfoundatFU NSC_intdcode $districtFE sex_app $cohortFE final_select T_0 survey_year
	
	gen participation_LTFU = (notfoundatLTFU == 0) if notfoundatLTFU != . 
	
	gen participation_FU = (notfoundatFU == 0) if notfoundatFU != .	 
	
	gen participation_caregiver = participation_c
	
	tempfile temp_caregiver
	save `temp_caregiver'
	
	**Attrition in Applicant survey	
	
	use "$applicant_mast/Data/LTFU_Cohort_2014_2015_ApplicantDataset_cleaned_deid.dta", clear

	*gen survey_year_a = year(date)
	
/*
	rename id id_new 
*/
	
	gen participation_alum = (participation == 1)
	
	gen notfoundatLTFU_alum = (participation == 0 | aa6 == 0)
	
 
	keep id_new participation_alum notfoundatLTFU_alum survey_year_a
	
	merge 1:1 id_new using `temp_caregiver'

replace participation_alum = 0 if participation_alum == . & notfoundatFU != . 
replace notfoundatLTFU_alum = 1 if participation_alum == 0 & notfoundatFU != . 
	
gen participation_any = (participation_alum == 1 |participation_caregiver == 1) if notfoundatFU != .

gen notfoundatLTFU_any = (notfoundatLTFU == 1 & notfoundatLTFU_alum == 1) if notfoundatFU != .

**Number of respondents by treatment group 

foreach var in participation_caregiver{
    sum `var' if NSC_intdcode != . & notfoundatLTFU == 0 & T_0 == 0
	local n_`var'_C = r(sum)
	sum `var' if NSC_intdcode != . & notfoundatLTFU == 0 & T_0 == 1
	local n_`var'_T = r(sum)
	sum `var' if NSC_intdcode != . & notfoundatLTFU == 0 
	local n_`var'_A = r(sum)
	
}

foreach var in participation_alum{
    sum `var' if NSC_intdcode != . & notfoundatLTFU_alum == 0 & T_0 == 0
	local n_`var'_C = r(sum)
	sum `var' if NSC_intdcode != . & notfoundatLTFU_alum == 0 & T_0 == 1
	local n_`var'_T = r(sum)
	sum `var' if NSC_intdcode != . & notfoundatLTFU_alum == 0 
	local n_`var'_A = r(sum)
	
}

foreach var in survey_year{
    sum `var' if NSC_intdcode != . & notfoundatLTFU == 0 & survey_year == 2022
	local n_`var'_22 = r(N)
	sum `var' if NSC_intdcode != . & notfoundatLTFU == 0 & survey_year == 2023
	local n_`var'_23 = r(N)

}

foreach var in survey_year_a{
    sum `var' if NSC_intdcode != . & notfoundatLTFU_alum == 0 & survey_year_a == 2022
	local n_`var'_22 = r(N)
	sum `var' if NSC_intdcode != . & notfoundatLTFU_alum == 0 & survey_year_a == 2023
	local n_`var'_23 = r(N)
	
}

**For participation table
foreach var in participation_FU participation_caregiver participation_alum participation_any {
    sum `var' if NSC_intdcode != . & notfoundatFU != .
	local sum_`var' = r(sum)
}

foreach var in notfoundatFU notfoundatLTFU notfoundatLTFU_alum notfoundatLTFU_any {
     sum `var'  if NSC_intdcode != . & notfoundatFU != . 
	local notfound_`var' = r(sum)
}

local total = r(N)

file open output_file using "$attrition_mast/Tables/LTFU_table_participation.tex", write replace
	
	file write output_file " Interviewed at Baseline &  " %5.0fc (`n_eligibles_FU') " &  &  " %5.0fc (`n_eligibles_FU') " \\  \\" _n
	
	file write output_file " Interviewed at Follow up &  " %5.0fc (`sum_participation_FU') " &  & " %5.0fc (`sum_participation_FU') "  \\ " _n
	
	file write output_file " Attrited at Follow up & " %5.0fc (`notfound_notfoundatFU') " &  & " %5.0fc (`notfound_notfoundatFU') " \\  \\" _n
		
	file write output_file " Interviewed at Long term Follow up & " %5.0fc (`sum_participation_caregiver') " & " %5.0fc (`sum_participation_alum') " & " %5.0fc (`sum_participation_any') " \\ " _n
	
	file write output_file " Attrited at Long term Follow up & " %5.0fc (`notfound_notfoundatLTFU') " & " %5.0fc (`notfound_notfoundatLTFU_alum') " & " %5.0fc (`notfound_notfoundatLTFU_any') " \\ " _n
	

	file close output_file
/*  // The following tables are not included in the paper
**Number of respondents per survey year 

file open output_file using "$attrition_mast/Tables/LTFU_table_participationBy_treatment.tex", write replace
	
	file write output_file "  &  Caregiver &  Applicant  \\  \hline" _n
	
	file write output_file " \textbf{\textit{Treatment Group}} \\" _n
	
	file write output_file " Control &  " %5.0fc (`n_participation_caregiver_C') " &  " %5.0fc (`n_participation_alum_C') " \\" _n
	
	file write output_file " Treatment &  " %5.0fc (`n_participation_caregiver_T') " &  " %5.0fc (`n_participation_alum_T') "  \\ \\" _n
	
	file write output_file " \textbf{\textit{Survey Year}} \\" _n
	
	file write output_file " 2022 &  " %5.0fc (`n_survey_year_22') " &  " %5.0fc (`n_survey_year_a_22') " \\" _n
	
	file write output_file " 2023 &  " %5.0fc (`n_survey_year_23') " &  " %5.0fc (`n_survey_year_a_23') "  \\ \\" _n
	
	file write output_file " Total & " %5.0fc (`n_participation_caregiver_A') " & " %5.0fc (`n_participation_alum_A') "  \\ " _n
	

	file close output_file

	
**Attrition table with applicant numbers 

		qui reg notfoundatFU T_0 $districtFE sex_app $cohortFE if final_select == 1 // baseline to FU
		scalar beta_eligibles_FU = e(b)[1,1]
		scalar sd_eligibles_FU = sqrt(e(V)[1,1])
		scalar beta_eligibles_FUpvalue = r(table)[4,1]

		scalar n_eligibles_FU = e(N)
		local 	n_eligibles_FU = e(N)

		sum notfoundatFU if T_0 == 0 & final_select == 1
		scalar mean_eligibles_FU = r(mean)
	
	* Attrition between baseline and LTFU of RCT Sample in which NSC_select == 1
	
		qui reg notfoundatLTFU T_0 $districtFE sex_app $cohortFE if final_select == 1 & notfoundatFU != . // baseline to LTFU
		scalar beta_eligibles_LTFU = e(b)[1,1]
		scalar sd_eligibles_LTFU = sqrt(e(V)[1,1])
		scalar beta_eligibles_LTFUpvalue = r(table)[4,1]

		scalar n_eligibles_LTFU = e(N)

		sum notfoundatLTFU if T_0 == 0 & final_select == 1 & notfoundatFU != .
		scalar mean_eligibles_LTFU = r(mean)

	* Attrition between FU and LTFU of RCT Sample in which NSC_select == 1 

		qui reg notfoundatLTFU T_0 $districtFE sex_app $cohortFE if final_select == 1 & notfoundatFU == 0
		scalar beta_eligibles_FU1 = e(b)[1,1]
		scalar sd_eligibles_FU1  = sqrt(e(V)[1,1])
		scalar beta_eligibles_FU1pvalue  = r(table)[4,1]

		scalar n_eligibles_FU1   = e(N)

		sum notfoundatLTFU if T_0 == 0 & final_select == 1 & notfoundatFU == 0
		scalar mean_eligibles_FU1  = r(mean)
		
	* Attrition between baseline and LTFU of RCT Sample in which NSC_select == 1 for applicants

		qui reg notfoundatLTFU_alum T_0 $districtFE sex_app $cohortFE if final_select == 1 
		scalar beta_eligibles_alum = e(b)[1,1]
		scalar sd_eligibles_alum  = sqrt(e(V)[1,1])
		scalar beta_eligibles_alumpvalue  = r(table)[4,1]

		scalar n_eligibles_alum   = e(N)

		sum notfoundatLTFU if T_0 == 0 & final_select == 1 & notfoundatFU == 0
		scalar mean_eligibles_alum  = r(mean)


	* Add Significance Stars
		
		local stars_eligibles_FU ""
		local stars_eligibles_LTFU ""
		local stars_eligibles_FU1 ""

		foreach coltype in /*all*/ eligibles_FU eligibles_LTFU eligibles_FU1 eligibles_alum {
						
			if beta_`coltype'pvalue < 0.10 local stars_`coltype'  "*"
			
			if beta_`coltype'pvalue < 0.05 local stars_`coltype'  "**"
			
			if beta_`coltype'pvalue < 0.01 local stars_`coltype'  "***"
			
		}
		
		capture file close output_file	
	
	file open output_file using "$attrition_mast/Tables/LTFU_table_attrition_applicant.tex", write replace
	
	
	file write output_file "T & " %5.3f (beta_eligibles_FU) " & " %5.3f (beta_eligibles_LTFU) " & " %5.3f (beta_eligibles_FU1) "  & " %5.3f (beta_eligibles_alum) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (sd_eligibles_FU) ")^{`stars_eligibles_FU'}$} & \scriptsize{$(" %5.3f (sd_eligibles_LTFU) ")^{`stars_eligibles_LTFU'}$} & \scriptsize{$(" %5.3f (sd_eligibles_FU1) ")^{`stars_eligibles_FU1'}$} & \scriptsize{$(" %5.3f (sd_eligibles_alum) ")^{`stars_eligibles_alum'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_eligibles_FU) " & " %5.2f (mean_eligibles_LTFU) " & " %5.2f (mean_eligibles_FU1) " & " %5.2f (mean_eligibles_alum) "\\ " _n
	
	file write output_file "Observations & " %5.0fc (n_eligibles_FU) " & " %5.0fc (n_eligibles_LTFU) " & " %5.0fc (n_eligibles_FU1) " & " %5.0fc (n_eligibles_alum) " \\ " _n

	file close output_file
*/
