   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               Mastercard Foundation Scholarship Program Uganda       *
   *               Long-term Follow-up								      *
   *               CAREGIVER MASTER DO_FILE                               *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      Long term follow up of the Mastercard Foundation Scholarship Program Uganda in 2022

       ** OUTLINE:      PART 0: Standardize settings and install packages
                        PART 1: Set globals for dynamic file paths
                        PART 2: Set globals for constants and varlist
                               used across the project. Install all user-contributed
                               commands needed.
                        PART 3: Call the task-specific master do-files 
                               that call all dofiles needed for that 
                               task. Do not include Part 0-2 in a task-
                               specific master do-file


       ** IDS VAR:      list_ID_var_here         //Uniquely identifies households (update for your project)

       ** NOTES:

       ** WRITTEN BY:   Bendetta Lerva, Raaga Akkineni

       ** Last date modified: 03 Dec 2024
       */


   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           - Set the global box to point to the project folder
   *            on each collaborator's computer.
   *           - Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *

* These lines are used to test that the name is not already used (do not edit manually)
*round**************************************************************************
*untObs*************************************************************************
*subFld*************************************************************************
*iefolder will not work properly if the lines above are edited


   * Project folder globals
   * ---------------------

*iefolder*1*FolderGlobals*subfolder*********************************************
*iefolder will not work properly if the line above is edited


*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited


*iefolder*1*FolderGlobals*encrypted*********************************************
*iefolder will not work properly if the line above is edited

*iefolder*1*FolderGlobals*endRounds*********************************************
*iefolder will not work properly if the line above is edited

   global mastdata_cg              "$caregiver_mast/Data" 			// Master Data 

*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, different sets of control variables,
   * adofile paths etc.


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited


*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DOFILE
   *
   *           - When survey rounds are added, this section will
   *            link to the master dofile for that round.
   *           - The default is that these dofiles are set to not
   *            run. It is rare that all round-specfic master dofiles
   *            are called at the same time; the round specific master
   *            dofiles are almost always called individually. The
   *            exception is when reviewing or replicating a full project.
   *
   * ******************************************************************** *
 
   global mastdata_do_cg              "$caregiver_mast_gt/Dofiles" 			// .do files for caregiver master data 
 
 *ACTION NEEDED: Set this value to "1" to run corresponding .do files 

 
********************************************************************************
*					OUTCOME VARIABLE CONSTRUCTION							   *
******************************************************************************** 
  
 ** Variable Construction 
   global caregiver_construction			0			// Runs .do file which constructs variables for Caregiver dataset
   
      if $caregiver_construction == 1 {
       
		do "$mastdata_do_cg/Construction/LTFU2022_Cohort_2014_2015_OutcomesCreation.do" 
   }
   
 ** Education Roster Vairable Construction
   global caregiver_construct_eduroster		0			// Runs .do file to create education roster
   
      if $caregiver_construct_eduroster == 1 {
       
		do "$mastdata_do_cg/Construction/LTFU2022_Cohort_2014_2015_EduRoster_OutcomesCreation.do" 	
   }
   
  ** Education Roster Vairable Construction
   global caregiver_construct_siblingdata	0			// Runs .do file to create outcomes for Sibling data
   
      if $caregiver_construct_siblingdata == 1 {
       
		do "$mastdata_do_cg/Construction/LTFU2022_Cohort_2014_2015_EduRoster_OutcomesCreation_SiblingData.do" 	
   }  
   
   
********************************************************************************
*							 OUTPUT CREATION								   *
********************************************************************************

********************************************************************************
*							 Tables (Latex files)							   *
********************************************************************************

	* Table II ATTRITION (LTFU_table_attrition_update1)
	* Table B.I: SAMPLE SIZE BY SURVEY AND RESPONDENT (LTFU_table_participation)
	
   global caregiver_attrition				1			// Runs .do file which constructs variables for Caregiver dataset
   
      if $caregiver_attrition == 1 {
       
		do "$attrition_mast_gt/LTFU2022_Cohort_2014_2015_AttritionTable.do" 	
   }   


	*Table I: DESCRIPTIVE CHARACTERISTICS AND BALANCE TESTS	(Balance Tables/table_balance_all_eligibles)*
	*Table E.I: BALANCE TESTS INCLUDING NON-RESPONDERS AT 2Y FOLLOW-UP (Balance Tables/table_balance_attrition_FU)*
	*Table E.II: BALANCE TESTS INCLUDING NON-RESPONDERS AT 8Y FOLLOW-UP	(Balance Tables/table_balance_attrition_LTFU)	   *
   
   global caregiver_balance  					1			// Runs .do file builds tables for Caregiver dataset for midline survey
   
      if $caregiver_balance == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_Balance_tables.do" 
	 
   }
   
	*Table III: EFFECTS ON SCHOOL OUTCOMES (table_education)									   *
   
   global caregiver_2y_followup_education 		1			// Runs .do file builds tables for Caregiver dataset for midline survey
   
      if $caregiver_2y_followup_education == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_2Y_FollowUp_Bounds.do" 	
	  
   }
   

	*Table B.II: PRE-INTERVENTION O-LEVEL PERFORMANCE OF APPLICANTS' SCHOOLS (table_schoolquality)   *
   
   global caregiver_2y_fu_school_quality 		1			// Runs .do file builds tables for Caregiver dataset for midline survey
   
      if $caregiver_2y_fu_school_quality == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_2Y_FollowUp_schoolranking_Bounds.do" 	
	  
   }
	

	* Table IV: SCHOOL COMPLETION (Education Outcomes/LTFU_education_outcome2_bounds_RI_MHT)	   *			
	* Table V: SCHOOL PERFORMANCE OF TEST TAKERS (Education Outcomes/LTFU_education_outcome1_bounds_RI_MHT)  *
   
   global caregiver_edu_outcomes  				1			// Runs .do file builds tables for education outcomes from the Caregiver dataset at LTFU
   
      if $caregiver_edu_outcomes == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_EducationOutcomes_bounds_RI_MHT.do" 
	  
   }
	
		
	*Table B.IV: EFFECTS ON SIBLINGS' EDUCATION	(Tab1_roster, Tab2_roster, Tab3_roster)	   *
	
	global caregiver_edu_siblings				1			// Runs .do file builds tables for education outcomes of siblings from the Caregiver dataset 
	
	if $caregiver_edu_siblings == 1 {
		
		do "$mastdata_do_cg/Tables/Cohort_2014_2015_Sibling_EducationOutcomes.do" 

	}
	*Table B.IX: SUMMARY OF EFFECTS - INCLUDING THE LONG-TERM FOLLOW-UP	(Tab0_compare)	   *

   
   global caregiver_ITTeffect  					1			// Runs .do file builds tables for Caregiver dataset
   
      if $caregiver_ITTeffect == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU2022_Cohort_2014_2015_ITT_Effects.do" 
	  
/*
	  do "$mastdata_do_cg/Tables/LTFU2022_Cohort_2014_2015_ITT_Effects_Alum.do" 	// for additional Alum rows in the summary tables
	 */  
   }
   
   	* Table F.III: FIRST STAGE TABLE (ITT Effects/Tab_FirstStage)	   						*			
	* Table F.IV: EFFECTS ON EXPENDITURES IN PAST 30 DAYS (ITT Effects/Follow_up_Tab2)		*			
	* Table F.V: EFFECTS ON NUTRITION (ITT Effects/Follow_up_Tab4) *
	* Table F.VI: EFFECTS ON ASSETS - INTENSIVE MARGIN (ITT Effects/Follow_up_Tab1)			*			
	* Table F.VII: EFFECTS ON ASSETS - EXTENSIVE MARGIN	(ITT Effects/Follow_up_Tab7)	   *
	* Table F.VIII: EFFECTS ON INCOME-GENERATING ACTIVITIES	(ITT Effects/Follow_up_Tab3)   *			
	* Table F.IX: EFFECTS ON PSYCHOLOGICAL WELLBEING (ITT Effects/Follow_up_Tab5 )*
	* Table F.X: EFFECTS ON WOMENS' EXPENDITURE DECISION (ITT Effects/Follow_up_Tab8)   *			
	* Table F.XI: EFFECTS ON WOMEN'S EMPOWERMENT (ITT Effects/Follow_up_Tab9)*
      
	 global caregiver_ITTeffect_IV			1			// Runs .do file builds tables for Caregiver dataset
   
      if $caregiver_ITTeffect_IV == 1 {
       
	  do "$mastdata_do_cg/Tables/Cohort_2014_2015_ITT_Effects.do" 
	  do "$mastdata_do_cg/Tables/First_Stage_Table.do" 
  
   }  
/*
   *Table 4: Education Outcomes												   *
	* Output: 																   *
	*	1) LTFU_table_education_outcome_scores_division.tex					   *
	*	2) LTFU_table_education_outcome_completion_participation			   *
   
   global caregiver_eduoutcomes  			1			// Runs .do file build education outcome tables for Caregiver dataset
   
      if $caregiver_eduoutcomes == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_EducationOutcomes.do" 
   }
   
    *Table 5: Education Outcomes - with bounds								   *
	* Output: 																   *
	*	1) LTFU_education_outcome1_bounds.tex								   *
	*	2) LTFU_education_outcome2_bounds.tex								   *
   
   global caregiver_eduoutcomes_bounds  		0			// Runs .do file build education outcome tables for Caregiver dataset with bounds
   
      if $caregiver_eduoutcomes_bounds == 1 {
       
	  do "$mastdata_do_cg/Tables/LTFU_Cohort_2014_2015_EducationOutcomes_bounds.do" 
   }
*/
   
********************************************************************************
*							 Figures (.pdf files)							   *
********************************************************************************      
	*Figure II: SUMMARY OF HOUSEHOLD IMPACTS AT 2-YEAR FOLLOW-UP (Coefplot_summary.pdf)		   *
   
   
   global caregiver_figure_ITTcoeffplot  	1			// Runs .do file creates all figures for Caregiver dataset

   
   if $caregiver_figure_ITTcoeffplot == 1 {
       
	  do "$mastdata_do_cg/Figures/Cohort_2014_2015_ITT_Effects_Coefplots.do" 
	  
   }  

  *Figure VI: SUMMARY OF HOUSEHOLD IMPACTS AT FOLLOW-UP (Coefplot_summary_T_0_compare)					   *
   
   
   global caregiver_figure_ITTcoeffplot  	1			// Runs .do file creates all figures for Caregiver dataset

   
   if $caregiver_figure_ITTcoeffplot == 1 {
       
	  do "$mastdata_do_cg/Figures/LTFU2022_Cohort_2014_2015_ITT_Effects_coefplots.do" 
	  
   }
   
   *Figure 1: ITT Effect Coeff Plot for Caregiver							   *
	* Output: 																   *
	*	1) Edu_outcomes_2Y_Followup.png	(not used in paper)					   *
   
   
   global caregiver_2y_followup  			1			

   
   *if $caregiver_2y_followup == 1 {
       
	*  do "$mastdata_do_cg/Figures/LTFU2022_Cohort_2014_2015_2Y_Followup.do" 
	  
   *} 
   
      *Figure 1: ITT Effect Coeff Plot for Caregiver							* 
	* Output: 																   *
	*	1) Edu_outcomes_2Y_Followup.png	(not used in paper)					   *
   
   *Figure A.IV: EFFECT ON SIBLINGS' EDUCATION BY SCHOOL GRADE	(Coefplot_TbySchoolGrade.pdf)		   *
   global caregiver_2y_sibling_fees  	1			

   
   if $caregiver_2y_sibling_fees == 1 {
       
	  do "$mastdata_do_cg/Figures/Coefplot_Siblings_Fees.do" 
	  
   } 
   
   	*Figure A.V: STUDENTS OFFERED A SCHOLARSHIP BY TREATMENT STATUS	(FinalSelected_byAssignment.pdf)		   *
   
   global caregiver_2y_firststage_hist  	1			

   
   if $caregiver_2y_firststage_hist == 1 {
       
	  do "$mastdata_do_cg/Figures/Histogram_FirstStage.do" 
	  
   } 

   
	*Figure A.VI: HETEROGENEITY IN INTENT-TO-TREAT EFFECTS (Binsc_AssetsHet.pdf, Binsc_BusinessHet.pdf, Binsc_WelfareHet.pdf)			   *
   
   global caregiver_2y_asset_welfare  	1			

   
   if $caregiver_2y_asset_welfare == 1 {
       
	  do "$mastdata_do_cg/Figures/Assets_Welfare_Business_Het.do" 
	  
   } 
   
   
   

*iefolder*3*End_RunDofiles******************************************************
*iefolder will not work properly if the line above is edited

