set scheme lean1

use  "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", clear

global cohortFE cohort2014
global districtFE i.NSC_intdcode

lab val T_0 treatment
lab def cohort 0 "Second Cohort" 1 "First Cohort"
lab val cohort2014 cohort
	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1
	
	keep if notfoundatFU == 0
	
	xtile ppitercile_b = out0_povscore09_c_b, nquantiles(3)
	xtile ppiquartile_b = out0_povscore09_c_b, nquantiles(4)
	xtile ppiquintile_b = out0_povscore09_c_b, nquantiles(5)	


	local indices_a index_a_education index_a_childhealth index_a_nutrition index_a_assets index_a_prodassets index_a_prodassetsD index_a_expenditures index_a_psywel index_a_conflict index_a_violence index_a_expdec index_a_empower index_a_business
	
	
	foreach var in `indices_a' out0_povscore09_c out4_savingsvaluePPP out4_prodassetvaluePPP out4_prodassetcat out6_nonagribusiness2 out6_businessno_roster out6_hours{
		
		* Follow-up Value
		
		sum `var' if T_0 == 0, d 
		
		gen `var'_Z = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if baseline == 0 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}
	
	lab var index_a_prodassets_Z "Assets Index"
	lab var out4_prodassetvaluePPP_Z "Assets Value"
	lab var out4_prodassetcat_Z "Assets Category"
	lab var out4_savingsvaluePPP_Z "Savings Value"
	lab var out0_povscore09_c_Z "PPI"
	lab var index_a_nutrition_Z "Nutrition Index"
	lab var index_a_psywel_Z "Psych Wellbeing Index"
	lab var index_a_business "Business Index" 
	lab var out6_nonagribusiness2_Z "Has Non-Ag Business" 
	lab var out6_businessno_roster_Z "No. of Activities"
	lab var out6_hours_Z "Hours Worked"


	* Assets
	foreach outcome in index_a_prodassets_Z out4_prodassetvaluePPP_Z out4_prodassetcat_Z out4_savingsvaluePPP_Z {
		
		local ytitle: variable label `outcome'
		binscatter `outcome' out0_povscore09_c_b , by(T_0) nquantiles(3) controls(`outcome'_b sex_app cohort2014 ) absorb(NSC_intdcode) name(binsc`outcome', replace) med line(connect) colors(gray maroon) xtitle(Baseline PPI) ytitle("`ytitle'") legend(order(1 "Control" 2 "Treatment")) 
		
	}

	grc1leg binscindex_a_prodassets_Z binscout4_prodassetvaluePPP_Z binscout4_prodassetcat_Z binscout4_savingsvaluePPP_Z, xcommon ycommon 
	graph export "$caregiver_mast/Outputs/Figures/Binsc_AssetsHet.pdf", replace
	
	* Welfare
	foreach outcome in out0_povscore09_c_Z index_a_nutrition_Z index_a_psywel_Z  {
		
		local ytitle: variable label `outcome'
		binscatter `outcome' out0_povscore09_c_b , by(T_0) nquantiles(3) controls(sex_app cohort2014 ) absorb(NSC_intdcode) name(binsc`outcome', replace) med line(connect) colors(gray maroon) xtitle(Baseline PPI) ytitle("`ytitle'") legend(order(1 "Control" 2 "Treatment"))
		
	}

	grc1leg binscout0_povscore09_c_Z binscindex_a_nutrition_Z binscindex_a_psywel_Z, xcommon ycommon cols(2) 

	graph export "$caregiver_mast/Outputs/Figures/Binsc_WelfareHet.pdf", replace
	
	*Business
	foreach outcome in index_a_business out6_nonagribusiness2_Z out6_businessno_roster_Z out6_hours_Z  {
		
		local ytitle: variable label `outcome'
		binscatter `outcome' out0_povscore09_c_b , by(T_0) nquantiles(3) controls(sex_app cohort2014 ) absorb(NSC_intdcode) name(binsc`outcome', replace) med line(connect) colors(gray maroon) xtitle(Baseline PPI) ytitle("`ytitle'") legend(order(1 "Control" 2 "Treatment"))

		
	}

	grc1leg binscindex_a_business binscout6_nonagribusiness2_Z binscout6_businessno_roster_Z binscout6_hours_Z, xcommon ycommon 
	graph export "$caregiver_mast/Outputs/Figures/Binsc_BusinessHet.pdf", replace
