version 13
set more off

clear all
clear mata

set seed 20200516
pause on

set scheme sj

/*
 //Check the path variable is set
if "$researchpath" == "" {
	di "No path found. Please first run your setpath_name.do file"
	exit
} 
 //Set the path to "Research".
cd "$researchpath"
*/

global cohortFE cohort2014
global districtFE i.NSC_intdcode
	
		
/*
	do "Data - Analysis/Code/Cohort_2014_2015_DatasetCreation_ForTables.do"
*/

	use "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta"
	
	** Formatting graphs 
	do "$mastdata_do_cg/Figures/GraphFormatting.do" 

	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1
	
	keep if notfoundatFU == 0
	
	rename index_a_* index_*
	
	local indices index_education index_childhealth index_nutrition index_assets index_prodassets index_expenditures index_psywel index_conflict index_violence index_expdec index_empower index_business

	foreach var in out0_povscore09_c out4_savingsvaluePPP out1_uceaggregate out1_appenrolled_fu out0_appwork `indices' {
		
		* Follow-up Value
		
		sum `var' if baseline == 0 & T_0 == 0, d 
		
		gen `var'_Z = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if baseline == 0 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}

replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/

	* Summary Graph
	
local summaryoutcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_Z index_nutrition_Z index_assets_Z index_prodassets_Z index_business_Z index_psywel_Z  index_empower_Z index_expdec_Z /* index_conflict_Z  index_childhealth_Z */ 

* out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z

	foreach outcome of local summaryoutcomes {
			
			di "`outcome'"
		
		// Treatment Column

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'
			
			eststo `outcome' 		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			eststo `outcome'rural 	: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if out0_urban_b == 0 , robust 

			eststo `outcome'urban 	: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if out0_urban_b == 1, robust 

			eststo `outcome'h1		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if out0_povscore09_c_b <= 50 , robust 

			eststo `outcome'h2		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if out0_povscore09_c_b > 50, robust
			
			eststo `outcome'm		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if sex_app == 1, robust 

			eststo `outcome'f 		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if sex_app == 0, robust 


		}
		
		if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'
			
			local variable "`variable'$ ^+$"
			
			eststo `outcome'		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014, robust 
	
			eststo `outcome'rural 	: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if out0_urban_b == 0 , robust 

			eststo `outcome'urban 	: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if out0_urban_b == 1, robust 
			
			eststo `outcome'h1		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if out0_povscore09_c_b <= 50 , robust 

			eststo `outcome'h2 		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if out0_povscore09_c_b > 50, robust
			
			eststo `outcome'm		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if sex_app == 1, robust 

			eststo `outcome'f 		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if sex_app == 0, robust 


		}

			local varlabel: variable label `outcome'

			local allvars `allvars' `outcome' ||
			local labels `labels' `varlabel'
			
			local allruralvars `allruralvars'  `outcome'rural  `outcome'urban ||

			local allpoorvars `allpoorvars'  `outcome'h1  `outcome'h2 ||

			local allgendervars `allgendervars'  `outcome'f  `outcome'm ||


		}
	
coefplot `allvars' , drop(_cons *_b sex_app cohort2014 *NSC_intdcode) xline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) xline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) bycoefs bylabels("Standardized Poverty Score" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index" "Assets Index"  "Business Index" "Psychological Wellbeing Index"  /*"Violence Index"*/ "Empowerment Index" "Expenditures Decision Index" /* "Conflict Index" */  /*"Applicant Enrolled" "Applicant Works" */ /* "Children Health Index" */ /*"Siblings Education Index"*/ ) xlabel(-1(0.1)1, labsize(vsmall)) ylabel(, labsize(medium)) mcolor(gs0) ciopts(recast(rcap)) graphregion(color(white)) bgcolor(white) eqlabels(, labels) xtitle(Standard Deviations of the Control Group, size(medium)) xscale(titlegap(3)) name(Coefplot_summary, replace) ysize(5) xsize(7)

graph export "$caregiver_mast/Outputs/Figures/Coefplot_summary.pdf", replace
/*


**Note: The following graphs are not included in the paper 
	
	stop
/*	
coefplot `allruralvars' , drop(_cons *_b sex_app cohort2014 *NSC_intdcode) xline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) xline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) bycoefs bylabels("PPI Index" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index" "Psychological Wellbeing Index" "Conflict Index" "Violence Index" "Expenditures Decision Index" "Empowerment Index" "Business Index" "Applicant Enrolled" "Applicant Works" "Children Health Index" "Siblings Education Index") xlabel(-1(0.1)1, labsize(vsmall)) ylabel(, labsize(medium)) msize(small) lwidth(thin) lcolor(gs10) ciopts(recast(rcap)) graphregion(color(white)) bgcolor(white) eqlabels(, labels) xtitle(Standard Deviations of the Control Group, size(medium)) xscale(titlegap(3)) legend(order( 2 "Rural" 4 "Urban") position(5) bplacement(s) rows(1)) name(Coefplot_byrural) ysize(5) xsize(7)

	graph export "Data - Analysis/Output/Coefplot_byrural.pdf", replace


coefplot `allpoorvars' , drop(_cons *_b sex_app cohort2014 *NSC_intdcode) xline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) xline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) bycoefs bylabels("PPI Index" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index" "Psychological Wellbeing Index" "Conflict Index" "Violence Index" "Expenditures Decision Index" "Empowerment Index" "Business Index" "Applicant Enrolled" "Applicant Works" "Children Health Index" "Siblings Education Index") xlabel(-1(0.1)1, labsize(vsmall)) ylabel(, labsize(medium)) msize(small) lwidth(thin) lcolor(gs10) ciopts(recast(rcap)) graphregion(color(white)) bgcolor(white) eqlabels(, labels) xtitle(Standard Deviations of the Control Group, size(medium)) xscale(titlegap(3)) legend(cols(1) ring(0) pos(1) order( 2 "Poorer" 4 "Richer") ) name(Coefplot_bypoor) ysize(5) xsize(7)

	graph export "Data - Analysis/Output/Coefplot_bypoor.pdf", replace

coefplot `allgendervars' , drop(_cons *_b sex_app cohort2014 *NSC_intdcode) xline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) xline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) bycoefs bylabels("PPI Index" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index" "Psychological Wellbeing Index" "Conflict Index" "Violence Index" "Expenditures Decision Index" "Empowerment Index" "Business Index" "Applicant Enrolled" "Applicant Works" "Children Health Index" "Siblings Education Index" ) xlabel(-1(0.1)1, labsize(vsmall)) ylabel(, labsize(medium)) msize(small) lwidth(thin) lcolor(gs10) ciopts(recast(rcap)) graphregion(color(white)) bgcolor(white) eqlabels(, labels) xtitle(Standard Deviations of the Control Group, size(medium)) xscale(titlegap(3)) legend(cols(1) ring(0) pos(1) order( 2 "Girls" 4 "Boys")) name(Coefplot_bygender) ysize(5) xsize(7)

	graph export "Data - Analysis/Output/Coefplot_bygender.pdf", replace
*/

	*************************************************
	********* Heterogeneity by baseline PPI *********
	*************************************************

	*Reset Locals
	local allvars
	local labels
	
	local baselinevarlist out0_povscore09_c index_assets_Z index_expenditures_Z index_nutrition_Z out4_assetvaluePPP out5_expendituresPPP index_education_Z
	
	local outcomehetlist `summaryoutcomes' out4_assetvaluePPP out5_expendituresPPP 
	
	foreach baselinevar of local baselinevarlist {

		qui sum `baselinevar'_b, d
		scalar q1 = r(p25)
		scalar q2 = r(p50)
		scalar q3 = r(p75)


		foreach outcome of local outcomehetlist {
			
			di "`outcome'"
		
		// Treatment Column

			qui sum `outcome'_b

			if r(N)>0 { /* Ancova Regression */
					
				local variable: var label `outcome'

				eststo `outcome'p1		:qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b <= q1 , robust 
			 
				eststo `outcome'p2		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q1 &   `baselinevar'_b <= q2, robust

				eststo `outcome'p3		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q2 &   `baselinevar'_b <= q3, robust
			
				eststo `outcome'p4	: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q3 & `baselinevar'_b < . , robust

			}


	
			if r(N) == 0 { /* No Ancova Regression */
				
				local variable: var label `outcome'
			
				local variable "`variable'$ ^+$"
			
				eststo `outcome'p1		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b <= q1 , robust 
			 
				eststo `outcome'p2		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q1 &   `baselinevar'_b <= q2, robust

				eststo `outcome'p3		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q2 &   `baselinevar'_b <= q3, robust
			
				eststo `outcome'p4	: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if `baselinevar'_b > q3 & `baselinevar'_b < . , robust


			}

			local varlabel: variable label `outcome'

			local labels `labels' `varlabel'
			
			local allpquartvars `allpquartvars'  `outcome'p1  `outcome'p2 `outcome'p3 `outcome'p4  ||


		}

	coefplot out0_povscore09_c_Zp* || out1_appenrolled_fu_Zp* || index_nutrition_Zp* || index_assets_Zp* ||  out4_savingsvaluePPP_Zp* || index_psywel_Zp* , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical legend(order(2 "Q1" 4 "Q2" 6 "Q3" 8 "Q4") cols(4))  ylabel(-0.2(0.2)0.8, labsize(small)) yscale(range(-0.2(0.1)0.8)) ytitle("") xla(, labcolor(bg) tlength(0)) bylabels("PPI Index" "Nutrition Index" "Assets Index" "Psychological Wellbeing Index" "Enrollment Applicant" "Savings Value") xscale(lc(bg)) name(Het_by`baselinevar')
	
		graph export "Data - Analysis/Output/Het_by`baselinevar'.pdf", replace

	/*
		if `baselinevar' == index_assets_Z {
		coefplot index_assets_Zp1 || index_assets_Zp2 || index_assets_Zp3 || index_assets_Zp4 , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical bycoefs recast(line) ciopts( lp(dash) lcolor(gs12)) ylabel(-0.2(0.2)0.8, labsize(small)) yscale(range(-0.2(0.1)0.8)) ytitle("") xla(, labcolor(bg) tlength(0)) xscale(lc(bg)) title(Impact on Assets by Asset Quartile at Baseline) name(QuartHet_`baselinevar')
		}
		
		if `baselinevar' == out4_assetvaluePPP {
		coefplot out4_assetvaluePPPp1 || out4_assetvaluePPPp2 || out4_assetvaluePPPp3 || out4_assetvaluePPPp4 , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical bycoefs recast(line) ciopts( lp(dash) lcolor(gs12)) ytitle("") xla(, labcolor(bg) tlength(0)) xscale(lc(bg)) title(Impact on Assets Value by Asset Value Quartile at Baseline) name(QuartHet_`baselinevar')
		}
				
		if `baselinevar' == out5_expendituresPPP {
		coefplot out5_expendituresPPPp1 || out5_expendituresPPPp2 || out5_expendituresPPPp3 || out5_expendituresPPPp4 , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical bycoefs recast(line) ciopts( lp(dash) lcolor(gs12)) ytitle("") xla(, labcolor(bg) tlength(0)) xscale(lc(bg)) title(Impact on Expenditures by Expenditure Quartile at Baseline) name(QuartHet_`baselinevar')
		}
		
		
		if `baselinevar' == index_education_Z {
		coefplot index_education_Zp1 || index_education_Zp2 || index_education_Zp3 || index_education_Zp4 , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical bycoefs recast(line) ciopts( lp(dash) lcolor(gs12)) ytitle("") xla(, labcolor(bg) tlength(0)) xscale(lc(bg)) title(Impact on Expenditures by Expenditure Quartile at Baseline) name(QuartHet_`baselinevar')
		}
		
		if `baselinevar' == out4_savingsvaluePPP_Z {
		coefplot out4_savingsvaluePPPp1 || out4_savingsvaluePPPp2 || out4_savingsvaluePPPp3 || out4_savingsvaluePPPp4 , yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical bycoefs recast(line) ciopts( lp(dash) lcolor(gs12)) ytitle("") xla(, labcolor(bg) tlength(0)) xscale(lc(bg)) title(Impact on savings Value by Quartile at Baseline) name(QuartHet_`baselinevar')
		}



		graph export "Data - Analysis/Output/QuartHet_`baselinevar'.pdf", replace


	*/	
	
}

	*************************************************
	********* Heterogeneity by baseline PLE *********
	*************************************************
	
	*Reset Locals
	local allvars
	local labels
	
	preserve
	use "Data - Experiment/Cohort_2015/surveys/Output/hh_ple_ds_complete", clear
	rename ple ple_aggregate 
	
		// Id - Make the id cohort-specific
	gen id_new = ""
	lab var id_new "Same as id but with cohort prefix"
	replace id_new = "15" + string(id)
	destring id_new, replace
	keep id_new ple_aggregate
	tempfile 2015PLE
	save `2015PLE'
	restore
	
	merge m:1 id_new using `2015PLE', gen(plemerge) keepus(ple_aggregate)
	drop if plemerge == 2
	drop plemerge 
	
	qui sum ple_aggregate, d
	scalar q1 = r(p25)
	scalar q2 = r(p50)
	scalar q3 = r(p75)


	foreach outcome of local summaryoutcomes {
			
			di "`outcome'"
		
		// Treatment Column

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'

			eststo `outcome'p1		:qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate <= q1 , robust 
			 
			eststo `outcome'p2		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q1 &   ple_aggregate <= q2, robust

			eststo `outcome'p3		: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q2 &   ple_aggregate <= q3, robust
			
			eststo `outcome'p4	: qui reg `outcome' `outcome'_b T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q3 & ple_aggregate != . , robust

		}


	
	 	if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'
			
			local variable "`variable'$ ^+$"
			
			eststo `outcome'p1		:qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate <= q1 , robust 
			 
			eststo `outcome'p2		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q1 &   ple_aggregate <= q2, robust

			eststo `outcome'p3		: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q2 &   ple_aggregate <= q3, robust
			
			eststo `outcome'p4	: qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if ple_aggregate > q3 & ple_aggregate != . , robust


		}

			local varlabel: variable label `outcome'

			local labels `labels' `varlabel'
			
			local allpquartvars `allpquartvars'  `outcome'p1  `outcome'p2 `outcome'p3 `outcome'p4  ||


		}

coefplot out0_povscore09_c_Zp*|| index_nutrition_Zp* || index_assets_Zp* || index_psywel_Zp* || out1_appenrolled_fu_Zp*, yline(0) drop(_cons *_b sex_app cohort2014 *NSC_intdcode) vertical legend(order(2 "Q1" 4 "Q2" 6 "Q3" 8 "Q4") cols(4))  ylabel(-0.2(0.2)0.8, labsize(small)) yscale(range(-0.2(0.1)0.8)) ytitle("") xla(, labcolor(bg) tlength(0)) bylabels("PPI Index" "Nutrition Index" "Assets Index" "Psychological Wellbeing Index" "Enrollment Applicant") xscale(lc(bg))

		graph export "Data - Analysis/Output/Het_byPLE.pdf", replace

