/*---------------------------------------------------------------------------*
*Description: 	Generate coefplots for main outcomes						*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*Input:													     				*
*Output:		Coefplot_summary_T_0.pdf  									*
*				Coefplot_summary_T_0_compare.pdf							*
*Note: 																		*
*---------------------------------------------------------------------------*/


version 17

global cohortFE cohort2014
global districtFE i.NSC_intdcode
	
set scheme s2gcolor
		
use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data_deid.dta", clear

/*
**Graph formatting

do "$mastdata_do_ap/Figures/GraphFormatting.do" 
*/

**Applicant data

preserve 

	*** Sample

	*keep if baseline == 0 /*(2,092 observations deleted)*/	
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted

	**Data from Applicant dataset
	keep if participation_alum == 1
	
	local indices_alum index_psywel_alum out0_povscore09_a_c
	
		foreach var in out7_happiness_a_p out7_lifesatisfaction_a_p out7_cesd_a_p `indices_alum' {
		
		* Long term Follow-up Value
		
		sum `var'_l if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"

		}
	
	lab var out0_povscore09_a_c_Z_l "Standardized Poverty Score (Alum)"	
	
	**** Tables : Mental Health (no pre values) - Alum
	local tab0outcomes_alum index_psywel_alum_Z out0_povscore09_a_c_Z

	local tab1outcomes_alum out7_cesd_a_p_Z out7_happiness_a_p_Z out7_lifesatisfaction_a_p_Z index_psywel_alum_Z
	
	foreach outcome of local tab0outcomes_alum {
			
			di "`outcome'_l"
		
		// Treatment Column

					
			local variable: var label `outcome'_l
			
			eststo `outcome'_l 	: qui reg `outcome'_l T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust


			local varlabel: var label `outcome'_l
			local labels `labels' `varlabel'
			
			local allvars_alum `allvars_alum' `outcome'_l ||

		}
		
		
restore 


**Caregiver data
rename *PPP_2022* *PPP_22*
rename *PPP_2018* *PPP_18* 

	*** Sample

	*keep if baseline == 0 /*(2,092 observations deleted)*/	
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted
	
	keep if notfoundatLTFU == 0	// 74 observations deleted
	
	local indices index_education /* index_childhealth */ index_nutrition index_assets index_prodassets index_expenditures index_psywel index_conflict index_violence index_expdec /* index_empower */ /* index_business
*/

	foreach var in out0_povscore09_c out4_savingsvaluePPP_22 /* out1_uceaggregate */ /* out1_appenrolled out0_appwork */ `indices' {
		
		* Long term Follow-up Value
		
		sum `var'_l if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"
		
		* Follow-up Value
		
		sum `var'_f if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_f = 1*((`var'_f - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_f "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if ltfu == 1 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"

	}

**replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/

lab var out0_povscore09_c_Z_l "Standardized Poverty Score"
lab var out0_povscore09_c_Z_f "Standardized Poverty Score"

* Summary Graph
	
local summaryoutcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_22_Z  index_nutrition_Z index_assets_Z  /* index_empower_Z */ index_expdec_Z index_psywel_Z


* out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z

	foreach outcome of local summaryoutcomes {
			
			di "`outcome'_l"
		
		// Treatment Column

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'_l
			
			eststo `outcome'_l 	: qui reg `outcome'_l T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year, robust
			
			
			local variable_f: var label `outcome'_f
			
			eststo `outcome'_f 	: qui reg `outcome'_f T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014, robust


		}
		
		if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'_l
			
			local variable "`variable'$ ^+$"
			
			eststo `outcome'_l	: qui reg `outcome'_l T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust 
			
	
			local variable_f: var label `outcome'_f
			
			local variable_f "`variable_f'$ ^+$"
			
			eststo `outcome'_f	: qui reg `outcome'_f T_0 i.NSC_intdcode sex_app cohort2014, robust 


		}

			local varlabel: var label `outcome'_l
			local labels `labels' `varlabel'
			
			local allvars `allvars' `outcome'_l ||
			
			local allvars_c `allvars_c' `outcome'_f `outcome'_l ||


		}
		
	
/* 

** Note: the follow Long-term follow-up graph in not included in the paper
	
preserve 
	
coefplot `allvars' `allvars_alum' , drop(_cons *_b *_f sex_app *NSC_intdcode cohort2014 survey_year) xline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) xline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) bycoefs bylabels("Standardized Poverty Score" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index"  "Women's Expenditures Decision Index" "Psychological Wellbeing Index*" "Psychological Wellbeing Index (Alum)**" "Standardized Poverty Score (Alum)**"  /*"Violence Index"*/ /* "Empowerment Index" */ /*  "Conflict Index" */  /*"Applicant Enrolled" "Applicant Works" */ /* "Children Health Index" */ /*"Siblings Education Index"*/ ) xlabel(-1(0.1)1, labsize(vsmall)) ylabel(, labsize(small)) mcolor(maroon) ciopts(recast(rcap) lcolor(maroon)) graphregion(color(white)) bgcolor(white) eqlabels(, labels) xtitle(Standard Deviations of the Control Group, size(small)) xscale(titlegap(3)) name(Coefplot_summary, replace) ysize(5) xsize(6)
	
	graph export "$caregiver_mast/Outputs/Figures/Coefplot_summary_T_0.pdf", replace
	
	
restore	
*/

coefplot `allvars_c', vertical drop(_cons *_b *_fu *_f sex_app *NSC_intdcode cohort2014 survey_year) ///
	bycoefs bylabels("Standardized Poverty Score" "Expenditures Index" "Savings Value" "Nutrition Index" "Assets Index"  "Women's Expenditures Decision Index" "Psychological Wellbeing Index*") ///
	yline(0, lwidth(thin) lpattern(solid) lcolor(gs12)) yline(-0.5 0.5, lwidth(thin) lpattern(dash) lcolor(gs12)) ///
	ylabel(-0.6(0.2)0.6, labsize(vsmall)) ///
	xlabel(,  angle(60) labsize(small)) /// mcolor(navy) mcolor(maroon) ///
	graphregion(color(white)) bgcolor(white) eqlabels(, labels) ytitle(Standard Deviations of the Control Group, size(small)) yscale(titlegap(3)) ///
	name(Coefplot_summary_compare, replace) xsize(5) ysize(6) ///
	legend(order(2 "2Y Follow-Up " 4 "8Y Follow-Up") pos(4) ring(0) size(small) r(2)) 
	 
	 
	graph export "$caregiver_mast/Outputs/Figures/Coefplot_summary_T_0_compare.pdf", replace


	