version 17
set more off

clear all
clear mata


set seed 20200516
pause on 


global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

	*** Sample

	*keep if baseline == 0 /*(2,092 observations deleted)*/	
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted

	**Data from Applicant dataset
	keep if participation_alum == 1
	
	local indices_alum index_psywel_alum out0_povscore09_a_c
	
	foreach var in out7_happiness_a_p out7_lifesatisfaction_a_p out7_cesd_a_p `indices_alum' {
		
		* Long term Follow-up Value
		
		sum `var'_l if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"
		
/*
		* Follow-up Value
		
		sum `var'_f if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_f = 1*((`var'_f - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_f "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if ltfu == 1 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"
*/

	}
	
lab var out0_povscore09_a_c_Z_l "Standardized Poverty Score - Applicant"	
	
	**** Tables : Mental Health (no pre values) - Alum
local tab0outcomes_alum index_psywel_alum_Z out0_povscore09_a_c_Z

local tab1outcomes_alum out7_cesd_a_p_Z out7_happiness_a_p_Z out7_lifesatisfaction_a_p_Z index_psywel_alum_Z
	
local alltablesno 	= 1

forvalues tableno = 0(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Alum_Tab`tableno'.tex", write replace
		
		foreach outcome of local tab`tableno'outcomes_alum {
			
		di "`outcome'_l"
		
		// Treatment Column
				
				local variable: var label `outcome'_l
			
				local variable "`variable'$ ^+$$ ^+$"
			
				qui reg `outcome'_l T_0  i.NSC_intdcode sex_app cohort2014 survey_year, robust			/* No Ancova Regression */
		
					scalar obs = e(N)
					
					**Treatment variable
					scalar betaT = e(b)[1,1]
					scalar sd_betaT = sqrt(e(V)[1,1])
					scalar betaTpvalue = r(table)[4,1]
					
					qui sum `outcome'_l if T_0 == 0	
					scalar mean_C = r(mean)
					scalar sd_C = r(sd)
					
					// Add Significance Stars
					
					
					local starsT ""			// For treatment variable
									
						if betaTpvalue < 0.10 local starsT  "*"
						
						if betaTpvalue < 0.05 local starsT  "**"
						
						if betaTpvalue < 0.01 local starsT  "***"
						

					file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (mean_C) " & " %5.0fc (obs) " \\ " 	_n

					file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} & \medskip \\ " 	_n
		
		}
	
		
	
	file close output_file

		}
		