
*---------------------------------------------------------------------------*
*Description: 	Applicant Dataset - Education/Working by treatment groups	*		
*																			* 
*Date:			03/07/2024													*
*Author:		Raaga Akkineni 												*
*Input:													     				*
*Output:	*Applicant_workEdu.tex											*	
*---------------------------------------------------------------------------*

version 17
set more off

clear all
clear mata

pause on 
set seed 20200501

**Upload dataset
use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_EduRoster_Analysis_SiblingData.dta", clear

keep if cl_chld1_2 == 1 & cl_chld1_3 == 1			// Keep if 'child' at both FU and LTFU 

**Sibling panel: Follow up tp LTFU
local outcomes_1 out1_primary_com_l out1_lenrolled_sec out1_feesPPP_2022		// outcomes for those enrolled in primary at FU
local outcomes_2 out1_secondary_com_l out1_lenrolled_ter out1_feesPPP_2022		// outcomes for those enrolled in secondary at FU
local outcomes_3 out1_enrolled_l out1_primary_com_l out1_secondary_com_l		// outcomes for those who were too young at FU


	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Sibling Education/Applicant_sibling_edeucation.tex", write replace
	
	file write output_file " \textbf{\textit{Panel A: Primary at  Follow-up}} \\" 
	
	foreach outcome of local outcomes_1 {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 i.NSC_intdcode cohort2014 sex_app if out1_primary_f == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out1_primary_f == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"

		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
	
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$("%8.2fc (sd_`outcome'_C) ")$) &  \medskip \\ " 	_n
		
		}
		
	file write output_file " \textbf{\textit{Panel B: Secondary at  Follow-up}} \\" 
	
	foreach outcome of local outcomes_2 {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 i.NSC_intdcode cohort2014 sex_app if out1_secondary_f == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out1_secondary_f == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"

		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$("%8.2fc (sd_`outcome'_C) ")$) &  \medskip \\ " 	_n
		
		}
		
	file write output_file " \textbf{\textit{Panel B: Too Young at  Follow-up}} \\" 
	
	foreach outcome of local outcomes_3 {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 i.NSC_intdcode cohort2014 sex_app if out1_tooyoung_f == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out1_tooyoung_f == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"

		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$("%8.2fc (sd_`outcome'_C) ")$) &  \medskip \\ " 	_n
		
		}
		
	file write output_file " \hline \\ " 		 		
	
	file close output_file


		