version 17
set more off

clear all
clear mata
	
set seed 20200516
pause on

/*
 //Check the path variable is set
if "$researchpath" == "" {
	di "No path found. Please first run your setpath_name.do file"
	exit
} 
 //Set the path to "Research".
cd "$researchpath"
*/

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

**Renaming vairables to avoid errors with varnames reaching max characters 
rename *PPP_2022* *PPP_22*
rename *PPP_2018* *PPP_18* 

rename out7_lifesatisfaction_p* out7_lifesat_p*
rename out4_smallanimalvaluePPP_22* out4_smlanimalvaluePPP_22* 
rename *percapita* *pc* 

	*** Sample

	keep if baseline == 1 /* | (notfoundatFU == 0 & baseline == 0 & ltfu == 0)	 */		/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted
	
	**Data from caregiver dataset
	keep if notfoundatFU != . /* & notfoundatLTFU != . */ // 378 observations deleted
	
	local indices_ltfu index_education index_nutrition index_assets index_prodassets index_expenditures index_violence index_expdec /* index_empower */ index_business index_psywel 

	foreach var in out7_cesd_p out7_happiness_p out7_lifesat_p out7_cesd_a_p out7_happiness_a_p out7_lifesatisfaction_a_p out3_hdd out3_nmeals out4_savingsvaluePPP_22 out0_povscore09_c out1_appenrolled out0_appwork `indices_ltfu' {
	
		* Long term Follow-up Value
		
		sum `var'_l if baseline == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"
		
		* Follow-up Value
		
		sum `var'_f if baseline == 1 & T_0 == 0, d 
		
		gen `var'_Z_f = 1*((`var'_f - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_f "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if baseline == 1 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}

/*
replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/
*/

	local outcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_22_Z index_nutrition_Z index_assets_Z index_psywel_Z /* index_conflict_Z */ index_violence_Z index_expdec_Z /* index_empower_Z */ index_business_Z /* index_childhealth_Z */ index_education_Z  out4_landvaluePPP_22 out4_agritoolvaluePPP_22 out4_cowvaluePPP_22 out4_smlanimalvaluePPP_22  out4_birdvaluePPP_22 out4_bikevaluePPP_22 out4_motorvaluePPP_22 out4_appliancevaluePPP_22 out4_furniturevaluePPP_22 out4_mobilevaluePPP_22 out4_stockvaluePPP_22 out4_machineryvaluePPP_22 out4_housevaluePPP_22 out4_assetvaluePPP_22 out5_foodexpPPP_22 out5_foodexppcPPP_22 out5_medicalexpPPP_22 out5_eduexpPPP_22 out6_businessno out6_hours out6_invrevPPP_22 out3_nmeals_Z out3_hdd_Z out7_cesd_p_Z out7_happiness_p_Z out7_lifesat_p_Z  /* out1_uceaggregate_Z */ out6_nonagribusiness out3_meat out3_vitaminA /* out1_appenrolled_fu out1_appenrolled_fu_Z */ out1_appyrsofedu_fu /* out0_appwork */ out1_app_privschool out1_app_board out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out5_fuelexpPPP_22 out6_all_biz out6_nonagribusiness2 out6_agri_biz /*out6_nonagribusiness out6_businessno */ out6_businessno_roster out1_appenrolled out1_appyrsofedu
 	
	foreach yvar of local outcomes {
		
	// Imputation bounds for LTFU and FU outcomes: Calculate mean & s.d. within treatment-season bins
		
		**For LTFU
		bys T_0 : egen `yvar'_mean_l = mean(`yvar'_l)
		bys T_0 : egen `yvar'_sd_l   = sd(`yvar'_l)
		
/*
		**For FU
		bys T_0: egen `yvar'_mean_f = mean(`yvar'_f)
		bys T_0: egen `yvar'_sd_f   = sd(`yvar'_f)
	
*/
		// Correct Outcome Variable - for both FU and LTFU 
		
		gen `yvar'_l_L5 = `yvar'_l 		if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U5 = `yvar'_l 		if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_L10 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U10 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_L20 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U20 = `yvar'_l		if notfoundatLTFU == 0	| notfoundatFU == 0
		
				
		replace `yvar'_l_U5 = `yvar'_mean_l + 0.05 * `yvar'_sd_l if `yvar'_l_U5 == . & T_0 == 1 
		replace `yvar'_l_U5 = `yvar'_mean_l - 0.05 * `yvar'_sd_l if `yvar'_l_U5 == . & T_0 == 0 
		
		replace `yvar'_l_L5 = `yvar'_mean_l - 0.05 * `yvar'_sd_l if `yvar'_l_L5 == . & T_0 == 1 
		replace `yvar'_l_L5 = `yvar'_mean_l + 0.05 * `yvar'_sd_l if `yvar'_l_L5 == . & T_0 == 0 

		replace `yvar'_l_U10 = `yvar'_mean_l + 0.10 * `yvar'_sd_l if `yvar'_l_U10 == . & T_0 == 1 
		replace `yvar'_l_U10 = `yvar'_mean_l - 0.10 * `yvar'_sd_l if `yvar'_l_U10 == . & T_0 == 0 
	
		replace `yvar'_l_L10 = `yvar'_mean_l - 0.10 * `yvar'_sd_l if `yvar'_l_L10 == . & T_0 == 1 
		replace `yvar'_l_L10 = `yvar'_mean_l + 0.10 * `yvar'_sd_l if `yvar'_l_L10 == . & T_0 == 0 

		replace `yvar'_l_U20 = `yvar'_mean_l + 0.20 * `yvar'_sd_l if `yvar'_l_U20 == . & T_0 == 1 
		replace `yvar'_l_U20 = `yvar'_mean_l - 0.20 * `yvar'_sd_l if `yvar'_l_U20 == . & T_0 == 0 
	
		replace `yvar'_l_L20 = `yvar'_mean_l - 0.20 * `yvar'_sd_l if `yvar'_l_L20 == . & T_0 == 1 
		replace `yvar'_l_L20 = `yvar'_mean_l + 0.20 * `yvar'_sd_l if `yvar'_l_L20 == . & T_0 == 0 

	}

	lab var out0_povscore09_c_Z_l "Standardized Poverty Score"
	lab var out0_povscore09_c_Z_f "Standardized Poverty Score"
	
	* And now replicate the tables
local tab0outcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_22_Z index_nutrition_Z index_assets_Z  /* index_empower_Z */ index_expdec_Z index_psywel_Z 

*index_business_Z out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z

**** Tables : Assets
local tab1outcomes out4_landvaluePPP_22 out4_agritoolvaluePPP_22 out4_cowvaluePPP_22 out4_smlanimalvaluePPP_22 out4_birdvaluePPP_22	out4_bikevaluePPP_22 out4_motorvaluePPP_22 out4_appliancevaluePPP_22 out4_furniturevaluePPP_22 	out4_mobilevaluePPP_22 out4_stockvaluePPP_22 out4_machineryvaluePPP_22 out4_housevaluePPP_22 out4_assetvaluePPP_22  index_assets_Z

**** Tables : Expenditures 
local tab2outcomes out5_foodexpPPP_22 out5_foodexppcPPP_22 /* out5_medicalexpPPP_2022  out5_eduexpPPP_2022 out5_waterexpPPP_2022 out5_personalexpPPP_2022 */ out5_fuelexpPPP_22 index_expenditures_Z

**** Tables : Business
local tab3outcomes out6_all_biz out6_nonagribusiness2 out6_agri_biz /*out6_nonagribusiness out6_businessno */ out6_businessno_roster out6_hours out6_invrevPPP_22 index_business_Z

*** Tables : Nutrition 
local tab4outcomes out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out3_nmeals_Z out3_hdd_Z index_nutrition_Z

**** Tables : Mental Health (no pre values)
local tab5outcomes out7_cesd_p_Z out7_happiness_p_Z out7_lifesat_p_Z index_psywel_Z

**** Tables : Applicant Education (no pre values)
local tab6outcomes  out1_appenrolled out1_appyrsofedu /* out1_uceaggregate_Z */ out1_app_privschool out1_app_board /* out0_appwork */

local alltablesno 	= 7



forvalues tableno = 0(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Karlan Bounds/Tab`tableno'_Imputation_1.tex", write replace

	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'_l"
		
		// To label the line in the table:
		
		local variable: var label `outcome'_l
		
		// To label non-ancova regressions:

		qui sum `outcome'_b

			if r(N) == 0 { 
					
				local variable "`variable'$ ^+$"

			}
		
		// To obtain number of regressions:


		// Karlan Bounds
		
		foreach boundtype in U5 L5 U10 L10 U20 L20 {

			qui sum `outcome'_b

			if r(N)>0 {
					
				qui reg `outcome'_l_`boundtype' T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year, robust
				scalar obs = e(N) /* not elegant, as it overwrites e(N) of different regressions - but e(N) does not change across boundtypes so the result is correct. */

			}

			if r(N) == 0 { 
					
				qui reg `outcome'_l_`boundtype' T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust
				scalar obs = e(N)

			}

		scalar beta`boundtype' = e(b)[1,1]
		scalar sd_beta`boundtype' = sqrt(e(V)[1,1])
		scalar beta`boundtype'pvalue = r(table)[4,1]

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if beta`boundtype'pvalue < 0.10 local stars`boundtype'  "*"
			
			if beta`boundtype'pvalue < 0.05 local stars`boundtype'  "**"
			
			if beta`boundtype'pvalue < 0.01 local stars`boundtype'  "***"
			
		}

		file write output_file "`variable' & {\footnotesize [" %8.2fc (betaU5) "\$^{`starsU5'}\$" "," %8.2fc (betaL5) "\$^{`starsL5'}\$" "] }  & {\footnotesize [" %8.2fc (betaU10) "\$^{`starsU10'}\$" "," %8.2fc (betaL10) "\$^{`starsL10'}\$" "] } & {\footnotesize [" %8.2fc (betaU20) "\$^{`starsU20'}\$" "," %8.2fc (betaL20) "\$^{`starsL20'}\$" "] } &" %5.0fc (obs) " \bigskip \\  " 	_n
			
		}
		
		file close output_file

	}