version 14
set more off

clear all
clear mata

pause on

/*
* Check the path variable is set
if "$researchpath" == "" {
	di "No path found. Please first run your setpath_name.do file"
	exit
} 
* Set the path to "Research".
cd "$researchpath"
*/

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

rename *PPP_2022* *PPP_22*
rename *PPP_2018* *PPP_18* 

rename out7_lifesatisfaction_p* out7_lifesat_p*

	*** Sample
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted
	
	**Data from caregiver dataset
	keep if notfoundatLTFU == 0 // 378 observations deleted

	local indices_ltfu index_education index_nutrition index_assets index_prodassets index_expenditures index_violence index_expdec /* index_empower */ index_business index_psywel index_psywel_alum

	foreach var in out7_cesd_p out7_happiness_p out7_lifesat_p out7_cesd_a_p out7_happiness_a_p out7_lifesatisfaction_a_p out3_hdd out3_nmeals out4_savingsvaluePPP_22 out0_povscore09_c out1_appenrolled out0_appwork `indices_ltfu' {
		
		* Long term Follow-up Value
		
		sum `var'_l if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"
		
		* Follow-up Value
		
		sum `var'_f if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_f = 1*((`var'_f - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_f "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if ltfu == 1 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}
 
 	* Divide outcomes in binary and continuous to build the trimmed variables

	*replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/

	local outcomes_binary out6_nonagribusiness out3_meat out3_vitaminA /* out1_appenrolled_fu */ /* out1_appenrolled_fu_Z */ out1_app_privschool out0_appwork out1_app_board out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out6_all_biz out6_nonagribusiness2 out6_agri_biz out1_appenrolled out4_landD out4_agritoolD out4_smallanimalD out4_birdD out4_cowD out4_bikeD out4_motorD out4_applianceD out4_furnitureD 	out4_mobileD out4_stockD out4_machineryD out4_houseD

	local outcomes_conts out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_22_Z index_nutrition_Z index_assets_Z index_psywel_Z /* index_conflict_Z */ index_violence_Z index_expdec_Z /* index_empower_Z */ index_business_Z /* index_childhealth_Z */ index_education_Z  out4_landvaluePPP_22 out4_agritoolvaluePPP_22 out4_cowvaluePPP_22 out4_smallanimalvaluePPP_22 out4_birdvaluePPP_22 out4_bikevaluePPP_22 out4_motorvaluePPP_22 out4_appliancevaluePPP_22 out4_furniturevaluePPP_22 out4_mobilevaluePPP_22 out4_stockvaluePPP_22 out4_machineryvaluePPP_22 out4_housevaluePPP_22 out4_assetvaluePPP_22 out5_foodexpPPP_22 out5_foodexppercapitaPPP_22 out5_medicalexpPPP_22 out5_eduexpPPP_22 out5_waterexpPPP_22 out5_personalexpPPP_22 out5_fuelexpPPP_22 out6_businessno out6_hours out6_invrevPPP_22 out3_nmeals_Z out3_hdd_Z out7_cesd_p_Z out7_happiness_p_Z out7_lifesat_p_Z  /* out1_uceaggregate_Z */ out1_appyrsofedu out6_businessno_roster 
	
	* From table printed in AttritionTable.do,  I need to trim 89 observations to equalize attrition with C (for continuous vars, top 13%).

	* Binary variables
	
	set seed 20200501
	
	cap drop random1
	
	sort id_new
	
	gen random1=uniform()


	foreach var of local outcomes_binary {

		gen `var'_lt=`var'_l
	
		gen `var'_ut=`var'_l

		sort T_0 `var' random1

		egen grp_`var'=group(T_0 `var'_l), missing /* 4 groups: T = 0 & var = 0, T = 0 & var = 1, T = 1 & var = 0, T = 1 & var = 1*/

		egen rank_`var'=rank(random1), by(grp_`var') 

		replace `var'_lt=. if rank_`var'<= 89 & T_0 == 1 & `var'_l==0

		replace `var'_ut=. if rank_`var'<= 89 & T_0 == 1 & `var'_l==1

	}
	
	
	* Continuous variables
	
	foreach var of local outcomes_conts {
	
	gen `var'_lt=`var'_l
	
	gen `var'_ut=`var'_l

	sort T_0 `var'_l random1

	egen grp_`var'=group(T_0 `var'_l), missing
	
	egen rank_`var'=rank(random1), by(grp_`var') 

	replace `var'_lt=. if rank_`var'<= 89 & T_0 == 1 & `var'_l==0
	
	egen lwr_`var'=pctile(`var'_l) 	if 	T_0 == 1 , p(13)
	
	replace `var'_lt=. 			if  T_0 == 1 & `var'_l<lwr_`var'

	drop lwr_`var'

	egen upr_`var'=pctile(`var'_l) 	if 	T_0 == 1 , p(87)
	
	replace `var'_ut=. 			if  T_0 == 1 & `var'_l>upr_`var'

	drop upr_`var'

}

	lab var out0_povscore09_c_Z_l "Standardized Poverty Score"
	lab var out0_povscore09_c_Z_f "Standardized Poverty Score"

	* And now replicate the tables
local tab0outcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_22_Z index_nutrition_Z index_assets_Z  /* index_empower_Z */ index_expdec_Z 	index_psywel_Z 

*index_business_Z out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z

**** Tables : Assets
local tab1outcomes out4_landvaluePPP_22 out4_agritoolvaluePPP_22 out4_cowvaluePPP_22 out4_smallanimalvaluePPP_22 out4_birdvaluePPP_22	out4_bikevaluePPP_22 out4_motorvaluePPP_22 out4_appliancevaluePPP_22 out4_furniturevaluePPP_22 	out4_mobilevaluePPP_22 out4_stockvaluePPP_22 out4_machineryvaluePPP_22 out4_housevaluePPP_22 out4_assetvaluePPP_22  index_assets_Z

**** Tables : Expenditures 
local tab2outcomes out5_foodexpPPP_22 out5_foodexppercapitaPPP_22 /* out5_medicalexpPPP_2022  out5_eduexpPPP_2022 out5_waterexpPPP_2022 out5_personalexpPPP_2022 */ out5_fuelexpPPP_22 index_expenditures_Z


**** Tables : Business
local tab3outcomes  out6_all_biz out6_nonagribusiness2 out6_agri_biz /*out6_nonagribusiness out6_businessno */ out6_businessno_roster out6_hours out6_invrevPPP_22 index_business_Z

*** Tables : Nutrition 
local tab4outcomes out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out3_nmeals_Z out3_hdd_Z index_nutrition_Z

**** Tables : Mental Health (no pre values)
local tab5outcomes out7_cesd_p_Z out7_happiness_p_Z out7_lifesat_p_Z index_psywel_Z


**** Tables : Applicant Education (no pre values)
local tab6outcomes  out1_appenrolled out1_appyrsofedu /* out1_uceaggregate_Z */ out1_app_privschool out1_app_board /* out0_appwork */

**** Tables : Assets
local tab7outcomes out4_landD out4_agritoolD out4_cowD out4_smallanimalD out4_birdD	out4_bikeD out4_motorD out4_applianceD out4_furnitureD 	out4_mobileD out4_stockD out4_machineryD out4_houseD

local alltablesno 	= 7

forvalues tableno = 0(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Lee Bounds/Tab`tableno'_Lee.tex", write replace

	
	foreach outcome of local tab`tableno'outcomes {
			
	di "`outcome'_l"
		
		// Treatment Column
		
			qui sum `outcome'_b

			if r(N)>0 { 							/* Ancova Regression */
						
				local variable: var label `outcome'_l
			
				qui reg `outcome'_l T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year, robust		// updated ANCOVA 		
		
			}
		
			if r(N) == 0 { 							/* No Ancova Regression */
				
				local variable: var label `outcome'_l
			
				local variable "`variable'$ ^+$"
			
				qui reg `outcome'_l T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust
		
			}
		 
		scalar obs = e(N)

		scalar betaT = e(b)[1,1]
		scalar sd_betaT = sqrt(e(V)[1,1])
		scalar betaTpvalue = r(table)[4,1]
		
		// Upper Lee Bound Column

		qui sum `outcome'_b

		if r(N)>0 {
					
			qui reg `outcome'_ut T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year
		}

		if r(N) == 0 { 
					
			qui reg `outcome'_ut T_0 i.NSC_intdcode sex_app cohort2014 survey_year
		}


		scalar betaU = e(b)[1,1]
		scalar sd_betaU = sqrt(e(V)[1,1])
		scalar betaUpvalue = r(table)[4,1]

		// Lower Lee Bound Column

		qui sum `outcome'_b

		if r(N)>0 {
					
			qui reg `outcome'_lt T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year
		}

		if r(N) == 0 { 
					
			qui reg `outcome'_lt T_0 i.NSC_intdcode sex_app cohort2014 survey_year
		}

		 
		scalar betaL = e(b)[1,1]
		scalar sd_betaL = sqrt(e(V)[1,1])
		scalar betaLpvalue = r(table)[4,1]
		
		qui sum `outcome'_l if T_0 == 0
		scalar mean_C = r(mean)
		scalar sd_C = r(sd)
		
		// Add Significance Stars
		
		local starsT ""
		local starsU ""
		local starsL ""

		foreach coltype in T U L {
						
			if beta`coltype'pvalue < 0.10 local stars`coltype'  "*"
			
			if beta`coltype'pvalue < 0.05 local stars`coltype'  "**"
			
			if beta`coltype'pvalue < 0.01 local stars`coltype'  "***"
			
		}

		*file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (mean_C) " & " %8.2fc (betaU) " & " %8.2fc (betaL) " & " %5.0fc (obs) " \\ " 	_n

		*file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} &  \scriptsize{$(" %8.2fc (sd_betaU) ")^{`starsU'}$} &  \scriptsize{$(" %8.2fc (sd_betaL) ")^{`starsL'}$} & \medskip \\ " 	_n
		
		file write output_file "`variable' & " %8.2fc (betaT) "\$^{`starsT'}\$" " & " %8.2fc (mean_C) " & {\footnotesize [" %8.2fc (betaU) "\$^{`starsU'}\$" "," %8.2fc (betaL) "\$^{`starsL'}\$" "] }  & " %5.0fc (obs) " \bigskip \\  " _n

		*file write output_file "`variable' & {\footnotesize [" %8.2fc (betaU5) "\$^{`starsU5'}\$" "," %8.2fc (betaL5) "\$^{`starsL5'}\$" "] }  & {\footnotesize [" %8.2fc (betaU10) "\$^{`starsU10'}\$" "," %8.2fc (betaL10) "\$^{`starsL10'}\$" "] } & {\footnotesize [" %8.2fc (betaU20) "\$^{`starsU20'}\$" "," %8.2fc (betaL20) "\$^{`starsL20'}\$" "] } &" %5.0fc (obs) " \bigskip \\  " 	_n

			
		}
		
	
	file close output_file


	}
