version 13
set more off

clear all
clear mata


set seed 20200516
pause on 

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

	*** Sample
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if participation_alum == 1	// 441 observations deleted

	**Creating a new scores vairables by imputing mock scores if actual scores are missing
	gen out1_uceaggregate_m = out1_uceaggregate if out1_uceaggregate != .
	replace out1_uceaggregate_m = out1_mock_uceaggregate if out1_uceaggregate == .  &  out1_mock_uceaggregate != .
	label var out1_uceaggregate_m "UCE scores with mock imputed"

	gen out1_uaceaggregate_m = out1_uaceaggregate if out1_uaceaggregate != .
	replace out1_uceaggregate_m = out1_mock_uaceaggregate if out1_uaceaggregate == .  &  out1_mock_uaceaggregate != .
	label var out1_uceaggregate_m "UACE scores with mock imputed"	
	
	
	foreach var in out1_uceaggregate out1_uceaggregate_m  out1_uaceaggregate out1_uaceaggregate_m {
		
		sum `var' if ltfu == 1 & T_0 == 0, d 
		
		replace `var' = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var' "`zscorelabel'"

	}
	
	
**Smaller scores mean better outcomes for UCE 
replace out1_uceaggregate 		= -1*(out1_uceaggregate) 
replace out1_uceaggregate_m		= -1*(out1_uceaggregate_m) 

*Creating table for UCE and UACE scores (actual + imputed with mock scores) 
foreach level in out1_uceaggregate out1_division1_scores out1_uaceaggregate out1_uace_top_scores{ 

		qui reg `level' T_0 $districtFE gender_app cohort2014 /* survey_year */ , robust
		 
		scalar beta_T`level' = e(b)[1,1]
		scalar betasd_T`level' = sqrt(e(V)[1,1])
		scalar beta_p_T`level' = r(table)[4,1]

		scalar n_`level' = e(N)

		sum `level' if T_0 == 0
		scalar mean_`level'_C = r(mean)
				
		if beta_p_T`level' < 0.10 local stars_`level'  "*"
			
		if beta_p_T`level' < 0.05 local stars_`level'  "**"
			
		if beta_p_T`level' < 0.01 local stars_`level'  "***"
		
}

** One Panel: All
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_table_education_outcome_scores_division.tex", write replace
	
	file write output_file "T & " %5.3f (beta_Tout1_uceaggregate) " & " %5.3f (beta_Tout1_division1_scores) " & " %5.3f (beta_Tout1_uaceaggregate) " & " %5.3f (beta_Tout1_uace_top_scores) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_uceaggregate) ")^{`stars_out1_uceaggregate'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_division1_scores) ")^{`stars_out1_division1_scores'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uaceaggregate) ")^{`stars_out1_uaceaggregate'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uace_top_scores) ")^{`stars_out1_uace_top_scores'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_uceaggregate_C) " & " %5.2f (mean_out1_division1_scores_C) " & " %5.2f (mean_out1_uaceaggregate_C) " & " %5.2f (mean_out1_uace_top_scores_C) "  \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_out1_uceaggregate) " & " %5.0fc (n_out1_division1_scores) " & " %5.0fc (n_out1_uaceaggregate) " & " %5.0fc (n_out1_uace_top_scores) " \\ " _n
	file write output_file "\hline \\ " 	_n

	file close output_file
	
** Gendered Effects: 3 Panels 
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_table_education_outcome_scores_division_gender.tex", write replace
	
	file write output_file "T & " %5.3f (beta_Tout1_uceaggregate) " & " %5.3f (beta_Tout1_division1_scores) " & " %5.3f (beta_Tout1_uaceaggregate) " & " %5.3f (beta_Tout1_uace_top_scores) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_uceaggregate) ")^{`stars_out1_uceaggregate'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_division1_scores) ")^{`stars_out1_division1_scores'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uaceaggregate) ")^{`stars_out1_uaceaggregate'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uace_top_scores) ")^{`stars_out1_uace_top_scores'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_uceaggregate_C) " & " %5.2f (mean_out1_division1_scores_C) " & " %5.2f (mean_out1_uaceaggregate_C) " & " %5.2f (mean_out1_uace_top_scores_C) "  \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_out1_uceaggregate) " & " %5.0fc (n_out1_division1_scores) " & " %5.0fc (n_out1_uaceaggregate) " & " %5.0fc (n_out1_uace_top_scores) " \\ " _n
	file write output_file "\hline \\ " 	_n
	
	
	file close output_file

**Completed O, A-levels and attended tertiary + attended UCE/UACE	

/*
	foreach var in out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary {
		
		sum `var' if ltfu == 1 & T_0 == 0, d 
		
		replace `var' = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var' "`zscorelabel'"

	}
*/
	
** For All - one panel 

foreach level in out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary{ 
		qui reg `level' T_0 $districtFE gender_app cohort2014 /* survey_year */, robust
		scalar beta_T`level' = e(b)[1,1]
		scalar betasd_T`level' = sqrt(e(V)[1,1])
		scalar beta_p_T`level' = r(table)[4,1]

		scalar n_`level' = e(N)

		sum `level' if T_0 == 0
		scalar mean_`level'_C = r(mean)
		
		if beta_p_T`level' < 0.10 local stars_`level'  "*"
			
		if beta_p_T`level' < 0.05 local stars_`level'  "**"
			
		if beta_p_T`level' < 0.01 local stars_`level'  "***"
		
		// For Women
		
		qui reg `level' T_0 $districtFE  cohort2014 /* survey_year */ if gender_app == 0
		scalar beta_T`level'_F = e(b)[1,1]
		scalar betasd_T`level'_F = sqrt(e(V)[1,1])
		scalar beta_p_T`level'_F = r(table)[4,1]

		scalar n_`level'_F = e(N)

		sum `level' if T_0 == 0 if gender_app == 0
		scalar mean_`level'_C_F = r(mean)
		
		if beta_p_T`level'_F < 0.10 local stars_`level'_F  "*"
			
		if beta_p_T`level'_F < 0.05 local stars_`level'_F  "**"
			
		if beta_p_T`level'_F < 0.01 local stars_`level'_F  "***"
		
		// For Men
		
		qui reg `level' T_0 $districtFE  cohort2014 /* survey_year */ if gender_app == 1
		scalar beta_T`level'_M = e(b)[1,1]
		scalar betasd_T`level'_M = sqrt(e(V)[1,1])
		scalar beta_p_T`level'_M = r(table)[4,1]

		scalar n_`level'_M = e(N)

		sum `level' if T_0 == 0 if gender_app == 1
		scalar mean_`level'_C_M = r(mean)
		
		if beta_p_T`level'_M < 0.10 local stars_`level'_M  "*"
			
		if beta_p_T`level'_M < 0.05 local stars_`level'_M  "**"
			
		if beta_p_T`level'_M < 0.01 local stars_`level'_M  "***"
		
}

	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_table_education_outcome_completion_participation.tex", write replace
	
	
	file write output_file "T & " %5.3f (beta_Tout1_olevel) " & " %5.3f (beta_Tout1_ucesat) " & " %5.3f (beta_Tout1_alevel) " & " %5.3f (beta_Tout1_uacesat) " & " %5.3f (beta_Tout1_tertiary) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_olevel) ")^{`stars_out1_olevel'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_ucesat) ")^{`stars_out1_ucesat'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_alevel) ")^{`stars_out1_alevel'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uacesat) ")^{`stars_out1_uacesat'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_tertiary) ")^{`stars_out1_tertiary'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_olevel_C) " & " %5.2f (mean_out1_ucesat_C) " & " %5.2f (mean_out1_alevel_C) " & " %5.2f (mean_out1_uacesat_C) " & " %5.2f (mean_out1_tertiary_C) " \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_out1_olevel) " & " %5.0fc (n_out1_ucesat) " & " %5.0fc (n_out1_alevel) " & " %5.0fc (n_out1_uacesat) " & " %5.0fc (n_out1_tertiary) " \\ " _n
	
	file write output_file "\hline \\ " 	_n
	
	file close output_file
	

** Gendered effects Panel
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_table_education_outcome_completion_participation_gender.tex", write replace
	
	file write output_file "T & " %5.3f (beta_Tout1_olevel) " & " %5.3f (beta_Tout1_ucesat) " & " %5.3f (beta_Tout1_alevel) " & " %5.3f (beta_Tout1_uacesat) " & " %5.3f (beta_Tout1_tertiary) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_olevel) ")^{`stars_out1_olevel'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_ucesat) ")^{`stars_out1_ucesat'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_alevel) ")^{`stars_out1_alevel'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uacesat) ")^{`stars_out1_uacesat'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_tertiary) ")^{`stars_out1_tertiary'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_olevel_C) " & " %5.2f (mean_out1_ucesat_C) " & " %5.2f (mean_out1_alevel_C) " & " %5.2f (mean_out1_uacesat_C) " & " %5.2f (mean_out1_tertiary_C) " \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_out1_olevel) " & " %5.0fc (n_out1_ucesat) " & " %5.0fc (n_out1_alevel) " & " %5.0fc (n_out1_uacesat) " & " %5.0fc (n_out1_tertiary) " \\ " _n
	
	file write output_file "\hline \\ " 	_n
	
	** For women only
	
	file write output_file "\multicolumn{6}{l}{\textbf{\textit{Panel B: Female}}} \\" 
	
	file write output_file " \medskip \\ " 	_n	

	file write output_file "T & " %5.3f (beta_Tout1_olevel_F) " & " %5.3f (beta_Tout1_ucesat_F) " & " %5.3f (beta_Tout1_alevel_F) " & " %5.3f (beta_Tout1_uacesat_F) " & " %5.3f (beta_Tout1_tertiary_F) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_olevel_F) ")^{`stars_out1_olevel_F'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_ucesat_F) ")^{`stars_out1_ucesat_F'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_alevel_F) ")^{`stars_out1_alevel_F'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uacesat_F) ")^{`stars_out1_uacesat_F'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_tertiary_F) ")^{`stars_out1_tertiary_F'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_olevel_C_F) " & " %5.2f (mean_out1_ucesat_C_F) " & " %5.2f (mean_out1_alevel_C_F) " & " %5.2f (mean_out1_uacesat_C_F) " & " %5.2f (mean_out1_tertiary_C_F) " \\ " _n
	
	
	
	file write output_file "Observations & " %5.0fc (n_out1_olevel_F) " & " %5.0fc (n_out1_ucesat_F) " & " %5.0fc (n_out1_alevel_F) " & " %5.0fc (n_out1_uacesat_F) " & " %5.0fc (n_out1_tertiary_F) " \\ " _n
	
	file write output_file "\hline \\ " 	_n
	
	** For men only
	
	file write output_file "\multicolumn{6}{l}{\textbf{\textit{Panel B: Male}}} \\" 
	
	file write output_file " \medskip \\ " 	_n	

	file write output_file "T & " %5.3f (beta_Tout1_olevel_M) " & " %5.3f (beta_Tout1_ucesat_M) " & " %5.3f (beta_Tout1_alevel_M) " & " %5.3f (beta_Tout1_uacesat_M) " & " %5.3f (beta_Tout1_tertiary_M) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (betasd_Tout1_olevel_M) ")^{`stars_out1_olevel_M'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_ucesat_M) ")^{`stars_out1_ucesat_M'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_alevel_M) ")^{`stars_out1_alevel_F'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_uacesat_M) ")^{`stars_out1_uacesat_M'}$} & \scriptsize{$(" %5.3f (betasd_Tout1_tertiary_M) ")^{`stars_out1_tertiary_M'}$} \\ " 	_n
	
	file write output_file "\midrule \\ " 	_n
	file write output_file "\hline \\ " 	_n
	
	file write output_file "Mean Outcome (C) & " %5.2f (mean_out1_olevel_C_M) " & " %5.2f (mean_out1_ucesat_C_M) " & " %5.2f (mean_out1_alevel_C_M) " & " %5.2f (mean_out1_uacesat_C_M) " & " %5.2f (mean_out1_tertiary_C_M) " \\ " _n
	
	
	
	file write output_file "Observations & " %5.0fc (n_out1_olevel_M) " & " %5.0fc (n_out1_ucesat_M) " & " %5.0fc (n_out1_alevel_M) " & " %5.0fc (n_out1_uacesat_M) " & " %5.0fc (n_out1_tertiary_M) " \\ " _n
	
	file write output_file "\hline \\ " 	_n
	
	file close output_file
	