version 13
set more off

clear all
clear mata


set seed 20200516
pause on 

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta", clear

	*** Sample
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if participation_alum == 1	// 441 observations deleted

	**Creating a new scores vairables by imputing mock scores if actual scores are missing
	gen out1_uceaggregate_m = out1_uceaggregate if out1_uceaggregate != .
	replace out1_uceaggregate_m = out1_mock_uceaggregate if out1_uceaggregate == .  &  out1_mock_uceaggregate != .
	label var out1_uceaggregate_m "UCE scores with mock imputed"

	gen out1_uaceaggregate_m = out1_uaceaggregate if out1_uaceaggregate != .
	replace out1_uceaggregate_m = out1_mock_uaceaggregate if out1_uaceaggregate == .  &  out1_mock_uaceaggregate != .
	label var out1_uceaggregate_m "UACE scores with mock imputed"	
	
	
	foreach var in out1_uceaggregate out1_uceaggregate_m  out1_uaceaggregate out1_uaceaggregate_m {
		
		sum `var' if ltfu == 1 & T_0 == 0, d 
		
		replace `var' = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var' "`zscorelabel'"

	}
	
	
**Smaller scores mean better outcomes for UCE 
replace out1_uceaggregate 		= -1*(out1_uceaggregate) 
replace out1_uceaggregate_m		= -1*(out1_uceaggregate_m) 


local tab1outcomes out1_uceaggregate out1_division1_scores out1_uaceaggregate out1_uace_top_scores

local tab2outcomes out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary

local alltablesno 	= 2



**Gender diff in BL format
forvalues tableno = 1(1)`alltablesno' {
	
	scalar var_count = `:word count `tab`tableno'outcomes''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_table_education_outcome_scores_gender_`tableno'.tex", write replace
	
	**Variable name
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		local variable: var label `outcome'
		local variable "`variable'"
		
/*
		file write output_file " & `variable'"
*/
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}
	
	file write output_file " \\ " _n
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel A: All}}} & \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' T_0 $districtFE gender_app cohort2014 
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		scalar n_`outcome' = e(N)
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_f  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_f  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_f  "***"
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_f'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
		
		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
	**For women only 
	file write output_file " \hline \\ " 

	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel B: Female}}} & \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' T_0 $districtFE cohort2014 if gender_app == 0 
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		scalar n_`outcome' = e(N)
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome''}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & gender_app == 0 

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
		
		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	
	**For men only 
	file write output_file " \hline \\ " 
	
	file write output_file " \multicolumn{`N'}{l}{\textbf{\textit{Panel C: Male}}} & \\" 
	
	file write output_file " \medskip \\ " 	_n	
	
	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui reg `outcome' T_0 $districtFE gender_app cohort2014 if gender_app == 1 
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		scalar n_`outcome' = e(N)
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'_m  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'_m  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'_m  "***"

		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")^{`stars_`outcome'_m'}$} " 
		
		}
	file write output_file "& \medskip \\ " 	_n	
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		qui sum `outcome' if T_0 == 0 & gender_app == 1 
		scalar mean_`outcome' = r(mean)

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \medskip \\ " 	_n	
	

	
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}		