
*---------------------------------------------------------------------------*
*Description: 	Generate outcomes for analysis 								*		
*																			* 
*Date:			10/10/2023													*
*Author:		Raaga Akkineni (based on 2017 script by Benedetta Lerva)	*
*Input:													     				*
*Output:	*Data - Analysis/Temp/Cohort2014_2015_AttritionAnalysis_Data.dta*	
*Note: 		same as DatasetCreation_AttritionAnalysis       				*									*
*---------------------------------------------------------------------------*

*************************************
* INDEX								*
* 									*
*PART I								*
* 	0.Preliminaries					*
*	1.Aggregate, Standardize Data	*
*	2.Select Sample					*
*	3.Define Treatment Variables	*
*	4.Define Identifiers			*
*									*
*PART II							*
*	Outcome 0: Demographics			*
*	Outcome 1: Education			*
*	Outcome 2: Health				*
*	Outcome 3: Dietary Diversity	*	
*	Outcome 4: Assets				*
* 									*
*************************************


version 17
set more off

clear all
clear mata

set seed 20200501

**Upload dataset
use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_EduRoster_AnalysisData.dta", clear

/*
local tab1outcomes out1_enrolled out1_enrolled_22 out1_enrolled_21 out1_enrolled_20 out1_enrolled_19 out1_enrolled_18 out1_enrolled_17 out1_enrolled_16 out1_feesPPP_2022 out1_private

local alltablesno 	= 1

forvalues tableno = 1(1)`alltablesno' {
	
	capture file close output_file	
								 
	file open output_file using "$caregiver_mast/Outputs/Tables/Sibling Education/Tab`tableno'_sibling.tex", write replace
	
	file write output_file " \midrule \\ "  
	
	file write output_file " \hline \\ "  
	
	file write output_file " Panel A: & \multicolumn{3}{c}{All} \\ " 
	
	file write output_file " \hline \\ " 
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
	
	file close output_file

		}
*/

		
**Split between ages
local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

local tab2outcomes out1_fees_priPPP_2022 out1_private_pri out1_fees_secPPP_2022 out1_private_sec

local alltablesno 	= 2

forvalues tableno = 1(1)`alltablesno' {
	
	capture file close output_file	
								 
	file open output_file using "$caregiver_mast/Outputs/Tables/Sibling Education/Tab`tableno'_sibling_panel.tex", write replace
	
	file write output_file " \midrule \\ "  
	
	file write output_file " \hline \\ "  
	
	file write output_file " \textbf{\textit{Panel A: Siblings Aged 6-11}} \\" 
	
	local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

	local tab2outcomes out1_fees_priPPP_2022 out1_private_pri /* out1_fees_secPPP_2022 out1_private_sec*/
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if out0_aged6to11 ==1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged6to11 ==1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}

		
	file write output_file " \\ " 
	
	local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

	local tab2outcomes out1_fees_priPPP_2022 out1_private_pri out1_fees_secPPP_2022 out1_private_sec
	
	file write output_file " \textbf{\textit{Panel B: Siblings Aged 12-18}} \\" 
	
		foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if out0_aged12to18 == 1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged12to18 == 1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
		
	file write output_file " \\ " 	
	
	file write output_file " \textbf{\textit{Panel C: Siblings Aged 18 and above}} \\" 
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if  out0_aged18orabv == 1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged18orabv == 1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
		
	file write output_file " \\ " 	
		
	file write output_file " \hline \\ " 

	
	file close output_file

		}
		

		
**Split between ages
local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

local tab2outcomes out1_fees_priPPP_2022 out1_private_pri out1_fees_secPPP_2022 out1_private_sec

local alltablesno 	= 2

forvalues tableno = 1(1)`alltablesno' {
	
	capture file close output_file	
								 
	file open output_file using "$caregiver_mast/Outputs/Tables/Sibling Education/Tab`tableno'_sibling_panel_2.tex", write replace
	
	file write output_file " \midrule \\ "  
	
	file write output_file " \hline \\ "  
	
	file write output_file " \textbf{\textit{Panel A: Siblings Aged 6-13}} \\" 
	
	local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

	local tab2outcomes out1_fees_priPPP_2022 out1_private_pri /* out1_fees_secPPP_2022 out1_private_sec*/
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if out0_aged6to13 ==1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged6to13 ==1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}

		
	file write output_file " \\ " 
	
	local tab1outcomes out1_eduyears out1_primary_att out1_primary_com_l out1_secondary_att out1_secondary_com_l 

	local tab2outcomes out1_fees_priPPP_2022 out1_private_pri out1_fees_secPPP_2022 out1_private_sec
	
	file write output_file " \textbf{\textit{Panel B: Siblings Aged 14-19}} \\" 
	
		foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if out0_aged14to19 == 1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged14to19 == 1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
		
	file write output_file " \\ " 	
	
	file write output_file " \textbf{\textit{Panel C: Siblings Aged 20 and above}} \\" 
	
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		// Treatment Column
		local variable: var label `outcome'
		local variable "`variable'"
		
		qui reg `outcome' T_0 $districtFE sex_app id_new if  out0_aged20orabv == 1 & participation_c == 1
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]

		scalar n_`outcome' = e(N)
		local n_`outcome' = e(N)
		
		qui sum `outcome' if T_0 == 0 & out0_aged20orabv == 1 & participation_c == 1
		scalar mean_`outcome' = r(mean)
		scalar sd_`outcome'_C = r(sd)
		
		local stars_`outcome' ""	
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
			
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
			
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
		
		
		
		file write output_file "`variable' & " %8.2fc (beta_`outcome') " & " %8.2fc (mean_`outcome') " & " %5.0fc (n_`outcome') " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_`outcome') ")^{`stars_`outcome''}$} & \scriptsize{$(" %8.2fc (sd_`outcome'_C) ")$} & \medskip \\ " 	_n
		
		}
		
	file write output_file " \\ " 	
		
	file write output_file " \hline \\ " 

	
	file close output_file

		}