version 13
set more off

clear all
clear mata

set seed 20200516
pause on

global cohortFE cohort2014
global districtFE i.NSC_intdcode



	use "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", clear
	
	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1
	
	keep if notfoundatFU == 0
	
	local indices index_a_education index_a_childhealth index_a_nutrition index_a_assets index_a_assetsD index_a_prodassets index_a_expenditures index_a_psywel index_a_conflict index_a_violence index_a_expdec index_a_empower index_a_business

	foreach var in out7_cesd out7_happiness out7_lifesat out3_hdd out3_nmeals out1_uceaggregate out4_savingsvaluePPP out0_povscore09_c out1_appenrolled_fu out0_appwork `indices' {
		
		* Follow-up Value
		
		sum `var' if baseline == 0 & T_0 == 0, d 
		
		gen `var'_Z = 1*((`var' - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if baseline == 0 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}

replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/
			lab var out0_povscore09_c_Z "Standardized Poverty Score"

	* And now replicate the tables
*local tab0outcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_Z index_nutrition_Z index_assets_Z index_psywel_Z   index_empower_Z index_expdec_Z index_childhealth_Z 

local tab0outcomes out0_povscore09_c_Z index_a_expenditures_Z out4_savingsvaluePPP_Z index_a_nutrition_Z index_a_assets_Z index_a_assetsD_Z index_a_psywel_Z   index_a_empower_Z index_a_expdec_Z 

*index_business_Z out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z


// Commented out locals are not in paper

**** Tables : Assets
local tab1outcomes out4_landvaluePPP  out4_cultlandvaluePPP out4_agritoolvaluePPP out4_cowvaluePPP out4_smallanimalvaluePPP out4_birdvaluePPP	out4_bikevaluePPP out4_motorvaluePPP out4_appliancevaluePPP out4_furniturevaluePPP 	out4_mobilevaluePPP out4_stockvaluePPP out4_machineryvaluePPP out4_housevaluePPP out4_assetvaluePPP  index_a_assets_Z

**** Tables : Expenditures 
local tab2outcomes out5_foodexpPPP out5_foodexppercapitaPPP out5_medicalexpPPP out5_eduexpPPP out5_waterexpPPP out5_personalexpPPP out5_fuelexpPPP index_a_expenditures_Z

**** Tables : Business
local tab3outcomes /*out6_all_biz*/ out6_nonagribusiness2 out6_agri_biz /*out6_nonagribusiness out6_businessno */ out6_businessno_roster out6_hours /* out6_invrevPPP */ index_a_business_Z 

*** Tables : Nutrition 
local tab4outcomes out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out3_nmeals_Z out3_hdd_Z index_a_nutrition_Z

**** Tables : Mental Health (no pre values)
local tab5outcomes out7_cesd_Z out7_happiness_Z out7_lifesat_Z index_a_psywel_Z

**** Tables : Applicant Education (no pre values)
local tab6outcomes  out1_appenrolled_fu out1_appyrsofedu_fu out1_uceaggregate_Z out1_app_privschool out1_app_board out0_appwork

**** Tables : Assets
local tab7outcomes out4_landD out4_cultlandD out4_agritoolD out4_cowD out4_smallanimalD out4_birdD	out4_bikeD out4_motorD out4_applianceD out4_furnitureD 	out4_mobileD out4_stockD out4_machineryD out4_houseD index_a_assetsD_Z


*** Tables Expenditure Decisions
local tab8outcomes out9_decide2spend out9_decide2purchase out9_refusetogivemoney out9_allowed2market index_a_expdec_Z 

*** Tables: Women's Empowerment
local tab9outcomes out9_right2spend out9_right2job out9_right2politics out9_right2edu out9_right2business out9_right2earn out9_right2market out9_right2speak index_a_empower_Z


local alltablesno 	= 9

forvalues tableno = 0(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Follow_up_Tab`tableno'.tex", write replace
	
		foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'"
		
		****** ITT Estimates

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'
			
			qui reg `outcome' T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014, robust
		}
		
		if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'
			
			local variable "`variable'$ ^+$"
			
			qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014, robust
			
		}

		scalar obs = e(N)

		scalar betaT = e(b)[1,1]
		scalar sd_betaT = sqrt(e(V)[1,1])
		scalar betaTpvalue = r(table)[4,1]
		
		qui sum `outcome' if T_0 == 0
		scalar mean_C = r(mean)
		scalar sd_C = r(sd)
		
		// Add Significance Stars
		
		local starsT ""
						
			if betaTpvalue < 0.10 local starsT  "*"
			
			if betaTpvalue < 0.05 local starsT  "**"
			
			if betaTpvalue < 0.01 local starsT  "***"
			
		****** IV Estimates

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'
			
			qui ivregress 2sls `outcome' (NSC_final_select = T_0) `outcome'_b i.NSC_intdcode sex_app cohort2014
		}
		
		if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'
			
			local variable "`variable'$ ^+$"
			
			qui ivregress 2sls `outcome' (NSC_final_select = T_0) i.NSC_intdcode sex_app cohort2014
			
		}


		scalar betaIV = e(b)[1,1]
		scalar sd_betaIV = sqrt(e(V)[1,1])
		scalar betaIVpvalue = r(table)[4,1]
				
		// Add Significance Stars
		
		local starsIV ""
						
			if betaIVpvalue < 0.10 local starsIV  "*"
			
			if betaIVpvalue < 0.05 local starsIV  "**"
			
			if betaIVpvalue < 0.01 local starsIV  "***"
		file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (betaIV) " & " %8.2fc (mean_C) " & " %5.0fc (obs) " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$("%8.2fc (sd_betaIV) ")^{`starsIV'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} & \medskip \\ " 	_n

			
		}
		
	
	file close output_file


	}
	


