********************************************************************************
global cohortFE cohort2014
global districtFE i.NSC_intdcode
global sexFE sex_app

use "$caregiver_mast/Data/Cohort2014_2015_AttritionAnalysisRosters_Data_deid.dta", clear

*** Define "not found at followup" variable
	
	gen notfoundatFU = (attrited == 2)
	
	replace notfoundatFU = . if attrited == 1 | attrited == 3 /* if attrited at baseline or never found*/

* Select Sample (9613 observations deleted - 9907 obs stay)


keep if baseline == 0 	

keep if final_select == 1

keep if notfoundatFU == 0


lab var out1_feesPPP "School Fees"
lab var out1_private "Private School"

// Remove applicants 
keep if rel != 10 /* (1,121 observations deleted) */

local tab1rosteroutcomes out1_enrolled out1_feesPPP out1_private  
local tab2rosteroutcomes out1_enrolled out1_feesPPP out1_private  
local tab3rosteroutcomes out1_enrolled out1_feesPPP out1_private  

local allrostertablesno 	= 3

forvalues tablerosterno = 1(1)`allrostertablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Tab`tablerosterno'_roster.tex", write replace
	
		foreach outcome of local tab`tablerosterno'rosteroutcomes {
			
		di "`outcome'"
		
		if `tablerosterno' == 1 local baselineschool "out1_primary_b == 1 | out1_secondary_b == 1"
		if `tablerosterno' == 2 local baselineschool "out1_primary_b == 1"
		if `tablerosterno' == 3 local baselineschool "out1_secondary_b == 1"
		
		// Treatment Column

		qui sum `outcome'_b

		if r(N)>0 { /* Ancova Regression */
					
			local variable: var label `outcome'
			
			qui reg `outcome' T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 if out1_student_b == 1 & (`baselineschool'), cluster(id_new) robust
			
		}
		
		if r(N) == 0 { /* No Ancova Regression */
				
			local variable: var label `outcome'
			
			local variable "`variable'$ ^+$"
			
			qui reg `outcome' T_0 i.NSC_intdcode sex_app cohort2014 if out1_student_b == 1 & ("`baselineschool'"), cluster(id_new) robust
			
		}

		scalar obs = e(N)

		scalar betaT = e(b)[1,1]
		scalar sd_betaT = sqrt(e(V)[1,1])
		scalar betaTpvalue = r(table)[4,1]
		
		if `tablerosterno' == 1 qui sum `outcome' if T_0 == 0 & out1_student_b == 1 & (out1_primary_b == 1 | out1_secondary_b == 1)
		if `tablerosterno' == 2 qui sum `outcome' if T_0 == 0 & out1_student_b == 1 & (out1_primary_b == 1)
		if `tablerosterno' == 3 qui sum `outcome' if T_0 == 0 & out1_student_b == 1 & (out1_secondary_b == 1)
		
		scalar mean_C = r(mean)
		scalar sd_C = r(sd)
		
		// Add Significance Stars
		
		local starsT ""
						
			if betaTpvalue < 0.10 local starsT  "*"
			
			if betaTpvalue < 0.05 local starsT  "**"
			
			if betaTpvalue < 0.01 local starsT  "***"
			

		file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (mean_C) " & " %5.0fc (obs) " \\ " 	_n

		file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} & \medskip \\ " 	_n

			
		}
		
	
	file close output_file


	}