version 13
set more off

clear all
clear mata


set seed 20200516
pause on 

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data_deid.dta", clear

	*** Sample
	
	keep if ltfu == 1 			/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted
	
	**Data from caregiver dataset
	keep if notfoundatLTFU == 0 // 378 observations deleted

	
	**For LTFU: index_conflict (not included in ltfu), index_childhealth (not included)
	local indices_ltfu index_education index_nutrition index_assets index_prodassets index_expenditures index_violence index_expdec /* index_empower */ index_business index_psywel index_psywel_alum   //FIXMERA

	**For LTFU: missing "out1_uceaggregate", 
	foreach var in out7_cesd_p out7_happiness_p out7_lifesatisfaction_p out7_cesd_a_p out7_happiness_a_p out7_lifesatisfaction_a_p out3_hdd out3_nmeals out4_savingsvaluePPP_2022 out0_povscore09_c out1_appenrolled out0_appwork `indices_ltfu' {
		
		* Long term Follow-up Value
		
		sum `var'_l if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_l "`zscorelabel'"
		
		* Follow-up Value
		
		sum `var'_f if ltfu == 1 & T_0 == 0, d 
		
		gen `var'_Z_f = 1*((`var'_f - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'
		
		lab var `var'_Z_f "`zscorelabel'"
		
		* Baseline Value
		
		sum `var'_b if ltfu == 1 & T_0 == 0, d 

		gen `var'_Z_b = 1*((`var'_b - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_b
		
		lab var `var'_Z_b "`zscorelabel'"


	}			// (788 missing values generated)

**FIXMERA: to be updated once education outcomes finalized	
*replace out1_uceaggregate_Z = -1*out1_uceaggregate_Z /* Smaller scores mean better outcomes*/	

lab var out0_povscore09_c_Z_l "Standardized Poverty Score"
lab var out0_povscore09_c_Z_f "Standardized Poverty Score"

* And now replicate the tables
local tab0outcomes out0_povscore09_c_Z index_expenditures_Z out4_savingsvaluePPP_2022_Z index_nutrition_Z index_assets_Z  /* index_empower_Z */ index_expdec_Z 	index_psywel_Z

/*
Note: following tables not in paper
*index_business_Z out1_appenrolled_fu_Z index_education_Z index_conflict_Z index_violence_Z

**** Tables : Assets
local tab1outcomes out4_landvaluePPP_2022  out4_cultlandvaluePPP_2022 out4_agritoolvaluePPP_2022 out4_cowvaluePPP_2022 out4_smallanimalvaluePPP_2022 out4_birdvaluePPP_2022	out4_bikevaluePPP_2022 out4_motorvaluePPP_2022	out4_appliancevaluePPP_2022 out4_furniturevaluePPP_2022 out4_mobilevaluePPP_2022 out4_stockvaluePPP_2022 out4_machineryvaluePPP_2022 out4_housevaluePPP_2022 out4_assetvaluePPP_2022  index_assets_Z

**** Tables : Expenditures 
local tab2outcomes out5_foodexpPPP_2022 out5_foodexppercapitaPPP_2022 /* out5_medicalexpPPP_2022  out5_eduexpPPP_2022 out5_waterexpPPP_2022 out5_personalexpPPP_2022 */ out5_fuelexpPPP_2022 index_expenditures_Z

**** Tables : Business
local tab3outcomes out6_all_biz out6_nonagribusiness2 out6_agri_biz /*out6_nonagribusiness out6_businessno */ out6_businessno_roster out6_hours out6_invrevPPP_2022 index_business_Z

*** Tables : Nutrition 
local tab4outcomes out3_food2 out3_food4 out3_food7 out3_food8 out3_food9 out3_food10 out3_food11 out3_food14 out3_food15 out3_food16 out3_food17 out3_food18 out3_food19 out3_nmeals_Z out3_hdd_Z index_nutrition_Z

**** Tables : Mental Health (no pre values) - Caregiver
local tab5outcomes out7_cesd_p_Z out7_happiness_p_Z out7_lifesatisfaction_p_Z index_psywel_Z

**** Tables : Applicant Education (no pre values)
local tab6outcomes  out1_appenrolled out1_appyrsofedu /* out1_uceaggregate_Z */ out1_app_privschool out1_app_board /* out0_appwork
*/

**** Tables : Assets
local tab7outcomes out4_landD out4_agritoolD out4_cowD out4_smallanimalD out4_birdD	out4_bikeD out4_motorD out4_applianceD out4_furnitureD 	out4_mobileD out4_stockD out4_machineryD out4_houseD



local alltablesno 	= 7
	

forvalues tableno = 0(1)`alltablesno' {
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Tab`tableno'.tex", write replace
		
		foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'_l"
		
		// Treatment Column
		
			qui sum `outcome'_b

			if r(N)>0 { 							/* Ancova Regression */
						
				local variable: var label `outcome'_l
			
				qui reg `outcome'_l T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year , robust		// updated ANCOVA 		
		
			}
		
			if r(N) == 0 { 							/* No Ancova Regression */
				
				local variable: var label `outcome'_l
			
				local variable "`variable'$ ^+$"
			
				qui reg `outcome'_l T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust
		
			}
		
					scalar obs = e(N)
					
					**Treatment variable
					scalar betaT = e(b)[1,1]
					scalar sd_betaT = sqrt(e(V)[1,1])
					scalar betaTpvalue = r(table)[4,1]
					
					qui sum `outcome'_l if T_0 == 0	
					scalar mean_C = r(mean)
					scalar sd_C = r(sd)
					
					// Add Significance Stars
					
					
					local starsT ""			// For treatment variable
									
						if betaTpvalue < 0.10 local starsT  "*"
						
						if betaTpvalue < 0.05 local starsT  "**"
						
						if betaTpvalue < 0.01 local starsT  "***"
						

					file write output_file "`variable' & " %8.2fc (betaT) " & " %8.2fc (mean_C) " & " %5.0fc (obs) " \\ " 	_n

					file write output_file " & \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \scriptsize{$(" %8.2fc (sd_C) ")$} & \medskip \\ " 	_n
		
		}
		
		file write output_file " \hline \\ " 	
	
	file close output_file

		}
	
		

**follow up outcomes for HH found at LTFU		
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Tab0_followup.tex", write replace
		
		foreach outcome of local tab0outcomes {
		
		di "`outcome'_f"
		
		// Treatment Column
		
			qui sum `outcome'_b

			if r(N)>0 { 							/* Ancova Regression */
						
				local variable: var label `outcome'_f
			
				qui reg `outcome'_f T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014, robust		// updated ANCOVA 		
		
			}
		
			if r(N) == 0 { 							/* No Ancova Regression */
				
				local variable: var label `outcome'_f
			
				local variable "`variable'$ ^+$"
			
				qui reg `outcome'_f T_0 i.NSC_intdcode sex_app cohort2014, robust
		
			}
		
					scalar obs_f = e(N)
					
					**Treatment variable
					scalar betaT_f = e(b)[1,1]
					scalar sd_betaT_f = sqrt(e(V)[1,1])
					scalar betaTpvalue_f = r(table)[4,1]
					
					qui sum `outcome'_f if T_0 == 0	
					scalar mean_C_f = r(mean)
					scalar sd_C_f = r(sd)
					
					// Add Significance Stars
					
					
					local starsT_f ""			// For treatment variable
									
						if betaTpvalue_f < 0.10 local starsT_f  "*"
						
						if betaTpvalue_f < 0.05 local starsT_f  "**"
						
						if betaTpvalue_f < 0.01 local starsT_f  "***"
						

					file write output_file "`variable' & " %8.2fc (betaT_f) " & " %8.2fc (mean_C_f) " & " %5.0fc (obs_f) " \\ " 	_n

					file write output_file " & \scriptsize{$("%8.2fc (sd_betaT_f) ")^{`starsT_f'}$} & \scriptsize{$(" %8.2fc (sd_C_f) ")$} & \medskip \\ " 	_n
		}
		
		file write output_file " \hline \\ " 	
	
	file close output_file
*/		
**wirte file to compare coeffs side by side

**follow up but using HH found at LTFU		

	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/ITT Effects/Tab0_compare.tex", write replace
		
		foreach outcome of local tab0outcomes {
		
		di "`outcome'_l"
		
		// Treatment Column - for LTFU
		
		qui sum `outcome'_b

		if r(N)>0 {							/* Ancova Regression */
						
				local variable: var label `outcome'_l
			
				qui reg `outcome'_l T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 survey_year, robust		// updated ANCOVA 		
		
			}
		
			if r(N) == 0 { 							/* No Ancova Regression */
				
				local variable: var label `outcome'_l
			
				local variable "`variable'$ ^+$"
			
				qui reg `outcome'_l T_0 i.NSC_intdcode sex_app cohort2014 survey_year, robust
		
			}
		
					scalar obs = e(N)
					
					**Treatment variable
					scalar betaT = e(b)[1,1]
					scalar sd_betaT = sqrt(e(V)[1,1])
					scalar betaTpvalue = r(table)[4,1]
					
					qui sum `outcome'_l if T_0 == 0	
					scalar mean_C = r(mean)
					scalar sd_C = r(sd)
					
					// Add Significance Stars
					
					
					local starsT ""			// For treatment variable
									
						if betaTpvalue < 0.10 local starsT  "*"
						
						if betaTpvalue < 0.05 local starsT  "**"
						
						if betaTpvalue < 0.01 local starsT  "***"
		
		
		
		di "`outcome'_f"
		
		// Treatment Column- for FU
		
			qui sum `outcome'_b

			if r(N)>0 { 							/* Ancova Regression */
						
				local variable: var label `outcome'_f
			
				qui reg `outcome'_f T_0 `outcome'_b i.NSC_intdcode sex_app cohort2014 , robust		// updated ANCOVA 		
		
			}
				
			if r(N) == 0 { 							/* No Ancova Regression */
				
				local variable: var label `outcome'_f
			
				local variable "`variable'$ ^+$"
			
				qui reg `outcome'_f T_0 i.NSC_intdcode sex_app cohort2014 , robust
		
			}
		
					scalar obs_f = e(N)
					
					**Treatment variable
					scalar betaT_f = e(b)[1,1]
					scalar sd_betaT_f = sqrt(e(V)[1,1])
					scalar betaTpvalue_f = r(table)[4,1]
					
					qui sum `outcome'_f if T_0 == 0	
					scalar mean_C_f = r(mean)
					scalar sd_C_f = r(sd)
					
					// Add Significance Stars
					
					
					local starsT_f ""			// For treatment variable
									
						if betaTpvalue_f < 0.10 local starsT_f  "*"
						
						if betaTpvalue_f < 0.05 local starsT_f  "**"
						
						if betaTpvalue_f < 0.01 local starsT_f  "***"
						

					file write output_file "`variable' & " %8.2fc (betaT_f) "  & " %8.2fc (betaT) " & " %5.0fc (obs) "\\ " 	_n

					file write output_file " & \scriptsize{$("%8.2fc (sd_betaT_f) ")^{`starsT_f'}$} &  \scriptsize{$("%8.2fc (sd_betaT) ")^{`starsT'}$} & \medskip \\ " 	_n
		
		}
		
		file write output_file " \hline \\ " 	
	
	file close output_file
	
	

