version 13
set more off

clear all
clear mata

set seed 20200516
pause on

global cohortFE cohort2014
global districtFE i.NSC_intdcode

	use "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", clear
	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1 /* (662 observations deleted)*/
	
	*** Define Regressors
		
	sum out1_uceaggregate if baseline == 0 & T_0 == 0, d 
		
	gen out1_uceaggregate_Z = -1*((out1_uceaggregate - r(mean)) / r(sd)) 

	rename out1_appenrolled_fu out1_appenrolled
	
	gen out1_passuce = .
	recode out1_passuce (. = 1) if out1_uceaggregate < 60
	recode out1_passuce (. = 0) if out1_uceaggregate >= 60 & out1_uceaggregate != .
	

**Outcomes
local tab1outcomes 1_appenrolled 0_appwork 1_app_board 1_app_privschool /* 1_satuce 1_passuce 1_uceaggregate_Z
*/



	*** Estimation using standard specification
	
	foreach outcome in 1_appenrolled 0_appwork 1_app_board 1_app_privschool /* 1_satuce 1_passuce 1_uceaggregate_Z */  {
		
		qui reg out`outcome' T_0 i.NSC_intdcode sex_app cohort2014 if notfoundatFU == 0, robust
		
		scalar beta_`outcome' = e(b)[1,1]
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pvalue = r(table)[4,1]
		scalar n_`outcome'  = e(N)

		sum out`outcome' if T_0 == 0
		scalar mean_`outcome' = r(mean)

		// Add Significance Stars
		
		local stars_`outcome' ""

		if beta_`outcome'pvalue < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pvalue < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pvalue < 0.01 local stars_`outcome'  "***"

	}
		*** Write main panel of Table
		file open output_file using "$caregiver_mast/Outputs/Tables/table_education.tex", write replace
	
		file write output_file "T & " %5.3f (beta_1_appenrolled)  " & " %5.3f (beta_0_appwork) " & " %5.3f (beta_1_app_board) " & " %5.3f (beta_1_app_privschool) " \\ " 	_n

		file write output_file " & \scriptsize{$(" %5.3f (sd_1_appenrolled) ")$} & \scriptsize{$(" %5.3f (sd_0_appwork) ")$} & \scriptsize{$(" %5.3f (sd_1_app_board) ")$} & \scriptsize{$(" %5.3f (sd_1_app_privschool) ")$}  \\ " 	_n
	
	
		// Randomization Inference
		foreach var in out1_appenrolled out0_appwork out1_app_board  out1_app_privschool {
			
			ritest T_0 _b[T_0], reps(1000) seed(20200501): reg `var' T_0 $districtFE cohort2014 sex_app, robust
			matrix pvalues=r(p) // save the p-values from ritest
			scalar ri_p_`var' = r(p)[1,1]	
	}		
			
		file write output_file " & \scriptsize{$[" %5.3f (ri_p_out1_appenrolled) "]$} & \scriptsize{$[" %5.3f (ri_p_out0_appwork)  "]$} & \scriptsize{$[" %5.3f (ri_p_out1_app_board)  "]$} & \scriptsize{$[" %5.3f (ri_p_out1_app_privschool)  "]$} "	
		
		file write output_file "\medskip \\ " 	_n
		
		** Lee Bounds 
		
		cap drop random1
	
		sort id_new
	
		gen random1=uniform()
	
		foreach var in out1_appenrolled out0_appwork out1_app_board out1_app_privschool  {

		gen `var'_lt=`var'
	
		gen `var'_ut=`var'

		sort T_0 `var' random1

		egen grp_`var'=group(T_0 `var'), missing /* 4 groups: T = 0 & var = 0, T = 0 & var = 1, T = 1 & var = 0, T = 1 & var = 1*/

		egen rank_`var'=rank(random1), by(grp_`var') 

		replace `var'_lt=. if rank_`var'<= 89 & T_0 == 1 & `var' ==0

		replace `var'_ut=. if rank_`var'<= 89 & T_0 == 1 & `var' ==1
		
		
		// Upper Lee Bounds
			 qui reg `var'_ut T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			
			scalar betaU_`var' = e(b)[1,1]
			scalar sd_betaU_`var' = sqrt(e(V)[1,1])
			scalar Upvalue_`var' = r(table)[4,1]
			
			
			// Lower Lee Bound Column
			qui reg `var'_lt T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			scalar betaL_`var' = e(b)[1,1]
			scalar sd_betaL_`var' = sqrt(e(V)[1,1])
			scalar Lpvalue_`var' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`var'  < 0.10 local stars`coltype'_`var'   "*"
			
			if `coltype'pvalue_`var'  < 0.05 local stars`coltype'_`var'   "**"
			
			if `coltype'pvalue_`var'  < 0.01 local stars`coltype'_`var'   "***"
			
			}

	}
	

	
	
		file write output_file "\multicolumn{3}{l}{\textbf{Lee Bounds - Point Estimates}} \\" 
			
		file write output_file " & {\footnotesize [" %8.2fc (betaU_out1_appenrolled) "," %8.2fc (betaL_out1_appenrolled ) " ] } & {\footnotesize [" %8.2fc (betaU_out0_appwork ) "," %8.2fc (betaL_out0_appwork ) " ] } & {\footnotesize [" %8.2fc (betaU_out1_app_board ) "," %8.2fc (betaL_out1_app_board ) " ] } & {\footnotesize [" %8.2fc (betaU_out1_app_privschool ) "," %8.2fc (betaL_out1_app_privschool ) " ] } \\ "
		
		
		*** Fairlie et al Bounds
		
	foreach outcome in 1_appenrolled 0_appwork 1_app_board 1_app_privschool /* 1_satuce 1_passuce 1_uceaggregate_Z */ {

		// Group level mean and sd
		bys T_0 cohort2014: egen out`outcome'_mean = mean(out`outcome')
		bys T_0 cohort2014: egen out`outcome'_sd   = sd(out`outcome')
	
		gen out`outcome'_L5 = out`outcome' if notfoundatFU == 0
		gen out`outcome'_U5 = out`outcome' if notfoundatFU == 0
		gen out`outcome'_L10 = out`outcome' if notfoundatFU == 0
		gen out`outcome'_U10 = out`outcome' if notfoundatFU == 0
		gen out`outcome'_L20 = out`outcome' if notfoundatFU == 0
		gen out`outcome'_U20 = out`outcome' if notfoundatFU == 0
		
		// Condition so that the value is imputed only for relevant obs
		if "`outcome'" == "1_satuce" local notfoundatscoringsurvey "  & cohort2014 == 1"
		if "`outcome'" == "1_passuce" local notfoundatscoringsurvey "  & cohort2014 == 1"
		if "`outcome'" == "1_uceaggregate_Z" local notfoundatscoringsurvey " & cohort2014 == 1"


		replace out`outcome'_U5 = out`outcome'_mean + 0.05 * out`outcome'_sd if out`outcome'_U5 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_U5 = out`outcome'_mean - 0.05 * out`outcome'_sd if out`outcome'_U5 == . & T_0 == 0 `notfoundatscoringsurvey'
		
		replace out`outcome'_L5 = out`outcome'_mean - 0.05 * out`outcome'_sd if out`outcome'_L5 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_L5 = out`outcome'_mean + 0.05 * out`outcome'_sd if out`outcome'_L5 == . & T_0 == 0 `notfoundatscoringsurvey'

		replace out`outcome'_U10 = out`outcome'_mean + 0.10 * out`outcome'_sd if out`outcome'_U10 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_U10 = out`outcome'_mean - 0.10 * out`outcome'_sd if out`outcome'_U10 == . & T_0 == 0 `notfoundatscoringsurvey'
	
		replace out`outcome'_L10 = out`outcome'_mean - 0.10 * out`outcome'_sd if out`outcome'_L10 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_L10 = out`outcome'_mean + 0.10 * out`outcome'_sd if out`outcome'_L10 == . & T_0 == 0 `notfoundatscoringsurvey'

		replace out`outcome'_U20 = out`outcome'_mean + 0.20 * out`outcome'_sd if out`outcome'_U20 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_U20 = out`outcome'_mean - 0.20 * out`outcome'_sd if out`outcome'_U20 == . & T_0 == 0 `notfoundatscoringsurvey'
	
		replace out`outcome'_L20 = out`outcome'_mean - 0.20 * out`outcome'_sd if out`outcome'_L20 == . & T_0 == 1 `notfoundatscoringsurvey'
		replace out`outcome'_L20 = out`outcome'_mean + 0.20 * out`outcome'_sd if out`outcome'_L20 == . & T_0 == 0 `notfoundatscoringsurvey'



		foreach boundtype in U5 L5 U10 L10 U20 L20 {

			reg out`outcome'_`boundtype' T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			scalar beta`boundtype'_`outcome' = e(b)[1,1]
			scalar sd_beta`boundtype'_`outcome' = sqrt(e(V)[1,1])
			scalar beta`boundtype'pvalue_`outcome' = r(table)[4,1]

		// Add Significance Stars
			
			local stars`boundtype'_`outcome'  ""
			
			if beta`boundtype'pvalue_`outcome' < 0.10 local stars`boundtype'_`outcome'  "*"
			if beta`boundtype'pvalue_`outcome' < 0.05 local stars`boundtype'_`outcome'  "**"
			if beta`boundtype'pvalue_`outcome' < 0.01 local stars`boundtype'_`outcome'  "***"
		}

}

file write output_file "\multicolumn{3}{l}{\textbf{Fairlie Bounds - Point Estimates}} \\" 

	foreach imptype in 5 10 20 {
					
		file write output_file "`imptype'\% Imputation & {\footnotesize [" %8.2fc (betaU`imptype'_1_appenrolled) "," %8.2fc (betaL`imptype'_1_appenrolled) " ] }  & {\footnotesize [" %8.2fc (betaU`imptype'_0_appwork) "," %8.2fc (betaL`imptype'_0_appwork) " ] } & {\footnotesize [" %8.2fc (betaU`imptype'_1_app_board) "," %8.2fc (betaL`imptype'_1_app_board) " ] }  & {\footnotesize [" %8.2fc (betaU`imptype'_1_app_privschool) "," %8.2fc (betaL`imptype'_1_app_privschool) " ] }  \\  " 	_n
	
	}
	
**Multiple Hypothesis Testing

**Table 1: 

// 1_appenrolled 0_appwork
	mhtreg  (out1_appenrolled T_0 i.NSC_intdcode sex_app cohort2014)  (out0_appwork T_0 i.NSC_intdcode sex_app cohort2014) (out1_app_board T_0 i.NSC_intdcode sex_app cohort2014) (out1_app_privschool T_0 i.NSC_intdcode sex_app cohort2014), robust seed(20200501) 
	
	
	
	scalar mht_p_1_appenrolled = r(results)[1,3]
	scalar mht_p_0_appwork = r(results)[2,3]
	scalar mht_p_1_app_board = r(results)[3,3]
	scalar mht_p_1_app_privschool = r(results)[4,3]
	
	
	**MHT  p-value 
	file write output_file " \medskip \\ MHT p-Value & \scriptsize{$(" %5.3f (mht_p_1_appenrolled) "$} & \scriptsize{$(" %5.3f (mht_p_0_appwork)   ")$} & \scriptsize{$(" %5.3f (mht_p_1_app_board)   ")$} & \scriptsize{$(" %5.3f (mht_p_1_app_privschool)   ")$} " 
		file write output_file " \medskip \\ " 	_n	
	
	file write output_file " \hline \\ " 	_n
	
	**Mean outcome and number of obs 
		file write output_file "Mean Outcome (C) & " %5.2f (mean_1_appenrolled) " & " %5.2f (mean_0_appwork) " & " %5.2f (mean_1_app_board) " & " %5.2f (mean_1_app_privschool) " \\ " _n
	
		file write output_file "Observations & " %5.0fc (n_1_appenrolled) " & " %5.0fc (n_0_appwork) " & " %5.0fc (n_1_app_board) " & " %5.0fc (n_1_app_privschool) "  \\ " _n

		file write output_file " \medskip \\ " _n
	
		file write output_file " \hline \\ " 	
	
		file close output_file	