version 13
set more off

clear all
clear mata

set seed 20200516
pause on

global cohortFE cohort2014
global districtFE i.NSC_intdcode

	use "$caregiver_mast/Data/Cohort2014_2015_Data_ForTables_deid.dta", clear
	*** Sample

	keep if baseline == 0 /*(2,092 observations deleted)*/
	
	keep if final_select == 1
	
	keep if notfoundatFU == 0
	
	gen out1_schoolpassrate = .
	gen out1_school1divrate = . 
	gen out1_rank_schoolpassrate = .
	gen out1_rank_school1divrate = . 
	
	forvalues year = 2014(1)2017{
		rename UNEB_avg_pass_rate`year' 	UNEB_passrate_`year'
		rename UNEB_avg_firstdiv_rate`year' UNEB_1divrate_`year'
		rename UNEB_rank_passrate`year' 	UNEB_rank_passrate_`year'
		rename UNEB_rank_firstdivrate`year' UNEB_rank_1divrate_`year'
	}
	
	foreach var in passrate 1divrate rank_passrate rank_1divrate {
		
		
	* Generate variable
	gen out1_`var' = .
	
	* Replace with characteristic of school attended in year of followup 
	
	replace out1_`var' = UNEB_`var'_2016 if cohort2014 == 1
	replace out1_`var' = UNEB_`var'_2017 if cohort2014 == 0
		
	* or of school attended in previous year if followup year is missing

	replace out1_`var' = UNEB_`var'_2015 if out1_`var' == . & cohort2014 == 1 & UNEB_`var'_2016 == .
	replace out1_`var' = UNEB_`var'_2016 if out1_`var' == . & cohort2014 == 0 & UNEB_`var'_2017 == .

	* or of school attended in previous year if year before followup is missing

	replace out1_`var' = UNEB_`var'_2014 if out1_`var' == . & cohort2014 == 1 & UNEB_`var'_2015 == .
	replace out1_`var' = UNEB_`var'_2015 if out1_`var' == . & cohort2014 == 0 & UNEB_`var'_2016 == .
	
	* or with missing if the student was not enrolled at followup
	
	replace out1_`var' = .n if out1_appenrolled_fu == 0

	
	qui reg out1_`var' T_0  i.NSC_intdcode sex_app cohort2014, robust
	scalar beta_`var' = e(b)[1,1]
	scalar sd_`var' = sqrt(e(V)[1,1])
	scalar beta_`var'pvalue = r(table)[4,1]
	scalar n_`var'  = e(N)

	sum out1_`var' if T_0 == 0
	scalar mean_`var' = r(mean)

	* Add Significance Stars
		
	local stars_`var' ""

					
	if beta_`var'pvalue < 0.10 local stars_`var'  "*"
			
	if beta_`var'pvalue < 0.05 local stars_`var'  "**"
			
	if beta_`var'pvalue < 0.01 local stars_`var'  "***"
			
	
	}
	   
	
	file open output_file using "$caregiver_mast/Outputs/Tables/table_schoolquality.tex", write replace
	
	
	file write output_file "T & " %5.3f (beta_passrate)  " & " %5.3f (beta_1divrate) " & " %5.3f (beta_rank_passrate) " & " %5.3f (beta_rank_1divrate) " \\ " 	_n

	file write output_file " & \scriptsize{$(" %5.3f (sd_passrate) ")$} & \scriptsize{$(" %5.3f (sd_1divrate) ")$} & \scriptsize{$(" %5.3f (sd_rank_passrate) ")$} & \scriptsize{$(" %5.3f (sd_rank_1divrate) ")$} \\ " 	_n
	
	
	
		// Randomization Inference
		foreach var in passrate 1divrate rank_passrate rank_1divrate   {
			
			ritest T_0 _b[T_0], reps(1000) seed(20200501): reg out1_`var' T_0 $districtFE cohort2014 sex_app, robust
			matrix pvalues=r(p) // save the p-values from ritest
			scalar ri_p_`var' = r(p)[1,1]	
	}		
			
		file write output_file " & \scriptsize{$[" %5.3f (ri_p_passrate) "]$} & \scriptsize{$[" %5.3f (ri_p_1divrate) "]$} & \scriptsize{$[" %5.3f (ri_p_rank_passrate) "]$} & \scriptsize{$[" %5.3f (ri_p_rank_1divrate)  "]$} "	

	** Lee Bounds 
		file write output_file "\\    \multicolumn{5}{l}{\textbf{Lee Bounds - Point Estimates}} \\" 
		
		cap drop random1
	
		sort id_new
	
		gen random1=uniform()
	
		foreach var in out1_passrate out1_1divrate out1_rank_passrate out1_rank_1divrate   {

		gen `var'_lt=`var'
	
	gen `var'_ut=`var'

	sort T_0 `var' random1

	egen grp_`var'=group(T_0 `var'), missing
	
	egen rank_`var'=rank(random1), by(grp_`var') 

	replace `var'_lt=. if rank_`var'<= 89 & T_0 == 1 & `var'==0
	
	egen lwr_`var'=pctile(`var') 	if 	T_0 == 1 , p(13)
	
	replace `var'_lt=. 			if  T_0 == 1 & `var'<lwr_`var'

	drop lwr_`var'

	egen upr_`var'=pctile(`var') 	if 	T_0 == 1 , p(87)
	
	replace `var'_ut=. 			if  T_0 == 1 & `var'>upr_`var'

	drop upr_`var'

		
		
		// Upper Lee Bounds
			 qui reg `var'_ut T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			
			scalar betaU_`outcome' = e(b)[1,1]
			scalar sd_betaU_`outcome' = sqrt(e(V)[1,1])
			scalar Upvalue_`outcome' = r(table)[4,1]
			
			
			// Lower Lee Bound Column
			qui reg `var'_lt T_0 i.NSC_intdcode sex_app cohort2014, robust
			
			scalar betaL_`outcome' = e(b)[1,1]
			scalar sd_betaL_`outcome' = sqrt(e(V)[1,1])
			scalar Lpvalue_`outcome' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`outcome'  < 0.10 local stars`coltype'_`outcome'   "*"
			
			if `coltype'pvalue_`outcome'  < 0.05 local stars`coltype'_`outcome'   "**"
			
			if `coltype'pvalue_`outcome'  < 0.01 local stars`coltype'_`outcome'   "***"
			
			}
			
/*
		file write output_file " & {\footnotesize [" %8.2fc (betaU_`outcome' ) "\$^{`starsU_`outcome''}\$" "," %8.2fc (betaL_`outcome' ) "\$^{`starsL_`outcome''}\$" "] } "	
*/

			file write output_file " & {\footnotesize [" %8.2fc (betaU_`outcome' ) "," %8.2fc (betaL_`outcome' ) " ] } "	

	}
	
		*** Fairlie et al Bounds
		
		file write output_file "\\  \multicolumn{5}{l}{\textbf{Fairlie Bounds - Point Estimates}} \\" 
		
local outcomes	out1_passrate out1_1divrate out1_rank_passrate out1_rank_1divrate
		
foreach yvar of local outcomes {
		
	// Imputation bounds: Calculate mean & s.d. within treatment-season bins

		bys T_0: egen `yvar'_mean = mean(`yvar')
		bys T_0: egen `yvar'_sd   = sd(`yvar')
	
		// Correct Outcome Variable
		
		gen `yvar'_L5 = `yvar' 	if  notfoundatFU == 0
		gen `yvar'_U5 = `yvar' 	if  notfoundatFU == 0
		gen `yvar'_L10 = `yvar' if  notfoundatFU == 0
		gen `yvar'_U10 = `yvar' if  notfoundatFU == 0
		gen `yvar'_L20 = `yvar' if  notfoundatFU == 0
		gen `yvar'_U20 = `yvar' if  notfoundatFU == 0

		replace `yvar'_U5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 1 
		replace `yvar'_U5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_U5 == . & T_0 == 0 
		
		replace `yvar'_L5 = `yvar'_mean - 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 1 
		replace `yvar'_L5 = `yvar'_mean + 0.05 * `yvar'_sd if `yvar'_L5 == . & T_0 == 0 

		replace `yvar'_U10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 1 
		replace `yvar'_U10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_U10 == . & T_0 == 0 
	
		replace `yvar'_L10 = `yvar'_mean - 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 1 
		replace `yvar'_L10 = `yvar'_mean + 0.10 * `yvar'_sd if `yvar'_L10 == . & T_0 == 0 

		replace `yvar'_U20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 1 
		replace `yvar'_U20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_U20 == . & T_0 == 0 
	
		replace `yvar'_L20 = `yvar'_mean - 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 1 
		replace `yvar'_L20 = `yvar'_mean + 0.20 * `yvar'_sd if `yvar'_L20 == . & T_0 == 0 

		}
		
		foreach outcome in out1_passrate out1_1divrate out1_rank_passrate out1_rank_1divrate { 
	
		foreach boundtype in U5 L5 U10 L10 U20 L20 {			
				
		qui reg `outcome'_`boundtype' T_0 i.NSC_intdcode sex_app cohort2014, robust
		scalar obs = e(N)

		scalar beta_`outcome'`boundtype' = e(b)[1,1]
		scalar sd_`outcome'`boundtype' = sqrt(e(V)[1,1])
		scalar pv_`outcome'`boundtype' = r(table)[4,1]

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if pv_`outcome'`boundtype' < 0.10 local str_`outcome'`boundtype'  "*"
			
			if pv_`outcome'`boundtype' < 0.05 local str_`outcome'`boundtype'  "**"
			
			if pv_`outcome'`boundtype' < 0.01 local str_`outcome'`boundtype'  "***"
		}

	}	
	
	foreach imptype in 5 10 20 {
	    
		
	   
	   file write output_file "`imptype'\% Imputation"
		
	    foreach outcome in out1_passrate out1_1divrate out1_rank_passrate out1_rank_1divrate { 
					
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U`imptype') "," %8.2fc (beta_`outcome'L`imptype') " ] } " 	
		

	}
	
	file write output_file " \\ " _n
}	

**MHT  p-value 
	mhtreg  (out1_passrate T_0 i.NSC_intdcode sex_app cohort2014)  (out1_1divrate T_0 i.NSC_intdcode sex_app cohort2014) (out1_rank_passrate T_0 i.NSC_intdcode sex_app cohort2014) (out1_rank_1divrate T_0 i.NSC_intdcode sex_app cohort2014), robust seed(20200501) 

	scalar mht_p_passrate = r(results)[1,3]
	scalar mht_p_1divrate = r(results)[2,3]
	scalar mht_p_rank_passrate = r(results)[3,3]
	scalar mht_p_rank_1divrate = r(results)[4,3]

	file write output_file " \medskip \\ MHT p-Value & \scriptsize{$(" %5.3f (mht_p_passrate) ")$} & \scriptsize{$(" %5.3f (mht_p_1divrate) ")$} & \scriptsize{$(" %5.3f (mht_p_rank_passrate) ")$} & \scriptsize{$(" %5.3f (mht_p_rank_1divrate)   ")$} " 
		file write output_file " \medskip \\ " 	_n	
	
	file write output_file " \hline \\ " 	_n


file write output_file "Mean Outcome (C) & " %5.2f (mean_passrate) " & " %5.2f (mean_1divrate) " & " %5.2f (mean_rank_passrate) " & " %5.2f (mean_rank_1divrate) " \\ " _n
	
	file write output_file "Observations & " %5.0fc (n_passrate) " & " %5.0fc (n_1divrate) " & " %5.0fc (n_rank_passrate) " & " %5.0fc (n_rank_1divrate) " \\ " _n

file write output_file " \medskip \\ " _n
	
		file write output_file " \hline \\ " 	
	
			file close output_file

	