/*---------------------------------------------------------------------------*
*Description: 	Generate education outcome tables							*		
*																			* 
*Date:			19/10/2023													*
*Author:		Raaga Akkineni 												*
*																			*
*Input:			LTFU2022_Cohort2014_2015_AttritionAnalysis_Data.dta			*
*																			*
*Output:		LTFU_education_outcome1_bounds_RI_MHT.tex					*
*				LTFU_education_outcome2_bounds_RI_MHT.tex					*
*Note: 																		*
*---------------------------------------------------------------------------*/

version 13
set more off

clear all
clear mata


set seed 20200516
pause on 

global cohortFE cohort2014
global districtFE i.NSC_intdcode

use "$caregiver_mast/Data/LTFU2022_Cohort2014_2015_AttritionAnalysis_Data_deid.dta", clear


 *** Sample

	keep if baseline == 1 /* | (notfoundatFU == 0 & baseline == 0 & ltfu == 0)	 */		/*(4,184 observations deleted)*/
	
	keep if final_select == 1	// 0 observations deleted
	
	**Data from caregiver dataset
	keep if notfoundatFU != . /* & notfoundatLTFU != . */ // 378 observations deleted

	**Creating a new scores vairables by imputing mock scores if actual scores are missing
	gen out1_uceaggregate_m_l = out1_uceaggregate_l if out1_uceaggregate_l != .
	replace out1_uceaggregate_m_l = out1_mock_uceaggregate_l if out1_uceaggregate_l == .  &  out1_mock_uceaggregate_l != .
	label var out1_uceaggregate_m_l "UCE scores with mock imputed"

	gen out1_uaceaggregate_m_l = out1_uaceaggregate_l if out1_uaceaggregate_l != .
	replace out1_uceaggregate_m_l = out1_mock_uaceaggregate_l if out1_uaceaggregate_l == .  &  out1_mock_uaceaggregate_l != .
	label var out1_uceaggregate_m_l "UACE scores with mock imputed"	
	
	
	foreach var in out1_uceaggregate out1_uceaggregate_m  out1_uaceaggregate out1_uaceaggregate_m {
		
		sum `var'_l if baseline == 1 & T_0 == 0, d 
		
		**replace `var' = 1*((`var' - r(mean)) / r(sd)) 
		
		gen `var'_Z_l = 1*((`var'_l - r(mean)) / r(sd)) 
		
		local zscorelabel: variable label `var'_l
		
		lab var `var'_Z_l "`zscorelabel'"

	}


	**Smaller scores mean better outcomes for UCE 
	replace out1_uceaggregate_Z_l 		= -1*(out1_uceaggregate_Z_l) 
	replace out1_uceaggregate_m_Z_l		= -1*(out1_uceaggregate_m_Z_l) 


** Lee Bounds
	local outcomes_binary out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary

	local outcomes_conts out1_uceaggregate_Z out1_division1_scores out1_uaceaggregate_Z out1_uace_top_scores
	
	* From table printed in AttritionTable.do,  need to trim 208 observations from treatment to equalize attrition with C (60%) (for continuous vars, 43%).

	* Binary variables
	
	set seed 20200501
	
	cap drop random1
	
	sort id_new
	
	gen random1=uniform()
	
	gen random2=uniform()


	foreach var of local outcomes_binary {

		gen `var'_lt=`var'_l 
	
		gen `var'_ut=`var'_l 

		sort T_0 `var' random1

		egen grp_`var'=group(T_0 `var'_l)/* , missing */ /* 4 groups: T = 0 & var = 0, T = 0 & var = 1, T = 1 & var = 0, T = 1 & var = 1*/

		egen rank_`var'=rank(random1), by(grp_`var') 

		replace `var'_lt=. if rank_`var'<= 208 & T_0 == 1 & `var'_l==0


		replace `var'_ut=. if rank_`var'<= 208 & T_0 == 1 & `var'_l==1

		
	}
	
	
	* Continuous variables
	
	foreach var of local outcomes_conts {
	
	gen `var'_lt=`var'_l
	
	gen `var'_ut=`var'_l

	sort T_0 `var'_l random1

	egen grp_`var'=group(T_0 `var'_l), missing
	
	egen rank_`var'=rank(random1), by(grp_`var') 

	replace `var'_lt=. if rank_`var'<= 208 & T_0 == 1 & `var'_l==0
	
	egen lwr_`var'=pctile(`var'_l) 	if 	T_0 == 1 , p(43)
	
	replace `var'_lt=. 			if  T_0 == 1 & `var'_l<lwr_`var'

	drop lwr_`var'

	egen upr_`var'=pctile(`var'_l) 	if 	T_0 == 1 , p(43)
	
	replace `var'_ut=. 			if  T_0 == 1 & `var'_l>upr_`var'

	drop upr_`var'
	

}	


	
**Fairlie Bounds - 5%, 10% and 20% imputations

	foreach yvar in out1_uceaggregate_Z out1_division1_scores out1_uaceaggregate_Z out1_uace_top_scores out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary { 

		// Imputation bounds for LTFU outcomes: Calculate mean & s.d. within treatment-season bins
		
		**For LTFU
		bys T_0 : egen `yvar'_mean_l = mean(`yvar'_l)
		bys T_0 : egen `yvar'_sd_l   = sd(`yvar'_l)
		
		// Correct Outcome Variable - for LTFU 
		
		gen `yvar'_l_L5 = `yvar'_l 		if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U5 = `yvar'_l 		if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_L10 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U10 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_L20 = `yvar'_l 	if notfoundatLTFU == 0	| notfoundatFU == 0
		gen `yvar'_l_U20 = `yvar'_l		if notfoundatLTFU == 0	| notfoundatFU == 0
		
				
		replace `yvar'_l_U5 = `yvar'_mean_l + 0.05 * `yvar'_sd_l if `yvar'_l_U5 == . & T_0 == 1 
		replace `yvar'_l_U5 = `yvar'_mean_l - 0.05 * `yvar'_sd_l if `yvar'_l_U5 == . & T_0 == 0 
		
		replace `yvar'_l_L5 = `yvar'_mean_l - 0.05 * `yvar'_sd_l if `yvar'_l_L5 == . & T_0 == 1 
		replace `yvar'_l_L5 = `yvar'_mean_l + 0.05 * `yvar'_sd_l if `yvar'_l_L5 == . & T_0 == 0 

		replace `yvar'_l_U10 = `yvar'_mean_l + 0.10 * `yvar'_sd_l if `yvar'_l_U10 == . & T_0 == 1 
		replace `yvar'_l_U10 = `yvar'_mean_l - 0.10 * `yvar'_sd_l if `yvar'_l_U10 == . & T_0 == 0 
	
		replace `yvar'_l_L10 = `yvar'_mean_l - 0.10 * `yvar'_sd_l if `yvar'_l_L10 == . & T_0 == 1 
		replace `yvar'_l_L10 = `yvar'_mean_l + 0.10 * `yvar'_sd_l if `yvar'_l_L10 == . & T_0 == 0 

		replace `yvar'_l_U20 = `yvar'_mean_l + 0.20 * `yvar'_sd_l if `yvar'_l_U20 == . & T_0 == 1 
		replace `yvar'_l_U20 = `yvar'_mean_l - 0.20 * `yvar'_sd_l if `yvar'_l_U20 == . & T_0 == 0 
	
		replace `yvar'_l_L20 = `yvar'_mean_l - 0.20 * `yvar'_sd_l if `yvar'_l_L20 == . & T_0 == 1 
		replace `yvar'_l_L20 = `yvar'_mean_l + 0.20 * `yvar'_sd_l if `yvar'_l_L20 == . & T_0 == 0 
}
	

local tab1outcomes out1_uceaggregate_Z out1_division1_scores out1_uaceaggregate_Z out1_uace_top_scores

local tab2outcomes out1_olevel out1_ucesat out1_alevel out1_uacesat out1_tertiary
	
local alltablesno 	= 2	

**Multiple Hypothesis Testing

**Table 1: 
	mhtreg  (out1_uceaggregate_Z_l T_0 $districtFE cohort2014 sex_app)  (out1_division1_scores_l T_0 $districtFE cohort2014 sex_app)  (out1_uaceaggregate_Z_l T_0 $districtFE cohort2014 sex_app) (out1_uace_top_scores_l T_0 $districtFE cohort2014 sex_app)  , robust seed(20200501) 
	
	scalar mht_p_out1_uceaggregate_Z = r(results)[1,3]
	scalar mht_p_out1_division1_scores = r(results)[2,3]
	scalar mht_p_out1_uaceaggregate_Z = r(results)[3,3]
	scalar mht_p_out1_uace_top_scores = r(results)[4,3]
	
**Table 2: 
	mhtreg  (out1_olevel_l T_0 $districtFE cohort2014 sex_app)  (out1_ucesat_l T_0 $districtFE cohort2014 sex_app)  (out1_alevel_l T_0 $districtFE cohort2014 sex_app) (out1_uacesat_l T_0 $districtFE cohort2014 sex_app) (out1_tertiary_l T_0 $districtFE cohort2014 sex_app) , robust seed(20200501) 
	
	scalar mht_p_out1_olevel = r(results)[1,3]
	scalar mht_p_out1_ucesat = r(results)[2,3]
	scalar mht_p_out1_alevel = r(results)[3,3]
	scalar mht_p_out1_uacesat = r(results)[4,3]	
	scalar mht_p_out1_tertiary = r(results)[5,3]	
	
	
**Tables in BL's format
forvalues tableno = 1(1)`alltablesno' {
	
	scalar var_count = `:word count `tab`tableno'outcomes''		//no of elements in the local
	local N = var_count
	
	capture file close output_file	
	
	file open output_file using "$caregiver_mast/Outputs/Tables/Education Outcomes/LTFU_education_outcome`tableno'_bounds_RI_MHT.tex", write replace
	
	**Variable name
	foreach outcome of local tab`tableno'outcomes {
			
		di "`outcome'_l"
		
		local variable: var label `outcome'_l
		local variable "`variable'"
		
		*file write output_file " & `variable'"
		
		qui reg `outcome'_l T_0 $districtFE cohort2014 sex_app, robust
		scalar n_`outcome' = e(N)
		scalar beta_`outcome' = e(b)[1,1]
		
		scalar sd_`outcome' = sqrt(e(V)[1,1])
		scalar beta_`outcome'pval = r(table)[4,1]
		
		if beta_`outcome'pval < 0.10 local stars_`outcome'  "*"
		if beta_`outcome'pval < 0.05 local stars_`outcome'  "**"
		if beta_`outcome'pval < 0.01 local stars_`outcome'  "***"
	
		qui sum `outcome'_l if T_0 == 0 
		scalar mean_`outcome' = r(mean)
		
		// Randomization Inference
			ritest T_0 _b[T_0], reps(1000) seed(20200501): reg `outcome'_l T_0 $districtFE cohort2014 sex_app, robust
			matrix pvalues=r(p) // save the p-values from ritest
			scalar ri_p_`outcome' = r(p)[1,1]		
			
		
		//Lee Bounds
			
			// Upper Lee Bounds
			qui reg `outcome'_ut T_0 i.NSC_intdcode cohort2014 sex_app, robust 
			
			scalar betaU_`outcome' = e(b)[1,1]
			scalar sd_betaU_`outcome' = sqrt(e(V)[1,1])
			scalar Upvalue_`outcome' = r(table)[4,1]
			
			// Lower Lee Bound Column
			qui reg `outcome'_lt T_0 i.NSC_intdcode cohort2014 sex_app, robust
			
			scalar betaL_`outcome' = e(b)[1,1]
			scalar sd_betaL_`outcome' = sqrt(e(V)[1,1])
			scalar Lpvalue_`outcome' = r(table)[4,1]
			
			foreach coltype in U L {
						
			if `coltype'pvalue_`outcome'  < 0.10 local stars`coltype'_`outcome'   "*"
			
			if `coltype'pvalue_`outcome'  < 0.05 local stars`coltype'_`outcome'   "**"
			
			if `coltype'pvalue_`outcome'  < 0.01 local stars`coltype'_`outcome'   "***"
			
			}
		
		// Fairlie Bound
		foreach boundtype in U5 L5 U10 L10 U20 L20 {			
				
		qui reg `outcome'_l_`boundtype' T_0 $districtFE cohort2014 sex_app, robust
		scalar obs = e(N)

		scalar beta_`outcome'`boundtype' = e(b)[1,1]
		scalar sd_`outcome'`boundtype' = sqrt(e(V)[1,1])
		scalar pv_`outcome'`boundtype' = r(table)[4,1]
		
		

		// Add Significance Stars
		
		local stars`boundtype' ""
						
			if pv_`outcome'`boundtype' < 0.10 local str_`outcome'`boundtype'  "*"
			
			if pv_`outcome'`boundtype' < 0.05 local str_`outcome'`boundtype'  "**"
			
			if pv_`outcome'`boundtype' < 0.01 local str_`outcome'`boundtype'  "***"
		}
		
	}
	file write output_file " \\ " _n
	
	**Column Number
	forvalues i = 1(1)`N' {
		
		file write output_file " & (`i')"
	}


	file write output_file " \\ " _n
	file write output_file " \hline \\ " 


	**Treatment Row
	file write output_file "T"
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file "& " %5.3f (beta_`outcome') " "
	}
	file write output_file "\\ " 	_n
	
	
	**Std Dev and p value 
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & \scriptsize{$("%5.3f (sd_`outcome') ")$} " 
		
		}
	file write output_file " \\ " 	_n	
	
		** Radomization Inference 
	
/*
	file write output_file "RI"
*/
	
	foreach outcome of local tab`tableno'outcomes {
		
		file write output_file " & \scriptsize{$[" %5.3f (ri_p_`outcome') "]$} "
	}
	file write output_file " \medskip \\  " 	_n
	
	
	*Lee Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Lee Bounds - Point Estimates}} \\" 
	
		foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (betaU_`outcome' ) "," %8.2fc (betaL_`outcome' ) "] } "
		
		}
	
	file write output_file " \medskip \\  " 	_n
	
	*Fairlie Bounds
	file write output_file "  \multicolumn{`N'}{l}{\textbf{Fairlie Bounds - Point Estimates}} " 
	file write output_file " \\ " _n 
	*5% Imputations
	file write output_file "5\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U5) /* "\$^{`str_`outcome'U5'}\$" */ "," %8.2fc (beta_`outcome'L5) /* "\$^{`str_`outcome'L5'}\$" */ "] } "
		
		}
	file write output_file " \\ " _n
	
	*10% Imputations
	file write output_file "10\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U10) /* "\$^{`str_`outcome'U10'}\$" */ "," %8.2fc (beta_`outcome'L10) /* "\$^{`str_`outcome'L10'}\$" */ "] } "
		
		}
	file write output_file " \\ " _n
	
	*20% Imputations
	file write output_file "20\% Imputation"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & {\footnotesize [" %8.2fc (beta_`outcome'U20) /* "\$^{`str_`outcome'U20'}\$" */ "," %8.2fc (beta_`outcome'L20) /* "\$^{`str_`outcome'L20'}\$" */ "] } "
		
		}
	file write output_file " \medskip \\ " 	_n	
	
	*Multiple Hypothesis Testing
	file write output_file "  MHT p-Value" 
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & \scriptsize{$("%5.3f (mht_p_`outcome') ")$} " 
		
		}
	

	file write output_file " \medskip \\ " 	_n	
	
	file write output_file " \hline \\ " 	_n
	
	*Mean outcome
	file write output_file "Mean Outcome (C)"
	
	foreach outcome of local tab`tableno'outcomes {

		file write output_file " & " %5.2f (mean_`outcome') " "
		
		}
	file write output_file " \\ " _n
	
	
	*Number of observation
	file write output_file "Observations"
	
	foreach outcome of local tab`tableno'outcomes {
			
		file write output_file " & " %5.0fc (n_`outcome') " "
		
		}
	file write output_file " \bigskip \\ " _n
	
	file write output_file " \hline \\ " 	
	
	file close output_file

		}	

	
