   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               Mastercard Foundation Scholarship Program Uganda       *
   *               Long-term Follow-up								      *
   *               MASTER DO_FILE                                         *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

   /*
   ** PURPOSE:      Long term follow up of the Mastercard Foundation Scholarship Program Uganda in 2022

   ** OUTLINE:      PART 0: Standardize settings and install packages
                    PART 1: Set globals for dynamic file paths
                    PART 2: Set globals for constants and varlist
                            used across the project. Install all user-contributed
                            commands needed.
                    PART 3: Call the task-specific master do-files 
                            that call all dofiles needed for that 
                            task. Do not include Part 0-2 in a task-
                            specific master do-file


   ** IDS VAR:      list_ID_var_here         //Uniquely identifies households

   ** NOTES:

   ** WRITTEN BY:   Bendetta Lerva, Raaga Akkineni

   ** Last date modified: 12 March 2025
       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
   *
   *           - Install packages needed to run all dofiles called
   *            by this master dofile.
   *           - Use ieboilstart to harmonize settings across users
   *
   * ******************************************************************** *
   
sysdir set PLUS "C:/Users/wb614536/Documents/GitHub/mcfsp/ado"
*iefolder*0*End_StandardSettings************************************************
*iefolder will not work properly if the line above is edited

   *Install all packages that this project requires:
   *(Note that this never updates outdated versions of already installed commands, to update commands use adoupdate)
 *  local user_commands listtab stddiff estout ietoolkit iefieldkit swindex cibar coefplot schemepack mhtexp mhtreg binscatter moremata ranktest grc1leg2 //Fill this list will all user-written commands this project requires
  * foreach command of local user_commands {
   *    cap which `command'
   *    if _rc == 111 {
   *        ssc install `command'
   *    }
   *}
   
  *    local user_commands ritest grc1leg grc1leg2 ivreg2 //Fill this list will all user-written commands this project requires
  * foreach command of local user_commands {
  *     cap which `command'
  *     if _rc == 111 {
  *         net install `command'
  *     }
  * }

/*
   net install grc1leg, from (http://www.stata.com/users/vwiggins)
*/
   
   *Standardize settings accross users
   ieboilstart, version(13)          //Set the version number to the oldest version used by anyone in the project team
   `r(version)'                      //This line is needed to actually set the version from the command above

*iefolder*1*FolderGlobals*******************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           - Set the global box to point to the project folder
   *            on each collaborator's computer.
   *           - Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *

   * Users
   * -----------

   *User Number:
   * Bendetta Lerva          1    
   * Raaga Akkineni          2  
   * Replicator				 3

   global user  4				// ACTION NEEDED: update to switch user

   * Root folder globals
   * ---------------------

   if $user == 1 {
       global projectfolder "C:\Users\wb575347\OneDrive - WBG\MCFSP_BLRA"	
	   
	   global github "C:\Users\wb575347\github\mcfsp"			
   }

   if $user == 2 {
       global projectfolder "C:\Users\sakkineni\OneDrive - WBG\DIME\MCFSP_BLRA" 
	   
	   global github "C:\Users\sakkineni\github\mcfsp"
   }
   
    if $user == 3 {
       global projectfolder "C:\Users\wb575347\OneDrive - WBG\RepPackage_BigPush_ToThe_FinishLine"
	   
	   global github "C:\Users\wb575347\github\mcfsp"
   }

   if $user == 4 {
   	
	*path to where data is saved (it can be the same if they are saved in the same location just)
	* make sure that the structure matches the folder_structure.txt included in the package
       global projectfolder "xxx" 
	   
	   * path to where the code is saved
	   global github "xxxxx" 
   }

* These lines are used to test that the name is not already used (do not edit manually)
*round**************************************************************************
*untObs*************************************************************************
*subFld*************************************************************************
*iefolder will not work properly if the lines above are edited


   * Project folder globals
   * ---------------------

   global dataWorkFolder         "$projectfolder/DataWork"

*iefolder*1*FolderGlobals*subfolder*********************************************
*iefolder will not work properly if the line above is edited


*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited

   global mastData               "$dataWorkFolder/MasterData" 
   global mastData_gt		     "$github/MasterData"

*iefolder*1*FolderGlobals*encrypted*********************************************
*iefolder will not work properly if the line above is edited

   global encryptFolder          "$dataWorkFolder/EncryptedData" 
   global encryptFolder_gt       "$github/EncryptedData" 

*iefolder*1*FolderGlobals*endRounds*********************************************
*iefolder will not work properly if the line above is edited

  *Encrypted Data - Caregiver
  global caregiver_enc          "$encryptFolder/Caregiver"
  global caregiver_enc_gt       "$encryptFolder_gt/Caregiver"
  
  *Encrypted Data - Applicant
  global applicant_enc          "$encryptFolder/Applicant" 
  global applicant_enc_gt       "$encryptFolder_gt/Applicant" 
  
  *Master Data - Administrative
  global administrative_mast          "$mastData/Administrative"
  global administrative_mast_gt       "$mastData_gt/Administrative"
  
  *Master Data - Caregiver
  global caregiver_mast          "$mastData/Caregiver"
  global caregiver_mast_gt       "$mastData_gt/Caregiver"
  
  *Master Data - Applicant
  global applicant_mast          "$mastData/Applicant"
  global applicant_mast_gt       "$mastData_gt/Applicant" 
  
  *Attrition Analysis
  global attrition_mast          "$mastData/Attrition"
  global attrition_mast_gt       "$mastData_gt/Attrition"
  
*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, different sets of control variables,
   * adofile paths etc.

   do "$github/global_setup.do" 


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited


*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DOFILE
   *
   *           - When survey rounds are added, this section will
   *            link to the master dofile for that round.
   *           - The default is that these dofiles are set to not
   *            run. It is rare that all round-specfic master dofiles
   *            are called at the same time; the round specific master
   *            dofiles are almost always called individually. The
   *            exception is when reviewing or replicating a full project.
   *
   * ******************************************************************** *
 
 
 *ACTION NEEDED: Set global values to "1" to run corresponding .do files 
 
 *CLEANING ENCRYPTED DATASET
 
   global caregiver_encrypted	0			// Cleans Ecrypted Caregiver dataset to saves clean dataset in Encrypted dataset folder and cleaned deidentified dataset in Master dataset folder
   global applicant_encrypted	0			// Cleans Ecrypted Applicant dataset to saves clean dataset in Encrypted dataset folder and cleaned deidentified dataset in Master dataset folder

   
 * ATTRITION ANALYSIS - CAREGIVER AND APPLICANT
 
   global attrition_analysis	1			// Produces attrition tables for caregiver and applicant LTFU surveys - need both caregiver and applicant clean data to run this file 
 
 *CONSTRUCTING OUTCOME VARIABLES, TABLES AND FIGURES														     
   
   global caregiver_master  	1			// Runs Caregiver Master .do file which constructs variables, builds tables and creates all figures
   global applicant_master  	1			// Runs Applicant Master .do file which constructs variables, builds tables and creates all figures
   global administrative		1			// Uses adminisrative data to make figures 


    if $caregiver_encrypted == 1 {
       
	   do "$caregiver_enc_gt/LTFU2022_Cohort_2014_2015_Cleaning_Caregiver.do" 	
   }
   
      if $applicant_encrypted == 1 {
       
	  do "$applicant_enc_gt/LTFU2022_Cohort_2014_2015_Cleaning_Applicant.do" 
   }
   
      if $attrition_analysis == 1 {
       
	  do "$attrition_mast_gt/LTFU2022_Cohort_2014_2015_AttritionTable.do" 
   }
    
   
   if $caregiver_master == 1 {
       
	   do "$caregiver_mast_gt/Caregiver_MasterDofile.do" 	
   }
   
   if $applicant_master == 1 {
       
	  do "$applicant_mast_gt/Applicant_MasterDofile.do" 
   }	
   
   if $administrative == 1 {
   	
	  do "$administrative_mast_gt/Administrative_MasterDofile.do" 	
   }

*iefolder*3*End_RunDofiles******************************************************
*iefolder will not work properly if the line above is edited

